// Copyright (c) Brock Allen & Dominick Baier. All rights reserved.
// Licensed under the Apache License, Version 2.0. See LICENSE in the project root for license information.


using System.Runtime.CompilerServices;

[assembly: InternalsVisibleTo("IdentityServer4.EntityFramework.UnitTests")]
[assembly: InternalsVisibleTo("IdentityServer4.EntityFramework.IntegrationTests")]
