.ion-ios-add:before {
  content: "\f102";
}

.ion-ios-add-circle:before {
  content: "\f101";
}

.ion-ios-add-circle-outline:before {
  content: "\f100";
}

.ion-ios-add-outline:before {
  content: "\f102";
}

.ion-ios-alarm:before {
  content: "\f3c8";
}

.ion-ios-alarm-outline:before {
  content: "\f3c7";
}

.ion-ios-albums:before {
  content: "\f3ca";
}

.ion-ios-albums-outline:before {
  content: "\f3c9";
}

.ion-ios-alert:before {
  content: "\f104";
}

.ion-ios-alert-outline:before {
  content: "\f103";
}

.ion-ios-american-football:before {
  content: "\f106";
}

.ion-ios-american-football-outline:before {
  content: "\f105";
}

.ion-ios-analytics:before {
  content: "\f3ce";
}

.ion-ios-analytics-outline:before {
  content: "\f3cd";
}

.ion-ios-aperture:before {
  content: "\f108";
}

.ion-ios-aperture-outline:before {
  content: "\f107";
}

.ion-ios-apps:before {
  content: "\f10a";
}

.ion-ios-apps-outline:before {
  content: "\f109";
}

.ion-ios-appstore:before {
  content: "\f10c";
}

.ion-ios-appstore-outline:before {
  content: "\f10b";
}

.ion-ios-archive:before {
  content: "\f10e";
}

.ion-ios-archive-outline:before {
  content: "\f10d";
}

.ion-ios-arrow-back:before {
  content: "\f3cf";
}

.ion-ios-arrow-back-outline:before {
  content: "\f3cf";
}

.ion-ios-arrow-down:before {
  content: "\f3d0";
}

.ion-ios-arrow-down-outline:before {
  content: "\f3d0";
}

.ion-ios-arrow-dropdown:before {
  content: "\f110";
}

.ion-ios-arrow-dropdown-circle:before {
  content: "\f10f";
}

.ion-ios-arrow-dropdown-circle-outline:before {
  content: "\f10f";
}

.ion-ios-arrow-dropdown-outline:before {
  content: "\f110";
}

.ion-ios-arrow-dropleft:before {
  content: "\f112";
}

.ion-ios-arrow-dropleft-circle:before {
  content: "\f111";
}

.ion-ios-arrow-dropleft-circle-outline:before {
  content: "\f111";
}

.ion-ios-arrow-dropleft-outline:before {
  content: "\f112";
}

.ion-ios-arrow-dropright:before {
  content: "\f114";
}

.ion-ios-arrow-dropright-circle:before {
  content: "\f113";
}

.ion-ios-arrow-dropright-circle-outline:before {
  content: "\f113";
}

.ion-ios-arrow-dropright-outline:before {
  content: "\f114";
}

.ion-ios-arrow-dropup:before {
  content: "\f116";
}

.ion-ios-arrow-dropup-circle:before {
  content: "\f115";
}

.ion-ios-arrow-dropup-circle-outline:before {
  content: "\f115";
}

.ion-ios-arrow-dropup-outline:before {
  content: "\f116";
}

.ion-ios-arrow-forward:before {
  content: "\f3d1";
}

.ion-ios-arrow-forward-outline:before {
  content: "\f3d1";
}

.ion-ios-arrow-round-back:before {
  content: "\f117";
}

.ion-ios-arrow-round-back-outline:before {
  content: "\f117";
}

.ion-ios-arrow-round-down:before {
  content: "\f118";
}

.ion-ios-arrow-round-down-outline:before {
  content: "\f118";
}

.ion-ios-arrow-round-forward:before {
  content: "\f119";
}

.ion-ios-arrow-round-forward-outline:before {
  content: "\f119";
}

.ion-ios-arrow-round-up:before {
  content: "\f11a";
}

.ion-ios-arrow-round-up-outline:before {
  content: "\f11a";
}

.ion-ios-arrow-up:before {
  content: "\f3d8";
}

.ion-ios-arrow-up-outline:before {
  content: "\f3d8";
}

.ion-ios-at:before {
  content: "\f3da";
}

.ion-ios-at-outline:before {
  content: "\f3d9";
}

.ion-ios-attach:before {
  content: "\f11b";
}

.ion-ios-attach-outline:before {
  content: "\f11b";
}

.ion-ios-backspace:before {
  content: "\f11d";
}

.ion-ios-backspace-outline:before {
  content: "\f11c";
}

.ion-ios-barcode:before {
  content: "\f3dc";
}

.ion-ios-barcode-outline:before {
  content: "\f3db";
}

.ion-ios-baseball:before {
  content: "\f3de";
}

.ion-ios-baseball-outline:before {
  content: "\f3dd";
}

.ion-ios-basket:before {
  content: "\f11f";
}

.ion-ios-basket-outline:before {
  content: "\f11e";
}

.ion-ios-basketball:before {
  content: "\f3e0";
}

.ion-ios-basketball-outline:before {
  content: "\f3df";
}

.ion-ios-battery-charging:before {
  content: "\f120";
}

.ion-ios-battery-charging-outline:before {
  content: "\f120";
}

.ion-ios-battery-dead:before {
  content: "\f121";
}

.ion-ios-battery-dead-outline:before {
  content: "\f121";
}

.ion-ios-battery-full:before {
  content: "\f122";
}

.ion-ios-battery-full-outline:before {
  content: "\f122";
}

.ion-ios-beaker:before {
  content: "\f124";
}

.ion-ios-beaker-outline:before {
  content: "\f123";
}

.ion-ios-beer:before {
  content: "\f126";
}

.ion-ios-beer-outline:before {
  content: "\f125";
}

.ion-ios-bicycle:before {
  content: "\f127";
}

.ion-ios-bicycle-outline:before {
  content: "\f127";
}

.ion-ios-bluetooth:before {
  content: "\f128";
}

.ion-ios-bluetooth-outline:before {
  content: "\f128";
}

.ion-ios-boat:before {
  content: "\f12a";
}

.ion-ios-boat-outline:before {
  content: "\f129";
}

.ion-ios-body:before {
  content: "\f3e4";
}

.ion-ios-body-outline:before {
  content: "\f3e3";
}

.ion-ios-bonfire:before {
  content: "\f12c";
}

.ion-ios-bonfire-outline:before {
  content: "\f12b";
}

.ion-ios-book:before {
  content: "\f3e8";
}

.ion-ios-book-outline:before {
  content: "\f3e7";
}

.ion-ios-bookmark:before {
  content: "\f12e";
}

.ion-ios-bookmark-outline:before {
  content: "\f12d";
}

.ion-ios-bookmarks:before {
  content: "\f3ea";
}

.ion-ios-bookmarks-outline:before {
  content: "\f3e9";
}

.ion-ios-bowtie:before {
  content: "\f130";
}

.ion-ios-bowtie-outline:before {
  content: "\f12f";
}

.ion-ios-briefcase:before {
  content: "\f3ee";
}

.ion-ios-briefcase-outline:before {
  content: "\f3ed";
}

.ion-ios-browsers:before {
  content: "\f3f0";
}

.ion-ios-browsers-outline:before {
  content: "\f3ef";
}

.ion-ios-brush:before {
  content: "\f132";
}

.ion-ios-brush-outline:before {
  content: "\f131";
}

.ion-ios-bug:before {
  content: "\f134";
}

.ion-ios-bug-outline:before {
  content: "\f133";
}

.ion-ios-build:before {
  content: "\f136";
}

.ion-ios-build-outline:before {
  content: "\f135";
}

.ion-ios-bulb:before {
  content: "\f138";
}

.ion-ios-bulb-outline:before {
  content: "\f137";
}

.ion-ios-bus:before {
  content: "\f13a";
}

.ion-ios-bus-outline:before {
  content: "\f139";
}

.ion-ios-cafe:before {
  content: "\f13c";
}

.ion-ios-cafe-outline:before {
  content: "\f13b";
}

.ion-ios-calculator:before {
  content: "\f3f2";
}

.ion-ios-calculator-outline:before {
  content: "\f3f1";
}

.ion-ios-calendar:before {
  content: "\f3f4";
}

.ion-ios-calendar-outline:before {
  content: "\f3f3";
}

.ion-ios-call:before {
  content: "\f13e";
}

.ion-ios-call-outline:before {
  content: "\f13d";
}

.ion-ios-camera:before {
  content: "\f3f6";
}

.ion-ios-camera-outline:before {
  content: "\f3f5";
}

.ion-ios-car:before {
  content: "\f140";
}

.ion-ios-car-outline:before {
  content: "\f13f";
}

.ion-ios-card:before {
  content: "\f142";
}

.ion-ios-card-outline:before {
  content: "\f141";
}

.ion-ios-cart:before {
  content: "\f3f8";
}

.ion-ios-cart-outline:before {
  content: "\f3f7";
}

.ion-ios-cash:before {
  content: "\f144";
}

.ion-ios-cash-outline:before {
  content: "\f143";
}

.ion-ios-chatboxes:before {
  content: "\f3fa";
}

.ion-ios-chatboxes-outline:before {
  content: "\f3f9";
}

.ion-ios-chatbubbles:before {
  content: "\f146";
}

.ion-ios-chatbubbles-outline:before {
  content: "\f145";
}

.ion-ios-checkbox:before {
  content: "\f148";
}

.ion-ios-checkbox-outline:before {
  content: "\f147";
}

.ion-ios-checkmark:before {
  content: "\f3ff";
}

.ion-ios-checkmark-circle:before {
  content: "\f14a";
}

.ion-ios-checkmark-circle-outline:before {
  content: "\f149";
}

.ion-ios-checkmark-outline:before {
  content: "\f3ff";
}

.ion-ios-clipboard:before {
  content: "\f14c";
}

.ion-ios-clipboard-outline:before {
  content: "\f14b";
}

.ion-ios-clock:before {
  content: "\f403";
}

.ion-ios-clock-outline:before {
  content: "\f402";
}

.ion-ios-close:before {
  content: "\f406";
}

.ion-ios-close-circle:before {
  content: "\f14e";
}

.ion-ios-close-circle-outline:before {
  content: "\f14d";
}

.ion-ios-close-outline:before {
  content: "\f406";
}

.ion-ios-closed-captioning:before {
  content: "\f150";
}

.ion-ios-closed-captioning-outline:before {
  content: "\f14f";
}

.ion-ios-cloud:before {
  content: "\f40c";
}

.ion-ios-cloud-circle:before {
  content: "\f152";
}

.ion-ios-cloud-circle-outline:before {
  content: "\f151";
}

.ion-ios-cloud-done:before {
  content: "\f154";
}

.ion-ios-cloud-done-outline:before {
  content: "\f153";
}

.ion-ios-cloud-download:before {
  content: "\f408";
}

.ion-ios-cloud-download-outline:before {
  content: "\f407";
}

.ion-ios-cloud-outline:before {
  content: "\f409";
}

.ion-ios-cloud-upload:before {
  content: "\f40b";
}

.ion-ios-cloud-upload-outline:before {
  content: "\f40a";
}

.ion-ios-cloudy:before {
  content: "\f410";
}

.ion-ios-cloudy-night:before {
  content: "\f40e";
}

.ion-ios-cloudy-night-outline:before {
  content: "\f40d";
}

.ion-ios-cloudy-outline:before {
  content: "\f40f";
}

.ion-ios-code:before {
  content: "\f157";
}

.ion-ios-code-download:before {
  content: "\f155";
}

.ion-ios-code-download-outline:before {
  content: "\f155";
}

.ion-ios-code-outline:before {
  content: "\f157";
}

.ion-ios-code-working:before {
  content: "\f156";
}

.ion-ios-code-working-outline:before {
  content: "\f156";
}

.ion-ios-cog:before {
  content: "\f412";
}

.ion-ios-cog-outline:before {
  content: "\f411";
}

.ion-ios-color-fill:before {
  content: "\f159";
}

.ion-ios-color-fill-outline:before {
  content: "\f158";
}

.ion-ios-color-filter:before {
  content: "\f414";
}

.ion-ios-color-filter-outline:before {
  content: "\f413";
}

.ion-ios-color-palette:before {
  content: "\f15b";
}

.ion-ios-color-palette-outline:before {
  content: "\f15a";
}

.ion-ios-color-wand:before {
  content: "\f416";
}

.ion-ios-color-wand-outline:before {
  content: "\f415";
}

.ion-ios-compass:before {
  content: "\f15d";
}

.ion-ios-compass-outline:before {
  content: "\f15c";
}

.ion-ios-construct:before {
  content: "\f15f";
}

.ion-ios-construct-outline:before {
  content: "\f15e";
}

.ion-ios-contact:before {
  content: "\f41a";
}

.ion-ios-contact-outline:before {
  content: "\f419";
}

.ion-ios-contacts:before {
  content: "\f161";
}

.ion-ios-contacts-outline:before {
  content: "\f160";
}

.ion-ios-contract:before {
  content: "\f162";
}

.ion-ios-contract-outline:before {
  content: "\f162";
}

.ion-ios-contrast:before {
  content: "\f163";
}

.ion-ios-contrast-outline:before {
  content: "\f163";
}

.ion-ios-copy:before {
  content: "\f41c";
}

.ion-ios-copy-outline:before {
  content: "\f41b";
}

.ion-ios-create:before {
  content: "\f165";
}

.ion-ios-create-outline:before {
  content: "\f164";
}

.ion-ios-crop:before {
  content: "\f41e";
}

.ion-ios-crop-outline:before {
  content: "\f166";
}

.ion-ios-cube:before {
  content: "\f168";
}

.ion-ios-cube-outline:before {
  content: "\f167";
}

.ion-ios-cut:before {
  content: "\f16a";
}

.ion-ios-cut-outline:before {
  content: "\f169";
}

.ion-ios-desktop:before {
  content: "\f16c";
}

.ion-ios-desktop-outline:before {
  content: "\f16b";
}

.ion-ios-disc:before {
  content: "\f16e";
}

.ion-ios-disc-outline:before {
  content: "\f16d";
}

.ion-ios-document:before {
  content: "\f170";
}

.ion-ios-document-outline:before {
  content: "\f16f";
}

.ion-ios-done-all:before {
  content: "\f171";
}

.ion-ios-done-all-outline:before {
  content: "\f171";
}

.ion-ios-download:before {
  content: "\f420";
}

.ion-ios-download-outline:before {
  content: "\f41f";
}

.ion-ios-easel:before {
  content: "\f173";
}

.ion-ios-easel-outline:before {
  content: "\f172";
}

.ion-ios-egg:before {
  content: "\f175";
}

.ion-ios-egg-outline:before {
  content: "\f174";
}

.ion-ios-exit:before {
  content: "\f177";
}

.ion-ios-exit-outline:before {
  content: "\f176";
}

.ion-ios-expand:before {
  content: "\f178";
}

.ion-ios-expand-outline:before {
  content: "\f178";
}

.ion-ios-eye:before {
  content: "\f425";
}

.ion-ios-eye-off:before {
  content: "\f17a";
}

.ion-ios-eye-off-outline:before {
  content: "\f179";
}

.ion-ios-eye-outline:before {
  content: "\f424";
}

.ion-ios-fastforward:before {
  content: "\f427";
}

.ion-ios-fastforward-outline:before {
  content: "\f426";
}

.ion-ios-female:before {
  content: "\f17b";
}

.ion-ios-female-outline:before {
  content: "\f17b";
}

.ion-ios-filing:before {
  content: "\f429";
}

.ion-ios-filing-outline:before {
  content: "\f428";
}

.ion-ios-film:before {
  content: "\f42b";
}

.ion-ios-film-outline:before {
  content: "\f42a";
}

.ion-ios-finger-print:before {
  content: "\f17c";
}

.ion-ios-finger-print-outline:before {
  content: "\f17c";
}

.ion-ios-flag:before {
  content: "\f42d";
}

.ion-ios-flag-outline:before {
  content: "\f42c";
}

.ion-ios-flame:before {
  content: "\f42f";
}

.ion-ios-flame-outline:before {
  content: "\f42e";
}

.ion-ios-flash:before {
  content: "\f17e";
}

.ion-ios-flash-outline:before {
  content: "\f17d";
}

.ion-ios-flask:before {
  content: "\f431";
}

.ion-ios-flask-outline:before {
  content: "\f430";
}

.ion-ios-flower:before {
  content: "\f433";
}

.ion-ios-flower-outline:before {
  content: "\f432";
}

.ion-ios-folder:before {
  content: "\f435";
}

.ion-ios-folder-open:before {
  content: "\f180";
}

.ion-ios-folder-open-outline:before {
  content: "\f17f";
}

.ion-ios-folder-outline:before {
  content: "\f434";
}

.ion-ios-football:before {
  content: "\f437";
}

.ion-ios-football-outline:before {
  content: "\f436";
}

.ion-ios-funnel:before {
  content: "\f182";
}

.ion-ios-funnel-outline:before {
  content: "\f181";
}

.ion-ios-game-controller-a:before {
  content: "\f439";
}

.ion-ios-game-controller-a-outline:before {
  content: "\f438";
}

.ion-ios-game-controller-b:before {
  content: "\f43b";
}

.ion-ios-game-controller-b-outline:before {
  content: "\f43a";
}

.ion-ios-git-branch:before {
  content: "\f183";
}

.ion-ios-git-branch-outline:before {
  content: "\f183";
}

.ion-ios-git-commit:before {
  content: "\f184";
}

.ion-ios-git-commit-outline:before {
  content: "\f184";
}

.ion-ios-git-compare:before {
  content: "\f185";
}

.ion-ios-git-compare-outline:before {
  content: "\f185";
}

.ion-ios-git-merge:before {
  content: "\f186";
}

.ion-ios-git-merge-outline:before {
  content: "\f186";
}

.ion-ios-git-network:before {
  content: "\f187";
}

.ion-ios-git-network-outline:before {
  content: "\f187";
}

.ion-ios-git-pull-request:before {
  content: "\f188";
}

.ion-ios-git-pull-request-outline:before {
  content: "\f188";
}

.ion-ios-glasses:before {
  content: "\f43f";
}

.ion-ios-glasses-outline:before {
  content: "\f43e";
}

.ion-ios-globe:before {
  content: "\f18a";
}

.ion-ios-globe-outline:before {
  content: "\f189";
}

.ion-ios-grid:before {
  content: "\f18c";
}

.ion-ios-grid-outline:before {
  content: "\f18b";
}

.ion-ios-hammer:before {
  content: "\f18e";
}

.ion-ios-hammer-outline:before {
  content: "\f18d";
}

.ion-ios-hand:before {
  content: "\f190";
}

.ion-ios-hand-outline:before {
  content: "\f18f";
}

.ion-ios-happy:before {
  content: "\f192";
}

.ion-ios-happy-outline:before {
  content: "\f191";
}

.ion-ios-headset:before {
  content: "\f194";
}

.ion-ios-headset-outline:before {
  content: "\f193";
}

.ion-ios-heart:before {
  content: "\f443";
}

.ion-ios-heart-outline:before {
  content: "\f442";
}

.ion-ios-help:before {
  content: "\f446";
}

.ion-ios-help-buoy:before {
  content: "\f196";
}

.ion-ios-help-buoy-outline:before {
  content: "\f195";
}

.ion-ios-help-circle:before {
  content: "\f198";
}

.ion-ios-help-circle-outline:before {
  content: "\f197";
}

.ion-ios-help-outline:before {
  content: "\f446";
}

.ion-ios-home:before {
  content: "\f448";
}

.ion-ios-home-outline:before {
  content: "\f447";
}

.ion-ios-ice-cream:before {
  content: "\f19a";
}

.ion-ios-ice-cream-outline:before {
  content: "\f199";
}

.ion-ios-image:before {
  content: "\f19c";
}

.ion-ios-image-outline:before {
  content: "\f19b";
}

.ion-ios-images:before {
  content: "\f19e";
}

.ion-ios-images-outline:before {
  content: "\f19d";
}

.ion-ios-infinite:before {
  content: "\f44a";
}

.ion-ios-infinite-outline:before {
  content: "\f449";
}

.ion-ios-information:before {
  content: "\f44d";
}

.ion-ios-information-circle:before {
  content: "\f1a0";
}

.ion-ios-information-circle-outline:before {
  content: "\f19f";
}

.ion-ios-information-outline:before {
  content: "\f44d";
}

.ion-ios-ionic:before {
  content: "\f1a1";
}

.ion-ios-ionic-outline:before {
  content: "\f44e";
}

.ion-ios-ionitron:before {
  content: "\f1a3";
}

.ion-ios-ionitron-outline:before {
  content: "\f1a2";
}

.ion-ios-jet:before {
  content: "\f1a5";
}

.ion-ios-jet-outline:before {
  content: "\f1a4";
}

.ion-ios-key:before {
  content: "\f1a7";
}

.ion-ios-key-outline:before {
  content: "\f1a6";
}

.ion-ios-keypad:before {
  content: "\f450";
}

.ion-ios-keypad-outline:before {
  content: "\f44f";
}

.ion-ios-laptop:before {
  content: "\f1a8";
}

.ion-ios-laptop-outline:before {
  content: "\f1a8";
}

.ion-ios-leaf:before {
  content: "\f1aa";
}

.ion-ios-leaf-outline:before {
  content: "\f1a9";
}

.ion-ios-link:before {
  content: "\f22a";
}

.ion-ios-link-outline:before {
  content: "\f1ca";
}

.ion-ios-list:before {
  content: "\f454";
}

.ion-ios-list-box:before {
  content: "\f1ac";
}

.ion-ios-list-box-outline:before {
  content: "\f1ab";
}

.ion-ios-list-outline:before {
  content: "\f454";
}

.ion-ios-locate:before {
  content: "\f1ae";
}

.ion-ios-locate-outline:before {
  content: "\f1ad";
}

.ion-ios-lock:before {
  content: "\f1b0";
}

.ion-ios-lock-outline:before {
  content: "\f1af";
}

.ion-ios-log-in:before {
  content: "\f1b1";
}

.ion-ios-log-in-outline:before {
  content: "\f1b1";
}

.ion-ios-log-out:before {
  content: "\f1b2";
}

.ion-ios-log-out-outline:before {
  content: "\f1b2";
}

.ion-ios-magnet:before {
  content: "\f1b4";
}

.ion-ios-magnet-outline:before {
  content: "\f1b3";
}

.ion-ios-mail:before {
  content: "\f1b8";
}

.ion-ios-mail-open:before {
  content: "\f1b6";
}

.ion-ios-mail-open-outline:before {
  content: "\f1b5";
}

.ion-ios-mail-outline:before {
  content: "\f1b7";
}

.ion-ios-male:before {
  content: "\f1b9";
}

.ion-ios-male-outline:before {
  content: "\f1b9";
}

.ion-ios-man:before {
  content: "\f1bb";
}

.ion-ios-man-outline:before {
  content: "\f1ba";
}

.ion-ios-map:before {
  content: "\f1bd";
}

.ion-ios-map-outline:before {
  content: "\f1bc";
}

.ion-ios-medal:before {
  content: "\f1bf";
}

.ion-ios-medal-outline:before {
  content: "\f1be";
}

.ion-ios-medical:before {
  content: "\f45c";
}

.ion-ios-medical-outline:before {
  content: "\f45b";
}

.ion-ios-medkit:before {
  content: "\f45e";
}

.ion-ios-medkit-outline:before {
  content: "\f45d";
}

.ion-ios-megaphone:before {
  content: "\f1c1";
}

.ion-ios-megaphone-outline:before {
  content: "\f1c0";
}

.ion-ios-menu:before {
  content: "\f1c3";
}

.ion-ios-menu-outline:before {
  content: "\f1c2";
}

.ion-ios-mic:before {
  content: "\f461";
}

.ion-ios-mic-off:before {
  content: "\f45f";
}

.ion-ios-mic-off-outline:before {
  content: "\f1c4";
}

.ion-ios-mic-outline:before {
  content: "\f460";
}

.ion-ios-microphone:before {
  content: "\f1c6";
}

.ion-ios-microphone-outline:before {
  content: "\f1c5";
}

.ion-ios-moon:before {
  content: "\f468";
}

.ion-ios-moon-outline:before {
  content: "\f467";
}

.ion-ios-more:before {
  content: "\f1c8";
}

.ion-ios-more-outline:before {
  content: "\f1c7";
}

.ion-ios-move:before {
  content: "\f1cb";
}

.ion-ios-move-outline:before {
  content: "\f1cb";
}

.ion-ios-musical-note:before {
  content: "\f46b";
}

.ion-ios-musical-note-outline:before {
  content: "\f1cc";
}

.ion-ios-musical-notes:before {
  content: "\f46c";
}

.ion-ios-musical-notes-outline:before {
  content: "\f1cd";
}

.ion-ios-navigate:before {
  content: "\f46e";
}

.ion-ios-navigate-outline:before {
  content: "\f46d";
}

.ion-ios-no-smoking:before {
  content: "\f1cf";
}

.ion-ios-no-smoking-outline:before {
  content: "\f1ce";
}

.ion-ios-notifications:before {
  content: "\f1d3";
}

.ion-ios-notifications-off:before {
  content: "\f1d1";
}

.ion-ios-notifications-off-outline:before {
  content: "\f1d0";
}

.ion-ios-notifications-outline:before {
  content: "\f1d2";
}

.ion-ios-nuclear:before {
  content: "\f1d5";
}

.ion-ios-nuclear-outline:before {
  content: "\f1d4";
}

.ion-ios-nutrition:before {
  content: "\f470";
}

.ion-ios-nutrition-outline:before {
  content: "\f46f";
}

.ion-ios-open:before {
  content: "\f1d7";
}

.ion-ios-open-outline:before {
  content: "\f1d6";
}

.ion-ios-options:before {
  content: "\f1d9";
}

.ion-ios-options-outline:before {
  content: "\f1d8";
}

.ion-ios-outlet:before {
  content: "\f1db";
}

.ion-ios-outlet-outline:before {
  content: "\f1da";
}

.ion-ios-paper:before {
  content: "\f472";
}

.ion-ios-paper-outline:before {
  content: "\f471";
}

.ion-ios-paper-plane:before {
  content: "\f1dd";
}

.ion-ios-paper-plane-outline:before {
  content: "\f1dc";
}

.ion-ios-partly-sunny:before {
  content: "\f1df";
}

.ion-ios-partly-sunny-outline:before {
  content: "\f1de";
}

.ion-ios-pause:before {
  content: "\f478";
}

.ion-ios-pause-outline:before {
  content: "\f477";
}

.ion-ios-paw:before {
  content: "\f47a";
}

.ion-ios-paw-outline:before {
  content: "\f479";
}

.ion-ios-people:before {
  content: "\f47c";
}

.ion-ios-people-outline:before {
  content: "\f47b";
}

.ion-ios-person:before {
  content: "\f47e";
}

.ion-ios-person-add:before {
  content: "\f1e1";
}

.ion-ios-person-add-outline:before {
  content: "\f1e0";
}

.ion-ios-person-outline:before {
  content: "\f47d";
}

.ion-ios-phone-landscape:before {
  content: "\f1e2";
}

.ion-ios-phone-landscape-outline:before {
  content: "\f1e2";
}

.ion-ios-phone-portrait:before {
  content: "\f1e3";
}

.ion-ios-phone-portrait-outline:before {
  content: "\f1e3";
}

.ion-ios-photos:before {
  content: "\f482";
}

.ion-ios-photos-outline:before {
  content: "\f481";
}

.ion-ios-pie:before {
  content: "\f484";
}

.ion-ios-pie-outline:before {
  content: "\f483";
}

.ion-ios-pin:before {
  content: "\f1e5";
}

.ion-ios-pin-outline:before {
  content: "\f1e4";
}

.ion-ios-pint:before {
  content: "\f486";
}

.ion-ios-pint-outline:before {
  content: "\f485";
}

.ion-ios-pizza:before {
  content: "\f1e7";
}

.ion-ios-pizza-outline:before {
  content: "\f1e6";
}

.ion-ios-plane:before {
  content: "\f1e9";
}

.ion-ios-plane-outline:before {
  content: "\f1e8";
}

.ion-ios-planet:before {
  content: "\f1eb";
}

.ion-ios-planet-outline:before {
  content: "\f1ea";
}

.ion-ios-play:before {
  content: "\f488";
}

.ion-ios-play-outline:before {
  content: "\f487";
}

.ion-ios-podium:before {
  content: "\f1ed";
}

.ion-ios-podium-outline:before {
  content: "\f1ec";
}

.ion-ios-power:before {
  content: "\f1ef";
}

.ion-ios-power-outline:before {
  content: "\f1ee";
}

.ion-ios-pricetag:before {
  content: "\f48d";
}

.ion-ios-pricetag-outline:before {
  content: "\f48c";
}

.ion-ios-pricetags:before {
  content: "\f48f";
}

.ion-ios-pricetags-outline:before {
  content: "\f48e";
}

.ion-ios-print:before {
  content: "\f1f1";
}

.ion-ios-print-outline:before {
  content: "\f1f0";
}

.ion-ios-pulse:before {
  content: "\f493";
}

.ion-ios-pulse-outline:before {
  content: "\f1f2";
}

.ion-ios-qr-scanner:before {
  content: "\f1f3";
}

.ion-ios-qr-scanner-outline:before {
  content: "\f1f3";
}

.ion-ios-quote:before {
  content: "\f1f5";
}

.ion-ios-quote-outline:before {
  content: "\f1f4";
}

.ion-ios-radio:before {
  content: "\f1f9";
}

.ion-ios-radio-button-off:before {
  content: "\f1f6";
}

.ion-ios-radio-button-off-outline:before {
  content: "\f1f6";
}

.ion-ios-radio-button-on:before {
  content: "\f1f7";
}

.ion-ios-radio-button-on-outline:before {
  content: "\f1f7";
}

.ion-ios-radio-outline:before {
  content: "\f1f8";
}

.ion-ios-rainy:before {
  content: "\f495";
}

.ion-ios-rainy-outline:before {
  content: "\f494";
}

.ion-ios-recording:before {
  content: "\f497";
}

.ion-ios-recording-outline:before {
  content: "\f496";
}

.ion-ios-redo:before {
  content: "\f499";
}

.ion-ios-redo-outline:before {
  content: "\f498";
}

.ion-ios-refresh:before {
  content: "\f49c";
}

.ion-ios-refresh-circle:before {
  content: "\f226";
}

.ion-ios-refresh-circle-outline:before {
  content: "\f224";
}

.ion-ios-refresh-outline:before {
  content: "\f49c";
}

.ion-ios-remove:before {
  content: "\f1fc";
}

.ion-ios-remove-circle:before {
  content: "\f1fb";
}

.ion-ios-remove-circle-outline:before {
  content: "\f1fa";
}

.ion-ios-remove-outline:before {
  content: "\f1fc";
}

.ion-ios-reorder:before {
  content: "\f1fd";
}

.ion-ios-reorder-outline:before {
  content: "\f1fd";
}

.ion-ios-repeat:before {
  content: "\f1fe";
}

.ion-ios-repeat-outline:before {
  content: "\f1fe";
}

.ion-ios-resize:before {
  content: "\f1ff";
}

.ion-ios-resize-outline:before {
  content: "\f1ff";
}

.ion-ios-restaurant:before {
  content: "\f201";
}

.ion-ios-restaurant-outline:before {
  content: "\f200";
}

.ion-ios-return-left:before {
  content: "\f202";
}

.ion-ios-return-left-outline:before {
  content: "\f202";
}

.ion-ios-return-right:before {
  content: "\f203";
}

.ion-ios-return-right-outline:before {
  content: "\f203";
}

.ion-ios-reverse-camera:before {
  content: "\f49f";
}

.ion-ios-reverse-camera-outline:before {
  content: "\f49e";
}

.ion-ios-rewind:before {
  content: "\f4a1";
}

.ion-ios-rewind-outline:before {
  content: "\f4a0";
}

.ion-ios-ribbon:before {
  content: "\f205";
}

.ion-ios-ribbon-outline:before {
  content: "\f204";
}

.ion-ios-rose:before {
  content: "\f4a3";
}

.ion-ios-rose-outline:before {
  content: "\f4a2";
}

.ion-ios-sad:before {
  content: "\f207";
}

.ion-ios-sad-outline:before {
  content: "\f206";
}

.ion-ios-school:before {
  content: "\f209";
}

.ion-ios-school-outline:before {
  content: "\f208";
}

.ion-ios-search:before {
  content: "\f4a5";
}

.ion-ios-search-outline:before {
  content: "\f20a";
}

.ion-ios-send:before {
  content: "\f20c";
}

.ion-ios-send-outline:before {
  content: "\f20b";
}

.ion-ios-settings:before {
  content: "\f4a7";
}

.ion-ios-settings-outline:before {
  content: "\f20d";
}

.ion-ios-share:before {
  content: "\f211";
}

.ion-ios-share-alt:before {
  content: "\f20f";
}

.ion-ios-share-alt-outline:before {
  content: "\f20e";
}

.ion-ios-share-outline:before {
  content: "\f210";
}

.ion-ios-shirt:before {
  content: "\f213";
}

.ion-ios-shirt-outline:before {
  content: "\f212";
}

.ion-ios-shuffle:before {
  content: "\f4a9";
}

.ion-ios-shuffle-outline:before {
  content: "\f4a9";
}

.ion-ios-skip-backward:before {
  content: "\f215";
}

.ion-ios-skip-backward-outline:before {
  content: "\f214";
}

.ion-ios-skip-forward:before {
  content: "\f217";
}

.ion-ios-skip-forward-outline:before {
  content: "\f216";
}

.ion-ios-snow:before {
  content: "\f218";
}

.ion-ios-snow-outline:before {
  content: "\f22c";
}

.ion-ios-speedometer:before {
  content: "\f4b0";
}

.ion-ios-speedometer-outline:before {
  content: "\f4af";
}

.ion-ios-square:before {
  content: "\f21a";
}

.ion-ios-square-outline:before {
  content: "\f219";
}

.ion-ios-star:before {
  content: "\f4b3";
}

.ion-ios-star-half:before {
  content: "\f4b1";
}

.ion-ios-star-half-outline:before {
  content: "\f4b1";
}

.ion-ios-star-outline:before {
  content: "\f4b2";
}

.ion-ios-stats:before {
  content: "\f21c";
}

.ion-ios-stats-outline:before {
  content: "\f21b";
}

.ion-ios-stopwatch:before {
  content: "\f4b5";
}

.ion-ios-stopwatch-outline:before {
  content: "\f4b4";
}

.ion-ios-subway:before {
  content: "\f21e";
}

.ion-ios-subway-outline:before {
  content: "\f21d";
}

.ion-ios-sunny:before {
  content: "\f4b7";
}

.ion-ios-sunny-outline:before {
  content: "\f4b6";
}

.ion-ios-swap:before {
  content: "\f21f";
}

.ion-ios-swap-outline:before {
  content: "\f21f";
}

.ion-ios-switch:before {
  content: "\f221";
}

.ion-ios-switch-outline:before {
  content: "\f220";
}

.ion-ios-sync:before {
  content: "\f222";
}

.ion-ios-sync-outline:before {
  content: "\f222";
}

.ion-ios-tablet-landscape:before {
  content: "\f223";
}

.ion-ios-tablet-landscape-outline:before {
  content: "\f223";
}

.ion-ios-tablet-portrait:before {
  content: "\f24e";
}

.ion-ios-tablet-portrait-outline:before {
  content: "\f24e";
}

.ion-ios-tennisball:before {
  content: "\f4bb";
}

.ion-ios-tennisball-outline:before {
  content: "\f4ba";
}

.ion-ios-text:before {
  content: "\f250";
}

.ion-ios-text-outline:before {
  content: "\f24f";
}

.ion-ios-thermometer:before {
  content: "\f252";
}

.ion-ios-thermometer-outline:before {
  content: "\f251";
}

.ion-ios-thumbs-down:before {
  content: "\f254";
}

.ion-ios-thumbs-down-outline:before {
  content: "\f253";
}

.ion-ios-thumbs-up:before {
  content: "\f256";
}

.ion-ios-thumbs-up-outline:before {
  content: "\f255";
}

.ion-ios-thunderstorm:before {
  content: "\f4bd";
}

.ion-ios-thunderstorm-outline:before {
  content: "\f4bc";
}

.ion-ios-time:before {
  content: "\f4bf";
}

.ion-ios-time-outline:before {
  content: "\f4be";
}

.ion-ios-timer:before {
  content: "\f4c1";
}

.ion-ios-timer-outline:before {
  content: "\f4c0";
}

.ion-ios-train:before {
  content: "\f258";
}

.ion-ios-train-outline:before {
  content: "\f257";
}

.ion-ios-transgender:before {
  content: "\f259";
}

.ion-ios-transgender-outline:before {
  content: "\f259";
}

.ion-ios-trash:before {
  content: "\f4c5";
}

.ion-ios-trash-outline:before {
  content: "\f4c4";
}

.ion-ios-trending-down:before {
  content: "\f25a";
}

.ion-ios-trending-down-outline:before {
  content: "\f25a";
}

.ion-ios-trending-up:before {
  content: "\f25b";
}

.ion-ios-trending-up-outline:before {
  content: "\f25b";
}

.ion-ios-trophy:before {
  content: "\f25d";
}

.ion-ios-trophy-outline:before {
  content: "\f25c";
}

.ion-ios-umbrella:before {
  content: "\f25f";
}

.ion-ios-umbrella-outline:before {
  content: "\f25e";
}

.ion-ios-undo:before {
  content: "\f4c7";
}

.ion-ios-undo-outline:before {
  content: "\f4c6";
}

.ion-ios-unlock:before {
  content: "\f261";
}

.ion-ios-unlock-outline:before {
  content: "\f260";
}

.ion-ios-videocam:before {
  content: "\f4cd";
}

.ion-ios-videocam-outline:before {
  content: "\f4cc";
}

.ion-ios-volume-down:before {
  content: "\f262";
}

.ion-ios-volume-down-outline:before {
  content: "\f262";
}

.ion-ios-volume-mute:before {
  content: "\f263";
}

.ion-ios-volume-mute-outline:before {
  content: "\f263";
}

.ion-ios-volume-off:before {
  content: "\f264";
}

.ion-ios-volume-off-outline:before {
  content: "\f264";
}

.ion-ios-volume-up:before {
  content: "\f265";
}

.ion-ios-volume-up-outline:before {
  content: "\f265";
}

.ion-ios-walk:before {
  content: "\f266";
}

.ion-ios-walk-outline:before {
  content: "\f266";
}

.ion-ios-warning:before {
  content: "\f268";
}

.ion-ios-warning-outline:before {
  content: "\f267";
}

.ion-ios-watch:before {
  content: "\f269";
}

.ion-ios-watch-outline:before {
  content: "\f269";
}

.ion-ios-water:before {
  content: "\f26b";
}

.ion-ios-water-outline:before {
  content: "\f26a";
}

.ion-ios-wifi:before {
  content: "\f26d";
}

.ion-ios-wifi-outline:before {
  content: "\f26c";
}

.ion-ios-wine:before {
  content: "\f26f";
}

.ion-ios-wine-outline:before {
  content: "\f26e";
}

.ion-ios-woman:before {
  content: "\f271";
}

.ion-ios-woman-outline:before {
  content: "\f270";
}

.ion-logo-android:before {
  content: "\f225";
}

.ion-logo-angular:before {
  content: "\f227";
}

.ion-logo-apple:before {
  content: "\f229";
}

.ion-logo-bitcoin:before {
  content: "\f22b";
}

.ion-logo-buffer:before {
  content: "\f22d";
}

.ion-logo-chrome:before {
  content: "\f22f";
}

.ion-logo-codepen:before {
  content: "\f230";
}

.ion-logo-css3:before {
  content: "\f231";
}

.ion-logo-designernews:before {
  content: "\f232";
}

.ion-logo-dribbble:before {
  content: "\f233";
}

.ion-logo-dropbox:before {
  content: "\f234";
}

.ion-logo-euro:before {
  content: "\f235";
}

.ion-logo-facebook:before {
  content: "\f236";
}

.ion-logo-foursquare:before {
  content: "\f237";
}

.ion-logo-freebsd-devil:before {
  content: "\f238";
}

.ion-logo-github:before {
  content: "\f239";
}

.ion-logo-google:before {
  content: "\f23a";
}

.ion-logo-googleplus:before {
  content: "\f23b";
}

.ion-logo-hackernews:before {
  content: "\f23c";
}

.ion-logo-html5:before {
  content: "\f23d";
}

.ion-logo-instagram:before {
  content: "\f23e";
}

.ion-logo-javascript:before {
  content: "\f23f";
}

.ion-logo-linkedin:before {
  content: "\f240";
}

.ion-logo-markdown:before {
  content: "\f241";
}

.ion-logo-nodejs:before {
  content: "\f242";
}

.ion-logo-octocat:before {
  content: "\f243";
}

.ion-logo-pinterest:before {
  content: "\f244";
}

.ion-logo-playstation:before {
  content: "\f245";
}

.ion-logo-python:before {
  content: "\f246";
}

.ion-logo-reddit:before {
  content: "\f247";
}

.ion-logo-rss:before {
  content: "\f248";
}

.ion-logo-sass:before {
  content: "\f249";
}

.ion-logo-skype:before {
  content: "\f24a";
}

.ion-logo-snapchat:before {
  content: "\f24b";
}

.ion-logo-steam:before {
  content: "\f24c";
}

.ion-logo-tumblr:before {
  content: "\f24d";
}

.ion-logo-tux:before {
  content: "\f2ae";
}

.ion-logo-twitch:before {
  content: "\f2af";
}

.ion-logo-twitter:before {
  content: "\f2b0";
}

.ion-logo-usd:before {
  content: "\f2b1";
}

.ion-logo-vimeo:before {
  content: "\f2c4";
}

.ion-logo-whatsapp:before {
  content: "\f2c5";
}

.ion-logo-windows:before {
  content: "\f32f";
}

.ion-logo-wordpress:before {
  content: "\f330";
}

.ion-logo-xbox:before {
  content: "\f34c";
}

.ion-logo-yahoo:before {
  content: "\f34d";
}

.ion-logo-yen:before {
  content: "\f34e";
}

.ion-logo-youtube:before {
  content: "\f34f";
}

.ion-md-add:before {
  content: "\f273";
}

.ion-md-add-circle:before {
  content: "\f272";
}

.ion-md-alarm:before {
  content: "\f274";
}

.ion-md-albums:before {
  content: "\f275";
}

.ion-md-alert:before {
  content: "\f276";
}

.ion-md-american-football:before {
  content: "\f277";
}

.ion-md-analytics:before {
  content: "\f278";
}

.ion-md-aperture:before {
  content: "\f279";
}

.ion-md-apps:before {
  content: "\f27a";
}

.ion-md-appstore:before {
  content: "\f27b";
}

.ion-md-archive:before {
  content: "\f27c";
}

.ion-md-arrow-back:before {
  content: "\f27d";
}

.ion-md-arrow-down:before {
  content: "\f27e";
}

.ion-md-arrow-dropdown:before {
  content: "\f280";
}

.ion-md-arrow-dropdown-circle:before {
  content: "\f27f";
}

.ion-md-arrow-dropleft:before {
  content: "\f282";
}

.ion-md-arrow-dropleft-circle:before {
  content: "\f281";
}

.ion-md-arrow-dropright:before {
  content: "\f284";
}

.ion-md-arrow-dropright-circle:before {
  content: "\f283";
}

.ion-md-arrow-dropup:before {
  content: "\f286";
}

.ion-md-arrow-dropup-circle:before {
  content: "\f285";
}

.ion-md-arrow-forward:before {
  content: "\f287";
}

.ion-md-arrow-round-back:before {
  content: "\f288";
}

.ion-md-arrow-round-down:before {
  content: "\f289";
}

.ion-md-arrow-round-forward:before {
  content: "\f28a";
}

.ion-md-arrow-round-up:before {
  content: "\f28b";
}

.ion-md-arrow-up:before {
  content: "\f28c";
}

.ion-md-at:before {
  content: "\f28d";
}

.ion-md-attach:before {
  content: "\f28e";
}

.ion-md-backspace:before {
  content: "\f28f";
}

.ion-md-barcode:before {
  content: "\f290";
}

.ion-md-baseball:before {
  content: "\f291";
}

.ion-md-basket:before {
  content: "\f292";
}

.ion-md-basketball:before {
  content: "\f293";
}

.ion-md-battery-charging:before {
  content: "\f294";
}

.ion-md-battery-dead:before {
  content: "\f295";
}

.ion-md-battery-full:before {
  content: "\f296";
}

.ion-md-beaker:before {
  content: "\f297";
}

.ion-md-beer:before {
  content: "\f298";
}

.ion-md-bicycle:before {
  content: "\f299";
}

.ion-md-bluetooth:before {
  content: "\f29a";
}

.ion-md-boat:before {
  content: "\f29b";
}

.ion-md-body:before {
  content: "\f29c";
}

.ion-md-bonfire:before {
  content: "\f29d";
}

.ion-md-book:before {
  content: "\f29e";
}

.ion-md-bookmark:before {
  content: "\f29f";
}

.ion-md-bookmarks:before {
  content: "\f2a0";
}

.ion-md-bowtie:before {
  content: "\f2a1";
}

.ion-md-briefcase:before {
  content: "\f2a2";
}

.ion-md-browsers:before {
  content: "\f2a3";
}

.ion-md-brush:before {
  content: "\f2a4";
}

.ion-md-bug:before {
  content: "\f2a5";
}

.ion-md-build:before {
  content: "\f2a6";
}

.ion-md-bulb:before {
  content: "\f2a7";
}

.ion-md-bus:before {
  content: "\f2a8";
}

.ion-md-cafe:before {
  content: "\f2a9";
}

.ion-md-calculator:before {
  content: "\f2aa";
}

.ion-md-calendar:before {
  content: "\f2ab";
}

.ion-md-call:before {
  content: "\f2ac";
}

.ion-md-camera:before {
  content: "\f2ad";
}

.ion-md-car:before {
  content: "\f2b2";
}

.ion-md-card:before {
  content: "\f2b3";
}

.ion-md-cart:before {
  content: "\f2b4";
}

.ion-md-cash:before {
  content: "\f2b5";
}

.ion-md-chatboxes:before {
  content: "\f2b6";
}

.ion-md-chatbubbles:before {
  content: "\f2b7";
}

.ion-md-checkbox:before {
  content: "\f2b9";
}

.ion-md-checkbox-outline:before {
  content: "\f2b8";
}

.ion-md-checkmark:before {
  content: "\f2bc";
}

.ion-md-checkmark-circle:before {
  content: "\f2bb";
}

.ion-md-checkmark-circle-outline:before {
  content: "\f2ba";
}

.ion-md-clipboard:before {
  content: "\f2bd";
}

.ion-md-clock:before {
  content: "\f2be";
}

.ion-md-close:before {
  content: "\f2c0";
}

.ion-md-close-circle:before {
  content: "\f2bf";
}

.ion-md-closed-captioning:before {
  content: "\f2c1";
}

.ion-md-cloud:before {
  content: "\f2c9";
}

.ion-md-cloud-circle:before {
  content: "\f2c2";
}

.ion-md-cloud-done:before {
  content: "\f2c3";
}

.ion-md-cloud-download:before {
  content: "\f2c6";
}

.ion-md-cloud-outline:before {
  content: "\f2c7";
}

.ion-md-cloud-upload:before {
  content: "\f2c8";
}

.ion-md-cloudy:before {
  content: "\f2cb";
}

.ion-md-cloudy-night:before {
  content: "\f2ca";
}

.ion-md-code:before {
  content: "\f2ce";
}

.ion-md-code-download:before {
  content: "\f2cc";
}

.ion-md-code-working:before {
  content: "\f2cd";
}

.ion-md-cog:before {
  content: "\f2cf";
}

.ion-md-color-fill:before {
  content: "\f2d0";
}

.ion-md-color-filter:before {
  content: "\f2d1";
}

.ion-md-color-palette:before {
  content: "\f2d2";
}

.ion-md-color-wand:before {
  content: "\f2d3";
}

.ion-md-compass:before {
  content: "\f2d4";
}

.ion-md-construct:before {
  content: "\f2d5";
}

.ion-md-contact:before {
  content: "\f2d6";
}

.ion-md-contacts:before {
  content: "\f2d7";
}

.ion-md-contract:before {
  content: "\f2d8";
}

.ion-md-contrast:before {
  content: "\f2d9";
}

.ion-md-copy:before {
  content: "\f2da";
}

.ion-md-create:before {
  content: "\f2db";
}

.ion-md-crop:before {
  content: "\f2dc";
}

.ion-md-cube:before {
  content: "\f2dd";
}

.ion-md-cut:before {
  content: "\f2de";
}

.ion-md-desktop:before {
  content: "\f2df";
}

.ion-md-disc:before {
  content: "\f2e0";
}

.ion-md-document:before {
  content: "\f2e1";
}

.ion-md-done-all:before {
  content: "\f2e2";
}

.ion-md-download:before {
  content: "\f2e3";
}

.ion-md-easel:before {
  content: "\f2e4";
}

.ion-md-egg:before {
  content: "\f2e5";
}

.ion-md-exit:before {
  content: "\f2e6";
}

.ion-md-expand:before {
  content: "\f2e7";
}

.ion-md-eye:before {
  content: "\f2e9";
}

.ion-md-eye-off:before {
  content: "\f2e8";
}

.ion-md-fastforward:before {
  content: "\f2ea";
}

.ion-md-female:before {
  content: "\f2eb";
}

.ion-md-filing:before {
  content: "\f2ec";
}

.ion-md-film:before {
  content: "\f2ed";
}

.ion-md-finger-print:before {
  content: "\f2ee";
}

.ion-md-flag:before {
  content: "\f2ef";
}

.ion-md-flame:before {
  content: "\f2f0";
}

.ion-md-flash:before {
  content: "\f2f1";
}

.ion-md-flask:before {
  content: "\f2f2";
}

.ion-md-flower:before {
  content: "\f2f3";
}

.ion-md-folder:before {
  content: "\f2f5";
}

.ion-md-folder-open:before {
  content: "\f2f4";
}

.ion-md-football:before {
  content: "\f2f6";
}

.ion-md-funnel:before {
  content: "\f2f7";
}

.ion-md-game-controller-a:before {
  content: "\f2f8";
}

.ion-md-game-controller-b:before {
  content: "\f2f9";
}

.ion-md-git-branch:before {
  content: "\f2fa";
}

.ion-md-git-commit:before {
  content: "\f2fb";
}

.ion-md-git-compare:before {
  content: "\f2fc";
}

.ion-md-git-merge:before {
  content: "\f2fd";
}

.ion-md-git-network:before {
  content: "\f2fe";
}

.ion-md-git-pull-request:before {
  content: "\f2ff";
}

.ion-md-glasses:before {
  content: "\f300";
}

.ion-md-globe:before {
  content: "\f301";
}

.ion-md-grid:before {
  content: "\f302";
}

.ion-md-hammer:before {
  content: "\f303";
}

.ion-md-hand:before {
  content: "\f304";
}

.ion-md-happy:before {
  content: "\f305";
}

.ion-md-headset:before {
  content: "\f306";
}

.ion-md-heart:before {
  content: "\f308";
}

.ion-md-heart-outline:before {
  content: "\f307";
}

.ion-md-help:before {
  content: "\f30b";
}

.ion-md-help-buoy:before {
  content: "\f309";
}

.ion-md-help-circle:before {
  content: "\f30a";
}

.ion-md-home:before {
  content: "\f30c";
}

.ion-md-ice-cream:before {
  content: "\f30d";
}

.ion-md-image:before {
  content: "\f30e";
}

.ion-md-images:before {
  content: "\f30f";
}

.ion-md-infinite:before {
  content: "\f310";
}

.ion-md-information:before {
  content: "\f312";
}

.ion-md-information-circle:before {
  content: "\f311";
}

.ion-md-ionic:before {
  content: "\f313";
}

.ion-md-ionitron:before {
  content: "\f314";
}

.ion-md-jet:before {
  content: "\f315";
}

.ion-md-key:before {
  content: "\f316";
}

.ion-md-keypad:before {
  content: "\f317";
}

.ion-md-laptop:before {
  content: "\f318";
}

.ion-md-leaf:before {
  content: "\f319";
}

.ion-md-link:before {
  content: "\f22e";
}

.ion-md-list:before {
  content: "\f31b";
}

.ion-md-list-box:before {
  content: "\f31a";
}

.ion-md-locate:before {
  content: "\f31c";
}

.ion-md-lock:before {
  content: "\f31d";
}

.ion-md-log-in:before {
  content: "\f31e";
}

.ion-md-log-out:before {
  content: "\f31f";
}

.ion-md-magnet:before {
  content: "\f320";
}

.ion-md-mail:before {
  content: "\f322";
}

.ion-md-mail-open:before {
  content: "\f321";
}

.ion-md-male:before {
  content: "\f323";
}

.ion-md-man:before {
  content: "\f324";
}

.ion-md-map:before {
  content: "\f325";
}

.ion-md-medal:before {
  content: "\f326";
}

.ion-md-medical:before {
  content: "\f327";
}

.ion-md-medkit:before {
  content: "\f328";
}

.ion-md-megaphone:before {
  content: "\f329";
}

.ion-md-menu:before {
  content: "\f32a";
}

.ion-md-mic:before {
  content: "\f32c";
}

.ion-md-mic-off:before {
  content: "\f32b";
}

.ion-md-microphone:before {
  content: "\f32d";
}

.ion-md-moon:before {
  content: "\f32e";
}

.ion-md-more:before {
  content: "\f1c9";
}

.ion-md-move:before {
  content: "\f331";
}

.ion-md-musical-note:before {
  content: "\f332";
}

.ion-md-musical-notes:before {
  content: "\f333";
}

.ion-md-navigate:before {
  content: "\f334";
}

.ion-md-no-smoking:before {
  content: "\f335";
}

.ion-md-notifications:before {
  content: "\f338";
}

.ion-md-notifications-off:before {
  content: "\f336";
}

.ion-md-notifications-outline:before {
  content: "\f337";
}

.ion-md-nuclear:before {
  content: "\f339";
}

.ion-md-nutrition:before {
  content: "\f33a";
}

.ion-md-open:before {
  content: "\f33b";
}

.ion-md-options:before {
  content: "\f33c";
}

.ion-md-outlet:before {
  content: "\f33d";
}

.ion-md-paper:before {
  content: "\f33f";
}

.ion-md-paper-plane:before {
  content: "\f33e";
}

.ion-md-partly-sunny:before {
  content: "\f340";
}

.ion-md-pause:before {
  content: "\f341";
}

.ion-md-paw:before {
  content: "\f342";
}

.ion-md-people:before {
  content: "\f343";
}

.ion-md-person:before {
  content: "\f345";
}

.ion-md-person-add:before {
  content: "\f344";
}

.ion-md-phone-landscape:before {
  content: "\f346";
}

.ion-md-phone-portrait:before {
  content: "\f347";
}

.ion-md-photos:before {
  content: "\f348";
}

.ion-md-pie:before {
  content: "\f349";
}

.ion-md-pin:before {
  content: "\f34a";
}

.ion-md-pint:before {
  content: "\f34b";
}

.ion-md-pizza:before {
  content: "\f354";
}

.ion-md-plane:before {
  content: "\f355";
}

.ion-md-planet:before {
  content: "\f356";
}

.ion-md-play:before {
  content: "\f357";
}

.ion-md-podium:before {
  content: "\f358";
}

.ion-md-power:before {
  content: "\f359";
}

.ion-md-pricetag:before {
  content: "\f35a";
}

.ion-md-pricetags:before {
  content: "\f35b";
}

.ion-md-print:before {
  content: "\f35c";
}

.ion-md-pulse:before {
  content: "\f35d";
}

.ion-md-qr-scanner:before {
  content: "\f35e";
}

.ion-md-quote:before {
  content: "\f35f";
}

.ion-md-radio:before {
  content: "\f362";
}

.ion-md-radio-button-off:before {
  content: "\f360";
}

.ion-md-radio-button-on:before {
  content: "\f361";
}

.ion-md-rainy:before {
  content: "\f363";
}

.ion-md-recording:before {
  content: "\f364";
}

.ion-md-redo:before {
  content: "\f365";
}

.ion-md-refresh:before {
  content: "\f366";
}

.ion-md-refresh-circle:before {
  content: "\f228";
}

.ion-md-remove:before {
  content: "\f368";
}

.ion-md-remove-circle:before {
  content: "\f367";
}

.ion-md-reorder:before {
  content: "\f369";
}

.ion-md-repeat:before {
  content: "\f36a";
}

.ion-md-resize:before {
  content: "\f36b";
}

.ion-md-restaurant:before {
  content: "\f36c";
}

.ion-md-return-left:before {
  content: "\f36d";
}

.ion-md-return-right:before {
  content: "\f36e";
}

.ion-md-reverse-camera:before {
  content: "\f36f";
}

.ion-md-rewind:before {
  content: "\f370";
}

.ion-md-ribbon:before {
  content: "\f371";
}

.ion-md-rose:before {
  content: "\f372";
}

.ion-md-sad:before {
  content: "\f373";
}

.ion-md-school:before {
  content: "\f374";
}

.ion-md-search:before {
  content: "\f375";
}

.ion-md-send:before {
  content: "\f376";
}

.ion-md-settings:before {
  content: "\f377";
}

.ion-md-share:before {
  content: "\f379";
}

.ion-md-share-alt:before {
  content: "\f378";
}

.ion-md-shirt:before {
  content: "\f37a";
}

.ion-md-shuffle:before {
  content: "\f37b";
}

.ion-md-skip-backward:before {
  content: "\f37c";
}

.ion-md-skip-forward:before {
  content: "\f37d";
}

.ion-md-snow:before {
  content: "\f37e";
}

.ion-md-speedometer:before {
  content: "\f37f";
}

.ion-md-square:before {
  content: "\f381";
}

.ion-md-square-outline:before {
  content: "\f380";
}

.ion-md-star:before {
  content: "\f384";
}

.ion-md-star-half:before {
  content: "\f382";
}

.ion-md-star-outline:before {
  content: "\f383";
}

.ion-md-stats:before {
  content: "\f385";
}

.ion-md-stopwatch:before {
  content: "\f386";
}

.ion-md-subway:before {
  content: "\f387";
}

.ion-md-sunny:before {
  content: "\f388";
}

.ion-md-swap:before {
  content: "\f389";
}

.ion-md-switch:before {
  content: "\f38a";
}

.ion-md-sync:before {
  content: "\f38b";
}

.ion-md-tablet-landscape:before {
  content: "\f38c";
}

.ion-md-tablet-portrait:before {
  content: "\f38d";
}

.ion-md-tennisball:before {
  content: "\f38e";
}

.ion-md-text:before {
  content: "\f38f";
}

.ion-md-thermometer:before {
  content: "\f390";
}

.ion-md-thumbs-down:before {
  content: "\f391";
}

.ion-md-thumbs-up:before {
  content: "\f392";
}

.ion-md-thunderstorm:before {
  content: "\f393";
}

.ion-md-time:before {
  content: "\f394";
}

.ion-md-timer:before {
  content: "\f395";
}

.ion-md-train:before {
  content: "\f396";
}

.ion-md-transgender:before {
  content: "\f397";
}

.ion-md-trash:before {
  content: "\f398";
}

.ion-md-trending-down:before {
  content: "\f399";
}

.ion-md-trending-up:before {
  content: "\f39a";
}

.ion-md-trophy:before {
  content: "\f39b";
}

.ion-md-umbrella:before {
  content: "\f39c";
}

.ion-md-undo:before {
  content: "\f39d";
}

.ion-md-unlock:before {
  content: "\f39e";
}

.ion-md-videocam:before {
  content: "\f39f";
}

.ion-md-volume-down:before {
  content: "\f3a0";
}

.ion-md-volume-mute:before {
  content: "\f3a1";
}

.ion-md-volume-off:before {
  content: "\f3a2";
}

.ion-md-volume-up:before {
  content: "\f3a3";
}

.ion-md-walk:before {
  content: "\f3a4";
}

.ion-md-warning:before {
  content: "\f3a5";
}

.ion-md-watch:before {
  content: "\f3a6";
}

.ion-md-water:before {
  content: "\f3a7";
}

.ion-md-wifi:before {
  content: "\f3a8";
}

.ion-md-wine:before {
  content: "\f3a9";
}

.ion-md-woman:before {
  content: "\f3aa";
}

@font-face {
  font-family: "Ionicons";
  src: url("../assets/fonts/ionicons.woff2?v=3.0.0-alpha.3") format("woff2"), url("../assets/fonts/ionicons.woff?v=3.0.0-alpha.3") format("woff"), url("../assets/fonts/ionicons.ttf?v=3.0.0-alpha.3") format("truetype");
  font-weight: normal;
  font-style: normal;
}

ion-icon {
  display: inline-block;
  font-family: "Ionicons";
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  font-style: normal;
  font-variant: normal;
  font-weight: normal;
  line-height: 1;
  text-rendering: auto;
  text-transform: none;
  speak: none;
}

ion-icon::before {
  display: inline-block;
}

@font-face {
  font-family: "Roboto";
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Light"), local("Roboto-Light"), url("../assets/fonts/roboto-light.woff2") format("woff2"), url("../assets/fonts/roboto-light.woff") format("woff"), url("../assets/fonts/roboto-light.ttf") format("truetype");
}

@font-face {
  font-family: "Roboto";
  font-style: normal;
  font-weight: 400;
  src: local("Roboto"), local("Roboto-Regular"), url("../assets/fonts/roboto-regular.woff2") format("woff2"), url("../assets/fonts/roboto-regular.woff") format("woff"), url("../assets/fonts/roboto-regular.ttf") format("truetype");
}

@font-face {
  font-family: "Roboto";
  font-style: normal;
  font-weight: 500;
  src: local("Roboto Medium"), local("Roboto-Medium"), url("../assets/fonts/roboto-medium.woff2") format("woff2"), url("../assets/fonts/roboto-medium.woff") format("woff"), url("../assets/fonts/roboto-medium.ttf") format("truetype");
}

@font-face {
  font-family: "Roboto";
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Bold"), local("Roboto-Bold"), url("../assets/fonts/roboto-bold.woff2") format("woff2"), url("../assets/fonts/roboto-bold.woff") format("woff"), url("../assets/fonts/roboto-bold.ttf") format("truetype");
}

@font-face {
  font-family: "Noto Sans";
  font-style: normal;
  font-weight: 300;
  src: local("Noto Sans"), local("Noto-Sans-Regular"), url("../assets/fonts/noto-sans-regular.woff") format("woff"), url("../assets/fonts/noto-sans-regular.ttf") format("truetype");
}

@font-face {
  font-family: "Noto Sans";
  font-style: normal;
  font-weight: 400;
  src: local("Noto Sans"), local("Noto-Sans-Regular"), url("../assets/fonts/noto-sans-regular.woff") format("woff"), url("../assets/fonts/noto-sans-regular.ttf") format("truetype");
}

@font-face {
  font-family: "Noto Sans";
  font-style: normal;
  font-weight: 500;
  src: local("Noto Sans Bold"), local("Noto-Sans-Bold"), url("../assets/fonts/noto-sans-bold.woff") format("woff"), url("../assets/fonts/noto-sans-bold.ttf") format("truetype");
}

@font-face {
  font-family: "Noto Sans";
  font-style: normal;
  font-weight: 700;
  src: local("Noto Sans Bold"), local("Noto-Sans-Bold"), url("../assets/fonts/noto-sans-bold.woff") format("woff"), url("../assets/fonts/noto-sans-bold.ttf") format("truetype");
}

ion-action-sheet {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 1000;
  display: block;
  width: 100%;
  height: 100%;
}

.action-sheet-wrapper {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  margin: auto;
  -webkit-transform: translate3d(0,  100%,  0);
  transform: translate3d(0,  100%,  0);
  position: absolute;
  z-index: 10;
  display: block;
  width: 100%;
  max-width: 500px;
  pointer-events: none;
}

.action-sheet-button {
  width: 100%;
}

.action-sheet-container {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-flow: column;
  -ms-flex-flow: column;
  flex-flow: column;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  height: 100%;
  max-height: 100%;
}

.action-sheet-group {
  overflow: scroll;
  -webkit-flex-shrink: 2;
  -ms-flex-negative: 2;
  flex-shrink: 2;
  pointer-events: all;
}

.action-sheet-group-cancel {
  overflow: hidden;
  -webkit-flex-shrink: 0;
  -ms-flex-negative: 0;
  flex-shrink: 0;
}

.action-sheet-ios {
  text-align: center;
}

.action-sheet-ios .action-sheet-wrapper {
  margin: constant(safe-area-inset-top) auto constant(safe-area-inset-bottom);
  margin: env(safe-area-inset-top) auto env(safe-area-inset-bottom);
}

.action-sheet-ios .action-sheet-container {
  padding: 0 10px;
}

.action-sheet-ios .action-sheet-group {
  border-radius: 13px;
  margin-bottom: 8px;
  background: #f9f9f9;
}

.action-sheet-ios .action-sheet-group:first-child {
  margin-top: 10px;
}

.action-sheet-ios .action-sheet-group:last-child {
  margin-bottom: 10px;
}

.action-sheet-ios .action-sheet-title {
  padding: 1.5rem;
  text-align: center;
  border-radius: 0;
  border-bottom: 0.55px solid #d6d6da;
  font-size: 1.3rem;
  font-weight: 400;
  color: #8f8f8f;
}

.action-sheet-ios .action-sheet-button {
  margin: 0;
  padding: 18px;
  min-height: 5.6rem;
  border-bottom: 0.55px solid #d6d6da;
  font-size: 2rem;
  color: #007aff;
  background: transparent;
}

.action-sheet-ios .action-sheet-button:last-child {
  border-bottom-color: transparent;
}

.action-sheet-ios .action-sheet-button.activated {
  margin-top: -0.55px;
  border-top: 0.55px solid #ebebeb;
  border-bottom-color: #ebebeb;
  background: #ebebeb;
}

.action-sheet-ios .action-sheet-selected {
  font-weight: bold;
  background: #fff;
}

.action-sheet-ios .action-sheet-destructive {
  color: #f53d3d;
}

.action-sheet-ios .action-sheet-cancel {
  font-weight: 600;
  background: #fff;
}

.action-sheet-md .action-sheet-title {
  text-align: left;
  text-align: start;
  font-size: 1.6rem;
  color: #757575;
  padding: 11px 16px 17px;
}

.action-sheet-md .action-sheet-button {
  text-align: left;
  text-align: start;
  position: relative;
  overflow: hidden;
  min-height: 4.8rem;
  font-size: 1.6rem;
  color: #222;
  background: transparent;
  padding: 0 16px;
}

.action-sheet-md .action-sheet-button.activated {
  background: #f1f1f1;
}

.action-sheet-md .action-sheet-icon {
  padding: 0;
  text-align: center;
  width: 2.3rem;
  font-size: 2.4rem;
  vertical-align: middle;
  margin: 0 32px 0 0;
}

.action-sheet-md .action-sheet-group {
  background: #fafafa;
}

.action-sheet-md .action-sheet-group:first-child {
  padding-top: 0.8rem;
}

.action-sheet-md .action-sheet-group:last-child {
  padding-bottom: 0.8rem;
}

.action-sheet-md .action-sheet-group .button-inner {
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

.action-sheet-md .action-sheet-selected {
  font-weight: bold;
}

.action-sheet-wp .action-sheet-title {
  text-align: left;
  text-align: start;
  font-size: 2rem;
  color: #4d4d4d;
  padding: 11px 16px 17px;
}

.action-sheet-wp .action-sheet-button {
  text-align: left;
  text-align: start;
  min-height: 4.8rem;
  font-size: 1.5rem;
  color: #4d4d4d;
  background: transparent;
  padding: 0 16px;
}

.action-sheet-wp .action-sheet-button.activated {
  background: #aaa;
}

.action-sheet-wp .action-sheet-icon {
  padding: 0;
  text-align: center;
  width: 2.3rem;
  font-size: 2.4rem;
  vertical-align: middle;
  margin: 0 20px 0 0;
}

.action-sheet-wp .action-sheet-group {
  background: #fff;
}

.action-sheet-wp .action-sheet-group:first-child {
  padding-top: 0.8rem;
  -webkit-box-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
  box-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
}

.action-sheet-wp .action-sheet-group:last-child {
  padding-bottom: 0.8rem;
}

.action-sheet-wp .action-sheet-group .button-inner {
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

.action-sheet-wp .action-sheet-selected {
  font-weight: bold;
}

.action-sheet-wp .action-sheet-cancel {
  background: transparent;
}

ion-alert {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  z-index: 1000;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  contain: strict;
}

ion-alert.alert-top {
  padding-top: 50px;
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

ion-alert input {
  width: 100%;
}

.alert-wrapper {
  z-index: 10;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  min-width: 250px;
  max-height: 90%;
  opacity: 0;
  contain: content;
}

.alert-title {
  margin: 0;
  padding: 0;
}

.alert-sub-title {
  margin: 5px 0 0;
  padding: 0;
  font-weight: normal;
}

.alert-message {
  overflow-y: scroll;
  -webkit-overflow-scrolling: touch;
}

.alert-input {
  padding: 10px 0;
  border: 0;
  background: inherit;
}

.alert-input::-moz-placeholder {
  color: #999;
}

.alert-input:-ms-input-placeholder {
  color: #999;
}

.alert-input::-webkit-input-placeholder {
  text-indent: 0;
  color: #999;
}

.alert-button-group {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
}

.alert-button-group-vertical {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
}

.alert-button {
  margin: 0;
  z-index: 0;
  display: block;
  font-size: 14px;
  line-height: 20px;
}

.alert-tappable {
  text-align: left;
  text-align: start;
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  margin: 0;
  padding: 0;
  width: 100%;
  font-size: inherit;
  line-height: initial;
  background: transparent;
}

.alert-ios .alert-wrapper {
  border-radius: 13px;
  overflow: hidden;
  max-width: 270px;
  background-color: #f8f8f8;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.alert-ios .alert-head {
  text-align: center;
  padding: 12px 16px 7px;
}

.alert-ios .alert-title {
  margin-top: 8px;
  font-size: 17px;
  font-weight: 600;
}

.alert-ios .alert-sub-title {
  font-size: 14px;
  color: #666;
}

.alert-ios .alert-message,
.alert-ios .alert-input-group {
  text-align: center;
  font-size: 13px;
  color: inherit;
  padding: 0 16px 21px;
}

.alert-ios .alert-message {
  max-height: 240px;
}

.alert-ios .alert-message:empty {
  padding: 0 0 12px;
}

.alert-ios .alert-input {
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  margin-top: 10px;
  border-radius: 4px;
  border: 0.55px solid #ccc;
  background-color: #fff;
  padding: 6px;
}

.alert-ios .alert-radio-group,
.alert-ios .alert-checkbox-group {
  overflow: scroll;
  max-height: 240px;
  border-top: 0.55px solid #dbdbdf;
  -webkit-overflow-scrolling: touch;
}

.alert-ios .alert-tappable {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  min-height: 44px;
}

.alert-ios .alert-radio-label {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-ordinal-group: 1;
  -webkit-order: 0;
  -ms-flex-order: 0;
  order: 0;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: initial;
  padding: 13px;
}

.alert-ios [aria-checked=true] .alert-radio-label {
  color: #488aff;
}

.alert-ios .alert-radio-icon {
  position: relative;
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
  min-width: 30px;
}

.alert-ios [aria-checked=true] .alert-radio-inner {
  left: 7px;
  top: -7px;
  position: absolute;
  width: 6px;
  height: 12px;
  border-width: 2px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #488aff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.alert-ios .alert-checkbox-label {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: initial;
  padding: 13px;
}

.alert-ios [aria-checked=true] .alert-checkbox-label {
  color: initial;
}

.alert-ios .alert-checkbox-icon {
  border-radius: 50%;
  position: relative;
  width: 21px;
  height: 21px;
  border-width: 0.55px;
  border-style: solid;
  border-color: #c8c7cc;
  background-color: #fff;
  margin: 10px 6px 10px 16px;
}

.alert-ios [aria-checked=true] .alert-checkbox-icon {
  border-color: #488aff;
  background-color: #488aff;
}

.alert-ios [aria-checked=true] .alert-checkbox-inner {
  left: 7px;
  top: 4px;
  position: absolute;
  width: 4px;
  height: 9px;
  border-width: 0.55px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #fff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.alert-ios .alert-button-group {
  margin-right: -0.55px;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.alert-ios .alert-button {
  margin: 0;
  border-radius: 0;
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1 1 auto;
  -ms-flex: 1 1 auto;
  flex: 1 1 auto;
  min-width: 50%;
  height: 44px;
  border-top: 0.55px solid #dbdbdf;
  border-right: 0.55px solid #dbdbdf;
  font-size: 17px;
  color: #488aff;
  background-color: transparent;
}

.alert-ios .alert-button:last-child {
  border-right: 0;
  font-weight: bold;
}

.alert-ios .alert-button.activated {
  background-color: #e9e9e9;
}

.alert-md .alert-wrapper {
  border-radius: 2px;
  max-width: 280px;
  background-color: #fafafa;
  -webkit-box-shadow: 0 16px 20px rgba(0, 0, 0, 0.4);
  box-shadow: 0 16px 20px rgba(0, 0, 0, 0.4);
}

.alert-md .alert-head {
  text-align: left;
  text-align: start;
  padding: 24px 24px 20px;
}

.alert-md .alert-title {
  font-size: 22px;
}

.alert-md .alert-sub-title {
  font-size: 16px;
}

.alert-md .alert-message,
.alert-md .alert-input-group {
  color: rgba(0, 0, 0, 0.5);
  padding: 0 24px 24px;
}

.alert-md .alert-message {
  max-height: 240px;
  font-size: 15px;
}

.alert-md .alert-message:empty {
  padding: 0;
}

.alert-md .alert-input {
  margin: 5px 0;
  border-bottom: 1px solid #dedede;
  color: #000;
}

.alert-md .alert-input:focus {
  margin-bottom: 4px;
  border-bottom: 2px solid #488aff;
}

.alert-md .alert-radio-group,
.alert-md .alert-checkbox-group {
  position: relative;
  overflow: auto;
  max-height: 240px;
  border-top: 1px solid #dedede;
  border-bottom: 1px solid #dedede;
}

.alert-md .alert-tappable {
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  min-height: 4.4rem;
}

.alert-md .alert-radio-label {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: initial;
  padding: 13px 26px;
}

.alert-md .alert-radio-icon {
  left: 13px;
  top: 0;
  border-radius: 50%;
  position: relative;
  display: block;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: #787878;
}

.alert-md .alert-radio-inner {
  left: 2px;
  top: 2px;
  border-radius: 50%;
  position: absolute;
  width: 8px;
  height: 8px;
  background-color: #488aff;
  -webkit-transform: scale3d(0, 0, 0);
  transform: scale3d(0, 0, 0);
  -webkit-transition: -webkit-transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: -webkit-transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: transform 280ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
}

.alert-md [aria-checked=true] .alert-radio-label {
  color: #488aff;
}

.alert-md [aria-checked=true] .alert-radio-icon {
  border-color: #488aff;
}

.alert-md [aria-checked=true] .alert-radio-inner {
  -webkit-transform: scale3d(1, 1, 1);
  transform: scale3d(1, 1, 1);
}

.alert-md .alert-checkbox-label {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: initial;
  padding: 13px 26px;
}

.alert-md [aria-checked=true] .alert-checkbox-label {
  color: initial;
}

.alert-md .alert-checkbox-icon {
  left: 13px;
  top: 0;
  border-radius: 2px;
  position: relative;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: #787878;
}

.alert-md [aria-checked=true] .alert-checkbox-icon {
  border-color: #488aff;
  background-color: #488aff;
}

.alert-md [aria-checked=true] .alert-checkbox-inner {
  left: 3px;
  top: 0;
  position: absolute;
  width: 6px;
  height: 10px;
  border-width: 2px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #fff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.alert-md .alert-button-group {
  -webkit-flex-wrap: wrap-reverse;
  -ms-flex-wrap: wrap-reverse;
  flex-wrap: wrap-reverse;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  padding: 8px 8px 8px 24px;
}

.alert-md .alert-button {
  text-align: right;
  text-align: end;
  border-radius: 2px;
  position: relative;
  overflow: hidden;
  font-weight: 500;
  text-transform: uppercase;
  color: #488aff;
  background-color: transparent;
  margin: 0 8px 0 0;
  padding: 10px;
}

.alert-md .alert-button.activated {
  background-color: rgba(158, 158, 158, 0.2);
}

.alert-md .alert-button .button-inner {
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

.alert-wp ion-backdrop {
  background: #fff;
}

.alert-wp .alert-wrapper {
  border-radius: 0;
  width: 100%;
  max-width: 520px;
  border: 1px solid #488aff;
  background: #e6e6e6;
}

.alert-wp .alert-head {
  text-align: left;
  text-align: start;
  padding: 20px 22px 5px;
}

.alert-wp .alert-title {
  font-size: 20px;
  font-weight: 400;
}

.alert-wp .alert-sub-title {
  font-size: 16px;
}

.alert-wp .alert-message,
.alert-wp .alert-input-group {
  color: #000;
  padding: 0 22px 8px;
}

.alert-wp .alert-message {
  max-height: 240px;
  font-size: 13px;
}

.alert-wp .alert-message:empty {
  padding: 0;
}

.alert-wp .alert-input {
  border: 2px solid rgba(0, 0, 0, 0.5);
  line-height: 3rem;
  color: #000;
  margin: 5px 0;
  padding: 0 8px;
}

.alert-wp .alert-input:focus {
  border-color: #488aff;
}

.alert-wp .alert-radio-group,
.alert-wp .alert-checkbox-group {
  position: relative;
  overflow: auto;
  max-height: 240px;
}

.alert-wp .alert-tappable {
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  min-height: 4.4rem;
}

.alert-wp .alert-radio-label {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: initial;
  padding: 13px 26px;
}

.alert-wp .alert-radio-icon {
  left: 13px;
  top: 0;
  margin: 0;
  border-radius: 50%;
  position: relative;
  display: block;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.5);
}

.alert-wp .alert-radio-inner {
  left: 2px;
  top: 2px;
  border-radius: 50%;
  position: absolute;
  display: none;
  width: 8px;
  height: 8px;
  background: #488aff;
}

.alert-wp [aria-checked=true] .alert-radio-label {
  color: #000;
}

.alert-wp [aria-checked=true] .alert-radio-icon {
  border-color: rgba(0, 0, 0, 0.5);
}

.alert-wp [aria-checked=true] .alert-radio-inner {
  display: block;
}

.alert-wp .alert-checkbox-label {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: initial;
  padding: 13px 26px;
}

.alert-wp [aria-checked=true] .alert-checkbox-label {
  color: initial;
}

.alert-wp .alert-checkbox-icon {
  left: 13px;
  top: 0;
  border-radius: 0;
  position: relative;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.5);
  background: transparent;
}

.alert-wp [aria-checked=true] .alert-checkbox-icon {
  border-color: #488aff;
  background: #488aff;
}

.alert-wp [aria-checked=true] .alert-checkbox-inner {
  left: 3px;
  top: -2px;
  position: absolute;
  width: 6px;
  height: 12px;
  border-width: 1px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #fff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.alert-wp .alert-button-group {
  -webkit-flex-wrap: wrap-reverse;
  -ms-flex-wrap: wrap-reverse;
  flex-wrap: wrap-reverse;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  padding: 20px 22px;
}

.alert-wp .alert-button-group-vertical .alert-button {
  margin-top: 5px;
  width: 100%;
}

.alert-wp .alert-button-group-vertical .alert-button:first-child:not(:only-child) {
  margin-right: 0;
  margin-top: 0;
}

.alert-wp .alert-button {
  border-radius: 0;
  width: 49.5%;
  font-weight: 400;
  color: #000;
  background: #b8b8b8;
  padding: 5px;
}

.alert-wp .alert-button:first-child:not(:only-child) {
  margin-right: 1%;
}

.alert-wp .alert-button.activated {
  background: darkgray;
}

audio,
canvas,
progress,
video {
  vertical-align: baseline;
}

audio:not([controls]) {
  display: none;
  height: 0;
}

b,
strong {
  font-weight: bold;
}

img {
  max-width: 100%;
  border: 0;
}

svg:not(:root) {
  overflow: hidden;
}

figure {
  margin: 1em 40px;
}

hr {
  height: 1px;
  border-width: 0;
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
}

pre {
  overflow: auto;
}

code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em;
}

label,
input,
select,
textarea {
  font-family: inherit;
  line-height: normal;
}

textarea {
  overflow: auto;
  height: auto;
  font: inherit;
  color: inherit;
}

textarea::-webkit-input-placeholder {
  padding-left: 2px;
}

textarea:-ms-input-placeholder {
  padding-left: 2px;
}

textarea::-ms-input-placeholder {
  padding-left: 2px;
}

textarea::placeholder {
  padding-left: 2px;
}

form,
input,
optgroup,
select {
  margin: 0;
  font: inherit;
  color: inherit;
}

html input[type="button"],
input[type="reset"],
input[type="submit"] {
  cursor: pointer;
  -webkit-appearance: button;
}

a,
a div,
a span,
a ion-icon,
a ion-label,
button,
button div,
button span,
button ion-icon,
button ion-label,
[tappable],
[tappable] div,
[tappable] span,
[tappable] ion-icon,
[tappable] ion-label,
input,
textarea {
  -ms-touch-action: manipulation;
  touch-action: manipulation;
}

a ion-label,
button ion-label {
  pointer-events: none;
}

button {
  border: 0;
  font-family: inherit;
  font-style: inherit;
  font-variant: inherit;
  line-height: 1;
  text-transform: none;
  cursor: pointer;
  -webkit-appearance: button;
}

[tappable] {
  cursor: pointer;
}

a[disabled],
button[disabled],
html input[disabled] {
  cursor: default;
}

button::-moz-focus-inner,
input::-moz-focus-inner {
  padding: 0;
  border: 0;
}

input[type="checkbox"],
input[type="radio"] {
  padding: 0;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto;
}

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

td,
th {
  padding: 0;
}

.hide,
[hidden],
template {
  display: none !important;
}

.sticky {
  position: -webkit-sticky;
  position: sticky;
  top: 0;
}

:focus,
:active {
  outline: none;
}

.focus-outline :focus {
  outline: thin dotted;
  outline-offset: -1px;
}

.focus-outline button:focus,
.focus-outline [ion-button]:focus {
  border-color: #51a7e8;
  outline: 2px solid #51a7e8;
  -webkit-box-shadow: 0 0 8px 1px #51a7e8;
  box-shadow: 0 0 8px 1px #51a7e8;
}

ion-input :focus {
  outline: none;
}

.click-block {
  display: none;
}

.click-block-enabled {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  -webkit-transform: translate3d(0,  -100%,  0) translateY(1px);
  transform: translate3d(0,  -100%,  0) translateY(1px);
  position: absolute;
  z-index: 99999;
  display: block;
  opacity: 0;
  contain: strict;
}

.click-block-active {
  -webkit-transform: translate3d(0,  0,  0);
  transform: translate3d(0,  0,  0);
}

* {
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
  -webkit-tap-highlight-color: transparent;
  -webkit-touch-callout: none;
}

html {
  width: 100%;
  height: 100%;
  font-size: 62.5%;
  -webkit-text-size-adjust: 100%;
  -moz-text-size-adjust: 100%;
  -ms-text-size-adjust: 100%;
  text-size-adjust: 100%;
}

body {
  margin: 0;
  padding: 0;
  position: fixed;
  overflow: hidden;
  width: 100%;
  max-width: 100%;
  height: 100%;
  max-height: 100%;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  -webkit-user-drag: none;
  -ms-content-zooming: none;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
  word-wrap: break-word;
  -webkit-text-size-adjust: none;
  -moz-text-size-adjust: none;
  -ms-text-size-adjust: none;
  text-size-adjust: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

a {
  background-color: transparent;
}

.enable-hover a:hover {
  opacity: .7;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  margin-top: 1.6rem;
  margin-bottom: 1rem;
  font-weight: 500;
  line-height: 1.2;
}

[padding] h1:first-child,
[padding] h2:first-child,
[padding] h3:first-child,
[padding] h4:first-child,
[padding] h5:first-child,
[padding] h6:first-child {
  margin-top: -0.3rem;
}

h1 + h2,
h1 + h3,
h2 + h3 {
  margin-top: -0.3rem;
}

h1 {
  margin-top: 2rem;
  font-size: 2.6rem;
}

h2 {
  margin-top: 1.8rem;
  font-size: 2.4rem;
}

h3 {
  font-size: 2.2rem;
}

h4 {
  font-size: 2rem;
}

h5 {
  font-size: 1.8rem;
}

h6 {
  font-size: 1.6rem;
}

small {
  font-size: 75%;
}

sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline;
}

sup {
  top: -.5em;
}

sub {
  bottom: -.25em;
}

ion-app,
ion-nav,
ion-tab,
ion-tabs,
.app-root {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 0;
  display: block;
  width: 100%;
  height: 100%;
}

ion-nav,
ion-tab,
ion-tabs {
  overflow: hidden;
}

ion-tab {
  display: none;
}

ion-tab.show-tab {
  display: block;
}

ion-app,
ion-nav,
ion-tab,
ion-tabs,
.app-root,
.ion-page {
  contain: strict;
}

.ion-page {
  left: 0;
  top: 0;
  position: absolute;
  display: block;
  width: 100%;
  height: 100%;
  opacity: 0;
}

.ion-page.show-page {
  opacity: 1;
}

ion-header {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 10;
  display: block;
  width: 100%;
}

ion-footer {
  left: 0;
  bottom: 0;
  position: absolute;
  z-index: 10;
  display: block;
  width: 100%;
}

[app-viewport],
[overlay-portal],
[nav-viewport],
[tab-portal],
.nav-decor {
  display: none;
}

[text-center] {
  text-align: center !important;
}

[text-justify] {
  text-align: justify !important;
}

[text-start] {
  text-align: left;
  text-align: start !important;
}

[text-end] {
  text-align: right;
  text-align: end !important;
}

[text-left] {
  text-align: left !important;
}

[text-right] {
  text-align: right !important;
}

[text-nowrap] {
  white-space: nowrap !important;
}

[text-wrap] {
  white-space: normal !important;
}

@media (min-width: 576px) {
  [text-sm-center] {
    text-align: center !important;
  }
  [text-sm-justify] {
    text-align: justify !important;
  }
  [text-sm-start] {
    text-align: left;
    text-align: start !important;
  }
  [text-sm-end] {
    text-align: right;
    text-align: end !important;
  }
  [text-sm-left] {
    text-align: left !important;
  }
  [text-sm-right] {
    text-align: right !important;
  }
  [text-sm-nowrap] {
    white-space: nowrap !important;
  }
  [text-sm-wrap] {
    white-space: normal !important;
  }
}

@media (min-width: 768px) {
  [text-md-center] {
    text-align: center !important;
  }
  [text-md-justify] {
    text-align: justify !important;
  }
  [text-md-start] {
    text-align: left;
    text-align: start !important;
  }
  [text-md-end] {
    text-align: right;
    text-align: end !important;
  }
  [text-md-left] {
    text-align: left !important;
  }
  [text-md-right] {
    text-align: right !important;
  }
  [text-md-nowrap] {
    white-space: nowrap !important;
  }
  [text-md-wrap] {
    white-space: normal !important;
  }
}

@media (min-width: 992px) {
  [text-lg-center] {
    text-align: center !important;
  }
  [text-lg-justify] {
    text-align: justify !important;
  }
  [text-lg-start] {
    text-align: left;
    text-align: start !important;
  }
  [text-lg-end] {
    text-align: right;
    text-align: end !important;
  }
  [text-lg-left] {
    text-align: left !important;
  }
  [text-lg-right] {
    text-align: right !important;
  }
  [text-lg-nowrap] {
    white-space: nowrap !important;
  }
  [text-lg-wrap] {
    white-space: normal !important;
  }
}

@media (min-width: 1200px) {
  [text-xl-center] {
    text-align: center !important;
  }
  [text-xl-justify] {
    text-align: justify !important;
  }
  [text-xl-start] {
    text-align: left;
    text-align: start !important;
  }
  [text-xl-end] {
    text-align: right;
    text-align: end !important;
  }
  [text-xl-left] {
    text-align: left !important;
  }
  [text-xl-right] {
    text-align: right !important;
  }
  [text-xl-nowrap] {
    white-space: nowrap !important;
  }
  [text-xl-wrap] {
    white-space: normal !important;
  }
}

[text-uppercase] {
  text-transform: uppercase !important;
}

[text-lowercase] {
  text-transform: lowercase !important;
}

[text-capitalize] {
  text-transform: capitalize !important;
}

@media (min-width: 576px) {
  [text-sm-uppercase] {
    text-transform: uppercase !important;
  }
  [text-sm-lowercase] {
    text-transform: lowercase !important;
  }
  [text-sm-capitalize] {
    text-transform: capitalize !important;
  }
}

@media (min-width: 768px) {
  [text-md-uppercase] {
    text-transform: uppercase !important;
  }
  [text-md-lowercase] {
    text-transform: lowercase !important;
  }
  [text-md-capitalize] {
    text-transform: capitalize !important;
  }
}

@media (min-width: 992px) {
  [text-lg-uppercase] {
    text-transform: uppercase !important;
  }
  [text-lg-lowercase] {
    text-transform: lowercase !important;
  }
  [text-lg-capitalize] {
    text-transform: capitalize !important;
  }
}

@media (min-width: 1200px) {
  [text-xl-uppercase] {
    text-transform: uppercase !important;
  }
  [text-xl-lowercase] {
    text-transform: lowercase !important;
  }
  [text-xl-capitalize] {
    text-transform: capitalize !important;
  }
}

[float-left] {
  float: left !important;
}

[float-right] {
  float: right !important;
}

[float-start] {
  float: left !important;
}

[float-end] {
  float: right !important;
}

@media (min-width: 576px) {
  [float-sm-left] {
    float: left !important;
  }
  [float-sm-right] {
    float: right !important;
  }
  [float-sm-start] {
    float: left !important;
  }
  [float-sm-end] {
    float: right !important;
  }
}

@media (min-width: 768px) {
  [float-md-left] {
    float: left !important;
  }
  [float-md-right] {
    float: right !important;
  }
  [float-md-start] {
    float: left !important;
  }
  [float-md-end] {
    float: right !important;
  }
}

@media (min-width: 992px) {
  [float-lg-left] {
    float: left !important;
  }
  [float-lg-right] {
    float: right !important;
  }
  [float-lg-start] {
    float: left !important;
  }
  [float-lg-end] {
    float: right !important;
  }
}

@media (min-width: 1200px) {
  [float-xl-left] {
    float: left !important;
  }
  [float-xl-right] {
    float: right !important;
  }
  [float-xl-start] {
    float: left !important;
  }
  [float-xl-end] {
    float: right !important;
  }
}

ion-app.ios {
  font-family: -apple-system, "Helvetica Neue", "Roboto", sans-serif;
  font-size: 1.4rem;
  background-color: #fff;
}

ion-app.md {
  font-family: "Roboto", "Helvetica Neue", sans-serif;
  font-size: 1.4rem;
  background-color: #fff;
}

ion-app.wp {
  font-family: "Segoe UI", "Noto Sans", sans-serif;
  font-size: 1.4rem;
  background-color: #fff;
}

ion-backdrop {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 2;
  display: block;
  width: 100%;
  height: 100%;
  background-color: #000;
  opacity: .01;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

ion-backdrop.backdrop-no-tappable {
  cursor: auto;
}

ion-badge {
  padding: 3px 8px;
  text-align: center;
  display: inline-block;
  min-width: 10px;
  font-size: 1.3rem;
  font-weight: bold;
  line-height: 1;
  white-space: nowrap;
  vertical-align: baseline;
}

ion-badge:empty {
  display: none;
}

.badge-ios {
  border-radius: 10px;
  color: #fff;
  background-color: #488aff;
}

.badge-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.badge-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.badge-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.badge-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.badge-ios-dark {
  color: #fff;
  background-color: #222;
}

.badge-md {
  border-radius: 4px;
  color: #fff;
  background-color: #488aff;
}

.badge-md-primary {
  color: #fff;
  background-color: #488aff;
}

.badge-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.badge-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.badge-md-light {
  color: #000;
  background-color: #f4f4f4;
}

.badge-md-dark {
  color: #fff;
  background-color: #222;
}

.badge-wp {
  border-radius: 0;
  color: #fff;
  background-color: #488aff;
}

.badge-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.badge-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.badge-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.badge-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.badge-wp-dark {
  color: #fff;
  background-color: #222;
}

.button {
  text-align: center;
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  position: relative;
  z-index: 0;
  display: inline-block;
  text-overflow: ellipsis;
  text-transform: none;
  white-space: nowrap;
  cursor: pointer;
  vertical-align: top;
  vertical-align: -webkit-baseline-middle;
  -webkit-transition: background-color, opacity 100ms linear;
  transition: background-color, opacity 100ms linear;
  -webkit-font-kerning: none;
  font-kerning: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  contain: content;
}

.button-inner {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -webkit-flex-flow: row nowrap;
  -ms-flex-flow: row nowrap;
  flex-flow: row nowrap;
  -webkit-flex-shrink: 0;
  -ms-flex-negative: 0;
  flex-shrink: 0;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  width: 100%;
  height: 100%;
}

[ion-button] {
  text-decoration: none;
}

a[disabled],
button[disabled],
[ion-button][disabled] {
  cursor: default;
  opacity: .4;
  pointer-events: none;
}

.button-block {
  display: block;
  clear: both;
  width: 100%;
  contain: strict;
}

.button-block::after {
  clear: both;
}

.button-full {
  display: block;
  width: 100%;
  contain: strict;
}

.button-full.button-outline {
  border-radius: 0;
  border-right-width: 0;
  border-left-width: 0;
}

[icon-left] ion-icon,
[icon-start] ion-icon {
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
  padding-right: 0.3em;
}

[icon-right] ion-icon,
[icon-end] ion-icon {
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
  padding-left: 0.4em;
}

.button[icon-only] {
  padding: 0;
  min-width: .9em;
}

[icon-only] ion-icon {
  padding: 0 0.5em;
  font-size: 1.8em;
  line-height: .67;
  pointer-events: none;
}

.button-ios {
  border-radius: 4px;
  height: 2.8em;
  font-size: 1.6rem;
  color: #fff;
  background-color: #488aff;
  margin: 0.4rem 0.2rem;
  padding: 0 1em;
}

.button-ios.activated {
  background-color: #427feb;
  opacity: 1;
}

.button-ios:hover:not(.disable-hover) {
  opacity: 0.8;
}

.button-large-ios {
  height: 2.8em;
  font-size: 2rem;
  padding: 0 1em;
}

.button-small-ios {
  height: 2.1em;
  font-size: 1.3rem;
  padding: 0 0.9em;
}

.button-small-ios[icon-only] ion-icon {
  font-size: 1.3em;
}

.button-block-ios {
  margin-left: 0;
  margin-right: 0;
}

.button-full-ios {
  margin-left: 0;
  margin-right: 0;
  border-radius: 0;
  border-right-width: 0;
  border-left-width: 0;
}

.button-outline-ios {
  border-radius: 4px;
  border-width: 1px;
  border-style: solid;
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.button-outline-ios.activated {
  color: #fff;
  background-color: #488aff;
  opacity: 1;
}

.button-clear-ios {
  border-color: transparent;
  color: #488aff;
  background-color: transparent;
}

.button-clear-ios.activated {
  background-color: transparent;
  opacity: 0.4;
}

.button-clear-ios:hover:not(.disable-hover) {
  color: #488aff;
  opacity: 0.6;
}

.button-round-ios {
  border-radius: 64px;
  padding: 0 2.6rem;
}

.button-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.button-ios-primary.activated {
  background-color: #427feb;
}

.button-outline-ios-primary {
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.button-outline-ios-primary.activated {
  color: #fff;
  background-color: #488aff;
}

.button-clear-ios-primary {
  border-color: transparent;
  color: #488aff;
  background-color: transparent;
}

.button-clear-ios-primary.activated {
  opacity: 0.4;
}

.button-clear-ios-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.button-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.button-ios-secondary.activated {
  background-color: #2ec95c;
}

.button-outline-ios-secondary {
  border-color: #32db64;
  color: #32db64;
  background-color: transparent;
}

.button-outline-ios-secondary.activated {
  color: #fff;
  background-color: #32db64;
}

.button-clear-ios-secondary {
  border-color: transparent;
  color: #32db64;
  background-color: transparent;
}

.button-clear-ios-secondary.activated {
  opacity: 0.4;
}

.button-clear-ios-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.button-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.button-ios-danger.activated {
  background-color: #e13838;
}

.button-outline-ios-danger {
  border-color: #f53d3d;
  color: #f53d3d;
  background-color: transparent;
}

.button-outline-ios-danger.activated {
  color: #fff;
  background-color: #f53d3d;
}

.button-clear-ios-danger {
  border-color: transparent;
  color: #f53d3d;
  background-color: transparent;
}

.button-clear-ios-danger.activated {
  opacity: 0.4;
}

.button-clear-ios-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.button-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.button-ios-light.activated {
  background-color: #e0e0e0;
}

.button-outline-ios-light {
  border-color: #f4f4f4;
  color: #f4f4f4;
  background-color: transparent;
}

.button-outline-ios-light.activated {
  color: #000;
  background-color: #f4f4f4;
}

.button-clear-ios-light {
  border-color: transparent;
  color: #f4f4f4;
  background-color: transparent;
}

.button-clear-ios-light.activated {
  opacity: 0.4;
}

.button-clear-ios-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.button-ios-dark {
  color: #fff;
  background-color: #222;
}

.button-ios-dark.activated {
  background-color: #343434;
}

.button-outline-ios-dark {
  border-color: #222;
  color: #222;
  background-color: transparent;
}

.button-outline-ios-dark.activated {
  color: #fff;
  background-color: #222;
}

.button-clear-ios-dark {
  border-color: transparent;
  color: #222;
  background-color: transparent;
}

.button-clear-ios-dark.activated {
  opacity: 0.4;
}

.button-clear-ios-dark:hover:not(.disable-hover) {
  color: #222;
}

.button-strong-ios {
  font-weight: 600;
}

.button-md {
  border-radius: 2px;
  overflow: hidden;
  height: 3.6rem;
  font-size: 1.4rem;
  font-weight: 500;
  text-transform: uppercase;
  color: #fff;
  background-color: #488aff;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  -webkit-transition: background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1), background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1), background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
  margin: 0.4rem 0.2rem;
  padding: 0 1.1em;
}

.button-md:hover:not(.disable-hover) {
  background-color: #488aff;
}

.button-md.activated {
  background-color: #427feb;
  -webkit-box-shadow: 0 3px 5px rgba(0, 0, 0, 0.14), 0 3px 5px rgba(0, 0, 0, 0.21), 0 0 0 0 transparent;
  box-shadow: 0 3px 5px rgba(0, 0, 0, 0.14), 0 3px 5px rgba(0, 0, 0, 0.21), 0 0 0 0 transparent;
}

.button-md .button-effect {
  background-color: #fff;
}

.button-large-md {
  height: 2.8em;
  font-size: 2rem;
  padding: 0 1em;
}

.button-small-md {
  height: 2.1em;
  font-size: 1.3rem;
  padding: 0 0.9em;
}

.button-small-md[icon-only] ion-icon {
  font-size: 1.4em;
}

.button-block-md {
  margin-left: 0;
  margin-right: 0;
}

.button-full-md {
  margin-left: 0;
  margin-right: 0;
  border-radius: 0;
  border-right-width: 0;
  border-left-width: 0;
}

.button-outline-md {
  border-width: 1px;
  border-style: solid;
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.button-outline-md:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-md.activated {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
  opacity: 1;
}

.button-outline-md .button-effect {
  background-color: #488aff;
}

.button-clear-md {
  border-color: transparent;
  color: #488aff;
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
  opacity: 1;
}

.button-clear-md.activated {
  background-color: rgba(158, 158, 158, 0.2);
  -webkit-box-shadow: none;
  box-shadow: none;
}

.button-clear-md:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-clear-md .button-effect {
  background-color: #999;
}

.button-round-md {
  border-radius: 64px;
  padding: 0 2.6rem;
}

.button-md [icon-only] {
  padding: 0;
}

.button-effect {
  border-radius: 50%;
  -webkit-transform-origin: center center;
  transform-origin: center center;
  position: absolute;
  z-index: 0;
  display: none;
  background-color: #555;
  opacity: .2;
  -webkit-transition-timing-function: ease-in-out;
  transition-timing-function: ease-in-out;
  pointer-events: none;
  top: 0;
  left: 0;
}

.md button .button-effect {
  display: block;
}

.button-md-primary {
  color: #fff;
  background-color: #488aff;
}

.button-md-primary:hover:not(.disable-hover) {
  background-color: #488aff;
}

.button-md-primary.activated {
  background-color: #427feb;
  opacity: 1;
}

.button-md-primary .button-effect {
  background-color: #fff;
}

.button-outline-md-primary {
  border-color: #4483f2;
  color: #4483f2;
  background-color: transparent;
}

.button-outline-md-primary:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-md-primary.activated {
  background-color: transparent;
}

.button-outline-md-primary .button-effect {
  background-color: #4483f2;
}

.button-clear-md-primary {
  border-color: transparent;
  color: #488aff;
  background-color: transparent;
}

.button-clear-md-primary.activated {
  background-color: rgba(158, 158, 158, 0.2);
  -webkit-box-shadow: none;
  box-shadow: none;
}

.button-clear-md-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.button-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.button-md-secondary:hover:not(.disable-hover) {
  background-color: #32db64;
}

.button-md-secondary.activated {
  background-color: #2ec95c;
  opacity: 1;
}

.button-md-secondary .button-effect {
  background-color: #fff;
}

.button-outline-md-secondary {
  border-color: #30d05f;
  color: #30d05f;
  background-color: transparent;
}

.button-outline-md-secondary:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-md-secondary.activated {
  background-color: transparent;
}

.button-outline-md-secondary .button-effect {
  background-color: #30d05f;
}

.button-clear-md-secondary {
  border-color: transparent;
  color: #32db64;
  background-color: transparent;
}

.button-clear-md-secondary.activated {
  background-color: rgba(158, 158, 158, 0.2);
  -webkit-box-shadow: none;
  box-shadow: none;
}

.button-clear-md-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.button-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.button-md-danger:hover:not(.disable-hover) {
  background-color: #f53d3d;
}

.button-md-danger.activated {
  background-color: #e13838;
  opacity: 1;
}

.button-md-danger .button-effect {
  background-color: #fff;
}

.button-outline-md-danger {
  border-color: #e93a3a;
  color: #e93a3a;
  background-color: transparent;
}

.button-outline-md-danger:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-md-danger.activated {
  background-color: transparent;
}

.button-outline-md-danger .button-effect {
  background-color: #e93a3a;
}

.button-clear-md-danger {
  border-color: transparent;
  color: #f53d3d;
  background-color: transparent;
}

.button-clear-md-danger.activated {
  background-color: rgba(158, 158, 158, 0.2);
  -webkit-box-shadow: none;
  box-shadow: none;
}

.button-clear-md-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.button-md-light {
  color: #000;
  background-color: #f4f4f4;
}

.button-md-light:hover:not(.disable-hover) {
  background-color: #f4f4f4;
}

.button-md-light.activated {
  background-color: #e0e0e0;
  opacity: 1;
}

.button-md-light .button-effect {
  background-color: #000;
}

.button-outline-md-light {
  border-color: #e8e8e8;
  color: #e8e8e8;
  background-color: transparent;
}

.button-outline-md-light:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-md-light.activated {
  background-color: transparent;
}

.button-outline-md-light .button-effect {
  background-color: #e8e8e8;
}

.button-clear-md-light {
  border-color: transparent;
  color: #f4f4f4;
  background-color: transparent;
}

.button-clear-md-light.activated {
  background-color: rgba(158, 158, 158, 0.2);
  -webkit-box-shadow: none;
  box-shadow: none;
}

.button-clear-md-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.button-md-dark {
  color: #fff;
  background-color: #222;
}

.button-md-dark:hover:not(.disable-hover) {
  background-color: #222;
}

.button-md-dark.activated {
  background-color: #343434;
  opacity: 1;
}

.button-md-dark .button-effect {
  background-color: #fff;
}

.button-outline-md-dark {
  border-color: #2d2d2d;
  color: #2d2d2d;
  background-color: transparent;
}

.button-outline-md-dark:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-md-dark.activated {
  background-color: transparent;
}

.button-outline-md-dark .button-effect {
  background-color: #2d2d2d;
}

.button-clear-md-dark {
  border-color: transparent;
  color: #222;
  background-color: transparent;
}

.button-clear-md-dark.activated {
  background-color: rgba(158, 158, 158, 0.2);
  -webkit-box-shadow: none;
  box-shadow: none;
}

.button-clear-md-dark:hover:not(.disable-hover) {
  color: #222;
}

.button-strong-md {
  font-weight: bold;
}

.button-wp {
  border-radius: 0;
  height: 3.6rem;
  border: 3px solid transparent;
  font-size: 1.4rem;
  color: #fff;
  background-color: #488aff;
  margin: 0.4rem 0.2rem;
  padding: 0 1.1em;
}

.button-wp:hover:not(.disable-hover) {
  border-color: #427feb;
  background-color: #488aff;
}

.button-wp.activated {
  background-color: #427feb;
}

.button-large-wp {
  height: 2.8em;
  font-size: 2rem;
  padding: 0 1em;
}

.button-small-wp {
  height: 2.1em;
  font-size: 1.3rem;
  padding: 0 0.9em;
}

.button-small-wp[icon-only] ion-icon {
  font-size: 1.4em;
}

.button-block-wp {
  margin-left: 0;
  margin-right: 0;
}

.button-full-wp {
  margin-left: 0;
  margin-right: 0;
  border-radius: 0;
  border-right-width: 0;
  border-left-width: 0;
}

.button-outline-wp {
  border-width: 1px;
  border-style: solid;
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.button-outline-wp:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-wp.activated {
  background-color: rgba(72, 138, 255, 0.16);
}

.button-clear-wp {
  color: #488aff;
  background-color: transparent;
}

.button-clear-wp.activated {
  background-color: rgba(158, 158, 158, 0.2);
}

.button-clear-wp:hover:not(.disable-hover) {
  background-color: rgba(158, 158, 158, 0.1);
}

.button-round-wp {
  border-radius: 64px;
  padding: 0 2.6rem;
}

.button-wp [icon-only] {
  padding: 0;
}

.button-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.button-wp-primary:hover:not(.disable-hover) {
  border-color: #427feb;
  background-color: #488aff;
}

.button-wp-primary.activated {
  background-color: #427feb;
}

.button-outline-wp-primary {
  border-color: #4483f2;
  color: #4483f2;
  background-color: transparent;
}

.button-outline-wp-primary:hover:not(.disable-hover) {
  border-color: #4483f2;
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-wp-primary.activated {
  background-color: rgba(68, 131, 242, 0.16);
}

.button-clear-wp-primary {
  color: #488aff;
  background-color: transparent;
}

.button-clear-wp-primary.activated {
  background-color: rgba(158, 158, 158, 0.2);
}

.button-clear-wp-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.button-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.button-wp-secondary:hover:not(.disable-hover) {
  border-color: #2ec95c;
  background-color: #32db64;
}

.button-wp-secondary.activated {
  background-color: #2ec95c;
}

.button-outline-wp-secondary {
  border-color: #30d05f;
  color: #30d05f;
  background-color: transparent;
}

.button-outline-wp-secondary:hover:not(.disable-hover) {
  border-color: #30d05f;
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-wp-secondary.activated {
  background-color: rgba(48, 208, 95, 0.16);
}

.button-clear-wp-secondary {
  color: #32db64;
  background-color: transparent;
}

.button-clear-wp-secondary.activated {
  background-color: rgba(158, 158, 158, 0.2);
}

.button-clear-wp-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.button-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.button-wp-danger:hover:not(.disable-hover) {
  border-color: #e13838;
  background-color: #f53d3d;
}

.button-wp-danger.activated {
  background-color: #e13838;
}

.button-outline-wp-danger {
  border-color: #e93a3a;
  color: #e93a3a;
  background-color: transparent;
}

.button-outline-wp-danger:hover:not(.disable-hover) {
  border-color: #e93a3a;
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-wp-danger.activated {
  background-color: rgba(233, 58, 58, 0.16);
}

.button-clear-wp-danger {
  color: #f53d3d;
  background-color: transparent;
}

.button-clear-wp-danger.activated {
  background-color: rgba(158, 158, 158, 0.2);
}

.button-clear-wp-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.button-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.button-wp-light:hover:not(.disable-hover) {
  border-color: #e0e0e0;
  background-color: #f4f4f4;
}

.button-wp-light.activated {
  background-color: #e0e0e0;
}

.button-outline-wp-light {
  border-color: #e8e8e8;
  color: #e8e8e8;
  background-color: transparent;
}

.button-outline-wp-light:hover:not(.disable-hover) {
  border-color: #e8e8e8;
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-wp-light.activated {
  background-color: rgba(232, 232, 232, 0.16);
}

.button-clear-wp-light {
  color: #f4f4f4;
  background-color: transparent;
}

.button-clear-wp-light.activated {
  background-color: rgba(158, 158, 158, 0.2);
}

.button-clear-wp-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.button-wp-dark {
  color: #fff;
  background-color: #222;
}

.button-wp-dark:hover:not(.disable-hover) {
  border-color: #343434;
  background-color: #222;
}

.button-wp-dark.activated {
  background-color: #343434;
}

.button-outline-wp-dark {
  border-color: #2d2d2d;
  color: #2d2d2d;
  background-color: transparent;
}

.button-outline-wp-dark:hover:not(.disable-hover) {
  border-color: #2d2d2d;
  background-color: rgba(158, 158, 158, 0.1);
}

.button-outline-wp-dark.activated {
  background-color: rgba(45, 45, 45, 0.16);
}

.button-clear-wp-dark {
  color: #222;
  background-color: transparent;
}

.button-clear-wp-dark.activated {
  background-color: rgba(158, 158, 158, 0.2);
}

.button-clear-wp-dark:hover:not(.disable-hover) {
  color: #222;
}

.button-strong-wp {
  font-weight: bold;
}

ion-card {
  display: block;
  overflow: hidden;
}

ion-card img {
  display: block;
  width: 100%;
}

ion-card-header {
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

ion-card-content {
  display: block;
}

.card-ios {
  margin: 12px;
  border-radius: 2px;
  width: calc(100% - 24px);
  font-size: 1.4rem;
  background: #fff;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);
}

.card-ios ion-list {
  margin-bottom: 0;
}

.card-ios > .item:last-child,
.card-ios > .item:last-child .item-inner,
.card-ios > .item-wrapper:last-child .item {
  border-bottom: 0;
}

.card-ios .item-ios.item-block .item-inner {
  border: 0;
}

.card-content-ios {
  padding: 13px 16px 14px;
  font-size: 1.4rem;
  line-height: 1.4;
}

.card-header-ios {
  font-size: 1.6rem;
  font-weight: 500;
  color: #333;
  padding: 16px;
}

.card-header-ios + .card-content-ios,
.card-ios .item + .card-content-ios {
  padding-top: 0;
}

.card .note-ios {
  font-size: 1.3rem;
}

.card-title-ios {
  display: block;
  font-size: 1.8rem;
  line-height: 1.2;
  color: #222;
  margin: 2px 0;
  padding: 8px 0;
}

.card-ios h1 {
  margin: 0 0 2px;
  font-size: 2.4rem;
  font-weight: normal;
}

.card-ios h2 {
  margin: 2px 0;
  font-size: 1.6rem;
  font-weight: normal;
}

.card-ios h3,
.card-ios h4,
.card-ios h5,
.card-ios h6 {
  margin: 2px 0;
  font-size: 1.4rem;
  font-weight: normal;
}

.card-ios p {
  margin: 0 0 2px;
  font-size: 1.4rem;
  color: #666;
}

.card-ios + ion-card {
  margin-top: 0;
}

.card-ios .text-ios-primary {
  color: #488aff;
}

.card-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.card-ios-primary .card-header-ios,
.card-ios-primary .card-title-ios,
.card-ios-primary .card-content-ios,
.card-ios-primary p {
  color: #fff;
}

.card-ios-primary .text-ios-primary,
.card-ios-primary .card-header-ios-primary,
.card-ios-primary .card-title-ios-primary,
.card-ios-primary .card-content-ios-primary {
  color: #488aff;
}

.card-ios-primary .text-ios-secondary,
.card-ios-primary .card-header-ios-secondary,
.card-ios-primary .card-title-ios-secondary,
.card-ios-primary .card-content-ios-secondary {
  color: #32db64;
}

.card-ios-primary .text-ios-danger,
.card-ios-primary .card-header-ios-danger,
.card-ios-primary .card-title-ios-danger,
.card-ios-primary .card-content-ios-danger {
  color: #f53d3d;
}

.card-ios-primary .text-ios-light,
.card-ios-primary .card-header-ios-light,
.card-ios-primary .card-title-ios-light,
.card-ios-primary .card-content-ios-light {
  color: #f4f4f4;
}

.card-ios-primary .text-ios-dark,
.card-ios-primary .card-header-ios-dark,
.card-ios-primary .card-title-ios-dark,
.card-ios-primary .card-content-ios-dark {
  color: #222;
}

.card-header-ios-primary,
.card-title-ios-primary,
.card-content-ios-primary {
  color: #488aff;
}

.card-ios .text-ios-secondary {
  color: #32db64;
}

.card-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.card-ios-secondary .card-header-ios,
.card-ios-secondary .card-title-ios,
.card-ios-secondary .card-content-ios,
.card-ios-secondary p {
  color: #fff;
}

.card-ios-secondary .text-ios-primary,
.card-ios-secondary .card-header-ios-primary,
.card-ios-secondary .card-title-ios-primary,
.card-ios-secondary .card-content-ios-primary {
  color: #488aff;
}

.card-ios-secondary .text-ios-secondary,
.card-ios-secondary .card-header-ios-secondary,
.card-ios-secondary .card-title-ios-secondary,
.card-ios-secondary .card-content-ios-secondary {
  color: #32db64;
}

.card-ios-secondary .text-ios-danger,
.card-ios-secondary .card-header-ios-danger,
.card-ios-secondary .card-title-ios-danger,
.card-ios-secondary .card-content-ios-danger {
  color: #f53d3d;
}

.card-ios-secondary .text-ios-light,
.card-ios-secondary .card-header-ios-light,
.card-ios-secondary .card-title-ios-light,
.card-ios-secondary .card-content-ios-light {
  color: #f4f4f4;
}

.card-ios-secondary .text-ios-dark,
.card-ios-secondary .card-header-ios-dark,
.card-ios-secondary .card-title-ios-dark,
.card-ios-secondary .card-content-ios-dark {
  color: #222;
}

.card-header-ios-secondary,
.card-title-ios-secondary,
.card-content-ios-secondary {
  color: #32db64;
}

.card-ios .text-ios-danger {
  color: #f53d3d;
}

.card-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.card-ios-danger .card-header-ios,
.card-ios-danger .card-title-ios,
.card-ios-danger .card-content-ios,
.card-ios-danger p {
  color: #fff;
}

.card-ios-danger .text-ios-primary,
.card-ios-danger .card-header-ios-primary,
.card-ios-danger .card-title-ios-primary,
.card-ios-danger .card-content-ios-primary {
  color: #488aff;
}

.card-ios-danger .text-ios-secondary,
.card-ios-danger .card-header-ios-secondary,
.card-ios-danger .card-title-ios-secondary,
.card-ios-danger .card-content-ios-secondary {
  color: #32db64;
}

.card-ios-danger .text-ios-danger,
.card-ios-danger .card-header-ios-danger,
.card-ios-danger .card-title-ios-danger,
.card-ios-danger .card-content-ios-danger {
  color: #f53d3d;
}

.card-ios-danger .text-ios-light,
.card-ios-danger .card-header-ios-light,
.card-ios-danger .card-title-ios-light,
.card-ios-danger .card-content-ios-light {
  color: #f4f4f4;
}

.card-ios-danger .text-ios-dark,
.card-ios-danger .card-header-ios-dark,
.card-ios-danger .card-title-ios-dark,
.card-ios-danger .card-content-ios-dark {
  color: #222;
}

.card-header-ios-danger,
.card-title-ios-danger,
.card-content-ios-danger {
  color: #f53d3d;
}

.card-ios .text-ios-light {
  color: #f4f4f4;
}

.card-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.card-ios-light .card-header-ios,
.card-ios-light .card-title-ios,
.card-ios-light .card-content-ios,
.card-ios-light p {
  color: #000;
}

.card-ios-light .text-ios-primary,
.card-ios-light .card-header-ios-primary,
.card-ios-light .card-title-ios-primary,
.card-ios-light .card-content-ios-primary {
  color: #488aff;
}

.card-ios-light .text-ios-secondary,
.card-ios-light .card-header-ios-secondary,
.card-ios-light .card-title-ios-secondary,
.card-ios-light .card-content-ios-secondary {
  color: #32db64;
}

.card-ios-light .text-ios-danger,
.card-ios-light .card-header-ios-danger,
.card-ios-light .card-title-ios-danger,
.card-ios-light .card-content-ios-danger {
  color: #f53d3d;
}

.card-ios-light .text-ios-light,
.card-ios-light .card-header-ios-light,
.card-ios-light .card-title-ios-light,
.card-ios-light .card-content-ios-light {
  color: #f4f4f4;
}

.card-ios-light .text-ios-dark,
.card-ios-light .card-header-ios-dark,
.card-ios-light .card-title-ios-dark,
.card-ios-light .card-content-ios-dark {
  color: #222;
}

.card-header-ios-light,
.card-title-ios-light,
.card-content-ios-light {
  color: #f4f4f4;
}

.card-ios .text-ios-dark {
  color: #222;
}

.card-ios-dark {
  color: #fff;
  background-color: #222;
}

.card-ios-dark .card-header-ios,
.card-ios-dark .card-title-ios,
.card-ios-dark .card-content-ios,
.card-ios-dark p {
  color: #fff;
}

.card-ios-dark .text-ios-primary,
.card-ios-dark .card-header-ios-primary,
.card-ios-dark .card-title-ios-primary,
.card-ios-dark .card-content-ios-primary {
  color: #488aff;
}

.card-ios-dark .text-ios-secondary,
.card-ios-dark .card-header-ios-secondary,
.card-ios-dark .card-title-ios-secondary,
.card-ios-dark .card-content-ios-secondary {
  color: #32db64;
}

.card-ios-dark .text-ios-danger,
.card-ios-dark .card-header-ios-danger,
.card-ios-dark .card-title-ios-danger,
.card-ios-dark .card-content-ios-danger {
  color: #f53d3d;
}

.card-ios-dark .text-ios-light,
.card-ios-dark .card-header-ios-light,
.card-ios-dark .card-title-ios-light,
.card-ios-dark .card-content-ios-light {
  color: #f4f4f4;
}

.card-ios-dark .text-ios-dark,
.card-ios-dark .card-header-ios-dark,
.card-ios-dark .card-title-ios-dark,
.card-ios-dark .card-content-ios-dark {
  color: #222;
}

.card-header-ios-dark,
.card-title-ios-dark,
.card-content-ios-dark {
  color: #222;
}

.card-md {
  margin: 10px;
  border-radius: 2px;
  width: calc(100% - 20px);
  font-size: 1.4rem;
  background: #fff;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

.card-md ion-list {
  margin-bottom: 0;
}

.card-md > .item:last-child,
.card-md > .item:last-child .item-inner,
.card-md > .item-wrapper:last-child .item {
  border-bottom: 0;
}

.card-md .item-md.item-block .item-inner {
  border: 0;
}

.card-content-md {
  padding: 13px 16px;
  font-size: 1.4rem;
  line-height: 1.5;
}

.card-header-md {
  font-size: 1.6rem;
  color: #222;
  padding: 16px;
}

.card-header-md + .card-content-md,
.card-md .item + .card-content-md {
  padding-top: 0;
}

.card .note-md {
  font-size: 1.3rem;
}

.card-title-md {
  display: block;
  font-size: 2.4rem;
  line-height: 1.2;
  color: #222;
  margin: 2px 0;
  padding: 8px 0;
}

.card-md h1 {
  margin: 0 0 2px;
  font-size: 2.4rem;
  font-weight: normal;
  color: #222;
}

.card-md h2 {
  margin: 2px 0;
  font-size: 1.6rem;
  font-weight: normal;
  color: #222;
}

.card-md h3,
.card-md h4,
.card-md h5,
.card-md h6 {
  margin: 2px 0;
  font-size: 1.4rem;
  font-weight: normal;
  color: #222;
}

.card-md p {
  margin: 0 0 2px;
  font-size: 1.4rem;
  font-weight: normal;
  line-height: 1.5;
  color: #222;
}

.card-md + ion-card {
  margin-top: 0;
}

.card-md .text-md-primary {
  color: #488aff;
}

.card-md-primary {
  color: #fff;
  background-color: #488aff;
}

.card-md-primary .card-header-md,
.card-md-primary .card-title-md,
.card-md-primary .card-content-md,
.card-md-primary h1,
.card-md-primary h2,
.card-md-primary h3,
.card-md-primary h4,
.card-md-primary h5,
.card-md-primary h6,
.card-md-primary p {
  color: #fff;
}

.card-md-primary .text-md-primary,
.card-md-primary .card-header-md-primary,
.card-md-primary .card-title-md-primary,
.card-md-primary .card-content-md-primary {
  color: #488aff;
}

.card-md-primary .text-md-secondary,
.card-md-primary .card-header-md-secondary,
.card-md-primary .card-title-md-secondary,
.card-md-primary .card-content-md-secondary {
  color: #32db64;
}

.card-md-primary .text-md-danger,
.card-md-primary .card-header-md-danger,
.card-md-primary .card-title-md-danger,
.card-md-primary .card-content-md-danger {
  color: #f53d3d;
}

.card-md-primary .text-md-light,
.card-md-primary .card-header-md-light,
.card-md-primary .card-title-md-light,
.card-md-primary .card-content-md-light {
  color: #f4f4f4;
}

.card-md-primary .text-md-dark,
.card-md-primary .card-header-md-dark,
.card-md-primary .card-title-md-dark,
.card-md-primary .card-content-md-dark {
  color: #222;
}

.card-header-md-primary,
.card-title-md-primary,
.card-content-md-primary {
  color: #488aff;
}

.card-md .text-md-secondary {
  color: #32db64;
}

.card-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.card-md-secondary .card-header-md,
.card-md-secondary .card-title-md,
.card-md-secondary .card-content-md,
.card-md-secondary h1,
.card-md-secondary h2,
.card-md-secondary h3,
.card-md-secondary h4,
.card-md-secondary h5,
.card-md-secondary h6,
.card-md-secondary p {
  color: #fff;
}

.card-md-secondary .text-md-primary,
.card-md-secondary .card-header-md-primary,
.card-md-secondary .card-title-md-primary,
.card-md-secondary .card-content-md-primary {
  color: #488aff;
}

.card-md-secondary .text-md-secondary,
.card-md-secondary .card-header-md-secondary,
.card-md-secondary .card-title-md-secondary,
.card-md-secondary .card-content-md-secondary {
  color: #32db64;
}

.card-md-secondary .text-md-danger,
.card-md-secondary .card-header-md-danger,
.card-md-secondary .card-title-md-danger,
.card-md-secondary .card-content-md-danger {
  color: #f53d3d;
}

.card-md-secondary .text-md-light,
.card-md-secondary .card-header-md-light,
.card-md-secondary .card-title-md-light,
.card-md-secondary .card-content-md-light {
  color: #f4f4f4;
}

.card-md-secondary .text-md-dark,
.card-md-secondary .card-header-md-dark,
.card-md-secondary .card-title-md-dark,
.card-md-secondary .card-content-md-dark {
  color: #222;
}

.card-header-md-secondary,
.card-title-md-secondary,
.card-content-md-secondary {
  color: #32db64;
}

.card-md .text-md-danger {
  color: #f53d3d;
}

.card-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.card-md-danger .card-header-md,
.card-md-danger .card-title-md,
.card-md-danger .card-content-md,
.card-md-danger h1,
.card-md-danger h2,
.card-md-danger h3,
.card-md-danger h4,
.card-md-danger h5,
.card-md-danger h6,
.card-md-danger p {
  color: #fff;
}

.card-md-danger .text-md-primary,
.card-md-danger .card-header-md-primary,
.card-md-danger .card-title-md-primary,
.card-md-danger .card-content-md-primary {
  color: #488aff;
}

.card-md-danger .text-md-secondary,
.card-md-danger .card-header-md-secondary,
.card-md-danger .card-title-md-secondary,
.card-md-danger .card-content-md-secondary {
  color: #32db64;
}

.card-md-danger .text-md-danger,
.card-md-danger .card-header-md-danger,
.card-md-danger .card-title-md-danger,
.card-md-danger .card-content-md-danger {
  color: #f53d3d;
}

.card-md-danger .text-md-light,
.card-md-danger .card-header-md-light,
.card-md-danger .card-title-md-light,
.card-md-danger .card-content-md-light {
  color: #f4f4f4;
}

.card-md-danger .text-md-dark,
.card-md-danger .card-header-md-dark,
.card-md-danger .card-title-md-dark,
.card-md-danger .card-content-md-dark {
  color: #222;
}

.card-header-md-danger,
.card-title-md-danger,
.card-content-md-danger {
  color: #f53d3d;
}

.card-md .text-md-light {
  color: #f4f4f4;
}

.card-md-light {
  color: #000;
  background-color: #f4f4f4;
}

.card-md-light .card-header-md,
.card-md-light .card-title-md,
.card-md-light .card-content-md,
.card-md-light h1,
.card-md-light h2,
.card-md-light h3,
.card-md-light h4,
.card-md-light h5,
.card-md-light h6,
.card-md-light p {
  color: #000;
}

.card-md-light .text-md-primary,
.card-md-light .card-header-md-primary,
.card-md-light .card-title-md-primary,
.card-md-light .card-content-md-primary {
  color: #488aff;
}

.card-md-light .text-md-secondary,
.card-md-light .card-header-md-secondary,
.card-md-light .card-title-md-secondary,
.card-md-light .card-content-md-secondary {
  color: #32db64;
}

.card-md-light .text-md-danger,
.card-md-light .card-header-md-danger,
.card-md-light .card-title-md-danger,
.card-md-light .card-content-md-danger {
  color: #f53d3d;
}

.card-md-light .text-md-light,
.card-md-light .card-header-md-light,
.card-md-light .card-title-md-light,
.card-md-light .card-content-md-light {
  color: #f4f4f4;
}

.card-md-light .text-md-dark,
.card-md-light .card-header-md-dark,
.card-md-light .card-title-md-dark,
.card-md-light .card-content-md-dark {
  color: #222;
}

.card-header-md-light,
.card-title-md-light,
.card-content-md-light {
  color: #f4f4f4;
}

.card-md .text-md-dark {
  color: #222;
}

.card-md-dark {
  color: #fff;
  background-color: #222;
}

.card-md-dark .card-header-md,
.card-md-dark .card-title-md,
.card-md-dark .card-content-md,
.card-md-dark h1,
.card-md-dark h2,
.card-md-dark h3,
.card-md-dark h4,
.card-md-dark h5,
.card-md-dark h6,
.card-md-dark p {
  color: #fff;
}

.card-md-dark .text-md-primary,
.card-md-dark .card-header-md-primary,
.card-md-dark .card-title-md-primary,
.card-md-dark .card-content-md-primary {
  color: #488aff;
}

.card-md-dark .text-md-secondary,
.card-md-dark .card-header-md-secondary,
.card-md-dark .card-title-md-secondary,
.card-md-dark .card-content-md-secondary {
  color: #32db64;
}

.card-md-dark .text-md-danger,
.card-md-dark .card-header-md-danger,
.card-md-dark .card-title-md-danger,
.card-md-dark .card-content-md-danger {
  color: #f53d3d;
}

.card-md-dark .text-md-light,
.card-md-dark .card-header-md-light,
.card-md-dark .card-title-md-light,
.card-md-dark .card-content-md-light {
  color: #f4f4f4;
}

.card-md-dark .text-md-dark,
.card-md-dark .card-header-md-dark,
.card-md-dark .card-title-md-dark,
.card-md-dark .card-content-md-dark {
  color: #222;
}

.card-header-md-dark,
.card-title-md-dark,
.card-content-md-dark {
  color: #222;
}

.card-wp {
  margin: 8px;
  border-radius: 1px;
  width: calc(100% - 16px);
  font-size: 1.4rem;
  background: #fff;
  -webkit-box-shadow: 0 1px 1px 1px rgba(0, 0, 0, 0.2);
  box-shadow: 0 1px 1px 1px rgba(0, 0, 0, 0.2);
}

.card-wp ion-list {
  margin-bottom: 0;
}

.card-wp > .item:last-child,
.card-wp > .item:last-child .item-inner,
.card-wp > .item-wrapper:last-child .item {
  border-bottom: 0;
}

.card-wp .item-wp.item-block .item-inner {
  border: 0;
}

.card-content-wp {
  padding: 13px 16px;
  font-size: 1.4rem;
  line-height: 1.5;
}

.card-header-wp {
  font-size: 1.6rem;
  color: #222;
  padding: 16px;
}

.card-header-wp + .card-content-wp,
.card-wp .item + .card-content-wp {
  padding-top: 0;
}

.card .note-wp {
  font-size: 1.3rem;
}

.card-title-wp {
  display: block;
  font-size: 2.4rem;
  line-height: 1.2;
  color: #222;
  margin: 2px 0;
  padding: 8px 0;
}

.card-wp h1 {
  margin: 0 0 2px;
  font-size: 2.4rem;
  font-weight: normal;
  color: #222;
}

.card-wp h2 {
  margin: 2px 0;
  font-size: 1.6rem;
  font-weight: normal;
  color: #222;
}

.card-wp h3,
.card-wp h4,
.card-wp h5,
.card-wp h6 {
  margin: 2px 0;
  font-size: 1.4rem;
  font-weight: normal;
  color: #222;
}

.card-wp p {
  margin: 0 0 2px;
  font-size: 1.4rem;
  font-weight: normal;
  line-height: 1.5;
  color: #222;
}

.card-wp + ion-card {
  margin-top: 0;
}

.card-wp .text-wp-primary {
  color: #488aff;
}

.card-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.card-wp-primary .card-header-wp,
.card-wp-primary .card-title-wp,
.card-wp-primary .card-content-wp,
.card-wp-primary h1,
.card-wp-primary h2,
.card-wp-primary h3,
.card-wp-primary h4,
.card-wp-primary h5,
.card-wp-primary h6,
.card-wp-primary p {
  color: #fff;
}

.card-wp-primary .text-wp-primary,
.card-wp-primary .card-header-wp-primary,
.card-wp-primary .card-title-wp-primary,
.card-wp-primary .card-content-wp-primary {
  color: #488aff;
}

.card-wp-primary .text-wp-secondary,
.card-wp-primary .card-header-wp-secondary,
.card-wp-primary .card-title-wp-secondary,
.card-wp-primary .card-content-wp-secondary {
  color: #32db64;
}

.card-wp-primary .text-wp-danger,
.card-wp-primary .card-header-wp-danger,
.card-wp-primary .card-title-wp-danger,
.card-wp-primary .card-content-wp-danger {
  color: #f53d3d;
}

.card-wp-primary .text-wp-light,
.card-wp-primary .card-header-wp-light,
.card-wp-primary .card-title-wp-light,
.card-wp-primary .card-content-wp-light {
  color: #f4f4f4;
}

.card-wp-primary .text-wp-dark,
.card-wp-primary .card-header-wp-dark,
.card-wp-primary .card-title-wp-dark,
.card-wp-primary .card-content-wp-dark {
  color: #222;
}

.card-header-wp-primary,
.card-title-wp-primary,
.card-content-wp-primary {
  color: #488aff;
}

.card-wp .text-wp-secondary {
  color: #32db64;
}

.card-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.card-wp-secondary .card-header-wp,
.card-wp-secondary .card-title-wp,
.card-wp-secondary .card-content-wp,
.card-wp-secondary h1,
.card-wp-secondary h2,
.card-wp-secondary h3,
.card-wp-secondary h4,
.card-wp-secondary h5,
.card-wp-secondary h6,
.card-wp-secondary p {
  color: #fff;
}

.card-wp-secondary .text-wp-primary,
.card-wp-secondary .card-header-wp-primary,
.card-wp-secondary .card-title-wp-primary,
.card-wp-secondary .card-content-wp-primary {
  color: #488aff;
}

.card-wp-secondary .text-wp-secondary,
.card-wp-secondary .card-header-wp-secondary,
.card-wp-secondary .card-title-wp-secondary,
.card-wp-secondary .card-content-wp-secondary {
  color: #32db64;
}

.card-wp-secondary .text-wp-danger,
.card-wp-secondary .card-header-wp-danger,
.card-wp-secondary .card-title-wp-danger,
.card-wp-secondary .card-content-wp-danger {
  color: #f53d3d;
}

.card-wp-secondary .text-wp-light,
.card-wp-secondary .card-header-wp-light,
.card-wp-secondary .card-title-wp-light,
.card-wp-secondary .card-content-wp-light {
  color: #f4f4f4;
}

.card-wp-secondary .text-wp-dark,
.card-wp-secondary .card-header-wp-dark,
.card-wp-secondary .card-title-wp-dark,
.card-wp-secondary .card-content-wp-dark {
  color: #222;
}

.card-header-wp-secondary,
.card-title-wp-secondary,
.card-content-wp-secondary {
  color: #32db64;
}

.card-wp .text-wp-danger {
  color: #f53d3d;
}

.card-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.card-wp-danger .card-header-wp,
.card-wp-danger .card-title-wp,
.card-wp-danger .card-content-wp,
.card-wp-danger h1,
.card-wp-danger h2,
.card-wp-danger h3,
.card-wp-danger h4,
.card-wp-danger h5,
.card-wp-danger h6,
.card-wp-danger p {
  color: #fff;
}

.card-wp-danger .text-wp-primary,
.card-wp-danger .card-header-wp-primary,
.card-wp-danger .card-title-wp-primary,
.card-wp-danger .card-content-wp-primary {
  color: #488aff;
}

.card-wp-danger .text-wp-secondary,
.card-wp-danger .card-header-wp-secondary,
.card-wp-danger .card-title-wp-secondary,
.card-wp-danger .card-content-wp-secondary {
  color: #32db64;
}

.card-wp-danger .text-wp-danger,
.card-wp-danger .card-header-wp-danger,
.card-wp-danger .card-title-wp-danger,
.card-wp-danger .card-content-wp-danger {
  color: #f53d3d;
}

.card-wp-danger .text-wp-light,
.card-wp-danger .card-header-wp-light,
.card-wp-danger .card-title-wp-light,
.card-wp-danger .card-content-wp-light {
  color: #f4f4f4;
}

.card-wp-danger .text-wp-dark,
.card-wp-danger .card-header-wp-dark,
.card-wp-danger .card-title-wp-dark,
.card-wp-danger .card-content-wp-dark {
  color: #222;
}

.card-header-wp-danger,
.card-title-wp-danger,
.card-content-wp-danger {
  color: #f53d3d;
}

.card-wp .text-wp-light {
  color: #f4f4f4;
}

.card-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.card-wp-light .card-header-wp,
.card-wp-light .card-title-wp,
.card-wp-light .card-content-wp,
.card-wp-light h1,
.card-wp-light h2,
.card-wp-light h3,
.card-wp-light h4,
.card-wp-light h5,
.card-wp-light h6,
.card-wp-light p {
  color: #000;
}

.card-wp-light .text-wp-primary,
.card-wp-light .card-header-wp-primary,
.card-wp-light .card-title-wp-primary,
.card-wp-light .card-content-wp-primary {
  color: #488aff;
}

.card-wp-light .text-wp-secondary,
.card-wp-light .card-header-wp-secondary,
.card-wp-light .card-title-wp-secondary,
.card-wp-light .card-content-wp-secondary {
  color: #32db64;
}

.card-wp-light .text-wp-danger,
.card-wp-light .card-header-wp-danger,
.card-wp-light .card-title-wp-danger,
.card-wp-light .card-content-wp-danger {
  color: #f53d3d;
}

.card-wp-light .text-wp-light,
.card-wp-light .card-header-wp-light,
.card-wp-light .card-title-wp-light,
.card-wp-light .card-content-wp-light {
  color: #f4f4f4;
}

.card-wp-light .text-wp-dark,
.card-wp-light .card-header-wp-dark,
.card-wp-light .card-title-wp-dark,
.card-wp-light .card-content-wp-dark {
  color: #222;
}

.card-header-wp-light,
.card-title-wp-light,
.card-content-wp-light {
  color: #f4f4f4;
}

.card-wp .text-wp-dark {
  color: #222;
}

.card-wp-dark {
  color: #fff;
  background-color: #222;
}

.card-wp-dark .card-header-wp,
.card-wp-dark .card-title-wp,
.card-wp-dark .card-content-wp,
.card-wp-dark h1,
.card-wp-dark h2,
.card-wp-dark h3,
.card-wp-dark h4,
.card-wp-dark h5,
.card-wp-dark h6,
.card-wp-dark p {
  color: #fff;
}

.card-wp-dark .text-wp-primary,
.card-wp-dark .card-header-wp-primary,
.card-wp-dark .card-title-wp-primary,
.card-wp-dark .card-content-wp-primary {
  color: #488aff;
}

.card-wp-dark .text-wp-secondary,
.card-wp-dark .card-header-wp-secondary,
.card-wp-dark .card-title-wp-secondary,
.card-wp-dark .card-content-wp-secondary {
  color: #32db64;
}

.card-wp-dark .text-wp-danger,
.card-wp-dark .card-header-wp-danger,
.card-wp-dark .card-title-wp-danger,
.card-wp-dark .card-content-wp-danger {
  color: #f53d3d;
}

.card-wp-dark .text-wp-light,
.card-wp-dark .card-header-wp-light,
.card-wp-dark .card-title-wp-light,
.card-wp-dark .card-content-wp-light {
  color: #f4f4f4;
}

.card-wp-dark .text-wp-dark,
.card-wp-dark .card-header-wp-dark,
.card-wp-dark .card-title-wp-dark,
.card-wp-dark .card-content-wp-dark {
  color: #222;
}

.card-header-wp-dark,
.card-title-wp-dark,
.card-content-wp-dark {
  color: #222;
}

.checkbox-ios {
  position: relative;
  display: inline-block;
}

.checkbox-ios .checkbox-icon {
  border-radius: 50%;
  position: relative;
  width: 21px;
  height: 21px;
  border-width: 1px;
  border-style: solid;
  border-color: #c8c7cc;
  background-color: #fff;
}

.checkbox-ios .checkbox-checked {
  border-color: #488aff;
  background-color: #488aff;
}

.checkbox-ios .checkbox-checked .checkbox-inner {
  left: 7px;
  top: 4px;
  position: absolute;
  width: 4px;
  height: 9px;
  border-width: 1px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #fff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.checkbox-ios.checkbox-disabled,
.item-ios.item-checkbox-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.item.item-ios .checkbox-ios {
  position: static;
  display: block;
  margin: 8px 16px 8px 2px;
}

.item.item-ios .checkbox-ios[item-right],
.item.item-ios .checkbox-ios[item-end] {
  margin: 10px 8px 9px 0;
}

.checkbox-ios-primary .checkbox-checked {
  border-color: #488aff;
  background-color: #488aff;
}

.checkbox-ios-primary .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-ios-secondary .checkbox-checked {
  border-color: #32db64;
  background-color: #32db64;
}

.checkbox-ios-secondary .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-ios-danger .checkbox-checked {
  border-color: #f53d3d;
  background-color: #f53d3d;
}

.checkbox-ios-danger .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-ios-light .checkbox-checked {
  border-color: #f4f4f4;
  background-color: #f4f4f4;
}

.checkbox-ios-light .checkbox-checked .checkbox-inner {
  border-color: #000;
}

.checkbox-ios-dark .checkbox-checked {
  border-color: #222;
  background-color: #222;
}

.checkbox-ios-dark .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-md {
  position: relative;
  display: inline-block;
}

.checkbox-md .checkbox-icon {
  border-radius: 2px;
  position: relative;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: #787878;
  background-color: #fff;
  -webkit-transition-duration: 280ms;
  transition-duration: 280ms;
  -webkit-transition-property: background;
  transition-property: background;
  -webkit-transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
}

.checkbox-md .checkbox-checked {
  border-color: #488aff;
  background-color: #488aff;
}

.checkbox-md .checkbox-checked .checkbox-inner {
  left: 4px;
  top: 0;
  position: absolute;
  width: 5px;
  height: 10px;
  border-width: 2px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #fff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.checkbox-md.checkbox-disabled,
.item-md.item-checkbox-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.item.item-md .checkbox-md {
  position: static;
  display: block;
  margin: 9px 36px 9px 4px;
}

.item.item-md .checkbox-md[item-right],
.item.item-md .checkbox-md[item-end] {
  margin: 11px 10px 10px 0;
}

.checkbox-md + .item-inner ion-label {
  margin-left: 0;
}

.checkbox-md-primary .checkbox-checked {
  border-color: #488aff;
  background-color: #488aff;
}

.checkbox-md-primary .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-md-secondary .checkbox-checked {
  border-color: #32db64;
  background-color: #32db64;
}

.checkbox-md-secondary .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-md-danger .checkbox-checked {
  border-color: #f53d3d;
  background-color: #f53d3d;
}

.checkbox-md-danger .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-md-light .checkbox-checked {
  border-color: #f4f4f4;
  background-color: #f4f4f4;
}

.checkbox-md-light .checkbox-checked .checkbox-inner {
  border-color: #000;
}

.checkbox-md-dark .checkbox-checked {
  border-color: #222;
  background-color: #222;
}

.checkbox-md-dark .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-wp {
  position: relative;
  display: inline-block;
}

.checkbox-wp .checkbox-icon {
  border-radius: 0;
  position: relative;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: #333;
  background-color: #fff;
}

.checkbox-wp .checkbox-checked {
  border-color: #488aff;
  background-color: #488aff;
}

.checkbox-wp .checkbox-checked .checkbox-inner {
  left: 3px;
  top: -2px;
  position: absolute;
  width: 6px;
  height: 12px;
  border-width: 1px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #fff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.checkbox-wp.checkbox-disabled,
.item-wp.item-checkbox-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.item.item-wp .checkbox-wp {
  position: static;
  display: block;
  margin: 9px 16px 9px 4px;
}

.item.item-wp .checkbox-wp[item-right],
.item.item-wp .checkbox-wp[item-end] {
  margin: 11px 10px 10px 0;
}

.checkbox-wp + .item-inner ion-label {
  margin-left: 0;
}

.checkbox-wp-primary .checkbox-checked {
  border-color: #488aff;
  background-color: #488aff;
}

.checkbox-wp-primary .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-wp-secondary .checkbox-checked {
  border-color: #32db64;
  background-color: #32db64;
}

.checkbox-wp-secondary .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-wp-danger .checkbox-checked {
  border-color: #f53d3d;
  background-color: #f53d3d;
}

.checkbox-wp-danger .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

.checkbox-wp-light .checkbox-checked {
  border-color: #f4f4f4;
  background-color: #f4f4f4;
}

.checkbox-wp-light .checkbox-checked .checkbox-inner {
  border-color: #000;
}

.checkbox-wp-dark .checkbox-checked {
  border-color: #222;
  background-color: #222;
}

.checkbox-wp-dark .checkbox-checked .checkbox-inner {
  border-color: #fff;
}

ion-chip {
  display: -webkit-inline-box;
  display: -webkit-inline-flex;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-align-self: center;
  -ms-flex-item-align: center;
  align-self: center;
  font-weight: normal;
  vertical-align: middle;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

ion-chip .button {
  border-radius: 50%;
  width: 32px;
  height: 32px;
  margin: 0;
}

ion-chip ion-icon {
  text-align: center;
  border-radius: 50%;
  width: 32px;
  height: 32px;
  font-size: 18px;
  line-height: 32px;
}

ion-chip ion-avatar {
  border-radius: 50%;
  width: 32px;
  min-width: 32px;
  height: 32px;
  min-height: 32px;
}

ion-chip ion-avatar img {
  border-radius: 50%;
  display: block;
  width: 100%;
  max-width: 100%;
  height: 100%;
  max-height: 100%;
}

.chip-ios {
  border-radius: 16px;
  height: 32px;
  font-size: 13px;
  line-height: 32px;
  color: rgba(0, 0, 0, 0.87);
  background: rgba(0, 0, 0, 0.12);
  margin: 2px 0;
}

.chip-ios > ion-label {
  margin: 0 10px;
}

.chip-ios > ion-icon {
  color: #fff;
  background-color: #488aff;
}

.chip-ios-primary,
.chip-ios .icon-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.chip-ios-secondary,
.chip-ios .icon-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.chip-ios-danger,
.chip-ios .icon-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.chip-ios-light,
.chip-ios .icon-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.chip-ios-dark,
.chip-ios .icon-ios-dark {
  color: #fff;
  background-color: #222;
}

.chip-md {
  border-radius: 16px;
  height: 32px;
  font-size: 13px;
  line-height: 32px;
  color: rgba(0, 0, 0, 0.87);
  background: rgba(0, 0, 0, 0.12);
  margin: 2px 0;
}

.chip-md > ion-label {
  margin: 0 10px;
}

.chip-md > ion-icon {
  color: #fff;
  background-color: #488aff;
}

.chip-md-primary,
.chip-md .icon-md-primary {
  color: #fff;
  background-color: #488aff;
}

.chip-md-secondary,
.chip-md .icon-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.chip-md-danger,
.chip-md .icon-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.chip-md-light,
.chip-md .icon-md-light {
  color: #000;
  background-color: #f4f4f4;
}

.chip-md-dark,
.chip-md .icon-md-dark {
  color: #fff;
  background-color: #222;
}

.chip-wp {
  border-radius: 16px;
  height: 32px;
  font-size: 13px;
  line-height: 32px;
  color: rgba(0, 0, 0, 0.87);
  background: rgba(0, 0, 0, 0.12);
  margin: 2px 0;
}

.chip-wp > ion-label {
  margin: 0 10px;
}

.chip-wp > ion-icon {
  color: #fff;
  background-color: #488aff;
}

.chip-wp .button {
  border: 0;
}

.chip-wp-primary,
.chip-wp .icon-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.chip-wp-secondary,
.chip-wp .icon-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.chip-wp-danger,
.chip-wp .icon-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.chip-wp-light,
.chip-wp .icon-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.chip-wp-dark,
.chip-wp .icon-wp-dark {
  color: #fff;
  background-color: #222;
}

ion-content {
  left: 0;
  top: 0;
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
  contain: layout size style;
}

.ion-page > ion-content {
  position: absolute;
}

a {
  color: #488aff;
}

.scroll-content {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  z-index: 1;
  display: block;
  overflow-x: hidden;
  overflow-y: scroll;
  -webkit-overflow-scrolling: touch;
  will-change: scroll-position;
  contain: size style layout;
}

ion-content.js-scroll > .scroll-content {
  position: relative;
  min-height: 100%;
  overflow-x: initial;
  overflow-y: initial;
  -webkit-overflow-scrolling: auto;
  will-change: initial;
}

.disable-scroll .ion-page {
  pointer-events: none;
  -ms-touch-action: none;
  touch-action: none;
}

ion-content.has-refresher > .scroll-content {
  background-color: inherit;
}

.fixed-content {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  display: block;
}

[ion-fixed] {
  position: absolute;
  z-index: 999;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

ion-app [no-padding],
ion-app [no-padding] .scroll-content {
  padding: 0;
}

ion-app [no-margin],
ion-app [no-margin] .scroll-content {
  margin: 0;
}

.content-ios {
  color: #000;
  background-color: #fff;
}

.content-ios.outer-content {
  background: #efeff4;
}

.content-ios hr {
  height: 0.55px;
  background-color: rgba(0, 0, 0, 0.12);
}

.ios .ion-page.show-page ~ .nav-decor {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 0;
  display: block;
  width: 100%;
  height: 100%;
  background: #000;
  pointer-events: none;
}

ion-app.ios [padding] {
  padding: 16px;
}

ion-app.ios [padding-top] {
  padding-top: 16px;
}

ion-app.ios [padding-left] {
  padding-left: 16px;
}

ion-app.ios [padding-right] {
  padding-right: 16px;
}

ion-app.ios [padding-bottom] {
  padding-bottom: 16px;
}

ion-app.ios [padding-vertical] {
  padding-top: 16px;
  padding-bottom: 16px;
}

ion-app.ios [padding-horizontal] {
  padding-left: 16px;
  padding-right: 16px;
}

ion-app.ios [padding] .scroll-content {
  padding: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.ios [padding] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-top: 16px;
    padding-bottom: 16px;
    padding: 16px calc(env(safe-area-inset-right) + 16px) 16px calc(env(safe-area-inset-left) + 16px);
  }
}

ion-app.ios [padding-top] .scroll-content {
  padding-top: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.ios [padding-top] .scroll-content {
    padding-top: 16px;
    padding-top: 16px;
  }
}

ion-app.ios [padding-left] .scroll-content {
  padding-left: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.ios [padding-left] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
  }
}

ion-app.ios [padding-right] .scroll-content {
  padding-right: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.ios [padding-right] .scroll-content {
    padding-right: calc(constant(safe-area-inset-right) + 16px);
    padding-right: calc(env(safe-area-inset-right) + 16px);
  }
}

ion-app.ios [padding-bottom] .scroll-content {
  padding-bottom: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.ios [padding-bottom] .scroll-content {
    padding-bottom: 16px;
    padding-bottom: 16px;
  }
}

ion-app.ios [padding-vertical] .scroll-content {
  padding-top: 16px;
  padding-bottom: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.ios [padding-vertical] .scroll-content {
    padding-top: 16px;
    padding-bottom: 16px;
    padding-top: 16px;
    padding-bottom: 16px;
  }
}

ion-app.ios [padding-horizontal] .scroll-content {
  padding-left: 16px;
  padding-right: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.ios [padding-horizontal] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-right: calc(constant(safe-area-inset-right) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
    padding-right: calc(env(safe-area-inset-right) + 16px);
  }
}

ion-app.ios [margin],
ion-app.ios [margin] .scroll-content {
  margin: 16px;
}

ion-app.ios [margin-top],
ion-app.ios [margin-top] .scroll-content {
  margin-top: 16px;
}

ion-app.ios [margin-left],
ion-app.ios [margin-left] .scroll-content {
  margin-left: 16px;
}

ion-app.ios [margin-start],
ion-app.ios [margin-start] .scroll-content {
  margin-left: 16px;
}

ion-app.ios [margin-right],
ion-app.ios [margin-right] .scroll-content {
  margin-right: 16px;
}

ion-app.ios [margin-end],
ion-app.ios [margin-end] .scroll-content {
  margin-right: 16px;
}

ion-app.ios [margin-bottom],
ion-app.ios [margin-bottom] .scroll-content {
  margin-bottom: 16px;
}

ion-app.ios [margin-vertical],
ion-app.ios [margin-vertical] .scroll-content {
  margin-top: 16px;
  margin-bottom: 16px;
}

ion-app.ios [margin-horizontal],
ion-app.ios [margin-horizontal] .scroll-content {
  margin-left: 16px;
  margin-right: 16px;
}

.content-ios:not([no-bounce]) > .scroll-content::before,
.content-ios:not([no-bounce]) > .scroll-content::after {
  position: absolute;
  width: 1px;
  height: 1px;
  content: "";
}

.content-ios:not([no-bounce]) > .scroll-content::before {
  bottom: -1px;
}

.content-ios:not([no-bounce]) > .scroll-content::after {
  top: -1px;
}

.platform-core .content-ios .scroll-content::after,
.platform-core .content-ios .scroll-content::before {
  position: initial;
  top: initial;
  bottom: initial;
  width: initial;
  height: initial;
}

.content-md {
  color: #000;
  background-color: #fff;
}

.content-md hr {
  background-color: rgba(0, 0, 0, 0.08);
}

ion-app.md [padding] {
  padding: 16px;
}

ion-app.md [padding-top] {
  padding-top: 16px;
}

ion-app.md [padding-left] {
  padding-left: 16px;
}

ion-app.md [padding-right] {
  padding-right: 16px;
}

ion-app.md [padding-bottom] {
  padding-bottom: 16px;
}

ion-app.md [padding-vertical] {
  padding-top: 16px;
  padding-bottom: 16px;
}

ion-app.md [padding-horizontal] {
  padding-left: 16px;
  padding-right: 16px;
}

ion-app.md [padding] .scroll-content {
  padding: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.md [padding] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-top: 16px;
    padding-bottom: 16px;
    padding: 16px calc(env(safe-area-inset-right) + 16px) 16px calc(env(safe-area-inset-left) + 16px);
  }
}

ion-app.md [padding-top] .scroll-content {
  padding-top: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.md [padding-top] .scroll-content {
    padding-top: 16px;
    padding-top: 16px;
  }
}

ion-app.md [padding-left] .scroll-content {
  padding-left: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.md [padding-left] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
  }
}

ion-app.md [padding-right] .scroll-content {
  padding-right: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.md [padding-right] .scroll-content {
    padding-right: calc(constant(safe-area-inset-right) + 16px);
    padding-right: calc(env(safe-area-inset-right) + 16px);
  }
}

ion-app.md [padding-bottom] .scroll-content {
  padding-bottom: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.md [padding-bottom] .scroll-content {
    padding-bottom: 16px;
    padding-bottom: 16px;
  }
}

ion-app.md [padding-vertical] .scroll-content {
  padding-top: 16px;
  padding-bottom: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.md [padding-vertical] .scroll-content {
    padding-top: 16px;
    padding-bottom: 16px;
    padding-top: 16px;
    padding-bottom: 16px;
  }
}

ion-app.md [padding-horizontal] .scroll-content {
  padding-left: 16px;
  padding-right: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.md [padding-horizontal] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-right: calc(constant(safe-area-inset-right) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
    padding-right: calc(env(safe-area-inset-right) + 16px);
  }
}

ion-app.md [margin],
ion-app.md [margin] .scroll-content {
  margin: 16px;
}

ion-app.md [margin-top],
ion-app.md [margin-top] .scroll-content {
  margin-top: 16px;
}

ion-app.md [margin-left],
ion-app.md [margin-left] .scroll-content {
  margin-left: 16px;
}

ion-app.md [margin-start],
ion-app.md [margin-start] .scroll-content {
  margin-left: 16px;
}

ion-app.md [margin-right],
ion-app.md [margin-right] .scroll-content {
  margin-right: 16px;
}

ion-app.md [margin-end],
ion-app.md [margin-end] .scroll-content {
  margin-right: 16px;
}

ion-app.md [margin-bottom],
ion-app.md [margin-bottom] .scroll-content {
  margin-bottom: 16px;
}

ion-app.md [margin-vertical],
ion-app.md [margin-vertical] .scroll-content {
  margin-top: 16px;
  margin-bottom: 16px;
}

ion-app.md [margin-horizontal],
ion-app.md [margin-horizontal] .scroll-content {
  margin-left: 16px;
  margin-right: 16px;
}

.content-wp {
  color: #000;
  background-color: #fff;
}

.content-wp hr {
  background-color: rgba(0, 0, 0, 0.08);
}

ion-app.wp [padding] {
  padding: 16px;
}

ion-app.wp [padding-top] {
  padding-top: 16px;
}

ion-app.wp [padding-left] {
  padding-left: 16px;
}

ion-app.wp [padding-right] {
  padding-right: 16px;
}

ion-app.wp [padding-bottom] {
  padding-bottom: 16px;
}

ion-app.wp [padding-vertical] {
  padding-top: 16px;
  padding-bottom: 16px;
}

ion-app.wp [padding-horizontal] {
  padding-left: 16px;
  padding-right: 16px;
}

ion-app.wp [padding] .scroll-content {
  padding: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.wp [padding] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-top: 16px;
    padding-bottom: 16px;
    padding: 16px calc(env(safe-area-inset-right) + 16px) 16px calc(env(safe-area-inset-left) + 16px);
  }
}

ion-app.wp [padding-top] .scroll-content {
  padding-top: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.wp [padding-top] .scroll-content {
    padding-top: 16px;
    padding-top: 16px;
  }
}

ion-app.wp [padding-left] .scroll-content {
  padding-left: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.wp [padding-left] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
  }
}

ion-app.wp [padding-right] .scroll-content {
  padding-right: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.wp [padding-right] .scroll-content {
    padding-right: calc(constant(safe-area-inset-right) + 16px);
    padding-right: calc(env(safe-area-inset-right) + 16px);
  }
}

ion-app.wp [padding-bottom] .scroll-content {
  padding-bottom: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.wp [padding-bottom] .scroll-content {
    padding-bottom: 16px;
    padding-bottom: 16px;
  }
}

ion-app.wp [padding-vertical] .scroll-content {
  padding-top: 16px;
  padding-bottom: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.wp [padding-vertical] .scroll-content {
    padding-top: 16px;
    padding-bottom: 16px;
    padding-top: 16px;
    padding-bottom: 16px;
  }
}

ion-app.wp [padding-horizontal] .scroll-content {
  padding-left: 16px;
  padding-right: 16px;
}

@media screen and (orientation: landscape) {
  ion-app.wp [padding-horizontal] .scroll-content {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-right: calc(constant(safe-area-inset-right) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
    padding-right: calc(env(safe-area-inset-right) + 16px);
  }
}

ion-app.wp [margin],
ion-app.wp [margin] .scroll-content {
  margin: 16px;
}

ion-app.wp [margin-top],
ion-app.wp [margin-top] .scroll-content {
  margin-top: 16px;
}

ion-app.wp [margin-left],
ion-app.wp [margin-left] .scroll-content {
  margin-left: 16px;
}

ion-app.wp [margin-start],
ion-app.wp [margin-start] .scroll-content {
  margin-left: 16px;
}

ion-app.wp [margin-right],
ion-app.wp [margin-right] .scroll-content {
  margin-right: 16px;
}

ion-app.wp [margin-end],
ion-app.wp [margin-end] .scroll-content {
  margin-right: 16px;
}

ion-app.wp [margin-bottom],
ion-app.wp [margin-bottom] .scroll-content {
  margin-bottom: 16px;
}

ion-app.wp [margin-vertical],
ion-app.wp [margin-vertical] .scroll-content {
  margin-top: 16px;
  margin-bottom: 16px;
}

ion-app.wp [margin-horizontal],
ion-app.wp [margin-horizontal] .scroll-content {
  margin-left: 16px;
  margin-right: 16px;
}

ion-datetime {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
}

.datetime-text {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 16px;
  min-height: 1.2em;
  font-size: inherit;
  line-height: 1.2;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.datetime-disabled,
.item-datetime-disabled ion-label {
  opacity: .4;
  pointer-events: none;
}

.item-label-stacked ion-datetime,
.item-label-floating ion-datetime {
  padding-left: 0;
  width: 100%;
}

.datetime-ios {
  padding: 11px 8px 11px 16px;
}

.datetime-ios .datetime-placeholder {
  color: #999;
}

.datetime-md {
  padding: 13px 8px 13px 16px;
}

.datetime-md .datetime-placeholder {
  color: #999;
}

.datetime-wp {
  padding: 13px 8px 13px 16px;
  min-width: 45%;
}

.datetime-wp .datetime-text {
  padding: 0 8px;
  min-height: 3.4rem;
  border: 2px solid rgba(0, 0, 0, 0.5);
  line-height: 3rem;
}

.item-datetime .datetime-wp ion-label[floating] {
  -webkit-transform: translate3d(8px,  41px,  0);
  transform: translate3d(8px,  41px,  0);
}

.datetime-wp .datetime-placeholder {
  color: rgba(0, 0, 0, 0.5);
}

.fab {
  text-align: center;
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  border-radius: 50%;
  position: relative;
  z-index: 0;
  display: block;
  overflow: hidden;
  width: 56px;
  height: 56px;
  font-size: 14px;
  line-height: 56px;
  text-overflow: ellipsis;
  text-transform: none;
  white-space: nowrap;
  cursor: pointer;
  -webkit-transition: background-color, opacity 100ms linear;
  transition: background-color, opacity 100ms linear;
  background-clip: padding-box;
  -webkit-font-kerning: none;
  font-kerning: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  contain: strict;
}

.fab ion-icon {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  font-size: 2.4rem;
}

.fab[mini] {
  margin: 8px;
  width: 40px;
  height: 40px;
  line-height: 40px;
}

.fab[mini] .fab-close-icon {
  line-height: 40px;
}

ion-fab {
  position: absolute;
  z-index: 999;
}

ion-fab[center] {
  left: 50%;
  margin-left: -28px;
}

ion-fab[middle] {
  margin-top: -28px;
  top: 50%;
}

ion-fab[top] {
  top: 10px;
}

ion-fab[right] {
  right: 10px;
  right: calc(10px + constant(safe-area-inset-right));
  right: calc(10px + env(safe-area-inset-right));
}

ion-fab[end] {
  right: 10px;
  right: calc(constant(safe-area-inset-right) + 10px);
  right: calc(env(safe-area-inset-right) + 10px);
}

ion-fab[bottom] {
  bottom: 10px;
}

ion-fab[left] {
  left: 10px;
  left: calc(10px + constant(safe-area-inset-left));
  left: calc(10px + env(safe-area-inset-left));
}

ion-fab[start] {
  left: 10px;
  left: calc(constant(safe-area-inset-left) + 10px);
  left: calc(env(safe-area-inset-left) + 10px);
}

ion-fab[top][edge] {
  top: -28px;
}

ion-fab[bottom][edge] {
  bottom: -28px;
}

ion-fab-list {
  margin: 66px 0;
  position: absolute;
  top: 0;
  display: none;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  min-width: 56px;
  min-height: 56px;
}

.fab-in-list {
  margin: 8px 0;
  width: 40px;
  height: 40px;
  opacity: 0;
  visibility: hidden;
  -webkit-transform: scale(0);
  transform: scale(0);
}

.fab-in-list.show {
  opacity: 1;
  visibility: visible;
  -webkit-transform: scale(1);
  transform: scale(1);
}

ion-fab-list[side=left] .fab-in-list,
ion-fab-list[side=right] .fab-in-list {
  margin: 0 8px;
}

ion-fab-list[side=top] {
  top: auto;
  bottom: 0;
  -webkit-box-orient: vertical;
  -webkit-box-direction: reverse;
  -webkit-flex-direction: column-reverse;
  -ms-flex-direction: column-reverse;
  flex-direction: column-reverse;
}

ion-fab-list[side=left] {
  margin: 0 66px;
  right: 0;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: reverse;
  -webkit-flex-direction: row-reverse;
  -ms-flex-direction: row-reverse;
  flex-direction: row-reverse;
}

ion-fab-list[side=right] {
  margin: 0 66px;
  left: 0;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
}

.fab-list-active {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.fab-close-icon {
  left: 0;
  right: 0;
  top: 0;
  position: absolute;
  line-height: 56px;
  opacity: 0;
  -webkit-transform: scale(0.4) rotateZ(-45deg);
  transform: scale(0.4) rotateZ(-45deg);
  -webkit-transition: all ease-in-out 300ms;
  transition: all ease-in-out 300ms;
  -webkit-transition-property: opacity, -webkit-transform;
  transition-property: opacity, -webkit-transform;
  transition-property: transform, opacity;
  transition-property: transform, opacity, -webkit-transform;
}

.fab .button-inner {
  -webkit-transition: all ease-in-out 300ms;
  transition: all ease-in-out 300ms;
  -webkit-transition-property: opacity, -webkit-transform;
  transition-property: opacity, -webkit-transform;
  transition-property: transform, opacity;
  transition-property: transform, opacity, -webkit-transform;
}

.fab-close-active .fab-close-icon {
  opacity: 1;
  -webkit-transform: scale(1) rotateZ(0deg);
  transform: scale(1) rotateZ(0deg);
}

.fab-close-active .button-inner {
  opacity: 0;
  -webkit-transform: scale(0.4) rotateZ(45deg);
  transform: scale(0.4) rotateZ(45deg);
}

.fab-ios {
  color: #fff;
  background-color: #488aff;
}

.fab-ios.activated {
  background-color: #427feb;
}

.fab-ios-in-list {
  color: #000;
  background-color: #f4f4f4;
  -webkit-transition: opacity 200ms ease 10ms, -webkit-transform 200ms ease 10ms;
  transition: opacity 200ms ease 10ms, -webkit-transform 200ms ease 10ms;
  transition: transform 200ms ease 10ms, opacity 200ms ease 10ms;
  transition: transform 200ms ease 10ms, opacity 200ms ease 10ms, -webkit-transform 200ms ease 10ms;
}

.fab-ios-in-list.activated {
  background-color: #e0e0e0;
}

.fab-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.fab-ios-primary.activated {
  background-color: #427feb;
}

.fab-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.fab-ios-secondary.activated {
  background-color: #2ec95c;
}

.fab-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.fab-ios-danger.activated {
  background-color: #e13838;
}

.fab-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.fab-ios-light.activated {
  background-color: #e0e0e0;
}

.fab-ios-dark {
  color: #fff;
  background-color: #222;
}

.fab-ios-dark.activated {
  background-color: #343434;
}

.fab-md {
  color: #fff;
  background-color: #488aff;
  -webkit-box-shadow: 0 4px 6px 0 rgba(0, 0, 0, 0.14), 0 4px 5px rgba(0, 0, 0, 0.1);
  box-shadow: 0 4px 6px 0 rgba(0, 0, 0, 0.14), 0 4px 5px rgba(0, 0, 0, 0.1);
  -webkit-transition: background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1), background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1), background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
}

.fab-md.activated {
  background-color: #427feb;
  -webkit-box-shadow: 0 5px 15px 0 rgba(0, 0, 0, 0.4), 0 4px 7px 0 rgba(0, 0, 0, 0.1);
  box-shadow: 0 5px 15px 0 rgba(0, 0, 0, 0.4), 0 4px 7px 0 rgba(0, 0, 0, 0.1);
}

.fab-md-in-list {
  color: #000;
  background-color: #f4f4f4;
  -webkit-transition: opacity 200ms ease 10ms, background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-transform 200ms ease 10ms, -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: opacity 200ms ease 10ms, background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-transform 200ms ease 10ms, -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: transform 200ms ease 10ms, opacity 200ms ease 10ms, box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1), background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: transform 200ms ease 10ms, opacity 200ms ease 10ms, box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1), background-color 300ms cubic-bezier(0.4, 0, 0.2, 1), color 300ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-transform 200ms ease 10ms, -webkit-box-shadow 300ms cubic-bezier(0.4, 0, 0.2, 1);
}

.fab-md-in-list.activated {
  background-color: #e0e0e0;
}

.fab-md .button-effect {
  background-color: #fff;
}

.fab-md-primary {
  color: #fff;
  background-color: #488aff;
}

.fab-md-primary.activated {
  background-color: #427feb;
}

.fab-md-primary .button-effect {
  background-color: #fff;
}

.fab-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.fab-md-secondary.activated {
  background-color: #2ec95c;
}

.fab-md-secondary .button-effect {
  background-color: #fff;
}

.fab-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.fab-md-danger.activated {
  background-color: #e13838;
}

.fab-md-danger .button-effect {
  background-color: #fff;
}

.fab-md-light {
  color: #000;
  background-color: #f4f4f4;
}

.fab-md-light.activated {
  background-color: #e0e0e0;
}

.fab-md-light .button-effect {
  background-color: #000;
}

.fab-md-dark {
  color: #fff;
  background-color: #222;
}

.fab-md-dark.activated {
  background-color: #343434;
}

.fab-md-dark .button-effect {
  background-color: #fff;
}

.fab-wp {
  color: #fff;
  background-color: #488aff;
}

.fab-wp.activated {
  background-color: #427feb;
}

.fab-wp-in-list {
  color: #000;
  background-color: #f4f4f4;
  -webkit-transition: opacity 200ms ease 10ms, -webkit-transform 200ms ease 10ms;
  transition: opacity 200ms ease 10ms, -webkit-transform 200ms ease 10ms;
  transition: transform 200ms ease 10ms, opacity 200ms ease 10ms;
  transition: transform 200ms ease 10ms, opacity 200ms ease 10ms, -webkit-transform 200ms ease 10ms;
}

.fab-wp-in-list.activated {
  background-color: #e0e0e0;
}

.fab-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.fab-wp-primary.activated {
  background-color: #427feb;
}

.fab-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.fab-wp-secondary.activated {
  background-color: #2ec95c;
}

.fab-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.fab-wp-danger.activated {
  background-color: #e13838;
}

.fab-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.fab-wp-light.activated {
  background-color: #e0e0e0;
}

.fab-wp-dark {
  color: #fff;
  background-color: #222;
}

.fab-wp-dark.activated {
  background-color: #343434;
}

.grid {
  padding: 5px;
  margin-left: auto;
  margin-right: auto;
  width: 100%;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

.grid[no-padding] {
  padding: 0;
}

.grid[no-padding] > .row > .col {
  padding: 0;
}

@media (min-width: 576px) {
  .grid[fixed] {
    width: 540px;
    max-width: 100%;
  }
}

@media (min-width: 768px) {
  .grid[fixed] {
    width: 720px;
    max-width: 100%;
  }
}

@media (min-width: 992px) {
  .grid[fixed] {
    width: 960px;
    max-width: 100%;
  }
}

@media (min-width: 1200px) {
  .grid[fixed] {
    width: 1140px;
    max-width: 100%;
  }
}

.row {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.row[nowrap] {
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
}

.row[wrap-reverse] {
  -webkit-flex-wrap: wrap-reverse;
  -ms-flex-wrap: wrap-reverse;
  flex-wrap: wrap-reverse;
}

.row[align-items-start] {
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

.row[align-items-center] {
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.row[align-items-end] {
  -webkit-box-align: end;
  -webkit-align-items: flex-end;
  -ms-flex-align: end;
  align-items: flex-end;
}

.row[align-items-stretch] {
  -webkit-box-align: stretch;
  -webkit-align-items: stretch;
  -ms-flex-align: stretch;
  align-items: stretch;
}

.row[align-items-baseline] {
  -webkit-box-align: baseline;
  -webkit-align-items: baseline;
  -ms-flex-align: baseline;
  align-items: baseline;
}

.row[justify-content-start] {
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

.row[justify-content-center] {
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

.row[justify-content-end] {
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

.row[justify-content-around] {
  -webkit-justify-content: space-around;
  -ms-flex-pack: distribute;
  justify-content: space-around;
}

.row[justify-content-between] {
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
}

.col {
  padding: 5px;
  position: relative;
  width: 100%;
  margin: 0;
  min-height: 1px;
  -webkit-flex-basis: 0;
  -ms-flex-preferred-size: 0;
  flex-basis: 0;
  -webkit-box-flex: 1;
  -webkit-flex-grow: 1;
  -ms-flex-positive: 1;
  flex-grow: 1;
  max-width: 100%;
}

.col[align-self-start] {
  -webkit-align-self: flex-start;
  -ms-flex-item-align: start;
  align-self: flex-start;
}

.col[align-self-end] {
  -webkit-align-self: flex-end;
  -ms-flex-item-align: end;
  align-self: flex-end;
}

.col[align-self-center] {
  -webkit-align-self: center;
  -ms-flex-item-align: center;
  align-self: center;
}

.col[align-self-stretch] {
  -webkit-align-self: stretch;
  -ms-flex-item-align: stretch;
  align-self: stretch;
}

.col[align-self-baseline] {
  -webkit-align-self: baseline;
  -ms-flex-item-align: baseline;
  align-self: baseline;
}

[col-1] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-1] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-1] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-1] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-1] {
    padding: 5px;
  }
}

[col-2] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-2] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-2] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-2] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-2] {
    padding: 5px;
  }
}

[col-3] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-3] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-3] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-3] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-3] {
    padding: 5px;
  }
}

[col-4] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-4] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-4] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-4] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-4] {
    padding: 5px;
  }
}

[col-5] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-5] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-5] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-5] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-5] {
    padding: 5px;
  }
}

[col-6] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-6] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-6] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-6] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-6] {
    padding: 5px;
  }
}

[col-7] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-7] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-7] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-7] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-7] {
    padding: 5px;
  }
}

[col-8] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-8] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-8] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-8] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-8] {
    padding: 5px;
  }
}

[col-9] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-9] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-9] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-9] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-9] {
    padding: 5px;
  }
}

[col-10] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-10] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-10] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-10] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-10] {
    padding: 5px;
  }
}

[col-11] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-11] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-11] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-11] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-11] {
    padding: 5px;
  }
}

[col-12] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-12] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-12] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-12] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-12] {
    padding: 5px;
  }
}

[col] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col] {
    padding: 5px;
  }
}

[col] {
  -webkit-flex-basis: 0;
  -ms-flex-preferred-size: 0;
  flex-basis: 0;
  -webkit-box-flex: 1;
  -webkit-flex-grow: 1;
  -ms-flex-positive: 1;
  flex-grow: 1;
  max-width: 100%;
}

[col-auto] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 auto;
  -ms-flex: 0 0 auto;
  flex: 0 0 auto;
  width: auto;
}

[col-1] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 8.33333%;
  -ms-flex: 0 0 8.33333%;
  flex: 0 0 8.33333%;
  width: 8.33333%;
  max-width: 8.33333%;
}

[col-2] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 16.66667%;
  -ms-flex: 0 0 16.66667%;
  flex: 0 0 16.66667%;
  width: 16.66667%;
  max-width: 16.66667%;
}

[col-3] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 25%;
  -ms-flex: 0 0 25%;
  flex: 0 0 25%;
  width: 25%;
  max-width: 25%;
}

[col-4] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 33.33333%;
  -ms-flex: 0 0 33.33333%;
  flex: 0 0 33.33333%;
  width: 33.33333%;
  max-width: 33.33333%;
}

[col-5] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 41.66667%;
  -ms-flex: 0 0 41.66667%;
  flex: 0 0 41.66667%;
  width: 41.66667%;
  max-width: 41.66667%;
}

[col-6] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 50%;
  -ms-flex: 0 0 50%;
  flex: 0 0 50%;
  width: 50%;
  max-width: 50%;
}

[col-7] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 58.33333%;
  -ms-flex: 0 0 58.33333%;
  flex: 0 0 58.33333%;
  width: 58.33333%;
  max-width: 58.33333%;
}

[col-8] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 66.66667%;
  -ms-flex: 0 0 66.66667%;
  flex: 0 0 66.66667%;
  width: 66.66667%;
  max-width: 66.66667%;
}

[col-9] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 75%;
  -ms-flex: 0 0 75%;
  flex: 0 0 75%;
  width: 75%;
  max-width: 75%;
}

[col-10] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 83.33333%;
  -ms-flex: 0 0 83.33333%;
  flex: 0 0 83.33333%;
  width: 83.33333%;
  max-width: 83.33333%;
}

[col-11] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 91.66667%;
  -ms-flex: 0 0 91.66667%;
  flex: 0 0 91.66667%;
  width: 91.66667%;
  max-width: 91.66667%;
}

[col-12] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 100%;
  -ms-flex: 0 0 100%;
  flex: 0 0 100%;
  width: 100%;
  max-width: 100%;
}

[pull-0] {
  right: auto;
}

[pull-1] {
  right: 8.33333%;
}

[pull-2] {
  right: 16.66667%;
}

[pull-3] {
  right: 25%;
}

[pull-4] {
  right: 33.33333%;
}

[pull-5] {
  right: 41.66667%;
}

[pull-6] {
  right: 50%;
}

[pull-7] {
  right: 58.33333%;
}

[pull-8] {
  right: 66.66667%;
}

[pull-9] {
  right: 75%;
}

[pull-10] {
  right: 83.33333%;
}

[pull-11] {
  right: 91.66667%;
}

[pull-12] {
  right: 100%;
}

[push-0] {
  left: auto;
}

[push-1] {
  left: 8.33333%;
}

[push-2] {
  left: 16.66667%;
}

[push-3] {
  left: 25%;
}

[push-4] {
  left: 33.33333%;
}

[push-5] {
  left: 41.66667%;
}

[push-6] {
  left: 50%;
}

[push-7] {
  left: 58.33333%;
}

[push-8] {
  left: 66.66667%;
}

[push-9] {
  left: 75%;
}

[push-10] {
  left: 83.33333%;
}

[push-11] {
  left: 91.66667%;
}

[push-12] {
  left: 100%;
}

[offset-1] {
  margin-left: 8.33333%;
}

[offset-2] {
  margin-left: 16.66667%;
}

[offset-3] {
  margin-left: 25%;
}

[offset-4] {
  margin-left: 33.33333%;
}

[offset-5] {
  margin-left: 41.66667%;
}

[offset-6] {
  margin-left: 50%;
}

[offset-7] {
  margin-left: 58.33333%;
}

[offset-8] {
  margin-left: 66.66667%;
}

[offset-9] {
  margin-left: 75%;
}

[offset-10] {
  margin-left: 83.33333%;
}

[offset-11] {
  margin-left: 91.66667%;
}

[col-sm-1] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-1] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-1] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-1] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-1] {
    padding: 5px;
  }
}

[col-sm-2] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-2] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-2] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-2] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-2] {
    padding: 5px;
  }
}

[col-sm-3] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-3] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-3] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-3] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-3] {
    padding: 5px;
  }
}

[col-sm-4] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-4] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-4] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-4] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-4] {
    padding: 5px;
  }
}

[col-sm-5] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-5] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-5] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-5] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-5] {
    padding: 5px;
  }
}

[col-sm-6] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-6] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-6] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-6] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-6] {
    padding: 5px;
  }
}

[col-sm-7] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-7] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-7] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-7] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-7] {
    padding: 5px;
  }
}

[col-sm-8] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-8] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-8] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-8] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-8] {
    padding: 5px;
  }
}

[col-sm-9] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-9] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-9] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-9] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-9] {
    padding: 5px;
  }
}

[col-sm-10] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-10] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-10] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-10] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-10] {
    padding: 5px;
  }
}

[col-sm-11] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-11] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-11] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-11] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-11] {
    padding: 5px;
  }
}

[col-sm-12] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm-12] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm-12] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm-12] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm-12] {
    padding: 5px;
  }
}

[col-sm] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-sm] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-sm] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-sm] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-sm] {
    padding: 5px;
  }
}

@media (min-width: 576px) {
  [col-sm] {
    -webkit-flex-basis: 0;
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    -webkit-box-flex: 1;
    -webkit-flex-grow: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    max-width: 100%;
  }
  [col-sm-auto] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 auto;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    width: auto;
  }
  [col-sm-1] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 8.33333%;
    -ms-flex: 0 0 8.33333%;
    flex: 0 0 8.33333%;
    width: 8.33333%;
    max-width: 8.33333%;
  }
  [col-sm-2] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 16.66667%;
    -ms-flex: 0 0 16.66667%;
    flex: 0 0 16.66667%;
    width: 16.66667%;
    max-width: 16.66667%;
  }
  [col-sm-3] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 25%;
    -ms-flex: 0 0 25%;
    flex: 0 0 25%;
    width: 25%;
    max-width: 25%;
  }
  [col-sm-4] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 33.33333%;
    -ms-flex: 0 0 33.33333%;
    flex: 0 0 33.33333%;
    width: 33.33333%;
    max-width: 33.33333%;
  }
  [col-sm-5] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 41.66667%;
    -ms-flex: 0 0 41.66667%;
    flex: 0 0 41.66667%;
    width: 41.66667%;
    max-width: 41.66667%;
  }
  [col-sm-6] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 50%;
    -ms-flex: 0 0 50%;
    flex: 0 0 50%;
    width: 50%;
    max-width: 50%;
  }
  [col-sm-7] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 58.33333%;
    -ms-flex: 0 0 58.33333%;
    flex: 0 0 58.33333%;
    width: 58.33333%;
    max-width: 58.33333%;
  }
  [col-sm-8] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 66.66667%;
    -ms-flex: 0 0 66.66667%;
    flex: 0 0 66.66667%;
    width: 66.66667%;
    max-width: 66.66667%;
  }
  [col-sm-9] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 75%;
    -ms-flex: 0 0 75%;
    flex: 0 0 75%;
    width: 75%;
    max-width: 75%;
  }
  [col-sm-10] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 83.33333%;
    -ms-flex: 0 0 83.33333%;
    flex: 0 0 83.33333%;
    width: 83.33333%;
    max-width: 83.33333%;
  }
  [col-sm-11] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 91.66667%;
    -ms-flex: 0 0 91.66667%;
    flex: 0 0 91.66667%;
    width: 91.66667%;
    max-width: 91.66667%;
  }
  [col-sm-12] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 100%;
    -ms-flex: 0 0 100%;
    flex: 0 0 100%;
    width: 100%;
    max-width: 100%;
  }
  [pull-sm-0] {
    right: auto;
  }
  [pull-sm-1] {
    right: 8.33333%;
  }
  [pull-sm-2] {
    right: 16.66667%;
  }
  [pull-sm-3] {
    right: 25%;
  }
  [pull-sm-4] {
    right: 33.33333%;
  }
  [pull-sm-5] {
    right: 41.66667%;
  }
  [pull-sm-6] {
    right: 50%;
  }
  [pull-sm-7] {
    right: 58.33333%;
  }
  [pull-sm-8] {
    right: 66.66667%;
  }
  [pull-sm-9] {
    right: 75%;
  }
  [pull-sm-10] {
    right: 83.33333%;
  }
  [pull-sm-11] {
    right: 91.66667%;
  }
  [pull-sm-12] {
    right: 100%;
  }
  [push-sm-0] {
    left: auto;
  }
  [push-sm-1] {
    left: 8.33333%;
  }
  [push-sm-2] {
    left: 16.66667%;
  }
  [push-sm-3] {
    left: 25%;
  }
  [push-sm-4] {
    left: 33.33333%;
  }
  [push-sm-5] {
    left: 41.66667%;
  }
  [push-sm-6] {
    left: 50%;
  }
  [push-sm-7] {
    left: 58.33333%;
  }
  [push-sm-8] {
    left: 66.66667%;
  }
  [push-sm-9] {
    left: 75%;
  }
  [push-sm-10] {
    left: 83.33333%;
  }
  [push-sm-11] {
    left: 91.66667%;
  }
  [push-sm-12] {
    left: 100%;
  }
  [offset-sm-0] {
    margin-left: 0%;
  }
  [offset-sm-1] {
    margin-left: 8.33333%;
  }
  [offset-sm-2] {
    margin-left: 16.66667%;
  }
  [offset-sm-3] {
    margin-left: 25%;
  }
  [offset-sm-4] {
    margin-left: 33.33333%;
  }
  [offset-sm-5] {
    margin-left: 41.66667%;
  }
  [offset-sm-6] {
    margin-left: 50%;
  }
  [offset-sm-7] {
    margin-left: 58.33333%;
  }
  [offset-sm-8] {
    margin-left: 66.66667%;
  }
  [offset-sm-9] {
    margin-left: 75%;
  }
  [offset-sm-10] {
    margin-left: 83.33333%;
  }
  [offset-sm-11] {
    margin-left: 91.66667%;
  }
}

[col-md-1] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-1] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-1] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-1] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-1] {
    padding: 5px;
  }
}

[col-md-2] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-2] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-2] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-2] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-2] {
    padding: 5px;
  }
}

[col-md-3] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-3] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-3] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-3] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-3] {
    padding: 5px;
  }
}

[col-md-4] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-4] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-4] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-4] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-4] {
    padding: 5px;
  }
}

[col-md-5] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-5] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-5] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-5] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-5] {
    padding: 5px;
  }
}

[col-md-6] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-6] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-6] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-6] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-6] {
    padding: 5px;
  }
}

[col-md-7] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-7] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-7] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-7] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-7] {
    padding: 5px;
  }
}

[col-md-8] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-8] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-8] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-8] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-8] {
    padding: 5px;
  }
}

[col-md-9] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-9] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-9] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-9] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-9] {
    padding: 5px;
  }
}

[col-md-10] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-10] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-10] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-10] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-10] {
    padding: 5px;
  }
}

[col-md-11] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-11] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-11] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-11] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-11] {
    padding: 5px;
  }
}

[col-md-12] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md-12] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md-12] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md-12] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md-12] {
    padding: 5px;
  }
}

[col-md] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-md] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-md] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-md] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-md] {
    -webkit-flex-basis: 0;
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    -webkit-box-flex: 1;
    -webkit-flex-grow: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    max-width: 100%;
  }
  [col-md-auto] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 auto;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    width: auto;
  }
  [col-md-1] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 8.33333%;
    -ms-flex: 0 0 8.33333%;
    flex: 0 0 8.33333%;
    width: 8.33333%;
    max-width: 8.33333%;
  }
  [col-md-2] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 16.66667%;
    -ms-flex: 0 0 16.66667%;
    flex: 0 0 16.66667%;
    width: 16.66667%;
    max-width: 16.66667%;
  }
  [col-md-3] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 25%;
    -ms-flex: 0 0 25%;
    flex: 0 0 25%;
    width: 25%;
    max-width: 25%;
  }
  [col-md-4] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 33.33333%;
    -ms-flex: 0 0 33.33333%;
    flex: 0 0 33.33333%;
    width: 33.33333%;
    max-width: 33.33333%;
  }
  [col-md-5] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 41.66667%;
    -ms-flex: 0 0 41.66667%;
    flex: 0 0 41.66667%;
    width: 41.66667%;
    max-width: 41.66667%;
  }
  [col-md-6] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 50%;
    -ms-flex: 0 0 50%;
    flex: 0 0 50%;
    width: 50%;
    max-width: 50%;
  }
  [col-md-7] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 58.33333%;
    -ms-flex: 0 0 58.33333%;
    flex: 0 0 58.33333%;
    width: 58.33333%;
    max-width: 58.33333%;
  }
  [col-md-8] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 66.66667%;
    -ms-flex: 0 0 66.66667%;
    flex: 0 0 66.66667%;
    width: 66.66667%;
    max-width: 66.66667%;
  }
  [col-md-9] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 75%;
    -ms-flex: 0 0 75%;
    flex: 0 0 75%;
    width: 75%;
    max-width: 75%;
  }
  [col-md-10] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 83.33333%;
    -ms-flex: 0 0 83.33333%;
    flex: 0 0 83.33333%;
    width: 83.33333%;
    max-width: 83.33333%;
  }
  [col-md-11] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 91.66667%;
    -ms-flex: 0 0 91.66667%;
    flex: 0 0 91.66667%;
    width: 91.66667%;
    max-width: 91.66667%;
  }
  [col-md-12] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 100%;
    -ms-flex: 0 0 100%;
    flex: 0 0 100%;
    width: 100%;
    max-width: 100%;
  }
  [pull-md-0] {
    right: auto;
  }
  [pull-md-1] {
    right: 8.33333%;
  }
  [pull-md-2] {
    right: 16.66667%;
  }
  [pull-md-3] {
    right: 25%;
  }
  [pull-md-4] {
    right: 33.33333%;
  }
  [pull-md-5] {
    right: 41.66667%;
  }
  [pull-md-6] {
    right: 50%;
  }
  [pull-md-7] {
    right: 58.33333%;
  }
  [pull-md-8] {
    right: 66.66667%;
  }
  [pull-md-9] {
    right: 75%;
  }
  [pull-md-10] {
    right: 83.33333%;
  }
  [pull-md-11] {
    right: 91.66667%;
  }
  [pull-md-12] {
    right: 100%;
  }
  [push-md-0] {
    left: auto;
  }
  [push-md-1] {
    left: 8.33333%;
  }
  [push-md-2] {
    left: 16.66667%;
  }
  [push-md-3] {
    left: 25%;
  }
  [push-md-4] {
    left: 33.33333%;
  }
  [push-md-5] {
    left: 41.66667%;
  }
  [push-md-6] {
    left: 50%;
  }
  [push-md-7] {
    left: 58.33333%;
  }
  [push-md-8] {
    left: 66.66667%;
  }
  [push-md-9] {
    left: 75%;
  }
  [push-md-10] {
    left: 83.33333%;
  }
  [push-md-11] {
    left: 91.66667%;
  }
  [push-md-12] {
    left: 100%;
  }
  [offset-md-0] {
    margin-left: 0%;
  }
  [offset-md-1] {
    margin-left: 8.33333%;
  }
  [offset-md-2] {
    margin-left: 16.66667%;
  }
  [offset-md-3] {
    margin-left: 25%;
  }
  [offset-md-4] {
    margin-left: 33.33333%;
  }
  [offset-md-5] {
    margin-left: 41.66667%;
  }
  [offset-md-6] {
    margin-left: 50%;
  }
  [offset-md-7] {
    margin-left: 58.33333%;
  }
  [offset-md-8] {
    margin-left: 66.66667%;
  }
  [offset-md-9] {
    margin-left: 75%;
  }
  [offset-md-10] {
    margin-left: 83.33333%;
  }
  [offset-md-11] {
    margin-left: 91.66667%;
  }
}

[col-lg-1] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-1] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-1] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-1] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-1] {
    padding: 5px;
  }
}

[col-lg-2] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-2] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-2] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-2] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-2] {
    padding: 5px;
  }
}

[col-lg-3] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-3] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-3] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-3] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-3] {
    padding: 5px;
  }
}

[col-lg-4] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-4] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-4] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-4] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-4] {
    padding: 5px;
  }
}

[col-lg-5] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-5] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-5] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-5] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-5] {
    padding: 5px;
  }
}

[col-lg-6] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-6] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-6] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-6] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-6] {
    padding: 5px;
  }
}

[col-lg-7] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-7] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-7] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-7] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-7] {
    padding: 5px;
  }
}

[col-lg-8] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-8] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-8] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-8] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-8] {
    padding: 5px;
  }
}

[col-lg-9] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-9] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-9] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-9] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-9] {
    padding: 5px;
  }
}

[col-lg-10] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-10] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-10] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-10] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-10] {
    padding: 5px;
  }
}

[col-lg-11] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-11] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-11] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-11] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-11] {
    padding: 5px;
  }
}

[col-lg-12] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg-12] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg-12] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg-12] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg-12] {
    padding: 5px;
  }
}

[col-lg] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-lg] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-lg] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-lg] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-lg] {
    -webkit-flex-basis: 0;
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    -webkit-box-flex: 1;
    -webkit-flex-grow: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    max-width: 100%;
  }
  [col-lg-auto] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 auto;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    width: auto;
  }
  [col-lg-1] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 8.33333%;
    -ms-flex: 0 0 8.33333%;
    flex: 0 0 8.33333%;
    width: 8.33333%;
    max-width: 8.33333%;
  }
  [col-lg-2] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 16.66667%;
    -ms-flex: 0 0 16.66667%;
    flex: 0 0 16.66667%;
    width: 16.66667%;
    max-width: 16.66667%;
  }
  [col-lg-3] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 25%;
    -ms-flex: 0 0 25%;
    flex: 0 0 25%;
    width: 25%;
    max-width: 25%;
  }
  [col-lg-4] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 33.33333%;
    -ms-flex: 0 0 33.33333%;
    flex: 0 0 33.33333%;
    width: 33.33333%;
    max-width: 33.33333%;
  }
  [col-lg-5] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 41.66667%;
    -ms-flex: 0 0 41.66667%;
    flex: 0 0 41.66667%;
    width: 41.66667%;
    max-width: 41.66667%;
  }
  [col-lg-6] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 50%;
    -ms-flex: 0 0 50%;
    flex: 0 0 50%;
    width: 50%;
    max-width: 50%;
  }
  [col-lg-7] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 58.33333%;
    -ms-flex: 0 0 58.33333%;
    flex: 0 0 58.33333%;
    width: 58.33333%;
    max-width: 58.33333%;
  }
  [col-lg-8] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 66.66667%;
    -ms-flex: 0 0 66.66667%;
    flex: 0 0 66.66667%;
    width: 66.66667%;
    max-width: 66.66667%;
  }
  [col-lg-9] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 75%;
    -ms-flex: 0 0 75%;
    flex: 0 0 75%;
    width: 75%;
    max-width: 75%;
  }
  [col-lg-10] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 83.33333%;
    -ms-flex: 0 0 83.33333%;
    flex: 0 0 83.33333%;
    width: 83.33333%;
    max-width: 83.33333%;
  }
  [col-lg-11] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 91.66667%;
    -ms-flex: 0 0 91.66667%;
    flex: 0 0 91.66667%;
    width: 91.66667%;
    max-width: 91.66667%;
  }
  [col-lg-12] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 100%;
    -ms-flex: 0 0 100%;
    flex: 0 0 100%;
    width: 100%;
    max-width: 100%;
  }
  [pull-lg-0] {
    right: auto;
  }
  [pull-lg-1] {
    right: 8.33333%;
  }
  [pull-lg-2] {
    right: 16.66667%;
  }
  [pull-lg-3] {
    right: 25%;
  }
  [pull-lg-4] {
    right: 33.33333%;
  }
  [pull-lg-5] {
    right: 41.66667%;
  }
  [pull-lg-6] {
    right: 50%;
  }
  [pull-lg-7] {
    right: 58.33333%;
  }
  [pull-lg-8] {
    right: 66.66667%;
  }
  [pull-lg-9] {
    right: 75%;
  }
  [pull-lg-10] {
    right: 83.33333%;
  }
  [pull-lg-11] {
    right: 91.66667%;
  }
  [pull-lg-12] {
    right: 100%;
  }
  [push-lg-0] {
    left: auto;
  }
  [push-lg-1] {
    left: 8.33333%;
  }
  [push-lg-2] {
    left: 16.66667%;
  }
  [push-lg-3] {
    left: 25%;
  }
  [push-lg-4] {
    left: 33.33333%;
  }
  [push-lg-5] {
    left: 41.66667%;
  }
  [push-lg-6] {
    left: 50%;
  }
  [push-lg-7] {
    left: 58.33333%;
  }
  [push-lg-8] {
    left: 66.66667%;
  }
  [push-lg-9] {
    left: 75%;
  }
  [push-lg-10] {
    left: 83.33333%;
  }
  [push-lg-11] {
    left: 91.66667%;
  }
  [push-lg-12] {
    left: 100%;
  }
  [offset-lg-0] {
    margin-left: 0%;
  }
  [offset-lg-1] {
    margin-left: 8.33333%;
  }
  [offset-lg-2] {
    margin-left: 16.66667%;
  }
  [offset-lg-3] {
    margin-left: 25%;
  }
  [offset-lg-4] {
    margin-left: 33.33333%;
  }
  [offset-lg-5] {
    margin-left: 41.66667%;
  }
  [offset-lg-6] {
    margin-left: 50%;
  }
  [offset-lg-7] {
    margin-left: 58.33333%;
  }
  [offset-lg-8] {
    margin-left: 66.66667%;
  }
  [offset-lg-9] {
    margin-left: 75%;
  }
  [offset-lg-10] {
    margin-left: 83.33333%;
  }
  [offset-lg-11] {
    margin-left: 91.66667%;
  }
}

[col-xl-1] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-1] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-1] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-1] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-1] {
    padding: 5px;
  }
}

[col-xl-2] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-2] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-2] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-2] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-2] {
    padding: 5px;
  }
}

[col-xl-3] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-3] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-3] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-3] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-3] {
    padding: 5px;
  }
}

[col-xl-4] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-4] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-4] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-4] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-4] {
    padding: 5px;
  }
}

[col-xl-5] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-5] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-5] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-5] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-5] {
    padding: 5px;
  }
}

[col-xl-6] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-6] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-6] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-6] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-6] {
    padding: 5px;
  }
}

[col-xl-7] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-7] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-7] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-7] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-7] {
    padding: 5px;
  }
}

[col-xl-8] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-8] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-8] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-8] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-8] {
    padding: 5px;
  }
}

[col-xl-9] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-9] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-9] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-9] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-9] {
    padding: 5px;
  }
}

[col-xl-10] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-10] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-10] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-10] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-10] {
    padding: 5px;
  }
}

[col-xl-11] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-11] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-11] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-11] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-11] {
    padding: 5px;
  }
}

[col-xl-12] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl-12] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl-12] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl-12] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl-12] {
    padding: 5px;
  }
}

[col-xl] {
  padding: 5px;
}

@media (min-width: 576px) {
  [col-xl] {
    padding: 5px;
  }
}

@media (min-width: 768px) {
  [col-xl] {
    padding: 5px;
  }
}

@media (min-width: 992px) {
  [col-xl] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl] {
    padding: 5px;
  }
}

@media (min-width: 1200px) {
  [col-xl] {
    -webkit-flex-basis: 0;
    -ms-flex-preferred-size: 0;
    flex-basis: 0;
    -webkit-box-flex: 1;
    -webkit-flex-grow: 1;
    -ms-flex-positive: 1;
    flex-grow: 1;
    max-width: 100%;
  }
  [col-xl-auto] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 auto;
    -ms-flex: 0 0 auto;
    flex: 0 0 auto;
    width: auto;
  }
  [col-xl-1] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 8.33333%;
    -ms-flex: 0 0 8.33333%;
    flex: 0 0 8.33333%;
    width: 8.33333%;
    max-width: 8.33333%;
  }
  [col-xl-2] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 16.66667%;
    -ms-flex: 0 0 16.66667%;
    flex: 0 0 16.66667%;
    width: 16.66667%;
    max-width: 16.66667%;
  }
  [col-xl-3] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 25%;
    -ms-flex: 0 0 25%;
    flex: 0 0 25%;
    width: 25%;
    max-width: 25%;
  }
  [col-xl-4] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 33.33333%;
    -ms-flex: 0 0 33.33333%;
    flex: 0 0 33.33333%;
    width: 33.33333%;
    max-width: 33.33333%;
  }
  [col-xl-5] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 41.66667%;
    -ms-flex: 0 0 41.66667%;
    flex: 0 0 41.66667%;
    width: 41.66667%;
    max-width: 41.66667%;
  }
  [col-xl-6] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 50%;
    -ms-flex: 0 0 50%;
    flex: 0 0 50%;
    width: 50%;
    max-width: 50%;
  }
  [col-xl-7] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 58.33333%;
    -ms-flex: 0 0 58.33333%;
    flex: 0 0 58.33333%;
    width: 58.33333%;
    max-width: 58.33333%;
  }
  [col-xl-8] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 66.66667%;
    -ms-flex: 0 0 66.66667%;
    flex: 0 0 66.66667%;
    width: 66.66667%;
    max-width: 66.66667%;
  }
  [col-xl-9] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 75%;
    -ms-flex: 0 0 75%;
    flex: 0 0 75%;
    width: 75%;
    max-width: 75%;
  }
  [col-xl-10] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 83.33333%;
    -ms-flex: 0 0 83.33333%;
    flex: 0 0 83.33333%;
    width: 83.33333%;
    max-width: 83.33333%;
  }
  [col-xl-11] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 91.66667%;
    -ms-flex: 0 0 91.66667%;
    flex: 0 0 91.66667%;
    width: 91.66667%;
    max-width: 91.66667%;
  }
  [col-xl-12] {
    -webkit-box-flex: 0;
    -webkit-flex: 0 0 100%;
    -ms-flex: 0 0 100%;
    flex: 0 0 100%;
    width: 100%;
    max-width: 100%;
  }
  [pull-xl-0] {
    right: auto;
  }
  [pull-xl-1] {
    right: 8.33333%;
  }
  [pull-xl-2] {
    right: 16.66667%;
  }
  [pull-xl-3] {
    right: 25%;
  }
  [pull-xl-4] {
    right: 33.33333%;
  }
  [pull-xl-5] {
    right: 41.66667%;
  }
  [pull-xl-6] {
    right: 50%;
  }
  [pull-xl-7] {
    right: 58.33333%;
  }
  [pull-xl-8] {
    right: 66.66667%;
  }
  [pull-xl-9] {
    right: 75%;
  }
  [pull-xl-10] {
    right: 83.33333%;
  }
  [pull-xl-11] {
    right: 91.66667%;
  }
  [pull-xl-12] {
    right: 100%;
  }
  [push-xl-0] {
    left: auto;
  }
  [push-xl-1] {
    left: 8.33333%;
  }
  [push-xl-2] {
    left: 16.66667%;
  }
  [push-xl-3] {
    left: 25%;
  }
  [push-xl-4] {
    left: 33.33333%;
  }
  [push-xl-5] {
    left: 41.66667%;
  }
  [push-xl-6] {
    left: 50%;
  }
  [push-xl-7] {
    left: 58.33333%;
  }
  [push-xl-8] {
    left: 66.66667%;
  }
  [push-xl-9] {
    left: 75%;
  }
  [push-xl-10] {
    left: 83.33333%;
  }
  [push-xl-11] {
    left: 91.66667%;
  }
  [push-xl-12] {
    left: 100%;
  }
  [offset-xl-0] {
    margin-left: 0%;
  }
  [offset-xl-1] {
    margin-left: 8.33333%;
  }
  [offset-xl-2] {
    margin-left: 16.66667%;
  }
  [offset-xl-3] {
    margin-left: 25%;
  }
  [offset-xl-4] {
    margin-left: 33.33333%;
  }
  [offset-xl-5] {
    margin-left: 41.66667%;
  }
  [offset-xl-6] {
    margin-left: 50%;
  }
  [offset-xl-7] {
    margin-left: 58.33333%;
  }
  [offset-xl-8] {
    margin-left: 66.66667%;
  }
  [offset-xl-9] {
    margin-left: 75%;
  }
  [offset-xl-10] {
    margin-left: 83.33333%;
  }
  [offset-xl-11] {
    margin-left: 91.66667%;
  }
}

ion-icon {
  display: inline-block;
  font-size: 1.2em;
}

ion-icon[small] {
  min-height: 1.1em;
  font-size: 1.1em;
}

.icon-ios-primary {
  color: #488aff;
}

.icon-ios-secondary {
  color: #32db64;
}

.icon-ios-danger {
  color: #f53d3d;
}

.icon-ios-light {
  color: #f4f4f4;
}

.icon-ios-dark {
  color: #222;
}

.icon-md-primary {
  color: #488aff;
}

.icon-md-secondary {
  color: #32db64;
}

.icon-md-danger {
  color: #f53d3d;
}

.icon-md-light {
  color: #f4f4f4;
}

.icon-md-dark {
  color: #222;
}

.icon-wp-primary {
  color: #488aff;
}

.icon-wp-secondary {
  color: #32db64;
}

.icon-wp-danger {
  color: #f53d3d;
}

.icon-wp-light {
  color: #f4f4f4;
}

.icon-wp-dark {
  color: #222;
}

ion-img {
  display: inline-block;
  min-width: 20px;
  min-height: 20px;
  background: #eee;
  contain: strict;
}

ion-img img {
  -o-object-fit: cover;
  object-fit: cover;
}

ion-img.img-unloaded img {
  display: none;
}

ion-img.img-loaded img {
  display: block;
}

ion-infinite-scroll {
  display: block;
  width: 100%;
}

ion-infinite-scroll-content {
  text-align: center;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  height: 100%;
  min-height: 84px;
}

.infinite-loading {
  display: none;
  width: 100%;
  margin: 0 0 32px;
}

.infinite-loading-text {
  color: #666;
  margin: 4px 32px 0;
}

.infinite-loading-spinner .spinner-ios line,
.infinite-loading-spinner .spinner-ios-small line,
.infinite-loading-spinner .spinner-crescent circle {
  stroke: #666;
}

.infinite-loading-spinner .spinner-bubbles circle,
.infinite-loading-spinner .spinner-circles circle,
.infinite-loading-spinner .spinner-dots circle {
  fill: #666;
}

ion-infinite-scroll-content[state=loading] .infinite-loading {
  display: block;
}

ion-infinite-scroll-content[state=disabled] {
  display: none;
}

ion-input,
ion-textarea {
  position: relative;
  display: block;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  width: 100%;
}

.item-input ion-input,
.item-input ion-textarea {
  position: static;
}

.item.item-textarea {
  -webkit-box-align: stretch;
  -webkit-align-items: stretch;
  -ms-flex-align: stretch;
  align-items: stretch;
}

.text-input {
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  border-radius: 0;
  display: inline-block;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  width: 92%;
  width: calc(100% - 10px);
  border: 0;
  background: transparent;
}

.text-input::-moz-placeholder {
  color: #999;
}

.text-input:-ms-input-placeholder {
  color: #999;
}

.text-input::-webkit-input-placeholder {
  text-indent: 0;
  color: #999;
}

textarea.text-input {
  display: block;
}

.text-input[disabled] {
  opacity: .4;
}

input.text-input:-webkit-autofill {
  background-color: transparent;
}

.platform-mobile textarea.text-input {
  resize: none;
}

.input-cover {
  left: 0;
  top: 0;
  position: absolute;
  width: 100%;
  height: 100%;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
}

.input[disabled] .input-cover {
  pointer-events: none;
}

.item-input-has-focus .input-cover,
.input-has-focus .input-cover {
  display: none;
}

.item-input-has-focus,
.input-has-focus {
  pointer-events: none;
}

.item-input-has-focus input,
.input-has-focus input,
.item-input-has-focus textarea,
.input-has-focus textarea,
.item-input-has-focus a,
.input-has-focus a,
.item-input-has-focus button,
.input-has-focus button {
  pointer-events: auto;
}

.text-input-clear-icon {
  margin: 0;
  padding: 0;
  background-position: center;
  position: absolute;
  top: 0;
  display: none;
  height: 100%;
  background-repeat: no-repeat;
}

.item-input-has-focus.item-input-has-value .text-input-clear-icon,
.input-has-focus.input-has-value .text-input-clear-icon {
  display: block;
}

.text-input-ios {
  margin: 11px 8px 11px 0;
  padding: 0;
  width: calc(100% - 8px);
}

.input-ios .inset-input {
  padding: 5.5px 8px;
  margin: 5.5px 16px 5.5px 0;
}

.item-ios.item-label-stacked .text-input,
.item-ios.item-label-floating .text-input {
  margin-left: 0;
  margin-top: 8px;
  margin-bottom: 8px;
  width: calc(100% - 8px);
}

.item-ios.item-label-stacked .label-ios + .input + .cloned-input,
.item-ios.item-label-floating .label-ios + .input + .cloned-input {
  margin-left: 0;
}

.item-label-stacked .select-ios,
.item-label-floating .select-ios {
  padding-left: 0;
  padding-top: 8px;
  padding-bottom: 8px;
}

.input-ios[clearInput] {
  position: relative;
}

.input-ios[clearInput] .text-input {
  padding-right: 30px;
}

.input-ios .text-input-clear-icon {
  right: 8px;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='rgba(0,%200,%200,%200.5)'%20d='M403.1,108.9c-81.2-81.2-212.9-81.2-294.2,0s-81.2,212.9,0,294.2c81.2,81.2,212.9,81.2,294.2,0S484.3,190.1,403.1,108.9z%20M352,340.2L340.2,352l-84.4-84.2l-84,83.8L160,339.8l84-83.8l-84-83.8l11.8-11.8l84,83.8l84.4-84.2l11.8,11.8L267.6,256L352,340.2z'/></svg>");
  width: 30px;
  background-size: 18px;
}

.text-input-md {
  margin: 13px 8px;
  padding: 0;
  width: calc(100% - 8px - 8px);
}

.input-md .inset-input {
  padding: 6.5px 8px;
  margin: 6.5px 16px;
}

.item-md.item-input.item-input-has-focus .item-inner,
.item-md.item-input.input-has-focus .item-inner {
  border-bottom-color: #488aff;
  -webkit-box-shadow: inset 0 -1px 0 0 #488aff;
  box-shadow: inset 0 -1px 0 0 #488aff;
}

.list-md .item-input.item-input-has-focus:last-child,
.list-md .item-input.input-has-focus:last-child {
  border-bottom-color: #488aff;
  -webkit-box-shadow: inset 0 -1px 0 0 #488aff;
  box-shadow: inset 0 -1px 0 0 #488aff;
}

.list-md .item-input.item-input-has-focus:last-child .item-inner,
.list-md .item-input.input-has-focus:last-child .item-inner {
  -webkit-box-shadow: none;
  box-shadow: none;
}

.item-md.item-input.ng-valid.item-input-has-value:not(.input-has-focus):not(.item-input-has-focus) .item-inner,
.item-md.item-input.ng-valid.input-has-value:not(.input-has-focus):not(.item-input-has-focus) .item-inner {
  border-bottom-color: #32db64;
  -webkit-box-shadow: inset 0 -1px 0 0 #32db64;
  box-shadow: inset 0 -1px 0 0 #32db64;
}

.list-md .item-input.ng-valid.item-input-has-value:not(.input-has-focus):not(.item-input-has-focus):last-child,
.list-md .item-input.ng-valid.input-has-value:not(.input-has-focus):not(.item-input-has-focus):last-child {
  border-bottom-color: #32db64;
  -webkit-box-shadow: inset 0 -1px 0 0 #32db64;
  box-shadow: inset 0 -1px 0 0 #32db64;
}

.list-md .item-input.ng-valid.item-input-has-value:not(.input-has-focus):not(.item-input-has-focus):last-child .item-inner,
.list-md .item-input.ng-valid.input-has-value:not(.input-has-focus):not(.item-input-has-focus):last-child .item-inner {
  -webkit-box-shadow: none;
  box-shadow: none;
}

.item-md.item-input.ng-invalid.ng-touched:not(.input-has-focus):not(.item-input-has-focus) .item-inner {
  border-bottom-color: #f53d3d;
  -webkit-box-shadow: inset 0 -1px 0 0 #f53d3d;
  box-shadow: inset 0 -1px 0 0 #f53d3d;
}

.list-md .item-input.ng-invalid.ng-touched:not(.input-has-focus):not(.item-input-has-focus):last-child {
  border-bottom-color: #f53d3d;
  -webkit-box-shadow: inset 0 -1px 0 0 #f53d3d;
  box-shadow: inset 0 -1px 0 0 #f53d3d;
}

.list-md .item-input.ng-invalid.ng-touched:not(.input-has-focus):not(.item-input-has-focus):last-child .item-inner {
  -webkit-box-shadow: none;
  box-shadow: none;
}

.item-label-stacked .text-input-md,
.item-label-floating .text-input-md {
  margin-left: 0;
  margin-top: 8px;
  margin-bottom: 8px;
  width: calc(100% - 8px);
}

.item-label-stacked .select-md,
.item-label-floating .select-md {
  padding-left: 0;
  padding-top: 8px;
  padding-bottom: 8px;
}

.input-md[clearInput] {
  position: relative;
}

.input-md[clearInput] .text-input {
  padding-right: 30px;
}

.input-md .text-input-clear-icon {
  right: 8px;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><polygon%20fill='%235b5b5b'%20points='405,136.798%20375.202,107%20256,226.202%20136.798,107%20107,136.798%20226.202,256%20107,375.202%20136.798,405%20256,285.798%20375.202,405%20405,375.202%20285.798,256'/></svg>");
  width: 30px;
  background-size: 22px;
}

.text-input-wp {
  margin: 13px 8px;
  padding: 0 8px;
  width: calc(100% - 8px - 8px);
  border: 2px solid rgba(0, 0, 0, 0.5);
  line-height: 3rem;
}

.item-wp .inset-input {
  padding: 6.5px 8px;
  margin: 6.5px 16px;
}

.item-wp.item-input.item-input-has-focus .text-input,
.item-wp.item-input.input-has-focus .text-input {
  border-color: #488aff;
}

.item-wp.item-input.ng-valid.item-input-has-value:not(.input-has-focus):not(.item-input-has-focus) .text-input,
.item-wp.item-input.ng-valid.input-has-value:not(.input-has-focus):not(.item-input-has-focus) .text-input {
  border-color: #32db64;
}

.item-wp.item-input.ng-invalid.ng-touched:not(.input-has-focus):not(.item-input-has-focus) .text-input {
  border-color: #f53d3d;
}

.item-label-stacked .text-input-wp,
.item-label-floating .text-input-wp,
.item-label-stacked .select-wp,
.item-label-floating .select-wp {
  margin-left: 0;
  margin-top: 8px;
  margin-bottom: 8px;
  width: calc(100% - 8px);
}

.item-wp.item-label-stacked [item-right],
.item-wp.item-label-floating [item-right],
.item-wp.item-label-stacked [item-end],
.item-wp.item-label-floating [item-end] {
  -webkit-align-self: flex-end;
  -ms-flex-item-align: end;
  align-self: flex-end;
}

.input-wp[clearInput] {
  position: relative;
}

.input-wp[clearInput] .text-input {
  padding-right: 30px;
}

.input-wp .text-input-clear-icon {
  right: 8px;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><polygon%20fill='rgba(0,%200,%200,%200.5)'%20points='405,136.798%20375.202,107%20256,226.202%20136.798,107%20107,136.798%20226.202,256%20107,375.202%20136.798,405%20256,285.798%20375.202,405%20405,375.202%20285.798,256'/></svg>");
  width: 30px;
  background-size: 22px;
}

.item {
  contain: content;
}

.item-block {
  margin: 0;
  padding: 0;
  text-align: initial;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  width: 100%;
  min-height: 4.4rem;
  border: 0;
  font-weight: normal;
  line-height: normal;
  text-decoration: none;
  color: inherit;
}

.item-inner {
  margin: 0;
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-orient: inherit;
  -webkit-box-direction: inherit;
  -webkit-flex-direction: inherit;
  -ms-flex-direction: inherit;
  flex-direction: inherit;
  -webkit-box-align: inherit;
  -webkit-align-items: inherit;
  -ms-flex-align: inherit;
  align-items: inherit;
  -webkit-align-self: stretch;
  -ms-flex-item-align: stretch;
  align-self: stretch;
  min-height: inherit;
  border: 0;
}

.input-wrapper {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-orient: inherit;
  -webkit-box-direction: inherit;
  -webkit-flex-direction: inherit;
  -ms-flex-direction: inherit;
  flex-direction: inherit;
  -webkit-box-align: inherit;
  -webkit-align-items: inherit;
  -ms-flex-align: inherit;
  align-items: inherit;
  -webkit-align-self: stretch;
  -ms-flex-item-align: stretch;
  align-self: stretch;
  text-overflow: ellipsis;
}

.item[no-lines],
.item.item[no-lines] .item-inner {
  border: 0;
}

ion-item-group {
  display: block;
}

ion-item-divider {
  margin: 0;
  padding: 0;
  z-index: 100;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  width: 100%;
  min-height: 30px;
}

ion-item-divider[sticky] {
  position: -webkit-sticky;
  position: sticky;
  top: 0;
}

[vertical-align-top],
ion-input.item {
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}

.item > ion-icon[small]:first-child,
.item-inner > ion-icon[small]:first-child {
  min-width: 18px;
}

.item > ion-icon:first-child,
.item-inner > ion-icon:first-child {
  text-align: center;
  min-width: 24px;
}

.item > ion-icon,
.item-inner > ion-icon {
  min-height: 2.8rem;
  font-size: 2.8rem;
  line-height: 1;
}

.item > ion-icon[large],
.item-inner > ion-icon[large] {
  min-height: 3.2rem;
  font-size: 3.2rem;
}

.item > ion-icon[small],
.item-inner > ion-icon[small] {
  min-height: 1.8rem;
  font-size: 1.8rem;
}

ion-avatar,
ion-thumbnail {
  display: block;
  line-height: 1;
}

ion-avatar img,
ion-thumbnail img {
  display: block;
}

.item-cover {
  left: 0;
  top: 0;
  position: absolute;
  width: 100%;
  height: 100%;
  background: transparent;
  cursor: pointer;
}

ion-reorder {
  -webkit-transform: translate3d(300%,  0,  0);
  transform: translate3d(300%,  0,  0);
  display: none;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  max-width: 40px;
  height: 100%;
  font-size: 1.7em;
  opacity: .25;
  -webkit-transition: -webkit-transform 140ms ease-in;
  transition: -webkit-transform 140ms ease-in;
  transition: transform 140ms ease-in;
  transition: transform 140ms ease-in, -webkit-transform 140ms ease-in;
  pointer-events: all;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
}

.reorder-side-start ion-reorder {
  -webkit-transform: translate3d(-300%,  0,  0);
  transform: translate3d(-300%,  0,  0);
  -webkit-box-ordinal-group: 0;
  -webkit-order: -1;
  -ms-flex-order: -1;
  order: -1;
}

ion-reorder ion-icon {
  pointer-events: none;
}

.reorder-enabled ion-reorder {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.reorder-visible ion-reorder {
  -webkit-transform: translate3d(0,  0,  0);
  transform: translate3d(0,  0,  0);
}

.reorder-list-active .item,
.reorder-list-active .item-wrapper {
  -webkit-transition: -webkit-transform 300ms;
  transition: -webkit-transform 300ms;
  transition: transform 300ms;
  transition: transform 300ms, -webkit-transform 300ms;
  will-change: transform;
}

.reorder-list-active .item-inner {
  pointer-events: none;
}

.item-wrapper.reorder-active,
.item.reorder-active,
.reorder-active {
  z-index: 4;
  -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, 0.4);
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.4);
  opacity: .8;
  -webkit-transition: none;
  transition: none;
  pointer-events: none;
}

ion-item-sliding {
  position: relative;
  display: block;
  overflow: hidden;
  width: 100%;
}

ion-item-sliding .item {
  position: static;
}

ion-item-options {
  position: absolute;
  z-index: 1;
  display: none;
  height: 100%;
  font-size: 14px;
  visibility: hidden;
  top: 0;
  right: 0;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

ion-item-options[side=left] {
  right: auto;
  left: 0;
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

ion-item-options .button {
  margin: 0;
  padding: 0 0.7em;
  border-radius: 0;
  height: 100%;
  -webkit-box-shadow: none;
  box-shadow: none;
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
}

ion-item-options .button:last-child {
  padding-right: 0.7em;
}

@media screen and (orientation: landscape) {
  ion-item-options .button:last-child {
    padding-right: calc(constant(safe-area-inset-right) + 0.7em);
    padding-right: calc(env(safe-area-inset-right) + 0.7em);
  }
}

ion-item-options:not([icon-left]) .button:not([icon-only]) .button-inner,
ion-item-options:not([icon-start]) .button:not([icon-only]) .button-inner {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

ion-item-options:not([icon-left]) .button:not([icon-only]) ion-icon,
ion-item-options:not([icon-start]) .button:not([icon-only]) ion-icon {
  padding-left: 0;
  padding-right: 0;
  padding-bottom: 0.3em;
}

ion-item-sliding.active-slide .item,
ion-item-sliding.active-slide .item.activated {
  position: relative;
  z-index: 2;
  opacity: 1;
  -webkit-transition: -webkit-transform 500ms cubic-bezier(0.36, 0.66, 0.04, 1);
  transition: -webkit-transform 500ms cubic-bezier(0.36, 0.66, 0.04, 1);
  transition: transform 500ms cubic-bezier(0.36, 0.66, 0.04, 1);
  transition: transform 500ms cubic-bezier(0.36, 0.66, 0.04, 1), -webkit-transform 500ms cubic-bezier(0.36, 0.66, 0.04, 1);
  pointer-events: none;
  will-change: transform;
}

ion-item-sliding.active-slide ion-item-options {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

ion-item-sliding.active-slide.active-options-left ion-item-options[side=left],
ion-item-sliding.active-slide.active-options-right ion-item-options:not([side=left]) {
  width: 100%;
  visibility: visible;
}

button[expandable] {
  -webkit-flex-shrink: 0;
  -ms-flex-negative: 0;
  flex-shrink: 0;
  -webkit-transition-duration: 0;
  transition-duration: 0;
  -webkit-transition-property: none;
  transition-property: none;
  -webkit-transition-timing-function: cubic-bezier(0.65, 0.05, 0.36, 1);
  transition-timing-function: cubic-bezier(0.65, 0.05, 0.36, 1);
}

ion-item-sliding.active-swipe-right button[expandable] {
  -webkit-transition-duration: .6s;
  transition-duration: .6s;
  -webkit-transition-property: padding-left;
  transition-property: padding-left;
  padding-left: 90%;
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
}

ion-item-sliding.active-swipe-left button[expandable] {
  -webkit-transition-duration: .6s;
  transition-duration: .6s;
  -webkit-transition-property: padding-right;
  transition-property: padding-right;
  padding-right: 90%;
  -webkit-box-ordinal-group: 0;
  -webkit-order: -1;
  -ms-flex-order: -1;
  order: -1;
}

.item-ios {
  padding-left: 16px;
  padding-left: 16px;
  border-radius: 0;
  position: relative;
  font-size: 1.7rem;
  color: #000;
  background-color: #fff;
  -webkit-transition: background-color 200ms linear;
  transition: background-color 200ms linear;
}

@media screen and (orientation: landscape) {
  .item-ios {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
  }
}

.item-ios.activated {
  background-color: #d9d9d9;
  -webkit-transition-duration: 0ms;
  transition-duration: 0ms;
}

.item-ios h1 {
  margin: 0 0 2px;
  font-size: 2.4rem;
  font-weight: normal;
}

.item-ios h2 {
  margin: 0 0 2px;
  font-size: 1.7rem;
  font-weight: normal;
}

.item-ios h3,
.item-ios h4,
.item-ios h5,
.item-ios h6 {
  margin: 0 0 3px;
  font-size: 1.4rem;
  font-weight: normal;
  line-height: normal;
}

.item-ios p {
  overflow: inherit;
  font-size: 1.4rem;
  line-height: normal;
  text-overflow: inherit;
  color: #8e9093;
  margin: 0 0 2px;
}

.item-ios h2:last-child,
.item-ios h3:last-child,
.item-ios h4:last-child,
.item-ios h5:last-child,
.item-ios h6:last-child,
.item-ios p:last-child {
  margin-bottom: 0;
}

.item-ios.item-block .item-inner {
  padding-right: 8px;
  padding-right: 8px;
  border-bottom: 0.55px solid #c8c7cc;
}

@media screen and (orientation: landscape) {
  .item-ios.item-block .item-inner {
    padding-right: calc(constant(safe-area-inset-right) + 8px);
    padding-right: calc(env(safe-area-inset-right) + 8px);
  }
}

.item-ios [item-left],
.item-ios [item-start] {
  margin: 8px 16px 8px 0;
}

.item-ios [item-right],
.item-ios [item-end] {
  margin: 8px;
}

.item-ios ion-icon[item-left],
.item-ios ion-icon[item-right],
.item-ios ion-icon[item-start],
.item-ios ion-icon[item-end] {
  margin-left: 0;
  margin-top: 9px;
  margin-bottom: 8px;
}

.item-ios .item-button {
  padding: 0 0.5em;
  height: 24px;
  font-size: 1.3rem;
}

.item-ios .item-button[icon-only] ion-icon,
.item-ios .item-button[icon-only] {
  padding: 0 1px;
}

.item-ios ion-avatar[item-left],
.item-ios ion-thumbnail[item-left],
.item-ios ion-avatar[item-start],
.item-ios ion-thumbnail[item-start] {
  margin: 8px 16px 8px 0;
}

.item-ios ion-avatar[item-right],
.item-ios ion-thumbnail[item-right],
.item-ios ion-avatar[item-end],
.item-ios ion-thumbnail[item-end] {
  margin: 8px;
}

.item-ios ion-avatar {
  min-width: 36px;
  min-height: 36px;
}

.item-ios ion-avatar ion-img,
.item-ios ion-avatar img {
  border-radius: 50%;
  overflow: hidden;
  width: 36px;
  height: 36px;
}

.item-ios ion-thumbnail {
  min-width: 56px;
  min-height: 56px;
}

.item-ios ion-thumbnail ion-img,
.item-ios ion-thumbnail img {
  width: 56px;
  height: 56px;
}

.item-ios[detail-push] .item-inner,
button.item-ios:not([detail-none]) .item-inner,
a.item-ios:not([detail-none]) .item-inner {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%2012%2020'><path%20d='M2,20l-2-2l8-8L0,2l2-2l10,10L2,20z'%20fill='%23c8c7cc'/></svg>");
  padding-right: 32px;
  background-position: right 14px center;
  background-position: right calc(14px + constant(safe-area-inset-right)) center;
  background-position: right calc(14px + env(safe-area-inset-right)) center;
  background-repeat: no-repeat;
  background-size: 14px 14px;
}

ion-item-group .item-ios:first-child .item-inner {
  border-top-width: 0;
}

ion-item-group .item-ios:last-child .item-inner,
ion-item-group .item-wrapper:last-child .item-ios .item-inner {
  border: 0;
}

.item-divider-ios {
  padding-left: 16px;
  padding-left: 16px;
  color: #222;
  background-color: #f7f7f7;
}

@media screen and (orientation: landscape) {
  .item-divider-ios {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
  }
}

.item-ios .text-ios-primary {
  color: #488aff;
}

.item-ios-primary,
.item-divider-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.item-ios-primary p,
.item-divider-ios-primary p {
  color: #fff;
}

.item-ios-primary.activated,
.item-divider-ios-primary.activated {
  background-color: #427feb;
}

.item-ios .text-ios-secondary {
  color: #32db64;
}

.item-ios-secondary,
.item-divider-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.item-ios-secondary p,
.item-divider-ios-secondary p {
  color: #fff;
}

.item-ios-secondary.activated,
.item-divider-ios-secondary.activated {
  background-color: #2ec95c;
}

.item-ios .text-ios-danger {
  color: #f53d3d;
}

.item-ios-danger,
.item-divider-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.item-ios-danger p,
.item-divider-ios-danger p {
  color: #fff;
}

.item-ios-danger.activated,
.item-divider-ios-danger.activated {
  background-color: #e13838;
}

.item-ios .text-ios-light {
  color: #f4f4f4;
}

.item-ios-light,
.item-divider-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.item-ios-light p,
.item-divider-ios-light p {
  color: #000;
}

.item-ios-light.activated,
.item-divider-ios-light.activated {
  background-color: #e0e0e0;
}

.item-ios .text-ios-dark {
  color: #222;
}

.item-ios-dark,
.item-divider-ios-dark {
  color: #fff;
  background-color: #222;
}

.item-ios-dark p,
.item-divider-ios-dark p {
  color: #fff;
}

.item-ios-dark.activated,
.item-divider-ios-dark.activated {
  background-color: #343434;
}

.list-ios ion-item-sliding {
  background-color: #fff;
}

.item-md {
  padding-left: 16px;
  padding-right: 0;
  position: relative;
  font-size: 1.6rem;
  font-weight: normal;
  text-transform: none;
  color: #000;
  background-color: #fff;
  -webkit-box-shadow: none;
  box-shadow: none;
  -webkit-transition: background-color 300ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: background-color 300ms cubic-bezier(0.4, 0, 0.2, 1);
}

.item-md.activated {
  background-color: #f1f1f1;
}

.item-md[no-lines] {
  border-width: 0;
}

.item-md h1 {
  margin: 0 0 2px;
  font-size: 2.4rem;
  font-weight: normal;
}

.item-md h2 {
  margin: 2px 0;
  font-size: 1.6rem;
  font-weight: normal;
}

.item-md h3,
.item-md h4,
.item-md h5,
.item-md h6 {
  margin: 2px 0;
  font-size: 1.4rem;
  font-weight: normal;
  line-height: normal;
}

.item-md p {
  margin: 0 0 2px;
  overflow: inherit;
  font-size: 1.4rem;
  line-height: normal;
  text-overflow: inherit;
  color: #666;
}

.item-md.item-block .item-inner {
  padding-right: 8px;
  border-bottom: 1px solid #dedede;
}

.item-md [item-left],
.item-md [item-right],
.item-md [item-start],
.item-md [item-end] {
  margin: 9px 8px 9px 0;
}

.item-md ion-icon[item-left],
.item-md ion-icon[item-right],
.item-md ion-icon[item-start],
.item-md ion-icon[item-end] {
  margin-left: 0;
  margin-top: 11px;
  margin-bottom: 10px;
}

.item-md .item-button {
  padding: 0 0.6em;
  height: 25px;
  font-size: 1.2rem;
}

.item-md .item-button[icon-only] ion-icon,
.item-md .item-button[icon-only] {
  padding: 0 1px;
}

.item-md ion-icon[item-left] + .item-inner,
.item-md ion-icon[item-left] + .item-input,
.item-md ion-icon[item-start] + .item-inner,
.item-md ion-icon[item-start] + .item-input {
  margin-left: 24px;
}

.item-md ion-avatar[item-left],
.item-md ion-thumbnail[item-left],
.item-md ion-avatar[item-start],
.item-md ion-thumbnail[item-start] {
  margin: 8px 16px 8px 0;
}

.item-md ion-avatar[item-right],
.item-md ion-thumbnail[item-right],
.item-md ion-avatar[item-end],
.item-md ion-thumbnail[item-end] {
  margin: 8px;
}

.item-md ion-avatar {
  min-width: 40px;
  min-height: 40px;
}

.item-md ion-avatar ion-img,
.item-md ion-avatar img {
  border-radius: 50%;
  overflow: hidden;
  width: 40px;
  height: 40px;
}

.item-md ion-thumbnail {
  min-width: 80px;
  min-height: 80px;
}

.item-md ion-thumbnail ion-img,
.item-md ion-thumbnail img {
  width: 80px;
  height: 80px;
}

ion-item-group .item-md:first-child .item-inner {
  border-top-width: 0;
}

ion-item-group .item-md:last-child .item-inner,
ion-item-group .item-md .item-wrapper:last-child .item-inner {
  border: 0;
}

.item-divider-md {
  padding-left: 16px;
  border-bottom: 1px solid #dedede;
  font-size: 1.4rem;
  color: #858585;
  background-color: #fff;
}

.item-md .text-md-primary {
  color: #488aff;
}

.item-md-primary,
.item-divider-md-primary {
  color: #fff;
  background-color: #488aff;
}

.item-md-primary p,
.item-divider-md-primary p {
  color: #fff;
}

.item-md-primary.activated,
.item-divider-md-primary.activated {
  background-color: #427feb;
}

.item-md .text-md-secondary {
  color: #32db64;
}

.item-md-secondary,
.item-divider-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.item-md-secondary p,
.item-divider-md-secondary p {
  color: #fff;
}

.item-md-secondary.activated,
.item-divider-md-secondary.activated {
  background-color: #2ec95c;
}

.item-md .text-md-danger {
  color: #f53d3d;
}

.item-md-danger,
.item-divider-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.item-md-danger p,
.item-divider-md-danger p {
  color: #fff;
}

.item-md-danger.activated,
.item-divider-md-danger.activated {
  background-color: #e13838;
}

.item-md .text-md-light {
  color: #f4f4f4;
}

.item-md-light,
.item-divider-md-light {
  color: #000;
  background-color: #f4f4f4;
}

.item-md-light p,
.item-divider-md-light p {
  color: #000;
}

.item-md-light.activated,
.item-divider-md-light.activated {
  background-color: #e0e0e0;
}

.item-md .text-md-dark {
  color: #222;
}

.item-md-dark,
.item-divider-md-dark {
  color: #fff;
  background-color: #222;
}

.item-md-dark p,
.item-divider-md-dark p {
  color: #fff;
}

.item-md-dark.activated,
.item-divider-md-dark.activated {
  background-color: #343434;
}

.list-md ion-item-sliding {
  background-color: #fff;
}

.item-md ion-reorder {
  font-size: 1.5em;
  opacity: .3;
}

.item-wp {
  padding-left: 16px;
  padding-right: 0;
  position: relative;
  font-size: 1.6rem;
  font-weight: normal;
  text-transform: none;
  color: #000;
  background-color: #fff;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.item-wp.activated {
  background-color: #aaa;
}

.item-wp[no-lines] {
  border-width: 0;
}

.item-wp h1 {
  margin: 0 0 2px;
  font-size: 2.4rem;
  font-weight: normal;
}

.item-wp h2 {
  margin: 2px 0;
  font-size: 1.6rem;
  font-weight: normal;
}

.item-wp h3,
.item-wp h4,
.item-wp h5,
.item-wp h6 {
  margin: 2px 0;
  font-size: 1.4rem;
  font-weight: normal;
  line-height: normal;
}

.item-wp p {
  margin: 0 0 2px;
  overflow: inherit;
  font-size: 1.4rem;
  line-height: normal;
  text-overflow: inherit;
  color: #666;
}

.item-wp.item-block .item-inner {
  padding-right: 8px;
  border-bottom: 1px solid transparent;
}

.item-wp [item-left],
.item-wp [item-right],
.item-wp [item-start],
.item-wp [item-end] {
  margin: 9px 8px 9px 0;
}

.item-wp ion-icon[item-left],
.item-wp ion-icon[item-right],
.item-wp ion-icon[item-start],
.item-wp ion-icon[item-end] {
  margin-left: 0;
  margin-top: 11px;
  margin-bottom: 10px;
}

.item-wp .item-button {
  padding: 0 0.6em;
  height: 25px;
  font-size: 1.2rem;
}

.item-wp .item-button[icon-only] ion-icon,
.item-wp .item-button[icon-only] {
  padding: 0 1px;
}

.item-wp[text-wrap] ion-label {
  font-size: 1.4rem;
  line-height: 1.5;
}

.item-wp ion-icon[item-left] + .item-inner,
.item-wp ion-icon[item-left] + .item-input,
.item-wp ion-icon[item-start] + .item-inner,
.item-wp ion-icon[item-start] + .item-input {
  margin-left: 8px;
}

.item-wp ion-avatar[item-left],
.item-wp ion-thumbnail[item-left],
.item-wp ion-avatar[item-start],
.item-wp ion-thumbnail[item-start] {
  margin: 8px 16px 8px 0;
}

.item-wp ion-avatar[item-right],
.item-wp ion-thumbnail[item-right],
.item-wp ion-avatar[item-end],
.item-wp ion-thumbnail[item-end] {
  margin: 8px;
}

.item-wp ion-avatar {
  min-width: 40px;
  min-height: 40px;
}

.item-wp ion-avatar ion-img,
.item-wp ion-avatar img {
  border-radius: 50%;
  overflow: hidden;
  width: 40px;
  height: 40px;
}

.item-wp ion-thumbnail {
  min-width: 80px;
  min-height: 80px;
}

.item-wp ion-thumbnail ion-img,
.item-wp ion-thumbnail img {
  width: 80px;
  height: 80px;
}

.item-divider-wp {
  padding-left: 16px;
  border-bottom: 1px solid transparent;
  font-size: 2rem;
  color: #000;
  background-color: #fff;
}

.item-wp .text-wp-primary {
  color: #488aff;
}

.item-wp-primary,
.item-divider-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.item-wp-primary p,
.item-divider-wp-primary p {
  color: #fff;
}

.item-wp-primary.activated,
.item-divider-wp-primary.activated {
  background-color: #427feb;
}

.item-wp .text-wp-secondary {
  color: #32db64;
}

.item-wp-secondary,
.item-divider-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.item-wp-secondary p,
.item-divider-wp-secondary p {
  color: #fff;
}

.item-wp-secondary.activated,
.item-divider-wp-secondary.activated {
  background-color: #2ec95c;
}

.item-wp .text-wp-danger {
  color: #f53d3d;
}

.item-wp-danger,
.item-divider-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.item-wp-danger p,
.item-divider-wp-danger p {
  color: #fff;
}

.item-wp-danger.activated,
.item-divider-wp-danger.activated {
  background-color: #e13838;
}

.item-wp .text-wp-light {
  color: #f4f4f4;
}

.item-wp-light,
.item-divider-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.item-wp-light p,
.item-divider-wp-light p {
  color: #000;
}

.item-wp-light.activated,
.item-divider-wp-light.activated {
  background-color: #e0e0e0;
}

.item-wp .text-wp-dark {
  color: #222;
}

.item-wp-dark,
.item-divider-wp-dark {
  color: #fff;
  background-color: #222;
}

.item-wp-dark p,
.item-divider-wp-dark p {
  color: #fff;
}

.item-wp-dark.activated,
.item-divider-wp-dark.activated {
  background-color: #343434;
}

.list-wp ion-item-sliding {
  background-color: #fff;
}

ion-label {
  margin: 0;
  display: block;
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  font-size: inherit;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.item-input ion-label {
  -webkit-box-flex: initial;
  -webkit-flex: initial;
  -ms-flex: initial;
  flex: initial;
  max-width: 200px;
  pointer-events: none;
}

[text-wrap] ion-label {
  white-space: normal;
}

ion-label[fixed] {
  -webkit-box-flex: 0;
  -webkit-flex: 0 0 100px;
  -ms-flex: 0 0 100px;
  flex: 0 0 100px;
  width: 100px;
  min-width: 100px;
  max-width: 200px;
}

.item-label-stacked ion-label,
.item-label-floating ion-label {
  -webkit-align-self: stretch;
  -ms-flex-item-align: stretch;
  align-self: stretch;
  width: auto;
  max-width: 100%;
}

ion-label[stacked],
ion-label[floating] {
  margin-bottom: 0;
}

.item-label-stacked .input-wrapper,
.item-label-floating .input-wrapper {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

.item-label-stacked ion-select,
.item-label-floating ion-select {
  -webkit-align-self: stretch;
  -ms-flex-item-align: stretch;
  align-self: stretch;
  max-width: 100%;
}

.label-ios {
  margin: 11px 8px 11px 0;
}

.label-ios + ion-input .text-input,
.label-ios + ion-textarea .text-input,
.label-ios + .input + .cloned-input {
  margin-left: 16px;
  width: calc(100% - (16px / 2) - 16px);
}

.label-ios[stacked] {
  margin-bottom: 4px;
  font-size: 1.2rem;
}

.label-ios[floating] {
  margin-bottom: 0;
  -webkit-transform: translate3d(0,  27px,  0);
  transform: translate3d(0,  27px,  0);
  -webkit-transform-origin: left top;
  transform-origin: left top;
  -webkit-transition: -webkit-transform 150ms ease-in-out;
  transition: -webkit-transform 150ms ease-in-out;
  transition: transform 150ms ease-in-out;
  transition: transform 150ms ease-in-out, -webkit-transform 150ms ease-in-out;
}

.item-input-has-focus .label-ios[floating],
.input-has-focus .label-ios[floating],
.item-input-has-value .label-ios[floating],
.input-has-value .label-ios[floating] {
  -webkit-transform: translate3d(0,  0,  0) scale(0.8);
  transform: translate3d(0,  0,  0) scale(0.8);
}

.item-ios.item-label-stacked [item-right],
.item-ios.item-label-floating [item-right],
.item-ios.item-label-stacked [item-end],
.item-ios.item-label-floating [item-end] {
  margin-top: 6px;
  margin-bottom: 6px;
}

.label-ios-primary,
.item-input .label-ios-primary,
.item-select .label-ios-primary,
.item-datetime .label-ios-primary {
  color: #488aff;
}

.label-ios-secondary,
.item-input .label-ios-secondary,
.item-select .label-ios-secondary,
.item-datetime .label-ios-secondary {
  color: #32db64;
}

.label-ios-danger,
.item-input .label-ios-danger,
.item-select .label-ios-danger,
.item-datetime .label-ios-danger {
  color: #f53d3d;
}

.label-ios-light,
.item-input .label-ios-light,
.item-select .label-ios-light,
.item-datetime .label-ios-light {
  color: #f4f4f4;
}

.label-ios-dark,
.item-input .label-ios-dark,
.item-select .label-ios-dark,
.item-datetime .label-ios-dark {
  color: #222;
}

.label-md {
  margin: 13px 8px 13px 0;
}

[text-wrap] .label-md {
  font-size: 1.4rem;
  line-height: 1.5;
}

.item-input .label-md,
.item-select .label-md,
.item-datetime .label-md {
  color: #999;
}

.label-md[stacked] {
  font-size: 1.2rem;
}

.label-md[floating] {
  -webkit-transform: translate3d(0,  27px,  0);
  transform: translate3d(0,  27px,  0);
  -webkit-transform-origin: left top;
  transform-origin: left top;
  -webkit-transition: -webkit-transform 150ms ease-in-out;
  transition: -webkit-transform 150ms ease-in-out;
  transition: transform 150ms ease-in-out;
  transition: transform 150ms ease-in-out, -webkit-transform 150ms ease-in-out;
}

.label-md[stacked],
.label-md[floating] {
  margin-left: 0;
  margin-bottom: 0;
}

.item-input-has-focus .label-md[stacked],
.input-has-focus .label-md[stacked],
.item-input-has-focus .label-md[floating],
.input-has-focus .label-md[floating] {
  color: #488aff;
}

.item-input-has-focus .label-md[floating],
.input-has-focus .label-md[floating],
.item-input-has-value .label-md[floating],
.input-has-value .label-md[floating] {
  -webkit-transform: translate3d(0,  0,  0) scale(0.8);
  transform: translate3d(0,  0,  0) scale(0.8);
}

.item-md.item-label-stacked [item-right],
.item-md.item-label-floating [item-right],
.item-md.item-label-stacked [item-end],
.item-md.item-label-floating [item-end] {
  margin-top: 7px;
  margin-bottom: 7px;
}

.label-md-primary,
.item-input .label-md-primary,
.item-select .label-md-primary,
.item-datetime .label-md-primary {
  color: #488aff;
}

.label-md-secondary,
.item-input .label-md-secondary,
.item-select .label-md-secondary,
.item-datetime .label-md-secondary {
  color: #32db64;
}

.label-md-danger,
.item-input .label-md-danger,
.item-select .label-md-danger,
.item-datetime .label-md-danger {
  color: #f53d3d;
}

.label-md-light,
.item-input .label-md-light,
.item-select .label-md-light,
.item-datetime .label-md-light {
  color: #f4f4f4;
}

.label-md-dark,
.item-input .label-md-dark,
.item-select .label-md-dark,
.item-datetime .label-md-dark {
  color: #222;
}

.label-wp {
  margin: 13px 8px 13px 0;
}

.item-input .label-wp,
.item-select .label-wp,
.item-datetime .label-wp {
  color: #999;
}

.label-wp[stacked] {
  font-size: 1.2rem;
}

.label-wp[floating] {
  -webkit-transform: translate3d(8px,  34px,  0);
  transform: translate3d(8px,  34px,  0);
  -webkit-transform-origin: left top;
  transform-origin: left top;
}

.label-wp[stacked],
.label-wp[floating] {
  margin-left: 0;
  margin-bottom: 0;
}

.item-input-has-focus .label-wp[stacked],
.input-has-focus .label-wp[stacked],
.item-input-has-focus .label-wp[floating],
.input-has-focus .label-wp[floating] {
  color: #488aff;
}

.item-input-has-focus .label-wp[floating],
.input-has-focus .label-wp[floating],
.item-input-has-value .label-wp[floating],
.input-has-value .label-wp[floating] {
  -webkit-transform: translate3d(0,  0,  0) scale(0.8);
  transform: translate3d(0,  0,  0) scale(0.8);
}

.item-wp.item-label-stacked [item-right],
.item-wp.item-label-floating [item-right],
.item-wp.item-label-stacked [item-end],
.item-wp.item-label-floating [item-end] {
  margin-top: 13px;
  margin-bottom: 13px;
}

.label-wp-primary,
.item-input .label-wp-primary,
.item-select .label-wp-primary,
.item-datetime .label-wp-primary {
  color: #488aff;
}

.label-wp-secondary,
.item-input .label-wp-secondary,
.item-select .label-wp-secondary,
.item-datetime .label-wp-secondary {
  color: #32db64;
}

.label-wp-danger,
.item-input .label-wp-danger,
.item-select .label-wp-danger,
.item-datetime .label-wp-danger {
  color: #f53d3d;
}

.label-wp-light,
.item-input .label-wp-light,
.item-select .label-wp-light,
.item-datetime .label-wp-light {
  color: #f4f4f4;
}

.label-wp-dark,
.item-input .label-wp-dark,
.item-select .label-wp-dark,
.item-datetime .label-wp-dark {
  color: #222;
}

ion-list-header {
  margin: 0;
  padding: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  width: 100%;
  min-height: 4rem;
}

ion-list {
  margin: 0;
  padding: 0;
  display: block;
  list-style-type: none;
}

ion-list[inset] {
  overflow: hidden;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.list-ios {
  margin: -1px 0 32px;
}

.list-ios > .item-block:first-child {
  border-top: 0.55px solid #c8c7cc;
}

.list-ios > .item-block:last-child,
.list-ios > .item-wrapper:last-child .item-block {
  border-bottom: 0.55px solid #c8c7cc;
}

.list-ios > .item-block:last-child .item-inner,
.list-ios > .item-wrapper:last-child .item-block .item-inner {
  border-bottom: 0;
}

.list-ios .item-block .item-inner {
  border-bottom: 0.55px solid #c8c7cc;
}

.list-ios .item[no-lines],
.list-ios .item[no-lines] .item-inner {
  border-width: 0;
}

.list-ios ion-item-options {
  border-bottom: 0.55px solid #c8c7cc;
}

.list-ios ion-item-options .button {
  margin: 0;
  border-radius: 0;
  display: -webkit-inline-box;
  display: -webkit-inline-flex;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  height: 100%;
  min-height: 100%;
  border: 0;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.list-ios ion-item-options .button::before {
  margin: 0 auto;
}

.list-ios:not([inset]) + .list-ios:not([inset]) ion-list-header {
  margin-top: -10px;
  padding-top: 0;
}

.list-ios[inset] {
  margin: 16px;
  border-radius: 4px;
}

.list-ios[inset] ion-list-header {
  background-color: #fff;
}

.list-ios[inset] .item {
  border-bottom: 1px solid #c8c7cc;
}

.list-ios[inset] .item-inner {
  border-bottom: 0;
}

.list-ios[inset] > .item:first-child,
.list-ios[inset] > .item-wrapper:first-child .item {
  border-top: 0;
}

.list-ios[inset] > .item:last-child,
.list-ios[inset] > .item-wrapper:last-child .item {
  border-bottom: 0;
}

.list-ios[inset] + ion-list[inset] {
  margin-top: 0;
}

.list-ios[no-lines] ion-list-header,
.list-ios[no-lines] ion-item-options,
.list-ios[no-lines] .item,
.list-ios[no-lines] .item .item-inner {
  border-width: 0;
}

.list-header-ios {
  padding-left: 16px;
  padding-left: 16px;
  position: relative;
  border-bottom: 0.55px solid #c8c7cc;
  font-size: 1.2rem;
  font-weight: 500;
  letter-spacing: 0.1rem;
  text-transform: uppercase;
  color: #333;
  background: transparent;
}

@media screen and (orientation: landscape) {
  .list-header-ios {
    padding-left: calc(constant(safe-area-inset-left) + 16px);
    padding-left: calc(env(safe-area-inset-left) + 16px);
  }
}

.list-header-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.list-header-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.list-header-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.list-header-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.list-header-ios-dark {
  color: #fff;
  background-color: #222;
}

.list-md {
  margin: -1px 0 16px;
}

.list-md .item-block .item-inner {
  border-bottom: 1px solid #dedede;
}

.list-md > .item-block:last-child ion-label,
.list-md > .item-block:last-child .item-inner,
.list-md > .item-wrapper:last-child ion-label,
.list-md > .item-wrapper:last-child .item-inner {
  border-bottom: 0;
}

.list-md > ion-input:last-child::after {
  left: 0;
}

.list-md ion-item-options {
  border-bottom: 1px solid #dedede;
}

.list-md ion-item-options .button {
  margin: 0;
  border-radius: 0;
  display: -webkit-inline-box;
  display: -webkit-inline-flex;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  height: 100%;
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.list-md ion-item-options .button::before {
  margin: 0 auto;
}

.list-md .item[no-lines],
.list-md .item[no-lines] .item-inner {
  border-width: 0;
}

.list-md + ion-list ion-list-header {
  margin-top: -16px;
}

.list-md[inset] {
  margin: 16px;
  border-radius: 2px;
}

.list-md[inset] .item:first-child {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
  border-top-width: 0;
}

.list-md[inset] .item:last-child {
  border-bottom-right-radius: 2px;
  border-bottom-left-radius: 2px;
  border-bottom-width: 0;
}

.list-md[inset] .item-input {
  padding-left: 0;
  padding-right: 0;
}

.list-md[inset] + ion-list[inset] {
  margin-top: 0;
}

.list-md[inset] ion-list-header {
  background-color: #fff;
}

.list-md[no-lines] .item-block,
.list-md[no-lines] ion-item-options,
.list-md[no-lines] .item .item-inner {
  border-width: 0;
}

.list-header-md {
  padding-left: 16px;
  margin-bottom: 13px;
  min-height: 4.5rem;
  border-top: 1px solid #dedede;
  font-size: 1.4rem;
  color: #757575;
}

.list-header-md-primary {
  color: #fff;
  background-color: #488aff;
}

.list-header-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.list-header-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.list-header-md-light {
  color: #000;
  background-color: #f4f4f4;
}

.list-header-md-dark {
  color: #fff;
  background-color: #222;
}

.list-md .item-input:last-child {
  border-bottom: 1px solid #dedede;
}

.list-wp {
  margin: 0 0 16px;
}

.list-wp .item-block .item-inner {
  border-bottom: 1px solid transparent;
}

.list-wp > .item-block:first-child,
.list-wp > .item-wrapper:first-child .item-block {
  border-top: 1px solid transparent;
}

.list-wp > .item-block:last-child,
.list-wp > .item-wrapper:last-child .item-block {
  border-bottom: 1px solid transparent;
}

.list-wp > .item-block:last-child ion-label,
.list-wp > .item-block:last-child .item-inner,
.list-wp > .item-wrapper:last-child ion-label,
.list-wp > .item-wrapper:last-child .item-inner {
  border-bottom: 0;
}

.list-wp > ion-input:last-child::after {
  left: 0;
}

.list-wp ion-item-options .button {
  margin: 1px 0;
  border-radius: 0;
  display: -webkit-inline-box;
  display: -webkit-inline-flex;
  display: -ms-inline-flexbox;
  display: inline-flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  height: calc(100% - 2px);
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.list-wp ion-item-options .button::before {
  margin: 0 auto;
}

.list-wp .item[no-lines],
.list-wp .item[no-lines] .item-inner {
  border-width: 0;
}

.list-wp + ion-list ion-list-header {
  margin-top: -16px;
  padding-top: 0;
}

.list-wp[inset] {
  margin: 16px;
  border-radius: 2px;
}

.list-wp[inset] .item:first-child {
  border-top-left-radius: 2px;
  border-top-right-radius: 2px;
  border-top-width: 0;
}

.list-wp[inset] .item:last-child {
  border-bottom-right-radius: 2px;
  border-bottom-left-radius: 2px;
  border-bottom-width: 0;
}

.list-wp[inset] .item-input {
  padding-left: 0;
  padding-right: 0;
}

.list-wp[inset] + ion-list[inset] {
  margin-top: 0;
}

.list-wp[inset] ion-list-header {
  background-color: #fff;
}

.list-wp[no-lines] .item,
.list-wp[no-lines] .item .item-inner {
  border-width: 0;
}

.list-header-wp {
  padding-left: 16px;
  border-bottom: 1px solid transparent;
  font-size: 2rem;
  color: #000;
}

.list-header-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.list-header-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.list-header-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.list-header-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.list-header-wp-dark {
  color: #fff;
  background-color: #222;
}

ion-loading {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  z-index: 1000;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  contain: strict;
}

.loading-wrapper {
  z-index: 10;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  opacity: 0;
}

.loading-ios .loading-wrapper {
  border-radius: 8px;
  max-width: 270px;
  max-height: 90%;
  color: #000;
  background: #f8f8f8;
  padding: 24px 34px;
}

.loading-ios .loading-content {
  font-weight: bold;
}

.loading-ios .loading-spinner + .loading-content {
  margin-left: 16px;
}

.loading-ios .spinner-ios line,
.loading-ios .spinner-ios-small line {
  stroke: #69717d;
}

.loading-ios .spinner-bubbles circle {
  fill: #69717d;
}

.loading-ios .spinner-circles circle {
  fill: #69717d;
}

.loading-ios .spinner-crescent circle {
  stroke: #69717d;
}

.loading-ios .spinner-dots circle {
  fill: #69717d;
}

.loading-md .loading-wrapper {
  border-radius: 2px;
  max-width: 280px;
  max-height: 90%;
  color: rgba(0, 0, 0, 0.5);
  background: #fafafa;
  -webkit-box-shadow: 0 16px 20px rgba(0, 0, 0, 0.4);
  box-shadow: 0 16px 20px rgba(0, 0, 0, 0.4);
  padding: 24px;
}

.loading-md .loading-spinner + .loading-content {
  margin-left: 16px;
}

.loading-md .spinner-ios line,
.loading-md .spinner-ios-small line {
  stroke: #488aff;
}

.loading-md .spinner-bubbles circle {
  fill: #488aff;
}

.loading-md .spinner-circles circle {
  fill: #488aff;
}

.loading-md .spinner-crescent circle {
  stroke: #488aff;
}

.loading-md .spinner-dots circle {
  fill: #488aff;
}

.loading-wp .loading-wrapper {
  border-radius: 2px;
  max-width: 280px;
  max-height: 90%;
  color: #fff;
  background: #000;
  padding: 20px;
}

.loading-wp .loading-spinner + .loading-content {
  margin-left: 16px;
}

.loading-wp .spinner-ios line,
.loading-wp .spinner-ios-small line {
  stroke: #fff;
}

.loading-wp .spinner-bubbles circle {
  fill: #fff;
}

.loading-wp .spinner-circles circle {
  fill: #fff;
}

.loading-wp .spinner-crescent circle {
  stroke: #fff;
}

.loading-wp .spinner-dots circle {
  fill: #fff;
}

ion-menu {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  display: none;
  contain: strict;
}

ion-menu.show-menu {
  display: block;
}

.menu-inner {
  left: 0;
  right: auto;
  top: 0;
  bottom: 0;
  -webkit-transform: translate3d(-9999px,  0,  0);
  transform: translate3d(-9999px,  0,  0);
  position: absolute;
  display: block;
  width: 304px;
  height: 100%;
  contain: strict;
}

.menu-inner > ion-header,
.menu-inner > ion-content,
.menu-inner > ion-footer {
  position: absolute;
}

ion-menu[side=left] > .menu-inner {
  right: auto;
  left: 0;
}

ion-menu[side=right] > .menu-inner {
  right: 0;
  left: auto;
}

ion-menu[side=end] > .menu-inner {
  left: auto;
  right: 0;
}

ion-menu ion-backdrop {
  z-index: -1;
  display: none;
  opacity: .01;
}

.menu-content {
  -webkit-transform: translate3d(0,  0,  0);
  transform: translate3d(0,  0,  0);
}

.menu-content-open {
  cursor: pointer;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
}

.menu-content-open ion-pane,
.menu-content-open ion-content,
.menu-content-open .toolbar {
  pointer-events: none;
}

@media (max-width: 340px) {
  .menu-inner {
    width: 264px;
  }
}

ion-menu[type=reveal] {
  z-index: 0;
}

ion-menu[type=reveal].show-menu .menu-inner {
  -webkit-transform: translate3d(0,  0,  0);
  transform: translate3d(0,  0,  0);
}

ion-menu[type=overlay] {
  z-index: 80;
}

ion-menu[type=overlay] .show-backdrop {
  display: block;
}

.ios .menu-inner {
  background: #fff;
}

.ios .menu-content-reveal {
  -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
}

.ios .menu-content-push {
  -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
}

.ios ion-menu[type=overlay] .menu-inner {
  -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
}

.md .menu-inner {
  background: #fff;
}

.md .menu-content-reveal {
  -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
}

.md .menu-content-push {
  -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
}

.md ion-menu[type=overlay] .menu-inner {
  -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
}

.wp .menu-inner {
  background: #f2f2f2;
}

ion-modal {
  left: 0;
  top: 0;
  position: absolute;
  display: block;
  width: 100%;
  height: 100%;
  contain: strict;
}

@media not all and (min-width: 768px) and (min-height: 600px) {
  ion-modal ion-backdrop {
    visibility: hidden;
  }
}

.modal-wrapper {
  z-index: 10;
  height: 100%;
  contain: strict;
}

@media only screen and (min-width: 768px) and (min-height: 600px) {
  .modal-wrapper {
    left: calc(50% - (600px/2));
    top: calc(50% - (500px/2));
    position: absolute;
    width: 600px;
    height: 500px;
  }
}

@media only screen and (min-width: 768px) and (min-height: 768px) {
  .modal-wrapper {
    left: calc(50% - (600px/2));
    top: calc(50% - (600px/2));
    position: absolute;
    width: 600px;
    height: 600px;
  }
}

.ios .modal-wrapper {
  -webkit-transform: translate3d(0,  100%,  0);
  transform: translate3d(0,  100%,  0);
}

@media only screen and (min-width: 768px) and (min-height: 600px) {
  .ios .modal-wrapper {
    border-radius: 10px;
    overflow: hidden;
  }
}

.md .modal-wrapper {
  -webkit-transform: translate3d(0,  40px,  0);
  transform: translate3d(0,  40px,  0);
  opacity: .01;
}

@media only screen and (min-width: 768px) and (min-height: 600px) {
  .md .modal-wrapper {
    border-radius: 2px;
    overflow: hidden;
    -webkit-box-shadow: 0 28px 48px rgba(0, 0, 0, 0.4);
    box-shadow: 0 28px 48px rgba(0, 0, 0, 0.4);
  }
}

.wp .modal-wrapper {
  -webkit-transform: translate3d(0,  40px,  0);
  transform: translate3d(0,  40px,  0);
  opacity: .01;
}

.note-ios {
  color: #aeacb4;
}

.note-ios-primary {
  color: #488aff;
}

.note-ios-secondary {
  color: #32db64;
}

.note-ios-danger {
  color: #f53d3d;
}

.note-ios-light {
  color: #f4f4f4;
}

.note-ios-dark {
  color: #222;
}

.note-md {
  color: #c5c5c5;
}

.note-md-primary {
  color: #488aff;
}

.note-md-secondary {
  color: #32db64;
}

.note-md-danger {
  color: #f53d3d;
}

.note-md-light {
  color: #f4f4f4;
}

.note-md-dark {
  color: #222;
}

.note-wp {
  color: rgba(0, 0, 0, 0.5);
}

.note-wp-primary {
  color: #488aff;
}

.note-wp-secondary {
  color: #32db64;
}

.note-wp-danger {
  color: #f53d3d;
}

.note-wp-light {
  color: #f4f4f4;
}

.note-wp-dark {
  color: #222;
}

ion-picker-cmp {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 1000;
  display: block;
  width: 100%;
  height: 100%;
  contain: strict;
}

.picker-toolbar {
  z-index: 1;
  width: 100%;
  contain: strict;
}

.picker-wrapper {
  left: 0;
  right: 0;
  bottom: 0;
  margin: auto;
  -webkit-transform: translate3d(0,  100%,  0);
  transform: translate3d(0,  100%,  0);
  position: absolute;
  z-index: 10;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  width: 100%;
  max-width: 500px;
  contain: strict;
}

.picker-columns {
  margin-bottom: constant(safe-area-inset-bottom);
  margin-bottom: env(safe-area-inset-bottom);
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  contain: strict;
}

.picker-col {
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  height: 100%;
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
  contain: content;
}

.picker-opts {
  position: relative;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  max-width: 100%;
}

.picker-prefix {
  text-align: right;
  text-align: end;
  position: relative;
  -webkit-box-flex: 2;
  -webkit-flex: 2;
  -ms-flex: 2;
  flex: 2;
  min-width: 45%;
  max-width: 50%;
  white-space: nowrap;
}

.picker-suffix {
  text-align: left;
  text-align: start;
  position: relative;
  -webkit-box-flex: 2;
  -webkit-flex: 2;
  -ms-flex: 2;
  flex: 2;
  min-width: 45%;
  max-width: 50%;
  white-space: nowrap;
}

.picker-opt {
  left: 0;
  top: 0;
  text-align: center;
  position: absolute;
  display: block;
  overflow: hidden;
  width: 100%;
  text-overflow: ellipsis;
  white-space: nowrap;
  will-change: transform;
  contain: strict;
}

.picker-opt.picker-opt-disabled {
  pointer-events: none;
}

.picker-opt-disabled {
  opacity: 0;
}

.picker-opts-left {
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

.picker-opts-right {
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
}

.picker-above-highlight,
.picker-below-highlight {
  display: none;
  pointer-events: none;
}

.picker-ios .picker-wrapper {
  height: 260px;
  border-top: 1px solid #c8c7cc;
  background: #fff;
}

.picker-ios .picker-toolbar {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  height: 44px;
  border-bottom: 0.55px solid #c8c7cc;
  background: #fff;
}

.picker-ios .picker-toolbar-button {
  text-align: right;
  text-align: end;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
}

.picker-ios .picker-toolbar-button:last-child .picker-button {
  font-weight: 600;
}

.picker-ios .picker-toolbar-cancel {
  text-align: left;
  text-align: start;
  font-weight: normal;
}

.picker-ios .picker-button,
.picker-ios .picker-button.activated {
  margin: 0;
  height: 44px;
  color: #488aff;
  background: transparent;
}

.picker-columns {
  height: 215px;
  -webkit-perspective: 1000px;
  perspective: 1000px;
}

.picker-ios .picker-col {
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  padding: 0 4px;
}

.picker-ios .picker-prefix,
.picker-ios .picker-suffix,
.picker-ios .picker-opts {
  top: 77px;
  font-size: 20px;
  line-height: 42px;
  color: #000;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  pointer-events: none;
}

.picker-ios .picker-opt {
  margin: 0;
  -webkit-transform-origin: center center;
  transform-origin: center center;
  height: 4.6rem;
  font-size: 20px;
  line-height: 42px;
  color: #000;
  background: transparent;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  -webkit-transition-timing-function: ease-out;
  transition-timing-function: ease-out;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  pointer-events: auto;
  padding: 0;
}

.picker-ios .picker-above-highlight {
  left: 0;
  top: 0;
  -webkit-transform: translate3d(0,  0,  90px);
  transform: translate3d(0,  0,  90px);
  position: absolute;
  z-index: 10;
  display: block;
  width: 100%;
  height: 81px;
  border-bottom: 1px solid #c8c7cc;
  background: -webkit-gradient(linear, left top, left bottom, color-stop(20%, white), to(rgba(255, 255, 255, 0.7)));
  background: linear-gradient(to bottom, white 20%, rgba(255, 255, 255, 0.7) 100%);
}

.picker-ios .picker-below-highlight {
  left: 0;
  top: 115px;
  -webkit-transform: translate3d(0,  0,  90px);
  transform: translate3d(0,  0,  90px);
  position: absolute;
  z-index: 11;
  display: block;
  width: 100%;
  height: 119px;
  border-top: 1px solid #c8c7cc;
  background: -webkit-gradient(linear, left bottom, left top, color-stop(30%, white), to(rgba(255, 255, 255, 0.7)));
  background: linear-gradient(to top, white 30%, rgba(255, 255, 255, 0.7) 100%);
}

.picker-md .picker-wrapper {
  height: 260px;
  border-top: 0.55px solid #dedede;
  background: #fff;
}

.picker-md .picker-toolbar {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  height: 44px;
  background: #fff;
}

.picker-md .picker-button,
.picker-md .picker-button.activated {
  margin: 0;
  height: 44px;
  color: #488aff;
  background: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.picker-md .picker-columns {
  height: 216px;
  -webkit-perspective: 1800px;
  perspective: 1800px;
}

.picker-md .picker-col {
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  padding: 0 8px;
}

.picker-md .picker-prefix,
.picker-md .picker-suffix,
.picker-md .picker-opts {
  top: 77px;
  font-size: 22px;
  line-height: 42px;
  color: #000;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  pointer-events: none;
}

.picker-md .picker-opt {
  margin: 0;
  height: 4.3rem;
  font-size: 22px;
  line-height: 42px;
  color: #000;
  background: transparent;
  -webkit-transition-timing-function: ease-out;
  transition-timing-function: ease-out;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  pointer-events: auto;
  padding: 0;
}

.picker-md .picker-prefix,
.picker-md .picker-suffix,
.picker-md .picker-opt.picker-opt-selected {
  color: #488aff;
}

.picker-md .picker-above-highlight {
  left: 0;
  top: 0;
  -webkit-transform: translate3d(0,  0,  90px);
  transform: translate3d(0,  0,  90px);
  position: absolute;
  z-index: 10;
  width: 100%;
  height: 81px;
  border-bottom: 1px solid #dedede;
  background: -webkit-gradient(linear, left top, left bottom, color-stop(20%, white), to(rgba(255, 255, 255, 0.7)));
  background: linear-gradient(to bottom, white 20%, rgba(255, 255, 255, 0.7) 100%);
}

.picker-md .picker-below-highlight {
  left: 0;
  top: 115px;
  -webkit-transform: translate3d(0,  0,  90px);
  transform: translate3d(0,  0,  90px);
  position: absolute;
  z-index: 11;
  width: 100%;
  height: 119px;
  border-top: 1px solid #dedede;
  background: -webkit-gradient(linear, left bottom, left top, color-stop(30%, white), to(rgba(255, 255, 255, 0.7)));
  background: linear-gradient(to top, white 30%, rgba(255, 255, 255, 0.7) 100%);
}

.picker-wp .picker-wrapper {
  height: 260px;
  border-top: 0.55px solid transparent;
  background: #fff;
}

.picker-wp .picker-toolbar {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: end;
  -webkit-justify-content: flex-end;
  -ms-flex-pack: end;
  justify-content: flex-end;
  height: 44px;
  border-width: 0.55px;
  background: #fff;
}

.picker-wp .picker-toolbar-button {
  text-align: right;
  text-align: end;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
}

.picker-wp .picker-toolbar-cancel {
  text-align: left;
  text-align: start;
  font-weight: normal;
}

.picker-wp .picker-button,
.picker-wp .picker-button.activated {
  margin: 0;
  height: 44px;
  color: #488aff;
  background: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.picker-wp .picker-columns {
  height: 216px;
  -webkit-perspective: 1800px;
  perspective: 1800px;
}

.picker-wp .picker-col {
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  padding: 0 4px;
}

.picker-wp .picker-prefix,
.picker-wp .picker-suffix,
.picker-wp .picker-opts {
  top: 77px;
  font-size: 22px;
  line-height: 42px;
  color: #000;
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
  pointer-events: none;
}

.picker-wp .picker-opt {
  margin: 0;
  height: 4.2rem;
  font-size: 22px;
  line-height: 42px;
  color: #000;
  background: transparent;
  -webkit-transition-timing-function: ease-out;
  transition-timing-function: ease-out;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  pointer-events: auto;
  padding: 0;
}

.picker-wp .picker-prefix,
.picker-wp .picker-suffix,
.picker-wp .picker-opt-selected {
  color: #488aff;
}

.picker-wp .picker-above-highlight {
  left: 0;
  top: 0;
  -webkit-transform: translate3d(0,  0,  90px);
  transform: translate3d(0,  0,  90px);
  position: absolute;
  z-index: 10;
  width: 100%;
  height: 81px;
  border-bottom: 1px solid transparent;
  background: -webkit-gradient(linear, left top, left bottom, color-stop(20%, white), to(rgba(255, 255, 255, 0.7)));
  background: linear-gradient(to bottom, white 20%, rgba(255, 255, 255, 0.7) 100%);
}

.picker-wp .picker-below-highlight {
  left: 0;
  top: 115px;
  -webkit-transform: translate3d(0,  0,  90px);
  transform: translate3d(0,  0,  90px);
  position: absolute;
  z-index: 11;
  width: 100%;
  height: 119px;
  border-top: 1px solid transparent;
  background: -webkit-gradient(linear, left bottom, left top, color-stop(30%, white), to(rgba(255, 255, 255, 0.7)));
  background: linear-gradient(to top, white 30%, rgba(255, 255, 255, 0.7) 100%);
}

ion-popover {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  z-index: 1000;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

.popover-wrapper {
  z-index: 10;
  opacity: 0;
}

.popover-content {
  position: absolute;
  z-index: 10;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: auto;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

.popover-content ion-content,
.popover-content .scroll-content {
  contain: none;
}

.popover-content .scroll-content {
  position: relative;
}

.popover-ios .popover-content {
  border-radius: 10px;
  width: 200px;
  min-width: 0;
  min-height: 0;
  max-height: 90%;
  color: #000;
  background: #fff;
}

.popover-ios .popover-arrow {
  position: absolute;
  display: block;
  overflow: hidden;
  width: 20px;
  height: 10px;
}

.popover-ios .popover-arrow::after {
  left: 3px;
  top: 3px;
  border-radius: 3px;
  position: absolute;
  z-index: 10;
  width: 14px;
  height: 14px;
  background-color: #fff;
  content: "";
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.popover-ios.popover-bottom .popover-arrow {
  top: auto;
  bottom: -10px;
}

.popover-ios.popover-bottom .popover-arrow::after {
  top: -6px;
}

.popover-ios .item-ios {
  padding-left: 16px;
}

.popover-ios .item-ios[detail-push] .item-inner,
.popover-ios button.item-ios:not([detail-none]) .item-inner,
.popover-ios a.item-ios:not([detail-none]) .item-inner {
  background-position: right 14px center;
}

.popover-md .popover-content {
  border-radius: 2px;
  -webkit-transform-origin: left top;
  transform-origin: left top;
  width: 250px;
  min-width: 0;
  min-height: 0;
  max-height: 90%;
  color: #000;
  background: #fff;
  -webkit-box-shadow: 0 3px 12px 2px rgba(0, 0, 0, 0.3);
  box-shadow: 0 3px 12px 2px rgba(0, 0, 0, 0.3);
}

.popover-md .popover-viewport {
  opacity: 0;
  -webkit-transition-delay: 100ms;
  transition-delay: 100ms;
}

.popover-wp .popover-content {
  border-radius: 0;
  -webkit-transform-origin: left top;
  transform-origin: left top;
  width: 200px;
  min-width: 0;
  min-height: 0;
  max-height: 90%;
  border: 2px solid #ccc;
  color: #000;
  background: #fff;
}

.popover-wp .popover-viewport {
  opacity: 0;
  -webkit-transition-delay: 100ms;
  transition-delay: 100ms;
}

.radio-ios {
  position: relative;
  display: inline-block;
}

.radio-ios .radio-icon {
  position: relative;
  display: block;
  width: 16px;
  height: 21px;
}

.radio-ios .radio-checked .radio-inner {
  left: 7px;
  top: 4px;
  position: absolute;
  width: 5px;
  height: 12px;
  border-width: 2px;
  border-top-width: 0;
  border-left-width: 0;
  border-style: solid;
  border-color: #488aff;
  -webkit-transform: rotate(45deg);
  transform: rotate(45deg);
}

.radio-ios.radio-disabled,
.item-ios.item-radio-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.item-ios .radio-ios {
  position: static;
  display: block;
  margin: 8px 11px 8px 8px;
}

.item-ios .radio-ios[item-left], .item-ios .radio-ios[item-start] {
  margin: 8px 21px 8px 3px;
}

.item-radio.item-ios ion-label {
  margin-left: 0;
}

.item-radio-checked.item-ios ion-label {
  color: #488aff;
}

.item-radio-ios-primary.item-radio-checked ion-label {
  color: #488aff;
}

.radio-ios-primary .radio-checked {
  color: #488aff;
}

.radio-ios-primary .radio-checked .radio-inner {
  border-color: #488aff;
}

.item-radio-ios-secondary.item-radio-checked ion-label {
  color: #32db64;
}

.radio-ios-secondary .radio-checked {
  color: #32db64;
}

.radio-ios-secondary .radio-checked .radio-inner {
  border-color: #32db64;
}

.item-radio-ios-danger.item-radio-checked ion-label {
  color: #f53d3d;
}

.radio-ios-danger .radio-checked {
  color: #f53d3d;
}

.radio-ios-danger .radio-checked .radio-inner {
  border-color: #f53d3d;
}

.item-radio-ios-light.item-radio-checked ion-label {
  color: #f4f4f4;
}

.radio-ios-light .radio-checked {
  color: #f4f4f4;
}

.radio-ios-light .radio-checked .radio-inner {
  border-color: #f4f4f4;
}

.item-radio-ios-dark.item-radio-checked ion-label {
  color: #222;
}

.radio-ios-dark .radio-checked {
  color: #222;
}

.radio-ios-dark .radio-checked .radio-inner {
  border-color: #222;
}

.radio-md {
  position: relative;
  display: inline-block;
}

.radio-md .radio-icon {
  left: 0;
  top: 0;
  margin: 0;
  border-radius: 50%;
  position: relative;
  display: block;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: #787878;
}

.radio-md .radio-inner {
  left: 2px;
  top: 2px;
  border-radius: 50%;
  position: absolute;
  width: 8px;
  height: 8px;
  background-color: #488aff;
  -webkit-transform: scale3d(0, 0, 0);
  transform: scale3d(0, 0, 0);
  -webkit-transition: -webkit-transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: -webkit-transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
  transition: transform 280ms cubic-bezier(0.4, 0, 0.2, 1), -webkit-transform 280ms cubic-bezier(0.4, 0, 0.2, 1);
}

.radio-md .radio-checked {
  border-color: #488aff;
}

.radio-md .radio-checked .radio-inner {
  -webkit-transform: scale3d(1, 1, 1);
  transform: scale3d(1, 1, 1);
}

.radio-md.radio-disabled,
.item-md.item-radio-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.item-md .radio-md {
  position: static;
  display: block;
  margin: 9px 10px 9px 0;
}

.item-md .radio-md[item-left], .item-md .radio-md[item-start] {
  margin: 11px 36px 10px 4px;
}

.item-radio.item-md ion-label {
  margin-left: 0;
}

.item-radio-checked.item-md ion-label {
  color: #488aff;
}

.item-radio-md-primary.item-radio-checked ion-label {
  color: #488aff;
}

.radio-md-primary .radio-checked {
  border-color: #488aff;
}

.radio-md-primary .radio-inner {
  background-color: #488aff;
}

.item-radio-md-secondary.item-radio-checked ion-label {
  color: #32db64;
}

.radio-md-secondary .radio-checked {
  border-color: #32db64;
}

.radio-md-secondary .radio-inner {
  background-color: #32db64;
}

.item-radio-md-danger.item-radio-checked ion-label {
  color: #f53d3d;
}

.radio-md-danger .radio-checked {
  border-color: #f53d3d;
}

.radio-md-danger .radio-inner {
  background-color: #f53d3d;
}

.item-radio-md-light.item-radio-checked ion-label {
  color: #f4f4f4;
}

.radio-md-light .radio-checked {
  border-color: #f4f4f4;
}

.radio-md-light .radio-inner {
  background-color: #f4f4f4;
}

.item-radio-md-dark.item-radio-checked ion-label {
  color: #222;
}

.radio-md-dark .radio-checked {
  border-color: #222;
}

.radio-md-dark .radio-inner {
  background-color: #222;
}

.radio-wp {
  position: relative;
  display: inline-block;
}

.radio-wp .radio-icon {
  left: 0;
  top: 0;
  margin: 0;
  border-radius: 50%;
  position: relative;
  display: block;
  width: 16px;
  height: 16px;
  border-width: 2px;
  border-style: solid;
  border-color: #333;
}

.radio-wp .radio-inner {
  left: 2px;
  top: 2px;
  border-radius: 50%;
  position: absolute;
  display: none;
  width: 8px;
  height: 8px;
  background-color: #333;
}

.radio-wp .radio-checked {
  border-color: #488aff;
}

.radio-wp .radio-checked .radio-inner {
  display: block;
}

.radio-wp.radio-disabled,
.item-wp.item-radio-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.item-wp .radio-wp {
  position: static;
  display: block;
  -webkit-box-ordinal-group: 0;
  -webkit-order: -1;
  -ms-flex-order: -1;
  order: -1;
  margin: 9px 20px 9px 4px;
}

.item-wp .radio-wp[item-right], .item-wp .radio-wp[item-end] {
  -webkit-box-ordinal-group: 1;
  -webkit-order: 0;
  -ms-flex-order: 0;
  order: 0;
  margin: 11px 10px 10px 0;
}

.item-radio.item-wp ion-label {
  margin-left: 0;
}

.radio-wp-primary .radio-checked {
  border-color: #488aff;
}

.radio-wp-secondary .radio-checked {
  border-color: #32db64;
}

.radio-wp-danger .radio-checked {
  border-color: #f53d3d;
}

.radio-wp-light .radio-checked {
  border-color: #f4f4f4;
}

.radio-wp-dark .radio-checked {
  border-color: #222;
}

.item-range .item-inner {
  overflow: visible;
  width: 100%;
}

.item-range .input-wrapper {
  overflow: visible;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  width: 100%;
}

.item-range ion-range {
  width: 100%;
}

.item-range ion-range ion-label {
  -webkit-align-self: center;
  -ms-flex-item-align: center;
  align-self: center;
}

ion-range {
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

ion-range ion-label {
  -webkit-box-flex: initial;
  -webkit-flex: initial;
  -ms-flex: initial;
  flex: initial;
}

ion-range ion-icon {
  min-height: 2.4rem;
  font-size: 2.4rem;
  line-height: 1;
}

.range-slider {
  position: relative;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  cursor: pointer;
}

.range-ios {
  padding: 8px 16px;
}

.range-ios [range-left] {
  margin: 0 20px 0 0;
}

.range-ios [range-right] {
  margin: 0 0 0 20px;
}

.range-ios.range-has-pin {
  padding-top: 20px;
}

.range-ios .range-slider {
  height: 42px;
}

.range-ios .range-bar {
  left: 0;
  top: 21px;
  border-radius: 1px;
  position: absolute;
  width: 100%;
  height: 1px;
  background: #bdbdbd;
  pointer-events: none;
}

.range-ios.range-pressed .range-bar-active {
  will-change: left, right;
}

.range-ios.range-pressed .range-knob-handle {
  will-change: left;
}

.range-ios .range-bar-active {
  bottom: 0;
  width: auto;
  background: #488aff;
}

.range-ios .range-knob-handle {
  left: 0;
  top: 21px;
  margin-left: -21px;
  margin-top: -21px;
  text-align: center;
  position: absolute;
  width: 42px;
  height: 42px;
}

.range-ios .range-knob {
  left: 7px;
  top: 7px;
  border-radius: 50%;
  position: absolute;
  width: 28px;
  height: 28px;
  background: #fff;
  -webkit-box-shadow: 0 3px 1px rgba(0, 0, 0, 0.1), 0 4px 8px rgba(0, 0, 0, 0.13), 0 0 0 1px rgba(0, 0, 0, 0.02);
  box-shadow: 0 3px 1px rgba(0, 0, 0, 0.1), 0 4px 8px rgba(0, 0, 0, 0.13), 0 0 0 1px rgba(0, 0, 0, 0.02);
  pointer-events: none;
}

.range-ios .range-tick {
  margin-left: -0.5px;
  border-radius: 0;
  position: absolute;
  top: 17.5px;
  width: 1px;
  height: 8px;
  background: #bdbdbd;
  pointer-events: none;
}

.range-ios .range-tick-active {
  background: #488aff;
}

.range-ios .range-pin {
  text-align: center;
  border-radius: 50px;
  -webkit-transform: translate3d(0,  28px,  0) scale(0.01);
  transform: translate3d(0,  28px,  0) scale(0.01);
  position: relative;
  top: -20px;
  display: inline-block;
  min-width: 28px;
  font-size: 12px;
  color: #000;
  background: transparent;
  -webkit-transition: -webkit-transform 120ms ease;
  transition: -webkit-transform 120ms ease;
  transition: transform 120ms ease;
  transition: transform 120ms ease, -webkit-transform 120ms ease;
  padding: 8px;
}

.range-ios .range-knob-pressed .range-pin {
  -webkit-transform: translate3d(0,  0,  0) scale(1);
  transform: translate3d(0,  0,  0) scale(1);
}

.range-ios.range-disabled {
  opacity: .5;
}

.range-ios-primary .range-bar-active,
.range-ios-primary .range-tick-active {
  background: #488aff;
}

.range-ios-secondary .range-bar-active,
.range-ios-secondary .range-tick-active {
  background: #32db64;
}

.range-ios-danger .range-bar-active,
.range-ios-danger .range-tick-active {
  background: #f53d3d;
}

.range-ios-light .range-bar-active,
.range-ios-light .range-tick-active {
  background: #f4f4f4;
}

.range-ios-dark .range-bar-active,
.range-ios-dark .range-tick-active {
  background: #222;
}

.range-md {
  padding: 8px;
}

.range-md [range-left] {
  margin: 0 12px 0 0;
}

.range-md [range-right] {
  margin: 0 0 0 12px;
}

.range-md.range-has-pin {
  padding-top: 28px;
}

.range-md .range-slider {
  height: 42px;
}

.range-md .range-bar {
  left: 0;
  top: 21px;
  position: absolute;
  width: 100%;
  height: 2px;
  background: #bdbdbd;
  pointer-events: none;
}

.range-md.range-pressed .range-bar-active {
  will-change: left, right;
}

.range-md.range-pressed .range-knob-handle {
  will-change: left;
}

.range-md .range-bar-active {
  bottom: 0;
  width: auto;
  background: #488aff;
}

.range-md .range-knob-handle {
  left: 0;
  top: 21px;
  margin-left: -21px;
  margin-top: -21px;
  text-align: center;
  position: absolute;
  width: 42px;
  height: 42px;
}

.range-md .range-knob {
  left: 12px;
  top: 13px;
  border-radius: 50%;
  position: absolute;
  z-index: 2;
  width: 18px;
  height: 18px;
  background: #488aff;
  -webkit-transform: scale(0.67);
  transform: scale(0.67);
  -webkit-transition-duration: 120ms;
  transition-duration: 120ms;
  -webkit-transition-property: background-color, border, -webkit-transform;
  transition-property: background-color, border, -webkit-transform;
  transition-property: transform, background-color, border;
  transition-property: transform, background-color, border, -webkit-transform;
  -webkit-transition-timing-function: ease;
  transition-timing-function: ease;
  pointer-events: none;
}

.range-md .range-tick {
  margin-left: -1px;
  border-radius: 50%;
  position: absolute;
  top: 21px;
  z-index: 1;
  width: 2px;
  height: 2px;
  background: #000;
  pointer-events: none;
}

.range-md .range-tick-active {
  background: #000;
}

.range-md .range-pin {
  padding: 8px 0;
  text-align: center;
  border-radius: 50%;
  -webkit-transform: translate3d(0,  28px,  0) scale(0.01);
  transform: translate3d(0,  28px,  0) scale(0.01);
  position: relative;
  top: -20px;
  display: inline-block;
  min-width: 28px;
  height: 28px;
  font-size: 12px;
  color: #fff;
  background: #488aff;
  -webkit-transition: background-color 120ms ease, -webkit-transform 120ms ease;
  transition: background-color 120ms ease, -webkit-transform 120ms ease;
  transition: transform 120ms ease, background-color 120ms ease;
  transition: transform 120ms ease, background-color 120ms ease, -webkit-transform 120ms ease;
}

.range-md .range-pin::before {
  left: 50%;
  top: 3px;
  border-top-left-radius: 50%;
  border-top-right-radius: 50%;
  border-bottom-right-radius: 50%;
  border-bottom-left-radius: 0;
  margin-left: -13px;
  position: absolute;
  z-index: -1;
  width: 26px;
  height: 26px;
  background: #488aff;
  content: "";
  -webkit-transform: rotate(-45deg);
  transform: rotate(-45deg);
  -webkit-transition: background-color 120ms ease;
  transition: background-color 120ms ease;
}

.range-md .range-knob-pressed .range-pin {
  -webkit-transform: translate3d(0,  0,  0) scale(1);
  transform: translate3d(0,  0,  0) scale(1);
}

.range-md:not(.range-has-pin) .range-knob-pressed .range-knob {
  -webkit-transform: scale(1);
  transform: scale(1);
}

.range-md .range-knob-min.range-knob-min .range-knob {
  border: 2px solid #bdbdbd;
  background: #fff;
}

.range-md .range-knob-min.range-knob-min .range-pin,
.range-md .range-knob-min.range-knob-min .range-pin::before {
  color: #fff;
  background: #bdbdbd;
}

.range-md.range-disabled .range-bar-active {
  background-color: #bdbdbd;
}

.range-md.range-disabled .range-knob {
  outline: 5px solid #fff;
  background-color: #bdbdbd;
  -webkit-transform: scale(0.55);
  transform: scale(0.55);
}

.range-md-primary .range-md .range-knob-min.range-knob-min .range-knob {
  border: 2px solid #bdbdbd;
  background: #fff;
}

.range-md-primary .range-md .range-knob-min.range-knob-min .range-pin,
.range-md-primary .range-md .range-knob-min.range-knob-min .range-pin::before {
  color: #fff;
  background: #bdbdbd;
}

.range-md-primary .range-bar-active,
.range-md-primary .range-knob,
.range-md-primary .range-pin,
.range-md-primary .range-pin::before {
  background: #488aff;
}

.range-md-secondary .range-md .range-knob-min.range-knob-min .range-knob {
  border: 2px solid #bdbdbd;
  background: #fff;
}

.range-md-secondary .range-md .range-knob-min.range-knob-min .range-pin,
.range-md-secondary .range-md .range-knob-min.range-knob-min .range-pin::before {
  color: #fff;
  background: #bdbdbd;
}

.range-md-secondary .range-bar-active,
.range-md-secondary .range-knob,
.range-md-secondary .range-pin,
.range-md-secondary .range-pin::before {
  background: #32db64;
}

.range-md-danger .range-md .range-knob-min.range-knob-min .range-knob {
  border: 2px solid #bdbdbd;
  background: #fff;
}

.range-md-danger .range-md .range-knob-min.range-knob-min .range-pin,
.range-md-danger .range-md .range-knob-min.range-knob-min .range-pin::before {
  color: #fff;
  background: #bdbdbd;
}

.range-md-danger .range-bar-active,
.range-md-danger .range-knob,
.range-md-danger .range-pin,
.range-md-danger .range-pin::before {
  background: #f53d3d;
}

.range-md-light .range-md .range-knob-min.range-knob-min .range-knob {
  border: 2px solid #bdbdbd;
  background: #fff;
}

.range-md-light .range-md .range-knob-min.range-knob-min .range-pin,
.range-md-light .range-md .range-knob-min.range-knob-min .range-pin::before {
  color: #fff;
  background: #bdbdbd;
}

.range-md-light .range-bar-active,
.range-md-light .range-knob,
.range-md-light .range-pin,
.range-md-light .range-pin::before {
  background: #f4f4f4;
}

.range-md-dark .range-md .range-knob-min.range-knob-min .range-knob {
  border: 2px solid #bdbdbd;
  background: #fff;
}

.range-md-dark .range-md .range-knob-min.range-knob-min .range-pin,
.range-md-dark .range-md .range-knob-min.range-knob-min .range-pin::before {
  color: #fff;
  background: #bdbdbd;
}

.range-md-dark .range-bar-active,
.range-md-dark .range-knob,
.range-md-dark .range-pin,
.range-md-dark .range-pin::before {
  background: #222;
}

.range-wp {
  padding: 8px;
}

.range-wp [range-left] {
  margin: 0 12px 0 0;
}

.range-wp [range-right] {
  margin: 0 0 0 12px;
}

.range-wp.range-has-pin {
  padding-top: 28px;
}

.range-wp .range-slider {
  height: 42px;
}

.range-wp .range-bar {
  left: 0;
  top: 21px;
  position: absolute;
  width: 100%;
  height: 2px;
  background: #bdbdbd;
  pointer-events: none;
}

.range-wp.range-pressed .range-bar-active {
  will-change: left, right;
}

.range-wp.range-pressed .range-knob-handle {
  will-change: left;
}

.range-wp .range-bar-active {
  bottom: 0;
  width: auto;
  background: #488aff;
}

.range-wp .range-knob-handle {
  left: 0;
  top: 21px;
  margin-left: -21px;
  margin-top: -21px;
  text-align: center;
  position: absolute;
  width: 42px;
  height: 42px;
}

.range-wp .range-knob {
  left: 17px;
  top: 10px;
  border-radius: 4px;
  position: absolute;
  width: 8px;
  height: 24px;
  background: #488aff;
  pointer-events: none;
}

.range-wp .range-tick {
  margin-left: -1px;
  border-radius: 4px;
  position: absolute;
  top: 19px;
  width: 2px;
  height: 6px;
  background: #bdbdbd;
  pointer-events: none;
}

.range-wp .range-tick-active {
  background: #488aff;
}

.range-wp .range-pin {
  text-align: center;
  border-radius: 50px;
  -webkit-transform: translate3d(0,  28px,  0) scale(0.01);
  transform: translate3d(0,  28px,  0) scale(0.01);
  position: relative;
  top: -24px;
  display: inline-block;
  min-width: 28px;
  font-size: 12px;
  color: #fff;
  background: #488aff;
  -webkit-transition: -webkit-transform 120ms ease;
  transition: -webkit-transform 120ms ease;
  transition: transform 120ms ease;
  transition: transform 120ms ease, -webkit-transform 120ms ease;
  padding: 8px;
}

.range-wp .range-knob-pressed .range-pin {
  -webkit-transform: translate3d(0,  0,  0) scale(1);
  transform: translate3d(0,  0,  0) scale(1);
}

.range-wp.range-disabled {
  opacity: .5;
}

.range-wp-primary .range-bar-active,
.range-wp-primary .range-tick-active,
.range-wp-primary .range-knob,
.range-wp-primary .range-pin {
  background: #488aff;
}

.range-wp-secondary .range-bar-active,
.range-wp-secondary .range-tick-active,
.range-wp-secondary .range-knob,
.range-wp-secondary .range-pin {
  background: #32db64;
}

.range-wp-danger .range-bar-active,
.range-wp-danger .range-tick-active,
.range-wp-danger .range-knob,
.range-wp-danger .range-pin {
  background: #f53d3d;
}

.range-wp-light .range-bar-active,
.range-wp-light .range-tick-active,
.range-wp-light .range-knob,
.range-wp-light .range-pin {
  background: #f4f4f4;
}

.range-wp-dark .range-bar-active,
.range-wp-dark .range-tick-active,
.range-wp-dark .range-knob,
.range-wp-dark .range-pin {
  background: #222;
}

ion-refresher {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 0;
  display: none;
  width: 100%;
  height: 60px;
}

ion-refresher.refresher-active {
  display: block;
}

.has-refresher > .scroll-content {
  margin-top: -1px;
  border-top: 1px solid #ddd;
  -webkit-transition: -webkit-transform 320ms cubic-bezier(0.36, 0.66, 0.04, 1);
  transition: -webkit-transform 320ms cubic-bezier(0.36, 0.66, 0.04, 1);
  transition: transform 320ms cubic-bezier(0.36, 0.66, 0.04, 1);
  transition: transform 320ms cubic-bezier(0.36, 0.66, 0.04, 1), -webkit-transform 320ms cubic-bezier(0.36, 0.66, 0.04, 1);
}

ion-refresher-content {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  height: 100%;
}

.refresher-pulling,
.refresher-refreshing {
  display: none;
  width: 100%;
}

.refresher-pulling-icon,
.refresher-refreshing-icon {
  text-align: center;
  -webkit-transform-origin: center;
  transform-origin: center;
  font-size: 30px;
  color: #000;
  -webkit-transition: 200ms;
  transition: 200ms;
}

.refresher-pulling-text,
.refresher-refreshing-text {
  text-align: center;
  font-size: 16px;
  color: #000;
}

.refresher-refreshing .spinner-ios line,
.refresher-refreshing .spinner-ios-small line,
.refresher-refreshing .spinner-crescent circle {
  stroke: #000;
}

.refresher-refreshing .spinner-bubbles circle,
.refresher-refreshing .spinner-circles circle,
.refresher-refreshing .spinner-dots circle {
  fill: #000;
}

ion-refresher-content[state=pulling] .refresher-pulling {
  display: block;
}

ion-refresher-content[state=ready] .refresher-pulling {
  display: block;
}

ion-refresher-content[state=ready] .refresher-pulling-icon {
  -webkit-transform: rotate(180deg);
  transform: rotate(180deg);
}

ion-refresher-content[state=refreshing] .refresher-refreshing {
  display: block;
}

ion-refresher-content[state=cancelling] .refresher-pulling {
  display: block;
}

ion-refresher-content[state=cancelling] .refresher-pulling-icon {
  -webkit-transform: scale(0);
  transform: scale(0);
}

ion-refresher-content[state=completing] .refresher-refreshing {
  display: block;
}

ion-refresher-content[state=completing] .refresher-refreshing-icon {
  -webkit-transform: scale(0);
  transform: scale(0);
}

ion-scroll {
  position: relative;
  display: block;
}

ion-scroll.scroll-x .scroll-content {
  overflow-x: auto;
}

ion-scroll.scroll-y .scroll-content {
  overflow-y: auto;
}

ion-scroll[center] .scroll-content {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
}

ion-scroll .scroll-content {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  overflow-y: hidden;
  overflow-x: hidden;
  -webkit-overflow-scrolling: touch;
  will-change: scroll-position;
}

ion-searchbar {
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  width: 100%;
}

.searchbar-icon {
  pointer-events: none;
}

.searchbar-input-container {
  position: relative;
  display: block;
  -webkit-flex-shrink: 1;
  -ms-flex-negative: 1;
  flex-shrink: 1;
  width: 100%;
}

.searchbar-input {
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  display: block;
  width: 100%;
  border: 0;
  font-family: inherit;
}

.searchbar-clear-icon {
  margin: 0;
  padding: 0;
  display: none;
  min-height: 0;
}

.searchbar-has-value.searchbar-has-focus .searchbar-clear-icon {
  display: block;
}

.searchbar-ios {
  padding: 0 8px;
  min-height: 44px;
  border-top: 0.55px solid transparent;
  border-bottom: 0.55px solid rgba(0, 0, 0, 0.05);
  background: rgba(0, 0, 0, 0.2);
}

.searchbar-ios .searchbar-search-icon {
  left: 9px;
  top: 9px;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%2013%2013'><path%20fill='rgba(0,%200,%200,%200.5)'%20d='M5,1c2.2,0,4,1.8,4,4S7.2,9,5,9S1,7.2,1,5S2.8,1,5,1%20M5,0C2.2,0,0,2.2,0,5s2.2,5,5,5s5-2.2,5-5S7.8,0,5,0%20L5,0z'/><line%20stroke='rgba(0,%200,%200,%200.5)'%20stroke-miterlimit='10'%20x1='12.6'%20y1='12.6'%20x2='8.2'%20y2='8.2'/></svg>");
  margin-left: calc(50% - 60px);
  position: absolute;
  width: 14px;
  height: 14px;
  background-repeat: no-repeat;
  background-size: 13px;
}

.searchbar-ios .searchbar-input {
  padding: 0 28px;
  border-radius: 5px;
  height: 3rem;
  font-size: 1.4rem;
  font-weight: 400;
  color: #000;
  background-color: #fff;
}

.searchbar-ios .searchbar-input::-moz-placeholder {
  color: rgba(0, 0, 0, 0.5);
}

.searchbar-ios .searchbar-input:-ms-input-placeholder {
  color: rgba(0, 0, 0, 0.5);
}

.searchbar-ios .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: rgba(0, 0, 0, 0.5);
}

.searchbar-ios .searchbar-clear-icon {
  right: 0;
  top: 0;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='rgba(0,%200,%200,%200.5)'%20d='M403.1,108.9c-81.2-81.2-212.9-81.2-294.2,0s-81.2,212.9,0,294.2c81.2,81.2,212.9,81.2,294.2,0S484.3,190.1,403.1,108.9z%20M352,340.2L340.2,352l-84.4-84.2l-84,83.8L160,339.8l84-83.8l-84-83.8l11.8-11.8l84,83.8l84.4-84.2l11.8,11.8L267.6,256L352,340.2z'/></svg>");
  background-position: center;
  position: absolute;
  width: 30px;
  height: 100%;
  background-repeat: no-repeat;
  background-size: 18px;
}

.searchbar-ios .searchbar-ios-cancel {
  padding: 0 0 0 8px;
  margin-left: 0;
  display: none;
  -webkit-flex-shrink: 0;
  -ms-flex-negative: 0;
  flex-shrink: 0;
  height: 30px;
  cursor: pointer;
}

.searchbar-ios.searchbar-left-aligned .searchbar-search-icon {
  margin-left: 0;
}

.searchbar-ios.searchbar-left-aligned .searchbar-input {
  padding-left: 30px;
}

.searchbar-ios.searchbar-show-cancel.searchbar-has-focus .searchbar-ios-cancel {
  display: block;
}

.toolbar .searchbar-ios {
  border-bottom-width: 0;
  background: transparent;
}

.toolbar .searchbar-ios .searchbar-input {
  background: rgba(0, 0, 0, 0.08);
}

.toolbar .searchbar-ios .searchbar-ios-cancel {
  padding: 0;
}

.toolbar .searchbar-ios.searchbar-has-focus .searchbar-ios-cancel {
  padding-left: 8px;
}

.searchbar-ios .searchbar-md-cancel {
  display: none;
}

.searchbar-ios-primary .searchbar-ios-cancel {
  color: #488aff;
}

.searchbar-ios-primary .searchbar-ios-cancel:hover:not(.disable-hover) {
  color: #427feb;
}

.toolbar-ios-primary .searchbar-ios .searchbar-search-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%2013%2013'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M5,1c2.2,0,4,1.8,4,4S7.2,9,5,9S1,7.2,1,5S2.8,1,5,1%20M5,0C2.2,0,0,2.2,0,5s2.2,5,5,5s5-2.2,5-5S7.8,0,5,0%20L5,0z'/><line%20stroke='rgba(255,%20255,%20255,%200.5)'%20stroke-miterlimit='10'%20x1='12.6'%20y1='12.6'%20x2='8.2'%20y2='8.2'/></svg>");
}

.toolbar-ios-primary .searchbar-ios .searchbar-input {
  color: #fff;
  background: rgba(255, 255, 255, 0.08);
}

.toolbar-ios-primary .searchbar-ios .searchbar-input::-moz-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-primary .searchbar-ios .searchbar-input:-ms-input-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-primary .searchbar-ios .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-primary .searchbar-ios .searchbar-clear-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M403.1,108.9c-81.2-81.2-212.9-81.2-294.2,0s-81.2,212.9,0,294.2c81.2,81.2,212.9,81.2,294.2,0S484.3,190.1,403.1,108.9z%20M352,340.2L340.2,352l-84.4-84.2l-84,83.8L160,339.8l84-83.8l-84-83.8l11.8-11.8l84,83.8l84.4-84.2l11.8,11.8L267.6,256L352,340.2z'/></svg>");
}

.toolbar-ios-primary .searchbar-ios .searchbar-ios-cancel {
  color: #fff;
}

.searchbar-ios-secondary .searchbar-ios-cancel {
  color: #32db64;
}

.searchbar-ios-secondary .searchbar-ios-cancel:hover:not(.disable-hover) {
  color: #2ec95c;
}

.toolbar-ios-secondary .searchbar-ios .searchbar-search-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%2013%2013'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M5,1c2.2,0,4,1.8,4,4S7.2,9,5,9S1,7.2,1,5S2.8,1,5,1%20M5,0C2.2,0,0,2.2,0,5s2.2,5,5,5s5-2.2,5-5S7.8,0,5,0%20L5,0z'/><line%20stroke='rgba(255,%20255,%20255,%200.5)'%20stroke-miterlimit='10'%20x1='12.6'%20y1='12.6'%20x2='8.2'%20y2='8.2'/></svg>");
}

.toolbar-ios-secondary .searchbar-ios .searchbar-input {
  color: #fff;
  background: rgba(255, 255, 255, 0.08);
}

.toolbar-ios-secondary .searchbar-ios .searchbar-input::-moz-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-secondary .searchbar-ios .searchbar-input:-ms-input-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-secondary .searchbar-ios .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-secondary .searchbar-ios .searchbar-clear-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M403.1,108.9c-81.2-81.2-212.9-81.2-294.2,0s-81.2,212.9,0,294.2c81.2,81.2,212.9,81.2,294.2,0S484.3,190.1,403.1,108.9z%20M352,340.2L340.2,352l-84.4-84.2l-84,83.8L160,339.8l84-83.8l-84-83.8l11.8-11.8l84,83.8l84.4-84.2l11.8,11.8L267.6,256L352,340.2z'/></svg>");
}

.toolbar-ios-secondary .searchbar-ios .searchbar-ios-cancel {
  color: #fff;
}

.searchbar-ios-danger .searchbar-ios-cancel {
  color: #f53d3d;
}

.searchbar-ios-danger .searchbar-ios-cancel:hover:not(.disable-hover) {
  color: #e13838;
}

.toolbar-ios-danger .searchbar-ios .searchbar-search-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%2013%2013'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M5,1c2.2,0,4,1.8,4,4S7.2,9,5,9S1,7.2,1,5S2.8,1,5,1%20M5,0C2.2,0,0,2.2,0,5s2.2,5,5,5s5-2.2,5-5S7.8,0,5,0%20L5,0z'/><line%20stroke='rgba(255,%20255,%20255,%200.5)'%20stroke-miterlimit='10'%20x1='12.6'%20y1='12.6'%20x2='8.2'%20y2='8.2'/></svg>");
}

.toolbar-ios-danger .searchbar-ios .searchbar-input {
  color: #fff;
  background: rgba(255, 255, 255, 0.08);
}

.toolbar-ios-danger .searchbar-ios .searchbar-input::-moz-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-danger .searchbar-ios .searchbar-input:-ms-input-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-danger .searchbar-ios .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-danger .searchbar-ios .searchbar-clear-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M403.1,108.9c-81.2-81.2-212.9-81.2-294.2,0s-81.2,212.9,0,294.2c81.2,81.2,212.9,81.2,294.2,0S484.3,190.1,403.1,108.9z%20M352,340.2L340.2,352l-84.4-84.2l-84,83.8L160,339.8l84-83.8l-84-83.8l11.8-11.8l84,83.8l84.4-84.2l11.8,11.8L267.6,256L352,340.2z'/></svg>");
}

.toolbar-ios-danger .searchbar-ios .searchbar-ios-cancel {
  color: #fff;
}

.searchbar-ios-light .searchbar-ios-cancel {
  color: #f4f4f4;
}

.searchbar-ios-light .searchbar-ios-cancel:hover:not(.disable-hover) {
  color: #e0e0e0;
}

.toolbar-ios-light .searchbar-ios .searchbar-search-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%2013%2013'><path%20fill='rgba(0,%200,%200,%200.5)'%20d='M5,1c2.2,0,4,1.8,4,4S7.2,9,5,9S1,7.2,1,5S2.8,1,5,1%20M5,0C2.2,0,0,2.2,0,5s2.2,5,5,5s5-2.2,5-5S7.8,0,5,0%20L5,0z'/><line%20stroke='rgba(0,%200,%200,%200.5)'%20stroke-miterlimit='10'%20x1='12.6'%20y1='12.6'%20x2='8.2'%20y2='8.2'/></svg>");
}

.toolbar-ios-light .searchbar-ios .searchbar-input {
  color: #000;
  background: rgba(0, 0, 0, 0.08);
}

.toolbar-ios-light .searchbar-ios .searchbar-input::-moz-placeholder {
  color: rgba(0, 0, 0, 0.5);
}

.toolbar-ios-light .searchbar-ios .searchbar-input:-ms-input-placeholder {
  color: rgba(0, 0, 0, 0.5);
}

.toolbar-ios-light .searchbar-ios .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: rgba(0, 0, 0, 0.5);
}

.toolbar-ios-light .searchbar-ios .searchbar-clear-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='rgba(0,%200,%200,%200.5)'%20d='M403.1,108.9c-81.2-81.2-212.9-81.2-294.2,0s-81.2,212.9,0,294.2c81.2,81.2,212.9,81.2,294.2,0S484.3,190.1,403.1,108.9z%20M352,340.2L340.2,352l-84.4-84.2l-84,83.8L160,339.8l84-83.8l-84-83.8l11.8-11.8l84,83.8l84.4-84.2l11.8,11.8L267.6,256L352,340.2z'/></svg>");
}

.toolbar-ios-light .searchbar-ios .searchbar-ios-cancel {
  color: #488aff;
}

.searchbar-ios-dark .searchbar-ios-cancel {
  color: #222;
}

.searchbar-ios-dark .searchbar-ios-cancel:hover:not(.disable-hover) {
  color: #343434;
}

.toolbar-ios-dark .searchbar-ios .searchbar-search-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%2013%2013'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M5,1c2.2,0,4,1.8,4,4S7.2,9,5,9S1,7.2,1,5S2.8,1,5,1%20M5,0C2.2,0,0,2.2,0,5s2.2,5,5,5s5-2.2,5-5S7.8,0,5,0%20L5,0z'/><line%20stroke='rgba(255,%20255,%20255,%200.5)'%20stroke-miterlimit='10'%20x1='12.6'%20y1='12.6'%20x2='8.2'%20y2='8.2'/></svg>");
}

.toolbar-ios-dark .searchbar-ios .searchbar-input {
  color: #fff;
  background: rgba(255, 255, 255, 0.08);
}

.toolbar-ios-dark .searchbar-ios .searchbar-input::-moz-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-dark .searchbar-ios .searchbar-input:-ms-input-placeholder {
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-dark .searchbar-ios .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: rgba(255, 255, 255, 0.5);
}

.toolbar-ios-dark .searchbar-ios .searchbar-clear-icon {
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='rgba(255,%20255,%20255,%200.5)'%20d='M403.1,108.9c-81.2-81.2-212.9-81.2-294.2,0s-81.2,212.9,0,294.2c81.2,81.2,212.9,81.2,294.2,0S484.3,190.1,403.1,108.9z%20M352,340.2L340.2,352l-84.4-84.2l-84,83.8L160,339.8l84-83.8l-84-83.8l11.8-11.8l84,83.8l84.4-84.2l11.8,11.8L267.6,256L352,340.2z'/></svg>");
}

.toolbar-ios-dark .searchbar-ios .searchbar-ios-cancel {
  color: #fff;
}

.searchbar-ios.searchbar-animated.searchbar-show-cancel .searchbar-ios-cancel {
  display: block;
}

.searchbar-ios.searchbar-animated .searchbar-search-icon,
.searchbar-ios.searchbar-animated .searchbar-input {
  -webkit-transition: all 300ms ease;
  transition: all 300ms ease;
}

.searchbar-animated.searchbar-has-focus .searchbar-ios-cancel {
  opacity: 1;
  pointer-events: auto;
}

.searchbar-animated .searchbar-ios-cancel {
  margin-right: -100%;
  -webkit-transform: translate3d(0,  0,  0);
  transform: translate3d(0,  0,  0);
  opacity: 0;
  -webkit-transition: all 300ms ease;
  transition: all 300ms ease;
  pointer-events: none;
}

.searchbar-md {
  background: inherit;
  padding: 8px;
}

.searchbar-md .searchbar-search-icon {
  left: 16px;
  top: 11px;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='%235b5b5b'%20d='M337.509,305.372h-17.501l-6.571-5.486c20.791-25.232,33.922-57.054,33.922-93.257C347.358,127.632,283.896,64,205.135,64C127.452,64,64,127.632,64,206.629s63.452,142.628,142.225,142.628c35.011,0,67.831-13.167,92.991-34.008l6.561,5.487v17.551L415.18,448L448,415.086L337.509,305.372z%20M206.225,305.372c-54.702,0-98.463-43.887-98.463-98.743c0-54.858,43.761-98.742,98.463-98.742c54.7,0,98.462,43.884,98.462,98.742C304.687,261.485,260.925,305.372,206.225,305.372z'/></svg>");
  width: 21px;
  height: 21px;
}

.searchbar-md .searchbar-md-cancel {
  left: 10px;
  top: 0;
  margin: 0;
  display: none;
  width: 21px;
  height: 100%;
}

.searchbar-md .searchbar-search-icon,
.searchbar-md .searchbar-md-cancel {
  position: absolute;
  background-repeat: no-repeat;
  background-size: 20px;
}

.searchbar-md .searchbar-search-icon.activated,
.searchbar-md .searchbar-md-cancel.activated {
  background-color: transparent;
}

.searchbar-md .searchbar-input {
  padding: 6px 55px;
  border-radius: 2px;
  background-position: left 8px center;
  height: auto;
  font-size: 1.6rem;
  font-weight: 400;
  line-height: 3rem;
  color: #141414;
  background-color: #fff;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
}

.searchbar-md .searchbar-input::-moz-placeholder {
  color: #aeaeae;
}

.searchbar-md .searchbar-input:-ms-input-placeholder {
  color: #aeaeae;
}

.searchbar-md .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: #aeaeae;
}

.searchbar-md .searchbar-clear-icon {
  right: 13px;
  top: 0;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><polygon%20fill='%235b5b5b'%20points='405,136.798%20375.202,107%20256,226.202%20136.798,107%20107,136.798%20226.202,256%20107,375.202%20136.798,405%20256,285.798%20375.202,405%20405,375.202%20285.798,256'/></svg>");
  padding: 0;
  background-position: center;
  position: absolute;
  width: 22px;
  height: 100%;
  background-repeat: no-repeat;
  background-size: 22px;
}

.searchbar-md .searchbar-clear-icon.activated {
  background-color: transparent;
}

.searchbar-md.searchbar-has-focus.searchbar-show-cancel .searchbar-search-icon {
  display: none;
}

.searchbar-md.searchbar-has-focus.searchbar-show-cancel .searchbar-md-cancel {
  display: -webkit-inline-box;
  display: -webkit-inline-flex;
  display: -ms-inline-flexbox;
  display: inline-flex;
}

.toolbar .searchbar-md {
  padding: 3px;
}

.toolbar .searchbar-md .searchbar-md-cancel {
  left: 14px;
}

.searchbar-md .searchbar-ios-cancel {
  display: none;
}

.searchbar-wp {
  background: transparent;
  padding: 8px;
}

.searchbar-wp .searchbar-input-container {
  border: 2px solid rgba(0, 0, 0, 0.5);
}

.searchbar-wp .searchbar-search-icon {
  right: 8px;
  top: 5px;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><path%20fill='%23858585'%20d='M337.509,305.372h-17.501l-6.571-5.486c20.791-25.232,33.922-57.054,33.922-93.257C347.358,127.632,283.896,64,205.135,64C127.452,64,64,127.632,64,206.629s63.452,142.628,142.225,142.628c35.011,0,67.831-13.167,92.991-34.008l6.561,5.487v17.551L415.18,448L448,415.086L337.509,305.372z%20M206.225,305.372c-54.702,0-98.463-43.887-98.463-98.743c0-54.858,43.761-98.742,98.463-98.742c54.7,0,98.462,43.884,98.462,98.742C304.687,261.485,260.925,305.372,206.225,305.372z'/></svg>");
  position: absolute;
  width: 21px;
  height: 21px;
  background-repeat: no-repeat;
  background-size: 20px;
}

.searchbar-wp .searchbar-search-icon.activated {
  background-color: transparent;
}

.searchbar-wp .searchbar-input {
  padding: 0 8px;
  border-radius: 0;
  background-position: left 8px center;
  height: auto;
  font-size: 1.4rem;
  font-weight: 400;
  line-height: 3rem;
  color: #141414;
  background-color: #fff;
}

.searchbar-wp .searchbar-input::-moz-placeholder {
  color: #858585;
}

.searchbar-wp .searchbar-input:-ms-input-placeholder {
  color: #858585;
}

.searchbar-wp .searchbar-input::-webkit-input-placeholder {
  text-indent: 0;
  color: #858585;
}

.searchbar-wp .searchbar-clear-icon {
  right: 8px;
  top: 0;
  background-image: url("data:image/svg+xml;charset=utf-8,<svg%20xmlns='http://www.w3.org/2000/svg'%20viewBox='0%200%20512%20512'><polygon%20fill='%23858585'%20points='405,136.798%20375.202,107%20256,226.202%20136.798,107%20107,136.798%20226.202,256%20107,375.202%20136.798,405%20256,285.798%20375.202,405%20405,375.202%20285.798,256'/></svg>");
  padding: 0;
  background-position: center;
  position: absolute;
  width: 22px;
  height: 100%;
  background-repeat: no-repeat;
  background-size: 22px;
}

.searchbar-wp .searchbar-clear-icon.activated {
  background-color: transparent;
}

.searchbar-wp.searchbar-has-focus .searchbar-input-container {
  border-color: #488aff;
}

.searchbar-wp.searchbar-has-value .searchbar-search-icon {
  display: none;
}

.searchbar-wp .searchbar-ios-cancel {
  display: none;
}

.searchbar-wp .searchbar-md-cancel {
  display: none;
}

.toolbar .searchbar-wp {
  padding: 2px;
}

.searchbar-wp-primary.searchbar-has-focus .searchbar-input-container {
  border-color: #488aff;
}

.searchbar-wp-secondary.searchbar-has-focus .searchbar-input-container {
  border-color: #32db64;
}

.searchbar-wp-danger.searchbar-has-focus .searchbar-input-container {
  border-color: #f53d3d;
}

.searchbar-wp-light.searchbar-has-focus .searchbar-input-container {
  border-color: #f4f4f4;
}

.searchbar-wp-dark.searchbar-has-focus .searchbar-input-container {
  border-color: #222;
}

ion-segment {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  width: 100%;
}

.segment-button {
  margin-left: 0;
  margin-right: 0;
  text-align: center;
  position: relative;
  display: block;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  cursor: pointer;
}

.segment-ios .segment-button {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  width: 0;
  height: 3.2rem;
  border-width: 1px;
  border-style: solid;
  border-color: #488aff;
  font-size: 1.3rem;
  line-height: 3rem;
  color: #488aff;
  background-color: transparent;
}

.segment-ios .segment-button ion-icon {
  font-size: 2.6rem;
  line-height: 2.8rem;
}

.segment-ios .segment-button.segment-activated {
  color: #fff;
  background-color: #488aff;
  opacity: 1;
  -webkit-transition: 100ms all linear;
  transition: 100ms all linear;
}

.segment-ios .segment-button:hover:not(.segment-activated) {
  background-color: rgba(72, 138, 255, 0.1);
  -webkit-transition: 100ms all linear;
  transition: 100ms all linear;
}

.segment-ios .segment-button:active:not(.segment-activated) {
  background-color: rgba(72, 138, 255, 0.16);
  -webkit-transition: 100ms all linear;
  transition: 100ms all linear;
}

.segment-ios .segment-button:first-of-type {
  border-top-left-radius: 4px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 4px;
  margin-right: 0;
}

.segment-ios .segment-button:not(:first-of-type) {
  border-left-width: 0;
}

.segment-ios .segment-button:last-of-type {
  border-top-left-radius: 0;
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 0;
  margin-left: 0;
  border-left-width: 0;
}

[dir="rtl"] .segment-ios .segment-button:first-of-type {
  border-left-width: 0;
}

[dir="rtl"] .segment-ios .segment-button:last-of-type {
  border-left-width: 1px;
}

.segment-ios.segment-disabled {
  opacity: .4;
  pointer-events: none;
}

.segment-ios .segment-button-disabled {
  color: rgba(72, 138, 255, 0.3);
  pointer-events: none;
}

.toolbar-ios .segment-ios {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
}

.toolbar-ios .segment-button {
  max-width: 100px;
  height: 2.6rem;
  font-size: 1.2rem;
  line-height: 2.5rem;
}

.toolbar-ios .segment-button ion-icon {
  font-size: 2.2rem;
  line-height: 2.4rem;
}

.segment-ios-primary .segment-button {
  border-color: #488aff;
  color: #488aff;
}

.segment-ios-primary .segment-button:hover:not(.segment-activated) {
  background-color: rgba(72, 138, 255, 0.1);
}

.segment-ios-primary .segment-button:active:not(.segment-activated) {
  background-color: rgba(72, 138, 255, 0.16);
}

.segment-ios-primary .segment-button.segment-activated {
  color: #fff;
  background-color: #488aff;
}

.segment-ios-primary .segment-button-disabled {
  color: rgba(72, 138, 255, 0.3);
}

.toolbar-ios-primary .segment-ios .segment-button.segment-activated {
  color: #488aff;
}

.segment-ios-secondary .segment-button {
  border-color: #32db64;
  color: #32db64;
}

.segment-ios-secondary .segment-button:hover:not(.segment-activated) {
  background-color: rgba(50, 219, 100, 0.1);
}

.segment-ios-secondary .segment-button:active:not(.segment-activated) {
  background-color: rgba(50, 219, 100, 0.16);
}

.segment-ios-secondary .segment-button.segment-activated {
  color: #fff;
  background-color: #32db64;
}

.segment-ios-secondary .segment-button-disabled {
  color: rgba(50, 219, 100, 0.3);
}

.toolbar-ios-secondary .segment-ios .segment-button.segment-activated {
  color: #32db64;
}

.segment-ios-danger .segment-button {
  border-color: #f53d3d;
  color: #f53d3d;
}

.segment-ios-danger .segment-button:hover:not(.segment-activated) {
  background-color: rgba(245, 61, 61, 0.1);
}

.segment-ios-danger .segment-button:active:not(.segment-activated) {
  background-color: rgba(245, 61, 61, 0.16);
}

.segment-ios-danger .segment-button.segment-activated {
  color: #fff;
  background-color: #f53d3d;
}

.segment-ios-danger .segment-button-disabled {
  color: rgba(245, 61, 61, 0.3);
}

.toolbar-ios-danger .segment-ios .segment-button.segment-activated {
  color: #f53d3d;
}

.segment-ios-light .segment-button {
  border-color: #f4f4f4;
  color: #f4f4f4;
}

.segment-ios-light .segment-button:hover:not(.segment-activated) {
  background-color: rgba(244, 244, 244, 0.1);
}

.segment-ios-light .segment-button:active:not(.segment-activated) {
  background-color: rgba(244, 244, 244, 0.16);
}

.segment-ios-light .segment-button.segment-activated {
  color: #000;
  background-color: #f4f4f4;
}

.segment-ios-light .segment-button-disabled {
  color: rgba(244, 244, 244, 0.3);
}

.toolbar-ios-light .segment-ios .segment-button.segment-activated {
  color: #f4f4f4;
}

.segment-ios-dark .segment-button {
  border-color: #222;
  color: #222;
}

.segment-ios-dark .segment-button:hover:not(.segment-activated) {
  background-color: rgba(34, 34, 34, 0.1);
}

.segment-ios-dark .segment-button:active:not(.segment-activated) {
  background-color: rgba(34, 34, 34, 0.16);
}

.segment-ios-dark .segment-button.segment-activated {
  color: #fff;
  background-color: #222;
}

.segment-ios-dark .segment-button-disabled {
  color: rgba(34, 34, 34, 0.3);
}

.toolbar-ios-dark .segment-ios .segment-button.segment-activated {
  color: #222;
}

.segment-md .segment-button {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  width: 0;
  height: 4.2rem;
  border-bottom-width: 2px;
  border-bottom-style: solid;
  border-bottom-color: rgba(0, 0, 0, 0.1);
  font-size: 1.2rem;
  font-weight: 500;
  line-height: 4rem;
  text-transform: uppercase;
  color: #488aff;
  background-color: transparent;
  opacity: 0.7;
  -webkit-transition: 100ms all linear;
  transition: 100ms all linear;
  padding: 0 6px;
}

.segment-md .segment-button ion-icon {
  font-size: 2.6rem;
  line-height: 4rem;
}

.segment-md .segment-button.activated, .segment-md .segment-button.segment-activated {
  border-color: #488aff;
  opacity: 1;
}

.segment-md.segment-disabled,
.segment-md .segment-button-disabled {
  opacity: 0.3;
  pointer-events: none;
}

.toolbar .segment-md {
  margin: 0 auto;
}

.toolbar .segment-md .segment-button.activated,
.toolbar .segment-md .segment-button.segment-activated {
  opacity: 1;
}

.segment-md-primary .segment-button {
  color: #488aff;
}

.segment-md-primary .segment-button.activated, .segment-md-primary .segment-button.segment-activated {
  border-color: #488aff;
  color: #488aff;
  opacity: 1;
}

.segment-md-secondary .segment-button {
  color: #32db64;
}

.segment-md-secondary .segment-button.activated, .segment-md-secondary .segment-button.segment-activated {
  border-color: #32db64;
  color: #32db64;
  opacity: 1;
}

.segment-md-danger .segment-button {
  color: #f53d3d;
}

.segment-md-danger .segment-button.activated, .segment-md-danger .segment-button.segment-activated {
  border-color: #f53d3d;
  color: #f53d3d;
  opacity: 1;
}

.segment-md-light .segment-button {
  color: #f4f4f4;
}

.segment-md-light .segment-button.activated, .segment-md-light .segment-button.segment-activated {
  border-color: #f4f4f4;
  color: #f4f4f4;
  opacity: 1;
}

.segment-md-dark .segment-button {
  color: #222;
}

.segment-md-dark .segment-button.activated, .segment-md-dark .segment-button.segment-activated {
  border-color: #222;
  color: #222;
  opacity: 1;
}

.segment-wp {
  -webkit-box-pack: start;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
}

.segment-wp .segment-button {
  height: 4rem;
  font-size: 1.3rem;
  font-weight: bold;
  line-height: 4rem;
  text-transform: uppercase;
  color: #000;
  background-color: transparent;
  opacity: 0.5;
  padding: 0 6px;
}

.segment-wp .segment-button.segment-activated {
  opacity: 1;
}

.segment-wp .segment-button ion-icon {
  font-size: 2.6rem;
  line-height: 4rem;
}

.segment-wp.segment-disabled,
.segment-wp .segment-button-disabled {
  opacity: 0.3;
  pointer-events: none;
}

.toolbar .segment-wp {
  margin: 0 auto;
}

.segment-wp-primary .segment-button {
  color: #488aff;
}

.segment-wp-primary .segment-button.activated, .segment-wp-primary .segment-button.segment-activated {
  border-color: #488aff;
  color: #488aff;
  opacity: 1;
}

.segment-wp-secondary .segment-button {
  color: #32db64;
}

.segment-wp-secondary .segment-button.activated, .segment-wp-secondary .segment-button.segment-activated {
  border-color: #32db64;
  color: #32db64;
  opacity: 1;
}

.segment-wp-danger .segment-button {
  color: #f53d3d;
}

.segment-wp-danger .segment-button.activated, .segment-wp-danger .segment-button.segment-activated {
  border-color: #f53d3d;
  color: #f53d3d;
  opacity: 1;
}

.segment-wp-light .segment-button {
  color: #f4f4f4;
}

.segment-wp-light .segment-button.activated, .segment-wp-light .segment-button.segment-activated {
  border-color: #f4f4f4;
  color: #f4f4f4;
  opacity: 1;
}

.segment-wp-dark .segment-button {
  color: #222;
}

.segment-wp-dark .segment-button.activated, .segment-wp-dark .segment-button.segment-activated {
  border-color: #222;
  color: #222;
  opacity: 1;
}

ion-select {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  max-width: 45%;
}

.select-text {
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  min-width: 16px;
  font-size: inherit;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.item-multiple-inputs ion-select {
  position: relative;
}

.select-disabled,
.item-select-disabled ion-label {
  opacity: .4;
  pointer-events: none;
}

.select-popover ion-list {
  margin: -1px 0;
}

.select-ios {
  padding: 11px 8px 11px 16px;
}

.select-ios .select-placeholder {
  color: #999;
}

.select-ios .select-icon {
  position: relative;
  width: 12px;
  height: 18px;
}

.select-ios .select-icon .select-icon-inner {
  left: 5px;
  top: 50%;
  margin-top: -2px;
  position: absolute;
  width: 0;
  height: 0;
  border-top: 5px solid;
  border-right: 5px solid transparent;
  border-left: 5px solid transparent;
  color: #999;
  pointer-events: none;
}

.select-md {
  padding: 13px 8px 13px 16px;
}

.select-md .select-placeholder {
  color: #999;
}

.select-md .item-select ion-label {
  margin-left: 0;
}

.select-md .select-icon {
  position: relative;
  width: 12px;
  height: 19px;
}

.select-md .select-icon .select-icon-inner {
  left: 5px;
  top: 50%;
  margin-top: -3px;
  position: absolute;
  width: 0;
  height: 0;
  border-top: 5px solid;
  border-right: 5px solid transparent;
  border-left: 5px solid transparent;
  color: #999;
  pointer-events: none;
}

.select-wp {
  margin: 13px 8px;
  padding: 0 8px;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  max-width: 100%;
  border: 2px solid rgba(0, 0, 0, 0.5);
  line-height: 3rem;
}

.select-wp .select-placeholder {
  color: rgba(0, 0, 0, 0.5);
}

.item-wp.item-select ion-label {
  margin-left: 0;
}

.select-wp .select-icon {
  position: relative;
  -webkit-align-self: center;
  -ms-flex-item-align: center;
  align-self: center;
  width: 18px;
  height: 18px;
}

.select-wp .select-icon .select-icon-inner {
  left: 5px;
  top: 3px;
  position: absolute;
  display: block;
  width: 9px;
  height: 9px;
  border-top: 2px solid rgba(0, 0, 0, 0.5);
  border-right: 2px solid rgba(0, 0, 0, 0.5);
  -webkit-transform: rotate(135deg);
  transform: rotate(135deg);
  pointer-events: none;
}

.select-wp .select-text {
  min-height: 3rem;
}

.hidden-show-when {
  display: none !important;
}

.hidden-hide-when {
  display: none !important;
}

.swiper-container {
  margin-left: auto;
  margin-right: auto;
  padding: 0;
  position: relative;
  z-index: 1;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  width: 100%;
  height: 100%;
}

.swiper-container-no-flexbox .swiper-slide {
  float: left;
}

.swiper-container-vertical > .swiper-wrapper {
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
}

.swiper-wrapper {
  padding: 0;
  position: relative;
  z-index: 1;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  width: 100%;
  height: 100%;
  -webkit-transition-property: -webkit-transform;
  transition-property: -webkit-transform;
  transition-property: transform;
  transition-property: transform, -webkit-transform;
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
}

.swiper-container-android .swiper-slide,
.swiper-wrapper {
  -webkit-transform: translate3d(0,  0,  0);
  transform: translate3d(0,  0,  0);
}

.swiper-container-multirow > .swiper-wrapper {
  -webkit-flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  flex-wrap: wrap;
}

.swiper-container-free-mode > .swiper-wrapper {
  margin: 0 auto;
  -webkit-transition-timing-function: ease-out;
  transition-timing-function: ease-out;
}

.swiper-slide {
  text-align: center;
  position: relative;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-shrink: 0;
  -ms-flex-negative: 0;
  flex-shrink: 0;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  font-size: 18px;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.swiper-container-autoheight,
.swiper-container-autoheight .swiper-slide {
  height: auto;
}

.swiper-container-autoheight .swiper-wrapper {
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-transition-property: height, -webkit-transform;
  transition-property: height, -webkit-transform;
  transition-property: transform, height;
  transition-property: transform, height, -webkit-transform;
}

.swiper-container .swiper-notification {
  left: 0;
  top: 0;
  position: absolute;
  z-index: -1000;
  opacity: 0;
  pointer-events: none;
}

.swiper-wp8-horizontal {
  -ms-touch-action: pan-y;
  touch-action: pan-y;
}

.swiper-wp8-vertical {
  -ms-touch-action: pan-x;
  touch-action: pan-x;
}

.swiper-button-prev,
.swiper-button-next {
  top: 50%;
  margin-top: -22px;
  background-position: center;
  position: absolute;
  z-index: 10;
  width: 27px;
  height: 44px;
  background-repeat: no-repeat;
  background-size: 27px 44px;
  cursor: pointer;
}

.swiper-button-prev.swiper-button-disabled,
.swiper-button-next.swiper-button-disabled {
  cursor: auto;
  opacity: .35;
  pointer-events: none;
}

.swiper-button-prev,
.swiper-container-rtl .swiper-button-next {
  left: 10px;
  right: auto;
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M0%2C22L22%2C0l2.1%2C2.1L4.2%2C22l19.9%2C19.9L22%2C44L0%2C22L0%2C22L0%2C22z'%20fill%3D'%23007aff'%2F%3E%3C%2Fsvg%3E");
}

.swiper-button-prev.swiper-button-black,
.swiper-container-rtl .swiper-button-next.swiper-button-black {
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M0%2C22L22%2C0l2.1%2C2.1L4.2%2C22l19.9%2C19.9L22%2C44L0%2C22L0%2C22L0%2C22z'%20fill%3D'%23000000'%2F%3E%3C%2Fsvg%3E");
}

.swiper-button-prev.swiper-button-white,
.swiper-container-rtl .swiper-button-next.swiper-button-white {
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M0%2C22L22%2C0l2.1%2C2.1L4.2%2C22l19.9%2C19.9L22%2C44L0%2C22L0%2C22L0%2C22z'%20fill%3D'%23ffffff'%2F%3E%3C%2Fsvg%3E");
}

.swiper-button-next,
.swiper-container-rtl .swiper-button-prev {
  left: auto;
  right: 10px;
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M27%2C22L27%2C22L5%2C44l-2.1-2.1L22.8%2C22L2.9%2C2.1L5%2C0L27%2C22L27%2C22z'%20fill%3D'%23007aff'%2F%3E%3C%2Fsvg%3E");
}

.swiper-button-next.swiper-button-black,
.swiper-container-rtl .swiper-button-prev.swiper-button-black {
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M27%2C22L27%2C22L5%2C44l-2.1-2.1L22.8%2C22L2.9%2C2.1L5%2C0L27%2C22L27%2C22z'%20fill%3D'%23000000'%2F%3E%3C%2Fsvg%3E");
}

.swiper-button-next.swiper-button-white,
.swiper-container-rtl .swiper-button-prev.swiper-button-white {
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20viewBox%3D'0%200%2027%2044'%3E%3Cpath%20d%3D'M27%2C22L27%2C22L5%2C44l-2.1-2.1L22.8%2C22L2.9%2C2.1L5%2C0L27%2C22L27%2C22z'%20fill%3D'%23ffffff'%2F%3E%3C%2Fsvg%3E");
}

.swiper-pagination {
  text-align: center;
  -webkit-transform: translate3d(0,  0,  0);
  transform: translate3d(0,  0,  0);
  position: absolute;
  z-index: 10;
  -webkit-transition: 300ms;
  transition: 300ms;
  pointer-events: none;
}

.swiper-pagination.swiper-pagination-hidden {
  opacity: 0;
}

.swiper-pagination-fraction,
.swiper-pagination-custom,
.swiper-container-horizontal > .swiper-pagination-bullets {
  left: 0;
  bottom: 10px;
  width: 100%;
}

.swiper-pagination-bullet {
  border-radius: 100%;
  display: inline-block;
  width: 8px;
  height: 8px;
  background: #000;
  opacity: .2;
  pointer-events: auto;
}

button.swiper-pagination-bullet {
  margin: 0;
  padding: 0;
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  border: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.swiper-pagination-clickable .swiper-pagination-bullet {
  cursor: pointer;
}

.swiper-pagination-white .swiper-pagination-bullet {
  background: #fff;
}

.swiper-pagination-bullet-active {
  background: #007aff;
  opacity: 1;
}

.swiper-pagination-white .swiper-pagination-bullet-active {
  background: #fff;
}

.swiper-pagination-black .swiper-pagination-bullet-active {
  background: #000;
}

.swiper-container-vertical > .swiper-pagination-bullets {
  right: 10px;
  top: 50%;
  -webkit-transform: translate3d(0,  -50%,  0);
  transform: translate3d(0,  -50%,  0);
}

.swiper-container-vertical > .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 5px 0;
  display: block;
}

.swiper-container-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet {
  margin: 0 5px;
}

.swiper-pagination-progress {
  position: absolute;
  background: rgba(0, 0, 0, 0.25);
}

.swiper-pagination-progress .swiper-pagination-progressbar {
  left: 0;
  top: 0;
  -webkit-transform-origin: left top;
  transform-origin: left top;
  position: absolute;
  width: 100%;
  height: 100%;
  background: #007aff;
  -webkit-transform: scale(0);
  transform: scale(0);
}

.swiper-container-rtl .swiper-pagination-progress .swiper-pagination-progressbar {
  -webkit-transform-origin: right top;
  transform-origin: right top;
}

.swiper-container-horizontal > .swiper-pagination-progress {
  left: 0;
  top: 0;
  width: 100%;
  height: 4px;
}

.swiper-container-vertical > .swiper-pagination-progress {
  left: 0;
  top: 0;
  width: 4px;
  height: 100%;
}

.swiper-pagination-progress.swiper-pagination-white {
  background: rgba(255, 255, 255, 0.5);
}

.swiper-pagination-progress.swiper-pagination-white .swiper-pagination-progressbar {
  background: #fff;
}

.swiper-pagination-progress.swiper-pagination-black .swiper-pagination-progressbar {
  background: #000;
}

.swiper-container-3d {
  -webkit-perspective: 1200px;
  perspective: 1200px;
}

.swiper-container-3d .swiper-wrapper,
.swiper-container-3d .swiper-slide,
.swiper-container-3d .swiper-slide-shadow-left,
.swiper-container-3d .swiper-slide-shadow-right,
.swiper-container-3d .swiper-slide-shadow-top,
.swiper-container-3d .swiper-slide-shadow-bottom,
.swiper-container-3d .swiper-cube-shadow {
  -webkit-transform-style: preserve-3d;
  transform-style: preserve-3d;
}

.swiper-container-3d .swiper-slide-shadow-left,
.swiper-container-3d .swiper-slide-shadow-right,
.swiper-container-3d .swiper-slide-shadow-top,
.swiper-container-3d .swiper-slide-shadow-bottom {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 10;
  width: 100%;
  height: 100%;
  pointer-events: none;
}

.swiper-container-3d .swiper-slide-shadow-left {
  background-image: -webkit-gradient(linear, right top, left top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0)));
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}

.swiper-container-3d .swiper-slide-shadow-right {
  background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0)));
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}

.swiper-container-3d .swiper-slide-shadow-top {
  background-image: -webkit-gradient(linear, left bottom, left top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0)));
  background-image: linear-gradient(to top, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}

.swiper-container-3d .swiper-slide-shadow-bottom {
  background-image: -webkit-gradient(linear, left top, left bottom, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0)));
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
}

.swiper-container-coverflow .swiper-wrapper,
.swiper-container-flip .swiper-wrapper {
  -webkit-perspective: 1200px;
  perspective: 1200px;
}

.swiper-container-cube,
.swiper-container-flip {
  overflow: visible;
}

.swiper-container-cube .swiper-slide,
.swiper-container-flip .swiper-slide {
  z-index: 1;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  pointer-events: none;
}

.swiper-container-cube .swiper-slide .swiper-slide,
.swiper-container-flip .swiper-slide .swiper-slide {
  pointer-events: none;
}

.swiper-container-cube .swiper-slide-active,
.swiper-container-flip .swiper-slide-active,
.swiper-container-cube .swiper-slide-active .swiper-slide-active,
.swiper-container-flip .swiper-slide-active .swiper-slide-active {
  pointer-events: auto;
}

.swiper-container-cube .swiper-slide-shadow-top,
.swiper-container-flip .swiper-slide-shadow-top,
.swiper-container-cube .swiper-slide-shadow-bottom,
.swiper-container-flip .swiper-slide-shadow-bottom,
.swiper-container-cube .swiper-slide-shadow-left,
.swiper-container-flip .swiper-slide-shadow-left,
.swiper-container-cube .swiper-slide-shadow-right,
.swiper-container-flip .swiper-slide-shadow-right {
  z-index: 0;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
}

.swiper-container-cube .swiper-slide {
  -webkit-transform-origin: 0 0;
  transform-origin: 0 0;
  width: 100%;
  height: 100%;
  visibility: hidden;
}

.swiper-container-cube.swiper-container-rtl .swiper-slide {
  -webkit-transform-origin: 100% 0;
  transform-origin: 100% 0;
}

.swiper-container-cube .swiper-slide-active,
.swiper-container-cube .swiper-slide-next,
.swiper-container-cube .swiper-slide-prev,
.swiper-container-cube .swiper-slide-next + .swiper-slide {
  visibility: visible;
  pointer-events: auto;
}

.swiper-container-cube .swiper-cube-shadow {
  left: 0;
  bottom: 0;
  position: absolute;
  z-index: 0;
  width: 100%;
  height: 100%;
  background: #000;
  opacity: .6;
  -webkit-filter: blur(50px);
  filter: blur(50px);
}

.swiper-container-fade.swiper-container-free-mode .swiper-slide {
  -webkit-transition-timing-function: ease-out;
  transition-timing-function: ease-out;
}

.swiper-container-fade .swiper-slide {
  -webkit-transition-property: opacity;
  transition-property: opacity;
  pointer-events: none;
}

.swiper-container-fade .swiper-slide .swiper-slide {
  pointer-events: none;
}

.swiper-container-fade .swiper-slide-active,
.swiper-container-fade .swiper-slide-active .swiper-slide-active {
  pointer-events: auto;
}

.swiper-zoom-container {
  text-align: center;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  width: 100%;
  height: 100%;
}

.swiper-zoom-container > img,
.swiper-zoom-container > svg,
.swiper-zoom-container > canvas {
  max-width: 100%;
  max-height: 100%;
  -o-object-fit: contain;
  object-fit: contain;
}

.swiper-scrollbar {
  border-radius: 10px;
  position: relative;
  background: rgba(0, 0, 0, 0.1);
  -ms-touch-action: none;
  touch-action: none;
}

.swiper-container-horizontal > .swiper-scrollbar {
  left: 1%;
  bottom: 3px;
  position: absolute;
  z-index: 50;
  width: 98%;
  height: 5px;
}

.swiper-container-vertical > .swiper-scrollbar {
  right: 3px;
  top: 1%;
  position: absolute;
  z-index: 50;
  width: 5px;
  height: 98%;
}

.swiper-scrollbar-drag {
  left: 0;
  top: 0;
  border-radius: 10px;
  position: relative;
  width: 100%;
  height: 100%;
  background: rgba(0, 0, 0, 0.5);
}

.swiper-scrollbar-cursor-drag {
  cursor: move;
}

.swiper-lazy-preloader {
  left: 50%;
  top: 50%;
  margin-left: -21px;
  margin-top: -21px;
  -webkit-transform-origin: 50%;
  transform-origin: 50%;
  position: absolute;
  z-index: 10;
  width: 42px;
  height: 42px;
  -webkit-animation: swiper-preloader-spin 1s steps(12, end) infinite;
  animation: swiper-preloader-spin 1s steps(12, end) infinite;
}

.swiper-lazy-preloader::after {
  background-position: 50%;
  display: block;
  width: 100%;
  height: 100%;
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20viewBox%3D'0%200%20120%20120'%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20xmlns%3Axlink%3D'http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink'%3E%3Cdefs%3E%3Cline%20id%3D'l'%20x1%3D'60'%20x2%3D'60'%20y1%3D'7'%20y2%3D'27'%20stroke%3D'%236c6c6c'%20stroke-width%3D'11'%20stroke-linecap%3D'round'%2F%3E%3C%2Fdefs%3E%3Cg%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(30%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(60%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(90%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(120%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(150%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.37'%20transform%3D'rotate(180%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.46'%20transform%3D'rotate(210%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.56'%20transform%3D'rotate(240%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.66'%20transform%3D'rotate(270%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.75'%20transform%3D'rotate(300%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.85'%20transform%3D'rotate(330%2060%2C60)'%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E");
  background-repeat: no-repeat;
  background-size: 100%;
  content: "";
}

.swiper-lazy-preloader-white::after {
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg%20viewBox%3D'0%200%20120%20120'%20xmlns%3D'http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg'%20xmlns%3Axlink%3D'http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink'%3E%3Cdefs%3E%3Cline%20id%3D'l'%20x1%3D'60'%20x2%3D'60'%20y1%3D'7'%20y2%3D'27'%20stroke%3D'%23fff'%20stroke-width%3D'11'%20stroke-linecap%3D'round'%2F%3E%3C%2Fdefs%3E%3Cg%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(30%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(60%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(90%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(120%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.27'%20transform%3D'rotate(150%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.37'%20transform%3D'rotate(180%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.46'%20transform%3D'rotate(210%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.56'%20transform%3D'rotate(240%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.66'%20transform%3D'rotate(270%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.75'%20transform%3D'rotate(300%2060%2C60)'%2F%3E%3Cuse%20xlink%3Ahref%3D'%23l'%20opacity%3D'.85'%20transform%3D'rotate(330%2060%2C60)'%2F%3E%3C%2Fg%3E%3C%2Fsvg%3E");
}

@-webkit-keyframes swiper-preloader-spin {
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes swiper-preloader-spin {
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

ion-slides {
  display: block;
  width: 100%;
  height: 100%;
}

.slide-zoom {
  text-align: center;
  display: block;
  width: 100%;
}

.swiper-slide img {
  width: auto;
  max-width: 100%;
  height: auto;
  max-height: 100%;
}

ion-spinner {
  position: relative;
  display: inline-block;
  width: 28px;
  height: 28px;
}

ion-spinner svg {
  left: 0;
  top: 0;
  position: absolute;
  width: 100%;
  height: 100%;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

ion-spinner.spinner-paused svg {
  -webkit-animation-play-state: paused;
  animation-play-state: paused;
}

.spinner-ios line,
.spinner-ios-small line {
  stroke-width: 4px;
  stroke-linecap: round;
}

.spinner-ios svg,
.spinner-ios-small svg {
  -webkit-animation: spinner-fade-out 1s linear infinite;
  animation: spinner-fade-out 1s linear infinite;
}

.spinner-bubbles svg {
  -webkit-animation: spinner-scale-out 1s linear infinite;
  animation: spinner-scale-out 1s linear infinite;
}

.spinner-circles svg {
  -webkit-animation: spinner-fade-out 1s linear infinite;
  animation: spinner-fade-out 1s linear infinite;
}

.spinner-crescent circle {
  fill: transparent;
  stroke-width: 4px;
  stroke-dasharray: 128px;
  stroke-dashoffset: 82px;
}

.spinner-crescent svg {
  -webkit-animation: spinner-rotate 1s linear infinite;
  animation: spinner-rotate 1s linear infinite;
}

.spinner-dots circle {
  stroke-width: 0;
}

.spinner-dots svg {
  -webkit-transform-origin: center;
  transform-origin: center;
  -webkit-animation: spinner-dots 1s linear infinite;
  animation: spinner-dots 1s linear infinite;
}

@-webkit-keyframes spinner-fade-out {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}

@keyframes spinner-fade-out {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}

@-webkit-keyframes spinner-scale-out {
  0% {
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1);
  }
  100% {
    -webkit-transform: scale(0, 0);
    transform: scale(0, 0);
  }
}

@keyframes spinner-scale-out {
  0% {
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1);
  }
  100% {
    -webkit-transform: scale(0, 0);
    transform: scale(0, 0);
  }
}

@-webkit-keyframes spinner-rotate {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes spinner-rotate {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@-webkit-keyframes spinner-dots {
  0% {
    opacity: .9;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1);
  }
  50% {
    opacity: .3;
    -webkit-transform: scale(0.4, 0.4);
    transform: scale(0.4, 0.4);
  }
  100% {
    opacity: .9;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1);
  }
}

@keyframes spinner-dots {
  0% {
    opacity: .9;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1);
  }
  50% {
    opacity: .3;
    -webkit-transform: scale(0.4, 0.4);
    transform: scale(0.4, 0.4);
  }
  100% {
    opacity: .9;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1);
  }
}

.spinner-ios-ios line,
.spinner-ios-ios-small line {
  stroke: #69717d;
}

.spinner-ios-bubbles circle {
  fill: #000;
}

.spinner-ios-circles circle {
  fill: #69717d;
}

.spinner-ios-crescent circle {
  stroke: #000;
}

.spinner-ios-dots circle {
  fill: #444;
}

.spinner-ios-primary.spinner-ios line,
.spinner-ios-primary.spinner-ios-small line,
.spinner-ios-primary.spinner-crescent circle {
  stroke: #488aff;
}

.spinner-ios-primary.spinner-bubbles circle,
.spinner-ios-primary.spinner-circles circle,
.spinner-ios-primary.spinner-dots circle {
  fill: #488aff;
}

.spinner-ios-secondary.spinner-ios line,
.spinner-ios-secondary.spinner-ios-small line,
.spinner-ios-secondary.spinner-crescent circle {
  stroke: #32db64;
}

.spinner-ios-secondary.spinner-bubbles circle,
.spinner-ios-secondary.spinner-circles circle,
.spinner-ios-secondary.spinner-dots circle {
  fill: #32db64;
}

.spinner-ios-danger.spinner-ios line,
.spinner-ios-danger.spinner-ios-small line,
.spinner-ios-danger.spinner-crescent circle {
  stroke: #f53d3d;
}

.spinner-ios-danger.spinner-bubbles circle,
.spinner-ios-danger.spinner-circles circle,
.spinner-ios-danger.spinner-dots circle {
  fill: #f53d3d;
}

.spinner-ios-light.spinner-ios line,
.spinner-ios-light.spinner-ios-small line,
.spinner-ios-light.spinner-crescent circle {
  stroke: #f4f4f4;
}

.spinner-ios-light.spinner-bubbles circle,
.spinner-ios-light.spinner-circles circle,
.spinner-ios-light.spinner-dots circle {
  fill: #f4f4f4;
}

.spinner-ios-dark.spinner-ios line,
.spinner-ios-dark.spinner-ios-small line,
.spinner-ios-dark.spinner-crescent circle {
  stroke: #222;
}

.spinner-ios-dark.spinner-bubbles circle,
.spinner-ios-dark.spinner-circles circle,
.spinner-ios-dark.spinner-dots circle {
  fill: #222;
}

.spinner-md-ios line,
.spinner-md-ios-small line {
  stroke: #69717d;
}

.spinner-md-bubbles circle {
  fill: #000;
}

.spinner-md-circles circle {
  fill: #69717d;
}

.spinner-md-crescent circle {
  stroke: #000;
}

.spinner-md-dots circle {
  fill: #444;
}

.spinner-md-primary.spinner-ios line,
.spinner-md-primary.spinner-ios-small line,
.spinner-md-primary.spinner-crescent circle {
  stroke: #488aff;
}

.spinner-md-primary.spinner-bubbles circle,
.spinner-md-primary.spinner-circles circle,
.spinner-md-primary.spinner-dots circle {
  fill: #488aff;
}

.spinner-md-secondary.spinner-ios line,
.spinner-md-secondary.spinner-ios-small line,
.spinner-md-secondary.spinner-crescent circle {
  stroke: #32db64;
}

.spinner-md-secondary.spinner-bubbles circle,
.spinner-md-secondary.spinner-circles circle,
.spinner-md-secondary.spinner-dots circle {
  fill: #32db64;
}

.spinner-md-danger.spinner-ios line,
.spinner-md-danger.spinner-ios-small line,
.spinner-md-danger.spinner-crescent circle {
  stroke: #f53d3d;
}

.spinner-md-danger.spinner-bubbles circle,
.spinner-md-danger.spinner-circles circle,
.spinner-md-danger.spinner-dots circle {
  fill: #f53d3d;
}

.spinner-md-light.spinner-ios line,
.spinner-md-light.spinner-ios-small line,
.spinner-md-light.spinner-crescent circle {
  stroke: #f4f4f4;
}

.spinner-md-light.spinner-bubbles circle,
.spinner-md-light.spinner-circles circle,
.spinner-md-light.spinner-dots circle {
  fill: #f4f4f4;
}

.spinner-md-dark.spinner-ios line,
.spinner-md-dark.spinner-ios-small line,
.spinner-md-dark.spinner-crescent circle {
  stroke: #222;
}

.spinner-md-dark.spinner-bubbles circle,
.spinner-md-dark.spinner-circles circle,
.spinner-md-dark.spinner-dots circle {
  fill: #222;
}

.spinner-wp-ios line,
.spinner-wp-ios-small line {
  stroke: #69717d;
}

.spinner-wp-bubbles circle {
  fill: #000;
}

.spinner-wp-circles circle {
  fill: #69717d;
}

.spinner-wp-crescent circle {
  stroke: #000;
}

.spinner-wp-dots circle {
  fill: #444;
}

.spinner-wp-primary.spinner-ios line,
.spinner-wp-primary.spinner-ios-small line,
.spinner-wp-primary.spinner-crescent circle {
  stroke: #488aff;
}

.spinner-wp-primary.spinner-bubbles circle,
.spinner-wp-primary.spinner-circles circle,
.spinner-wp-primary.spinner-dots circle {
  fill: #488aff;
}

.spinner-wp-secondary.spinner-ios line,
.spinner-wp-secondary.spinner-ios-small line,
.spinner-wp-secondary.spinner-crescent circle {
  stroke: #32db64;
}

.spinner-wp-secondary.spinner-bubbles circle,
.spinner-wp-secondary.spinner-circles circle,
.spinner-wp-secondary.spinner-dots circle {
  fill: #32db64;
}

.spinner-wp-danger.spinner-ios line,
.spinner-wp-danger.spinner-ios-small line,
.spinner-wp-danger.spinner-crescent circle {
  stroke: #f53d3d;
}

.spinner-wp-danger.spinner-bubbles circle,
.spinner-wp-danger.spinner-circles circle,
.spinner-wp-danger.spinner-dots circle {
  fill: #f53d3d;
}

.spinner-wp-light.spinner-ios line,
.spinner-wp-light.spinner-ios-small line,
.spinner-wp-light.spinner-crescent circle {
  stroke: #f4f4f4;
}

.spinner-wp-light.spinner-bubbles circle,
.spinner-wp-light.spinner-circles circle,
.spinner-wp-light.spinner-dots circle {
  fill: #f4f4f4;
}

.spinner-wp-dark.spinner-ios line,
.spinner-wp-dark.spinner-ios-small line,
.spinner-wp-dark.spinner-crescent circle {
  stroke: #222;
}

.spinner-wp-dark.spinner-bubbles circle,
.spinner-wp-dark.spinner-circles circle,
.spinner-wp-dark.spinner-dots circle {
  fill: #222;
}

.split-pane {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: absolute;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-flex-wrap: nowrap;
  -ms-flex-wrap: nowrap;
  flex-wrap: nowrap;
  contain: strict;
}

.split-pane-side:not(ion-menu) {
  display: none;
}

.split-pane-visible > .split-pane-side,
.split-pane-visible > .split-pane-main {
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  position: relative;
  z-index: 0;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-shadow: none !important;
  box-shadow: none !important;
}

.split-pane-visible > .split-pane-side {
  -webkit-flex-shrink: 0;
  -ms-flex-negative: 0;
  flex-shrink: 0;
  -webkit-box-ordinal-group: 0;
  -webkit-order: -1;
  -ms-flex-order: -1;
  order: -1;
}

.split-pane-visible > .split-pane-main,
.split-pane-visible > ion-nav.split-pane-side,
.split-pane-visible > ion-tabs.split-pane-side,
.split-pane-visible > ion-menu.menu-enabled {
  display: block;
}

.split-pane-visible > ion-split-pane.split-pane-side,
.split-pane-visible > ion-split-pane.split-pane-main {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}

.split-pane-visible > ion-menu.menu-enabled > .menu-inner {
  left: 0;
  right: 0;
  width: auto;
  -webkit-box-shadow: none !important;
  box-shadow: none !important;
  -webkit-transform: none !important;
  transform: none !important;
}

.split-pane-visible > ion-menu.menu-enabled > .ion-backdrop {
  display: hidden !important;
}

.split-pane-visible > .split-pane-side[side=start] {
  -webkit-box-ordinal-group: 0;
  -webkit-order: -1;
  -ms-flex-order: -1;
  order: -1;
}

.split-pane-visible > .split-pane-side[side=end] {
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
}

.split-pane-visible > .split-pane-side[side=left] {
  -webkit-box-ordinal-group: 0;
  -webkit-order: -1;
  -ms-flex-order: -1;
  order: -1;
}

.split-pane-visible > .split-pane-side[side=right] {
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
}

.split-pane-ios.split-pane-visible > .split-pane-side {
  min-width: 270px;
  max-width: 28%;
  border-right: 0.55px solid #c8c7cc;
  border-left: 0;
}

.split-pane-ios.split-pane-visible > .split-pane-side[side=right] {
  border-right: 0;
  border-left: 0.55px solid #c8c7cc;
}

.split-pane-md.split-pane-visible > .split-pane-side {
  min-width: 270px;
  max-width: 28%;
  border-right: 1px solid #dedede;
  border-left: 0;
}

.split-pane-md.split-pane-visible > .split-pane-side[side=right] {
  border-right: 0;
  border-left: 1px solid #dedede;
}

.split-pane-wp.split-pane-visible > .split-pane-side {
  min-width: 270px;
  max-width: 28%;
  border-right: 1px solid transparent;
  border-left: 0;
}

.split-pane-wp.split-pane-visible > .split-pane-side[side=right] {
  border-right: 0;
  border-left: 1px solid transparent;
}

.tabbar {
  left: 0;
  bottom: 0;
  position: absolute;
  z-index: 10;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  width: 100%;
  opacity: 0;
}

.tabbar-hidden .tabbar {
  display: none;
}

.tabbar.show-tabbar {
  opacity: 1;
}

[tabsPlacement=top] > .tabbar {
  top: 0;
  bottom: auto;
}

.tab-button {
  margin: 0;
  text-align: center;
  border-radius: 0;
  position: relative;
  z-index: 0;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-align-self: center;
  -ms-flex-item-align: center;
  align-self: center;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  border: 0;
  text-decoration: none;
  background: none;
  cursor: pointer;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.tab-disabled {
  pointer-events: none;
}

.tab-disabled ion-badge,
.tab-disabled ion-icon,
.tab-disabled span {
  opacity: .4;
}

.tab-button-text {
  margin-top: 3px;
  margin-bottom: 2px;
}

.tab-button-text,
.tab-button-icon {
  display: none;
  overflow: hidden;
  -webkit-align-self: center;
  -ms-flex-item-align: center;
  align-self: center;
  min-width: 26px;
  max-width: 100%;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.has-icon .tab-button-icon,
.has-title .tab-button-text {
  display: block;
}

.has-title-only .tab-button-text {
  white-space: normal;
}

[tabsLayout=icon-bottom] .tab-button .tab-button-icon {
  -webkit-box-ordinal-group: 11;
  -webkit-order: 10;
  -ms-flex-order: 10;
  order: 10;
}

[tabsLayout=icon-left] .tab-button,
[tabsLayout=icon-right] .tab-button,
[tabsLayout=icon-start] .tab-button,
[tabsLayout=icon-end] .tab-button {
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
}

[tabsLayout=icon-left] .tab-button .tab-button-icon,
[tabsLayout=icon-start] .tab-button .tab-button-icon {
  padding-right: 8px;
  text-align: right;
  text-align: end;
}

[tabsLayout=icon-right] .tab-button .tab-button-icon,
[tabsLayout=icon-end] .tab-button .tab-button-icon {
  padding-left: 8px;
  text-align: left;
  text-align: start;
  -webkit-box-ordinal-group: 11;
  -webkit-order: 10;
  -ms-flex-order: 10;
  order: 10;
}

.tab-hidden,
.tab-highlight,
[tabsLayout=icon-hide] .tab-button-icon,
[tabsLayout=title-hide] .tab-button-text {
  display: none;
}

.tab-badge {
  right: 4%;
  top: 6%;
  right: calc(50% - 50px);
  padding: 1px 6px;
  position: absolute;
  height: auto;
  font-size: 12px;
  line-height: 16px;
}

.has-icon .tab-badge {
  right: calc(50% - 30px);
}

[tabsLayout=icon-bottom] .tab-badge,
[tabsLayout=icon-left] .tab-badge,
[tabsLayout=icon-right] .tab-badge,
[tabsLayout=icon-start] .tab-badge,
[tabsLayout=icon-end] .tab-badge {
  right: calc(50% - 50px);
}

.tabs-ios .tabbar {
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
  border-top: 0.55px solid rgba(0, 0, 0, 0.3);
  background: #f8f8f8;
}

.tabs-ios[tabsPlacement=top] .tabbar {
  border-top: 0;
  border-bottom: 0.55px solid rgba(0, 0, 0, 0.3);
}

.tabs-ios .tab-button {
  max-width: 240px;
  min-height: 49px;
  font-size: 10px;
  font-weight: 500;
  color: #8c8c8c;
  padding: 0 2px;
}

.tabs-ios .tab-button:hover:not(.disable-hover),
.tabs-ios .tab-button[aria-selected=true] {
  color: #488aff;
}

.tabs-ios .tab-button[aria-selected=true] .tab-button-icon {
  color: #488aff;
}

.tabs-ios .tab-button-text {
  margin-top: 0;
  margin-bottom: 1px;
  min-height: 11px;
}

.tabs-ios .has-title-only .tab-button-text {
  font-size: 12px;
}

.tabs-ios .tab-button-icon {
  margin-top: 4px;
  margin-bottom: 1px;
  min-width: 35px;
  height: 30px;
  font-size: 30px;
  color: #8c8c8c;
}

.tabs-ios .tab-button-icon::before {
  vertical-align: top;
}

.tabs-ios[tabsLayout=icon-right] .tab-button .tab-button-text,
.tabs-ios[tabsLayout=icon-left] .tab-button .tab-button-text,
.tabs-ios[tabsLayout=icon-end] .tab-button .tab-button-text,
.tabs-ios[tabsLayout=icon-start] .tab-button .tab-button-text {
  font-size: 1.4rem;
  line-height: 1.1;
}

.tabs-ios[tabsLayout=icon-right] .tab-button ion-icon,
.tabs-ios[tabsLayout=icon-left] .tab-button ion-icon,
.tabs-ios[tabsLayout=icon-end] .tab-button ion-icon,
.tabs-ios[tabsLayout=icon-start] .tab-button ion-icon {
  min-width: 24px;
  height: 26px;
  font-size: 24px;
}

.tabs-ios[tabsLayout=icon-hide] .tab-button,
.tabs-ios .tab-button.has-title-only {
  min-height: 41px;
}

.tabs-ios[tabsLayout=icon-hide] .tab-button .tab-button-text,
.tabs-ios .tab-button.has-title-only .tab-button-text {
  margin: 2px 0;
  font-size: 1.4rem;
  line-height: 1.1;
}

.tabs-ios[tabsLayout=title-hide] .tab-button,
.tabs-ios .tab-button.icon-only {
  min-height: 41px;
}

.tabs-ios-primary .tabbar {
  border-color: #1569ff;
  background-color: #488aff;
}

.tabs-ios-primary .tab-button,
.tabs-ios-primary .tab-button-icon,
.tabs-ios-primary .tab-button:hover:not(.disable-hover),
.tabs-ios-primary .tab-button:hover:not(.disable-hover) .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-ios-primary .tab-button[aria-selected=true],
.tabs-ios-primary .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-ios-secondary .tabbar {
  border-color: #21b94e;
  background-color: #32db64;
}

.tabs-ios-secondary .tab-button,
.tabs-ios-secondary .tab-button-icon,
.tabs-ios-secondary .tab-button:hover:not(.disable-hover),
.tabs-ios-secondary .tab-button:hover:not(.disable-hover) .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-ios-secondary .tab-button[aria-selected=true],
.tabs-ios-secondary .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-ios-danger .tabbar {
  border-color: #f30d0d;
  background-color: #f53d3d;
}

.tabs-ios-danger .tab-button,
.tabs-ios-danger .tab-button-icon,
.tabs-ios-danger .tab-button:hover:not(.disable-hover),
.tabs-ios-danger .tab-button:hover:not(.disable-hover) .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-ios-danger .tab-button[aria-selected=true],
.tabs-ios-danger .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-ios-light .tabbar {
  border-color: #dbdbdb;
  background-color: #f4f4f4;
}

.tabs-ios-light .tab-button,
.tabs-ios-light .tab-button-icon,
.tabs-ios-light .tab-button:hover:not(.disable-hover),
.tabs-ios-light .tab-button:hover:not(.disable-hover) .tab-button-icon {
  color: rgba(0, 0, 0, 0.7);
}

.tabs-ios-light .tab-button[aria-selected=true],
.tabs-ios-light .tab-button[aria-selected=true] .tab-button-icon {
  color: #000;
}

.tabs-ios-dark .tabbar {
  border-color: #090909;
  background-color: #222;
}

.tabs-ios-dark .tab-button,
.tabs-ios-dark .tab-button-icon,
.tabs-ios-dark .tab-button:hover:not(.disable-hover),
.tabs-ios-dark .tab-button:hover:not(.disable-hover) .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-ios-dark .tab-button[aria-selected=true],
.tabs-ios-dark .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-md .tabbar {
  background: #f8f8f8;
}

.tabs-md .tab-button {
  min-height: 5.6rem;
  font-weight: normal;
  color: rgba(60, 60, 60, 0.7);
  padding: 0;
}

.tabs-md .tab-button[aria-selected=true] {
  color: #488aff;
  padding: 0;
}

.tabs-md .tab-button-text {
  font-size: 1.2rem;
  text-transform: none;
  -webkit-transition: -webkit-transform 0.3s ease-in-out;
  transition: -webkit-transform 0.3s ease-in-out;
  transition: transform 0.3s ease-in-out;
  transition: transform 0.3s ease-in-out, -webkit-transform 0.3s ease-in-out;
  margin: 0;
  -webkit-transform-origin: 50% 80%;
  transform-origin: 50% 80%;
}

.tabs-md .tab-button[aria-selected=true] .tab-button-text {
  -webkit-transform: scale3d(1.16667, 1.16667, 1);
  transform: scale3d(1.16667, 1.16667, 1);
  -webkit-transition: -webkit-transform 0.3s ease-in-out;
  transition: -webkit-transform 0.3s ease-in-out;
  transition: transform 0.3s ease-in-out;
  transition: transform 0.3s ease-in-out, -webkit-transform 0.3s ease-in-out;
}

.tabs-md[tabsLayout=icon-top] .has-icon .tab-button-text {
  margin-top: 4px;
  margin-bottom: 0;
}

.tabs-md[tabsLayout=icon-bottom] .tab-button .tab-button-text {
  margin-top: 0;
}

.tabs-md .tab-button-icon {
  margin-top: 1px;
  min-width: 2.4rem;
  font-size: 2.4rem;
  color: rgba(60, 60, 60, 0.7);
  -webkit-transition: -webkit-transform 0.3s ease-in-out;
  transition: -webkit-transform 0.3s ease-in-out;
  transition: transform 0.3s ease-in-out;
  transition: transform 0.3s ease-in-out, -webkit-transform 0.3s ease-in-out;
  -webkit-transform-origin: 50% 150%;
  transform-origin: 50% 150%;
}

.tabs-md .tab-button[aria-selected=true] .tab-button-icon {
  color: #488aff;
  -webkit-transform: translate3d(0,  -2px,  0);
  transform: translate3d(0,  -2px,  0);
}

.tabs-md[tabsLayout=icon-right] .tab-button[aria-selected=true] .tab-button-icon,
.tabs-md[tabsLayout=icon-end] .tab-button[aria-selected=true] .tab-button-icon {
  -webkit-transform: translate3d(2px,  0,  0);
  transform: translate3d(2px,  0,  0);
}

.tabs-md[tabsLayout=icon-bottom] .tab-button[aria-selected=true] .tab-button-icon {
  -webkit-transform: translate3d(0,  2px,  0);
  transform: translate3d(0,  2px,  0);
}

.tabs-md[tabsLayout=icon-left] .tab-button[aria-selected=true] .tab-button-icon,
.tabs-md[tabsLayout=icon-start] .tab-button[aria-selected=true] .tab-button-icon {
  -webkit-transform: translate3d(-2px,  0,  0);
  transform: translate3d(-2px,  0,  0);
}

.tabs-md[tabsLayout=icon-hide] .tab-button,
.tabs-md[tabsLayout=title-hide] .tab-button,
.tabs-md .tab-button.icon-only,
.tabs-md .tab-button.has-title-only {
  padding: 0 10px;
}

.tabs-md[tabsHighlight=true] .tab-highlight {
  left: 0;
  bottom: 0;
  -webkit-transform-origin: 0 0;
  transform-origin: 0 0;
  position: absolute;
  display: block;
  width: 1px;
  height: 2px;
  background: #488aff;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.tabs-md[tabsHighlight=true] .tab-highlight.animate {
  -webkit-transition-duration: 300ms;
  transition-duration: 300ms;
}

.tabs-md[tabsHighlight=true][tabsPlacement=bottom] > .tabbar > .tab-highlight {
  top: 0;
}

.tabs-md-primary .tabbar {
  background-color: #488aff;
}

.tabs-md-primary .tab-button,
.tabs-md-primary .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-md-primary .tab-button:hover:not(.disable-hover),
.tabs-md-primary .tab-button[aria-selected=true],
.tabs-md-primary .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-md-primary[tabsHighlight=true] .tab-highlight {
  background: #fff;
}

.tabs-md-secondary .tabbar {
  background-color: #32db64;
}

.tabs-md-secondary .tab-button,
.tabs-md-secondary .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-md-secondary .tab-button:hover:not(.disable-hover),
.tabs-md-secondary .tab-button[aria-selected=true],
.tabs-md-secondary .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-md-secondary[tabsHighlight=true] .tab-highlight {
  background: #fff;
}

.tabs-md-danger .tabbar {
  background-color: #f53d3d;
}

.tabs-md-danger .tab-button,
.tabs-md-danger .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-md-danger .tab-button:hover:not(.disable-hover),
.tabs-md-danger .tab-button[aria-selected=true],
.tabs-md-danger .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-md-danger[tabsHighlight=true] .tab-highlight {
  background: #fff;
}

.tabs-md-light .tabbar {
  background-color: #f4f4f4;
}

.tabs-md-light .tab-button,
.tabs-md-light .tab-button-icon {
  color: rgba(0, 0, 0, 0.7);
}

.tabs-md-light .tab-button:hover:not(.disable-hover),
.tabs-md-light .tab-button[aria-selected=true],
.tabs-md-light .tab-button[aria-selected=true] .tab-button-icon {
  color: #000;
}

.tabs-md-light[tabsHighlight=true] .tab-highlight {
  background: #000;
}

.tabs-md-dark .tabbar {
  background-color: #222;
}

.tabs-md-dark .tab-button,
.tabs-md-dark .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-md-dark .tab-button:hover:not(.disable-hover),
.tabs-md-dark .tab-button[aria-selected=true],
.tabs-md-dark .tab-button[aria-selected=true] .tab-button-icon {
  color: #fff;
}

.tabs-md-dark[tabsHighlight=true] .tab-highlight {
  background: #fff;
}

.tabs-wp .tabbar {
  background: #f8f8f8;
}

.tabs-wp .tab-button {
  border-radius: 0;
  min-height: 4.8rem;
  border-bottom: 2px solid transparent;
  font-size: 1.2rem;
  font-weight: normal;
  color: rgba(140, 140, 140, 0.7);
  -webkit-box-shadow: none;
  box-shadow: none;
  padding: 12px 10px 5px;
}

.tabs-wp .tab-button[aria-selected=true] {
  border-bottom-color: #488aff;
  color: #488aff;
}

.tabs-wp .tab-button.activated {
  background: rgba(0, 0, 0, 0.1);
}

.tabs-wp[tabsPlacement=bottom] .tab-button {
  border-top: 2px solid transparent;
  border-bottom-width: 0;
}

.tabs-wp[tabsPlacement=bottom] .tab-button[aria-selected=true] {
  border-top-color: #488aff;
}

.tabs-wp .tab-button-text {
  margin-top: 5px;
  margin-bottom: 5px;
}

.tabs-wp .tab-button-icon {
  min-width: 2.4rem;
  font-size: 2.4rem;
  color: rgba(140, 140, 140, 0.7);
}

.tabs-wp .tab-button[aria-selected=true] .tab-button-icon {
  color: #488aff;
}

.tabs-wp[tabsLayout=icon-bottom] .tab-button {
  padding-top: 8px;
  padding-bottom: 8px;
}

.tabs-wp[tabsLayout=icon-right] .tab-button,
.tabs-wp[tabsLayout=icon-left] .tab-button,
.tabs-wp[tabsLayout=icon-end] .tab-button,
.tabs-wp[tabsLayout=icon-start] .tab-button {
  padding-bottom: 10px;
}

.tabs-wp[tabsLayout=icon-right] .tab-button ion-icon,
.tabs-wp[tabsLayout=icon-left] .tab-button ion-icon,
.tabs-wp[tabsLayout=icon-end] .tab-button ion-icon,
.tabs-wp[tabsLayout=icon-start] .tab-button ion-icon {
  min-width: 24px;
}

.tabs-wp[tabsLayout=icon-hide] .tab-button,
.tabs-wp[tabsLayout=title-hide] .tab-button,
.tabs-wp .tab-button.icon-only,
.tabs-wp .tab-button.has-title-only {
  padding: 6px 10px;
}

.tabs-wp-primary .tabbar {
  background-color: #488aff;
}

.tabs-wp-primary .tab-button,
.tabs-wp-primary .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-wp-primary .tab-button:hover:not(.disable-hover),
.tabs-wp-primary .tab-button:hover:not(.disable-hover) .tab-button-icon,
.tabs-wp-primary .tab-button[aria-selected=true],
.tabs-wp-primary .tab-button[aria-selected=true] .tab-button-icon {
  border-color: #fff;
  color: #fff;
}

.tabs-wp-secondary .tabbar {
  background-color: #32db64;
}

.tabs-wp-secondary .tab-button,
.tabs-wp-secondary .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-wp-secondary .tab-button:hover:not(.disable-hover),
.tabs-wp-secondary .tab-button:hover:not(.disable-hover) .tab-button-icon,
.tabs-wp-secondary .tab-button[aria-selected=true],
.tabs-wp-secondary .tab-button[aria-selected=true] .tab-button-icon {
  border-color: #fff;
  color: #fff;
}

.tabs-wp-danger .tabbar {
  background-color: #f53d3d;
}

.tabs-wp-danger .tab-button,
.tabs-wp-danger .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-wp-danger .tab-button:hover:not(.disable-hover),
.tabs-wp-danger .tab-button:hover:not(.disable-hover) .tab-button-icon,
.tabs-wp-danger .tab-button[aria-selected=true],
.tabs-wp-danger .tab-button[aria-selected=true] .tab-button-icon {
  border-color: #fff;
  color: #fff;
}

.tabs-wp-light .tabbar {
  background-color: #f4f4f4;
}

.tabs-wp-light .tab-button,
.tabs-wp-light .tab-button-icon {
  color: rgba(0, 0, 0, 0.7);
}

.tabs-wp-light .tab-button:hover:not(.disable-hover),
.tabs-wp-light .tab-button:hover:not(.disable-hover) .tab-button-icon,
.tabs-wp-light .tab-button[aria-selected=true],
.tabs-wp-light .tab-button[aria-selected=true] .tab-button-icon {
  border-color: #000;
  color: #000;
}

.tabs-wp-dark .tabbar {
  background-color: #222;
}

.tabs-wp-dark .tab-button,
.tabs-wp-dark .tab-button-icon {
  color: rgba(255, 255, 255, 0.7);
}

.tabs-wp-dark .tab-button:hover:not(.disable-hover),
.tabs-wp-dark .tab-button:hover:not(.disable-hover) .tab-button-icon,
.tabs-wp-dark .tab-button[aria-selected=true],
.tabs-wp-dark .tab-button[aria-selected=true] .tab-button-icon {
  border-color: #fff;
  color: #fff;
}

ion-toast {
  left: 0;
  top: 0;
  position: absolute;
  z-index: 1000;
  display: block;
  width: 100%;
  height: 100%;
  pointer-events: none;
  contain: strict;
}

.toast-container {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  pointer-events: auto;
  contain: content;
}

.toast-button {
  padding: 19px 16px 17px;
  font-size: 1.5rem;
}

.toast-message {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
}

.toast-ios .toast-wrapper {
  left: 10px;
  right: 10px;
  margin: auto;
  border-radius: 0.65rem;
  position: absolute;
  z-index: 10;
  display: block;
  max-width: 700px;
  background: rgba(0, 0, 0, 0.9);
}

.toast-ios .toast-wrapper.toast-top {
  -webkit-transform: translate3d(0,  -100%,  0);
  transform: translate3d(0,  -100%,  0);
  margin: constant(safe-area-inset-top) auto auto;
  margin: env(safe-area-inset-top) auto auto;
  top: 0;
}

.toast-ios .toast-wrapper.toast-bottom {
  -webkit-transform: translate3d(0,  100%,  0);
  transform: translate3d(0,  100%,  0);
  margin: auto auto constant(safe-area-inset-bottom);
  margin: auto auto env(safe-area-inset-bottom);
  bottom: 0;
}

.toast-ios .toast-wrapper.toast-middle {
  opacity: .01;
}

.toast-ios .toast-message {
  font-size: 1.4rem;
  color: #fff;
  padding: 1.5rem;
}

.toast-md .toast-wrapper {
  left: 0;
  right: 0;
  margin: auto;
  position: absolute;
  z-index: 10;
  display: block;
  width: 100%;
  max-width: 700px;
  background: #333;
}

.toast-md .toast-wrapper.toast-top {
  -webkit-transform: translate3d(0,  -100%,  0);
  transform: translate3d(0,  -100%,  0);
  top: 0;
}

.toast-md .toast-wrapper.toast-bottom {
  -webkit-transform: translate3d(0,  100%,  0);
  transform: translate3d(0,  100%,  0);
  bottom: 0;
}

.toast-md .toast-wrapper.toast-middle {
  opacity: .01;
}

.toast-md .toast-message {
  font-size: 1.5rem;
  color: #fff;
  padding: 19px 16px 17px;
}

.toast-wp .toast-wrapper {
  left: 0;
  right: 0;
  margin: auto;
  border-radius: 0;
  position: absolute;
  z-index: 10;
  display: block;
  max-width: 700px;
  background: black;
}

.toast-wp .toast-wrapper.toast-top {
  top: 0;
  opacity: .01;
}

.toast-wp .toast-wrapper.toast-bottom {
  bottom: 0;
  opacity: .01;
}

.toast-wp .toast-wrapper.toast-middle {
  opacity: .01;
}

.toast-message {
  font-size: 1.4rem;
  color: #fff;
  padding: 1.5rem;
}

.toast-button {
  color: #fff;
}

.toggle-ios {
  position: relative;
  width: 51px;
  height: 32px;
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
  contain: strict;
}

.toggle-ios .toggle-icon {
  border-radius: 16px;
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
  background-color: #e6e6e6;
  -webkit-transition: background-color 300ms;
  transition: background-color 300ms;
  pointer-events: none;
}

.toggle-ios .toggle-icon::before {
  left: 2px;
  right: 2px;
  top: 2px;
  bottom: 2px;
  border-radius: 16px;
  position: absolute;
  background-color: #fff;
  content: "";
  -webkit-transform: scale3d(1, 1, 1);
  transform: scale3d(1, 1, 1);
  -webkit-transition: -webkit-transform 300ms;
  transition: -webkit-transform 300ms;
  transition: transform 300ms;
  transition: transform 300ms, -webkit-transform 300ms;
}

.toggle-ios .toggle-inner {
  left: 2px;
  top: 2px;
  border-radius: 14px;
  position: absolute;
  width: 28px;
  height: 28px;
  background-color: #fff;
  -webkit-box-shadow: 0 3px 12px rgba(0, 0, 0, 0.16), 0 3px 1px rgba(0, 0, 0, 0.1);
  box-shadow: 0 3px 12px rgba(0, 0, 0, 0.16), 0 3px 1px rgba(0, 0, 0, 0.1);
  -webkit-transition: width 120ms ease-in-out 80ms, left 110ms ease-in-out 80ms, right 110ms ease-in-out 80ms, -webkit-transform 300ms;
  transition: width 120ms ease-in-out 80ms, left 110ms ease-in-out 80ms, right 110ms ease-in-out 80ms, -webkit-transform 300ms;
  transition: transform 300ms, width 120ms ease-in-out 80ms, left 110ms ease-in-out 80ms, right 110ms ease-in-out 80ms;
  transition: transform 300ms, width 120ms ease-in-out 80ms, left 110ms ease-in-out 80ms, right 110ms ease-in-out 80ms, -webkit-transform 300ms;
  will-change: transform;
  contain: strict;
}

.toggle-ios.toggle-checked .toggle-icon {
  background-color: #488aff;
}

.toggle-ios.toggle-activated .toggle-icon::before,
.toggle-ios.toggle-checked .toggle-icon::before {
  -webkit-transform: scale3d(0, 0, 0);
  transform: scale3d(0, 0, 0);
}

.toggle-ios.toggle-checked .toggle-inner {
  -webkit-transform: translate3d(19px,  0,  0);
  transform: translate3d(19px,  0,  0);
}

.toggle-ios.toggle-activated.toggle-checked .toggle-inner::before {
  -webkit-transform: scale3d(0, 0, 0);
  transform: scale3d(0, 0, 0);
}

.toggle-ios.toggle-activated .toggle-inner {
  width: 34px;
}

.toggle-ios.toggle-activated.toggle-checked .toggle-inner {
  left: -4px;
}

.toggle-ios.toggle-disabled,
.item-ios.item-toggle-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.item-ios .toggle-ios {
  margin: 0;
  padding: 6px 8px 5px 16px;
}

.item-ios .toggle-ios[item-left],
.item-ios .toggle-ios[item-start] {
  padding: 6px 16px 5px 0;
}

.toggle-ios-primary.toggle-checked .toggle-icon {
  background-color: #488aff;
}

.toggle-ios-secondary.toggle-checked .toggle-icon {
  background-color: #32db64;
}

.toggle-ios-danger.toggle-checked .toggle-icon {
  background-color: #f53d3d;
}

.toggle-ios-light.toggle-checked .toggle-icon {
  background-color: #f4f4f4;
}

.toggle-ios-dark.toggle-checked .toggle-icon {
  background-color: #222;
}

.toggle-md {
  position: relative;
  width: 36px;
  height: 14px;
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
  contain: strict;
  padding: 12px;
}

.toggle-md .toggle-icon {
  border-radius: 14px;
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
  background-color: #dedede;
  -webkit-transition: background-color 300ms;
  transition: background-color 300ms;
  pointer-events: none;
}

.toggle-md .toggle-inner {
  left: 0;
  top: -3px;
  border-radius: 50%;
  position: absolute;
  width: 20px;
  height: 20px;
  background-color: #fff;
  -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  -webkit-transition-duration: 300ms;
  transition-duration: 300ms;
  -webkit-transition-property: background-color, -webkit-transform;
  transition-property: background-color, -webkit-transform;
  transition-property: transform, background-color;
  transition-property: transform, background-color, -webkit-transform;
  will-change: transform, background-color;
  contain: strict;
}

.toggle-md.toggle-checked .toggle-icon {
  background-color: #c8dcff;
}

.toggle-md.toggle-checked .toggle-inner {
  -webkit-transform: translate3d(16px,  0,  0);
  transform: translate3d(16px,  0,  0);
  background-color: #488aff;
}

.toggle-md.toggle-disabled,
.item-md.item-toggle-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.toggle-md.toggle-disabled ion-radio {
  opacity: 0.3;
}

.item-md .toggle-md {
  cursor: pointer;
  margin: 0;
  padding: 12px 8px 12px 16px;
}

.item-md .toggle-md[item-left],
.item-md .toggle-md[item-start] {
  padding: 12px 18px 12px 2px;
}

.item-md.item-toggle ion-label {
  margin-left: 0;
}

.toggle-md-primary.toggle-checked .toggle-icon {
  background-color: #c8dcff;
}

.toggle-md-primary.toggle-checked .toggle-inner {
  background-color: #488aff;
}

.toggle-md-secondary.toggle-checked .toggle-icon {
  background-color: #9eeeb6;
}

.toggle-md-secondary.toggle-checked .toggle-inner {
  background-color: #32db64;
}

.toggle-md-danger.toggle-checked .toggle-icon {
  background-color: #fbb6b6;
}

.toggle-md-danger.toggle-checked .toggle-inner {
  background-color: #f53d3d;
}

.toggle-md-light.toggle-checked .toggle-icon {
  background-color: white;
}

.toggle-md-light.toggle-checked .toggle-inner {
  background-color: #f4f4f4;
}

.toggle-md-dark.toggle-checked .toggle-icon {
  background-color: #626262;
}

.toggle-md-dark.toggle-checked .toggle-inner {
  background-color: #222;
}

.toggle-wp {
  position: relative;
  width: 40px;
  height: 18px;
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
  contain: strict;
}

.toggle-wp .toggle-icon {
  border-radius: 18px;
  position: relative;
  display: block;
  width: 100%;
  height: 100%;
  border: 2px solid #323232;
  background-color: transparent;
  pointer-events: none;
  contain: strict;
}

.toggle-wp .toggle-inner {
  left: 2px;
  top: 2px;
  border-radius: 50%;
  position: absolute;
  width: 10px;
  height: 10px;
  background-color: #323232;
  -webkit-transition-duration: 300ms;
  transition-duration: 300ms;
  -webkit-transition-property: background-color, -webkit-transform;
  transition-property: background-color, -webkit-transform;
  transition-property: transform, background-color;
  transition-property: transform, background-color, -webkit-transform;
  will-change: transform, background-color;
}

.toggle-wp.toggle-checked .toggle-icon {
  border-color: #488aff;
  background-color: #488aff;
}

.toggle-wp.toggle-checked .toggle-inner {
  -webkit-transform: translate3d(22px,  0,  0);
  transform: translate3d(22px,  0,  0);
  background-color: #fff;
}

.toggle-wp.toggle-disabled,
.item-wp.item-toggle-disabled ion-label {
  opacity: 0.3;
  pointer-events: none;
}

.toggle-wp.toggle-disabled ion-radio {
  opacity: 0.3;
}

.item-wp .toggle-wp {
  margin: 0;
  cursor: pointer;
  padding: 12px 8px 12px 16px;
}

.item-wp .toggle-wp[item-left],
.item-wp .toggle-wp[item-start] {
  padding: 12px 18px 12px 2px;
}

.item-wp.item-toggle ion-label {
  margin-left: 0;
}

.toggle-wp-primary.toggle-checked .toggle-icon {
  border-color: #488aff;
  background-color: #488aff;
}

.toggle-wp-primary.toggle-checked .toggle-inner {
  background-color: #fff;
}

.toggle-wp-secondary.toggle-checked .toggle-icon {
  border-color: #32db64;
  background-color: #32db64;
}

.toggle-wp-secondary.toggle-checked .toggle-inner {
  background-color: #fff;
}

.toggle-wp-danger.toggle-checked .toggle-icon {
  border-color: #f53d3d;
  background-color: #f53d3d;
}

.toggle-wp-danger.toggle-checked .toggle-inner {
  background-color: #fff;
}

.toggle-wp-light.toggle-checked .toggle-icon {
  border-color: #f4f4f4;
  background-color: #f4f4f4;
}

.toggle-wp-light.toggle-checked .toggle-inner {
  background-color: #000;
}

.toggle-wp-dark.toggle-checked .toggle-icon {
  border-color: #222;
  background-color: #222;
}

.toggle-wp-dark.toggle-checked .toggle-inner {
  background-color: #fff;
}

ion-toolbar {
  position: relative;
  z-index: 10;
}

.toolbar {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  overflow: hidden;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
  -webkit-flex-direction: row;
  -ms-flex-direction: row;
  flex-direction: row;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -ms-flex-pack: justify;
  justify-content: space-between;
  width: 100%;
  contain: content;
}

.toolbar-background {
  left: 0;
  top: 0;
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 100%;
  border: 0;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
  pointer-events: none;
  contain: strict;
}

ion-title {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.toolbar-title {
  display: block;
  overflow: hidden;
  width: 100%;
  text-overflow: ellipsis;
  white-space: nowrap;
}

ion-buttons {
  margin: 0 0.2rem;
  display: block;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
  pointer-events: none;
}

ion-buttons button,
ion-buttons a,
ion-buttons input,
ion-buttons textarea,
ion-buttons div {
  pointer-events: auto;
}

.toolbar[transparent] .toolbar-background {
  border-color: transparent;
  background: transparent;
}

ion-buttons,
.bar-button-menutoggle {
  z-index: 99;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

ion-navbar.toolbar {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.bar-button {
  margin: 0;
  padding: 0;
  text-align: center;
  -moz-appearance: none;
  -ms-appearance: none;
  -webkit-appearance: none;
  appearance: none;
  position: relative;
  display: inline-block;
  line-height: 1;
  text-overflow: ellipsis;
  text-transform: none;
  white-space: nowrap;
  cursor: pointer;
  vertical-align: top;
  vertical-align: -webkit-baseline-middle;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.bar-button::after {
  left: -2px;
  right: -2px;
  top: -7px;
  bottom: -6px;
  position: absolute;
  content: "";
}

.bar-button-menutoggle {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.back-button {
  display: none;
}

.back-button.show-back-button {
  display: inline-block;
}

.back-button-text {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -ms-flex-align: center;
  align-items: center;
}

.toolbar-ios {
  padding: 4px;
  padding-left: 4px;
  padding-right: 4px;
  min-height: 44px;
}

@media screen and (orientation: landscape) {
  .toolbar-ios {
    padding-left: calc(constant(safe-area-inset-left) + 4px);
    padding-right: calc(constant(safe-area-inset-right) + 4px);
    padding-left: calc(env(safe-area-inset-left) + 4px);
    padding-right: calc(env(safe-area-inset-right) + 4px);
  }
}

.toolbar-background-ios {
  background: #f8f8f8;
}

.header-ios .toolbar-background-ios,
.footer-ios .toolbar-background-ios {
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.3);
}

.header-ios .toolbar-ios:last-child .toolbar-background-ios {
  border-width: 0 0 0.55px;
}

.footer-ios .toolbar-ios:first-child .toolbar-background-ios {
  border-width: 0.55px 0 0;
}

.header-ios[no-border] .toolbar-ios:last-child .toolbar-background-ios {
  border-bottom-width: 0;
}

.footer-ios[no-border] .toolbar-ios:first-child .toolbar-background-ios {
  border-top-width: 0;
}

.toolbar-content-ios {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-ordinal-group: 5;
  -webkit-order: 4;
  -ms-flex-order: 4;
  order: 4;
  min-width: 0;
}

.toolbar-title-ios {
  text-align: center;
  font-size: 1.7rem;
  font-weight: 600;
  color: #000;
  pointer-events: auto;
}

.toolbar-ios ion-title {
  left: 0;
  top: 0;
  padding: 0 90px 1px;
  position: absolute;
  width: 100%;
  height: 100%;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
  pointer-events: none;
}

.bar-buttons-ios {
  -webkit-box-ordinal-group: 4;
  -webkit-order: 3;
  -ms-flex-order: 3;
  order: 3;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.bar-buttons-ios[left] {
  -webkit-box-ordinal-group: 3;
  -webkit-order: 2;
  -ms-flex-order: 2;
  order: 2;
}

.bar-buttons-ios[end] {
  text-align: right;
  text-align: end;
  -webkit-box-ordinal-group: 6;
  -webkit-order: 5;
  -ms-flex-order: 5;
  order: 5;
}

.bar-buttons-ios[right] {
  text-align: right;
  -webkit-box-ordinal-group: 7;
  -webkit-order: 6;
  -ms-flex-order: 6;
  order: 6;
}

.bar-button-ios {
  padding: 0 4px;
  border-radius: 4px;
  height: 32px;
  border: 0;
  font-size: 1.7rem;
}

.bar-button-outline-ios {
  border-width: 1px;
  border-style: solid;
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.bar-button-outline-ios:hover:not(.disable-hover) {
  opacity: .4;
}

.bar-button-outline-ios.activated {
  color: #fff;
  background-color: #488aff;
}

.bar-button-solid-ios {
  color: #fff;
  background-color: #488aff;
}

.bar-button-solid-ios:hover:not(.disable-hover) {
  color: #fff;
  opacity: .4;
}

.bar-button-solid-ios.activated {
  color: #fff;
  background-color: #427feb;
  opacity: .4;
}

.bar-button-ios.bar-button-icon-start ion-icon {
  padding-right: 0.3em;
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
}

.bar-button-ios.bar-button-icon-end ion-icon {
  padding-left: 0.4em;
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
}

.bar-button-ios[icon-only] {
  padding: 0;
  min-width: .9em;
}

.bar-button-ios[icon-only] ion-icon {
  padding: 0 0.1em;
  font-size: 1.8em;
  line-height: .67;
  pointer-events: none;
}

.back-button-ios {
  margin: 0;
  z-index: 99;
  overflow: visible;
  -webkit-box-ordinal-group: 1;
  -webkit-order: 0;
  -ms-flex-order: 0;
  order: 0;
  min-height: 3.2rem;
  line-height: 1;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.back-button-icon-ios {
  margin: -1px 0 0;
  display: inherit;
  min-width: 18px;
  font-size: 3.4rem;
}

.back-button-text-ios {
  letter-spacing: -.01em;
}

.bar-button-menutoggle-ios {
  margin: 0 6px;
  padding: 0;
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
  min-width: 36px;
}

.bar-button-menutoggle-ios ion-icon {
  padding: 0 6px;
  font-size: 2.8rem;
}

.bar-button-menutoggle-ios[end],
.bar-button-menutoggle-ios[right] {
  -webkit-box-ordinal-group: 8;
  -webkit-order: 7;
  -ms-flex-order: 7;
  order: 7;
}

.bar-button-default-ios,
.bar-button-default.bar-button-ios-default,
.bar-button-clear-ios-default {
  color: #488aff;
  background-color: transparent;
}

.bar-button-default-ios:hover:not(.disable-hover),
.bar-button-default.bar-button-ios-default:hover:not(.disable-hover),
.bar-button-clear-ios-default:hover:not(.disable-hover) {
  color: #488aff;
}

.bar-button-default-ios.activated,
.bar-button-default.bar-button-ios-default.activated,
.bar-button-clear-ios-default.activated {
  opacity: .4;
}

.bar-button-clear-ios,
.bar-button-default.bar-button-ios-clear,
.bar-button-clear-ios-clear {
  color: #488aff;
  background-color: transparent;
}

.bar-button-clear-ios:hover:not(.disable-hover),
.bar-button-default.bar-button-ios-clear:hover:not(.disable-hover),
.bar-button-clear-ios-clear:hover:not(.disable-hover) {
  color: #488aff;
}

.bar-button-clear-ios.activated,
.bar-button-default.bar-button-ios-clear.activated,
.bar-button-clear-ios-clear.activated {
  opacity: .4;
}

.toolbar-ios-primary .toolbar-background-ios {
  background: #488aff;
}

.toolbar-ios-primary .toolbar-title-ios,
.toolbar-ios-primary .bar-button-clear-ios,
.toolbar-ios-primary .bar-button-default-ios {
  color: #fff;
}

.toolbar-ios-primary .bar-button-primary-ios,
.toolbar-ios-primary .bar-button-default.bar-button-ios-primary,
.toolbar-ios-primary .bar-button-clear-ios-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-primary-ios:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-default.bar-button-ios-primary:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-clear-ios-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-ios-primary .bar-button-primary-ios.activated,
.toolbar-ios-primary .bar-button-default.bar-button-ios-primary.activated,
.toolbar-ios-primary .bar-button-clear-ios-primary.activated {
  opacity: .4;
}

.toolbar-ios-primary .bar-button-outline-ios-primary {
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-outline-ios-primary.activated {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-primary .bar-button-solid-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-primary .bar-button-solid-ios-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-ios-primary .bar-button-secondary-ios,
.toolbar-ios-primary .bar-button-default.bar-button-ios-secondary,
.toolbar-ios-primary .bar-button-clear-ios-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-secondary-ios:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-default.bar-button-ios-secondary:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-clear-ios-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-ios-primary .bar-button-secondary-ios.activated,
.toolbar-ios-primary .bar-button-default.bar-button-ios-secondary.activated,
.toolbar-ios-primary .bar-button-clear-ios-secondary.activated {
  opacity: .4;
}

.toolbar-ios-primary .bar-button-outline-ios-secondary {
  border-color: #32db64;
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-outline-ios-secondary.activated {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-primary .bar-button-solid-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-primary .bar-button-solid-ios-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-ios-primary .bar-button-danger-ios,
.toolbar-ios-primary .bar-button-default.bar-button-ios-danger,
.toolbar-ios-primary .bar-button-clear-ios-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-danger-ios:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-default.bar-button-ios-danger:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-clear-ios-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-ios-primary .bar-button-danger-ios.activated,
.toolbar-ios-primary .bar-button-default.bar-button-ios-danger.activated,
.toolbar-ios-primary .bar-button-clear-ios-danger.activated {
  opacity: .4;
}

.toolbar-ios-primary .bar-button-outline-ios-danger {
  border-color: #f53d3d;
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-outline-ios-danger.activated {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-primary .bar-button-solid-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-primary .bar-button-solid-ios-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-ios-primary .bar-button-light-ios,
.toolbar-ios-primary .bar-button-default.bar-button-ios-light,
.toolbar-ios-primary .bar-button-clear-ios-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-light-ios:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-default.bar-button-ios-light:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-clear-ios-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-ios-primary .bar-button-light-ios.activated,
.toolbar-ios-primary .bar-button-default.bar-button-ios-light.activated,
.toolbar-ios-primary .bar-button-clear-ios-light.activated {
  opacity: .4;
}

.toolbar-ios-primary .bar-button-outline-ios-light {
  border-color: #f4f4f4;
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-outline-ios-light.activated {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-primary .bar-button-solid-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-primary .bar-button-solid-ios-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-ios-primary .bar-button-dark-ios,
.toolbar-ios-primary .bar-button-default.bar-button-ios-dark,
.toolbar-ios-primary .bar-button-clear-ios-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-dark-ios:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-default.bar-button-ios-dark:hover:not(.disable-hover),
.toolbar-ios-primary .bar-button-clear-ios-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-ios-primary .bar-button-dark-ios.activated,
.toolbar-ios-primary .bar-button-default.bar-button-ios-dark.activated,
.toolbar-ios-primary .bar-button-clear-ios-dark.activated {
  opacity: .4;
}

.toolbar-ios-primary .bar-button-outline-ios-dark {
  border-color: #222;
  color: #222;
  background-color: transparent;
}

.toolbar-ios-primary .bar-button-outline-ios-dark.activated {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-primary .bar-button-solid-ios-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-primary .bar-button-solid-ios-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-primary-ios,
.bar-button-default.bar-button-ios-primary,
.bar-button-clear-ios-primary {
  color: #488aff;
  background-color: transparent;
}

.bar-button-primary-ios:hover:not(.disable-hover),
.bar-button-default.bar-button-ios-primary:hover:not(.disable-hover),
.bar-button-clear-ios-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.bar-button-primary-ios.activated,
.bar-button-default.bar-button-ios-primary.activated,
.bar-button-clear-ios-primary.activated {
  opacity: .4;
}

.bar-button-outline-ios-primary {
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.bar-button-outline-ios-primary.activated {
  color: #fff;
  background-color: #488aff;
}

.bar-button-solid-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.bar-button-solid-ios-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-ios-secondary .toolbar-background-ios {
  background: #32db64;
}

.toolbar-ios-secondary .toolbar-title-ios,
.toolbar-ios-secondary .bar-button-clear-ios,
.toolbar-ios-secondary .bar-button-default-ios {
  color: #fff;
}

.toolbar-ios-secondary .bar-button-primary-ios,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-primary,
.toolbar-ios-secondary .bar-button-clear-ios-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-primary-ios:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-default.bar-button-ios-primary:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-clear-ios-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-ios-secondary .bar-button-primary-ios.activated,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-primary.activated,
.toolbar-ios-secondary .bar-button-clear-ios-primary.activated {
  opacity: .4;
}

.toolbar-ios-secondary .bar-button-outline-ios-primary {
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-outline-ios-primary.activated {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-secondary .bar-button-solid-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-secondary .bar-button-solid-ios-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-ios-secondary .bar-button-secondary-ios,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-secondary,
.toolbar-ios-secondary .bar-button-clear-ios-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-secondary-ios:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-default.bar-button-ios-secondary:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-clear-ios-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-ios-secondary .bar-button-secondary-ios.activated,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-secondary.activated,
.toolbar-ios-secondary .bar-button-clear-ios-secondary.activated {
  opacity: .4;
}

.toolbar-ios-secondary .bar-button-outline-ios-secondary {
  border-color: #32db64;
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-outline-ios-secondary.activated {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-secondary .bar-button-solid-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-secondary .bar-button-solid-ios-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-ios-secondary .bar-button-danger-ios,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-danger,
.toolbar-ios-secondary .bar-button-clear-ios-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-danger-ios:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-default.bar-button-ios-danger:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-clear-ios-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-ios-secondary .bar-button-danger-ios.activated,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-danger.activated,
.toolbar-ios-secondary .bar-button-clear-ios-danger.activated {
  opacity: .4;
}

.toolbar-ios-secondary .bar-button-outline-ios-danger {
  border-color: #f53d3d;
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-outline-ios-danger.activated {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-secondary .bar-button-solid-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-secondary .bar-button-solid-ios-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-ios-secondary .bar-button-light-ios,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-light,
.toolbar-ios-secondary .bar-button-clear-ios-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-light-ios:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-default.bar-button-ios-light:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-clear-ios-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-ios-secondary .bar-button-light-ios.activated,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-light.activated,
.toolbar-ios-secondary .bar-button-clear-ios-light.activated {
  opacity: .4;
}

.toolbar-ios-secondary .bar-button-outline-ios-light {
  border-color: #f4f4f4;
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-outline-ios-light.activated {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-secondary .bar-button-solid-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-secondary .bar-button-solid-ios-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-ios-secondary .bar-button-dark-ios,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-dark,
.toolbar-ios-secondary .bar-button-clear-ios-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-dark-ios:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-default.bar-button-ios-dark:hover:not(.disable-hover),
.toolbar-ios-secondary .bar-button-clear-ios-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-ios-secondary .bar-button-dark-ios.activated,
.toolbar-ios-secondary .bar-button-default.bar-button-ios-dark.activated,
.toolbar-ios-secondary .bar-button-clear-ios-dark.activated {
  opacity: .4;
}

.toolbar-ios-secondary .bar-button-outline-ios-dark {
  border-color: #222;
  color: #222;
  background-color: transparent;
}

.toolbar-ios-secondary .bar-button-outline-ios-dark.activated {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-secondary .bar-button-solid-ios-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-secondary .bar-button-solid-ios-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-secondary-ios,
.bar-button-default.bar-button-ios-secondary,
.bar-button-clear-ios-secondary {
  color: #32db64;
  background-color: transparent;
}

.bar-button-secondary-ios:hover:not(.disable-hover),
.bar-button-default.bar-button-ios-secondary:hover:not(.disable-hover),
.bar-button-clear-ios-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.bar-button-secondary-ios.activated,
.bar-button-default.bar-button-ios-secondary.activated,
.bar-button-clear-ios-secondary.activated {
  opacity: .4;
}

.bar-button-outline-ios-secondary {
  border-color: #32db64;
  color: #32db64;
  background-color: transparent;
}

.bar-button-outline-ios-secondary.activated {
  color: #fff;
  background-color: #32db64;
}

.bar-button-solid-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.bar-button-solid-ios-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-ios-danger .toolbar-background-ios {
  background: #f53d3d;
}

.toolbar-ios-danger .toolbar-title-ios,
.toolbar-ios-danger .bar-button-clear-ios,
.toolbar-ios-danger .bar-button-default-ios {
  color: #fff;
}

.toolbar-ios-danger .bar-button-primary-ios,
.toolbar-ios-danger .bar-button-default.bar-button-ios-primary,
.toolbar-ios-danger .bar-button-clear-ios-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-primary-ios:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-default.bar-button-ios-primary:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-clear-ios-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-ios-danger .bar-button-primary-ios.activated,
.toolbar-ios-danger .bar-button-default.bar-button-ios-primary.activated,
.toolbar-ios-danger .bar-button-clear-ios-primary.activated {
  opacity: .4;
}

.toolbar-ios-danger .bar-button-outline-ios-primary {
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-outline-ios-primary.activated {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-danger .bar-button-solid-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-danger .bar-button-solid-ios-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-ios-danger .bar-button-secondary-ios,
.toolbar-ios-danger .bar-button-default.bar-button-ios-secondary,
.toolbar-ios-danger .bar-button-clear-ios-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-secondary-ios:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-default.bar-button-ios-secondary:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-clear-ios-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-ios-danger .bar-button-secondary-ios.activated,
.toolbar-ios-danger .bar-button-default.bar-button-ios-secondary.activated,
.toolbar-ios-danger .bar-button-clear-ios-secondary.activated {
  opacity: .4;
}

.toolbar-ios-danger .bar-button-outline-ios-secondary {
  border-color: #32db64;
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-outline-ios-secondary.activated {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-danger .bar-button-solid-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-danger .bar-button-solid-ios-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-ios-danger .bar-button-danger-ios,
.toolbar-ios-danger .bar-button-default.bar-button-ios-danger,
.toolbar-ios-danger .bar-button-clear-ios-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-danger-ios:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-default.bar-button-ios-danger:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-clear-ios-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-ios-danger .bar-button-danger-ios.activated,
.toolbar-ios-danger .bar-button-default.bar-button-ios-danger.activated,
.toolbar-ios-danger .bar-button-clear-ios-danger.activated {
  opacity: .4;
}

.toolbar-ios-danger .bar-button-outline-ios-danger {
  border-color: #f53d3d;
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-outline-ios-danger.activated {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-danger .bar-button-solid-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-danger .bar-button-solid-ios-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-ios-danger .bar-button-light-ios,
.toolbar-ios-danger .bar-button-default.bar-button-ios-light,
.toolbar-ios-danger .bar-button-clear-ios-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-light-ios:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-default.bar-button-ios-light:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-clear-ios-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-ios-danger .bar-button-light-ios.activated,
.toolbar-ios-danger .bar-button-default.bar-button-ios-light.activated,
.toolbar-ios-danger .bar-button-clear-ios-light.activated {
  opacity: .4;
}

.toolbar-ios-danger .bar-button-outline-ios-light {
  border-color: #f4f4f4;
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-outline-ios-light.activated {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-danger .bar-button-solid-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-danger .bar-button-solid-ios-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-ios-danger .bar-button-dark-ios,
.toolbar-ios-danger .bar-button-default.bar-button-ios-dark,
.toolbar-ios-danger .bar-button-clear-ios-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-dark-ios:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-default.bar-button-ios-dark:hover:not(.disable-hover),
.toolbar-ios-danger .bar-button-clear-ios-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-ios-danger .bar-button-dark-ios.activated,
.toolbar-ios-danger .bar-button-default.bar-button-ios-dark.activated,
.toolbar-ios-danger .bar-button-clear-ios-dark.activated {
  opacity: .4;
}

.toolbar-ios-danger .bar-button-outline-ios-dark {
  border-color: #222;
  color: #222;
  background-color: transparent;
}

.toolbar-ios-danger .bar-button-outline-ios-dark.activated {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-danger .bar-button-solid-ios-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-danger .bar-button-solid-ios-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-danger-ios,
.bar-button-default.bar-button-ios-danger,
.bar-button-clear-ios-danger {
  color: #f53d3d;
  background-color: transparent;
}

.bar-button-danger-ios:hover:not(.disable-hover),
.bar-button-default.bar-button-ios-danger:hover:not(.disable-hover),
.bar-button-clear-ios-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.bar-button-danger-ios.activated,
.bar-button-default.bar-button-ios-danger.activated,
.bar-button-clear-ios-danger.activated {
  opacity: .4;
}

.bar-button-outline-ios-danger {
  border-color: #f53d3d;
  color: #f53d3d;
  background-color: transparent;
}

.bar-button-outline-ios-danger.activated {
  color: #fff;
  background-color: #f53d3d;
}

.bar-button-solid-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.bar-button-solid-ios-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-ios-light .toolbar-background-ios {
  background: #f4f4f4;
}

.toolbar-ios-light .toolbar-title-ios,
.toolbar-ios-light .bar-button-clear-ios,
.toolbar-ios-light .bar-button-default-ios {
  color: #000;
}

.toolbar-ios-light .bar-button-primary-ios,
.toolbar-ios-light .bar-button-default.bar-button-ios-primary,
.toolbar-ios-light .bar-button-clear-ios-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-primary-ios:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-default.bar-button-ios-primary:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-clear-ios-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-ios-light .bar-button-primary-ios.activated,
.toolbar-ios-light .bar-button-default.bar-button-ios-primary.activated,
.toolbar-ios-light .bar-button-clear-ios-primary.activated {
  opacity: .4;
}

.toolbar-ios-light .bar-button-outline-ios-primary {
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-outline-ios-primary.activated {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-light .bar-button-solid-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-light .bar-button-solid-ios-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-ios-light .bar-button-secondary-ios,
.toolbar-ios-light .bar-button-default.bar-button-ios-secondary,
.toolbar-ios-light .bar-button-clear-ios-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-secondary-ios:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-default.bar-button-ios-secondary:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-clear-ios-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-ios-light .bar-button-secondary-ios.activated,
.toolbar-ios-light .bar-button-default.bar-button-ios-secondary.activated,
.toolbar-ios-light .bar-button-clear-ios-secondary.activated {
  opacity: .4;
}

.toolbar-ios-light .bar-button-outline-ios-secondary {
  border-color: #32db64;
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-outline-ios-secondary.activated {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-light .bar-button-solid-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-light .bar-button-solid-ios-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-ios-light .bar-button-danger-ios,
.toolbar-ios-light .bar-button-default.bar-button-ios-danger,
.toolbar-ios-light .bar-button-clear-ios-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-danger-ios:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-default.bar-button-ios-danger:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-clear-ios-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-ios-light .bar-button-danger-ios.activated,
.toolbar-ios-light .bar-button-default.bar-button-ios-danger.activated,
.toolbar-ios-light .bar-button-clear-ios-danger.activated {
  opacity: .4;
}

.toolbar-ios-light .bar-button-outline-ios-danger {
  border-color: #f53d3d;
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-outline-ios-danger.activated {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-light .bar-button-solid-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-light .bar-button-solid-ios-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-ios-light .bar-button-light-ios,
.toolbar-ios-light .bar-button-default.bar-button-ios-light,
.toolbar-ios-light .bar-button-clear-ios-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-light-ios:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-default.bar-button-ios-light:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-clear-ios-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-ios-light .bar-button-light-ios.activated,
.toolbar-ios-light .bar-button-default.bar-button-ios-light.activated,
.toolbar-ios-light .bar-button-clear-ios-light.activated {
  opacity: .4;
}

.toolbar-ios-light .bar-button-outline-ios-light {
  border-color: #f4f4f4;
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-outline-ios-light.activated {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-light .bar-button-solid-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-light .bar-button-solid-ios-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-ios-light .bar-button-dark-ios,
.toolbar-ios-light .bar-button-default.bar-button-ios-dark,
.toolbar-ios-light .bar-button-clear-ios-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-dark-ios:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-default.bar-button-ios-dark:hover:not(.disable-hover),
.toolbar-ios-light .bar-button-clear-ios-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-ios-light .bar-button-dark-ios.activated,
.toolbar-ios-light .bar-button-default.bar-button-ios-dark.activated,
.toolbar-ios-light .bar-button-clear-ios-dark.activated {
  opacity: .4;
}

.toolbar-ios-light .bar-button-outline-ios-dark {
  border-color: #222;
  color: #222;
  background-color: transparent;
}

.toolbar-ios-light .bar-button-outline-ios-dark.activated {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-light .bar-button-solid-ios-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-light .bar-button-solid-ios-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-light-ios,
.bar-button-default.bar-button-ios-light,
.bar-button-clear-ios-light {
  color: #f4f4f4;
  background-color: transparent;
}

.bar-button-light-ios:hover:not(.disable-hover),
.bar-button-default.bar-button-ios-light:hover:not(.disable-hover),
.bar-button-clear-ios-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.bar-button-light-ios.activated,
.bar-button-default.bar-button-ios-light.activated,
.bar-button-clear-ios-light.activated {
  opacity: .4;
}

.bar-button-outline-ios-light {
  border-color: #f4f4f4;
  color: #f4f4f4;
  background-color: transparent;
}

.bar-button-outline-ios-light.activated {
  color: #000;
  background-color: #f4f4f4;
}

.bar-button-solid-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.bar-button-solid-ios-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-ios-dark .toolbar-background-ios {
  background: #222;
}

.toolbar-ios-dark .toolbar-title-ios,
.toolbar-ios-dark .bar-button-clear-ios,
.toolbar-ios-dark .bar-button-default-ios {
  color: #fff;
}

.toolbar-ios-dark .bar-button-primary-ios,
.toolbar-ios-dark .bar-button-default.bar-button-ios-primary,
.toolbar-ios-dark .bar-button-clear-ios-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-primary-ios:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-default.bar-button-ios-primary:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-clear-ios-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-ios-dark .bar-button-primary-ios.activated,
.toolbar-ios-dark .bar-button-default.bar-button-ios-primary.activated,
.toolbar-ios-dark .bar-button-clear-ios-primary.activated {
  opacity: .4;
}

.toolbar-ios-dark .bar-button-outline-ios-primary {
  border-color: #488aff;
  color: #488aff;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-outline-ios-primary.activated {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-dark .bar-button-solid-ios-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-ios-dark .bar-button-solid-ios-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-ios-dark .bar-button-secondary-ios,
.toolbar-ios-dark .bar-button-default.bar-button-ios-secondary,
.toolbar-ios-dark .bar-button-clear-ios-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-secondary-ios:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-default.bar-button-ios-secondary:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-clear-ios-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-ios-dark .bar-button-secondary-ios.activated,
.toolbar-ios-dark .bar-button-default.bar-button-ios-secondary.activated,
.toolbar-ios-dark .bar-button-clear-ios-secondary.activated {
  opacity: .4;
}

.toolbar-ios-dark .bar-button-outline-ios-secondary {
  border-color: #32db64;
  color: #32db64;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-outline-ios-secondary.activated {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-dark .bar-button-solid-ios-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-ios-dark .bar-button-solid-ios-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-ios-dark .bar-button-danger-ios,
.toolbar-ios-dark .bar-button-default.bar-button-ios-danger,
.toolbar-ios-dark .bar-button-clear-ios-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-danger-ios:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-default.bar-button-ios-danger:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-clear-ios-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-ios-dark .bar-button-danger-ios.activated,
.toolbar-ios-dark .bar-button-default.bar-button-ios-danger.activated,
.toolbar-ios-dark .bar-button-clear-ios-danger.activated {
  opacity: .4;
}

.toolbar-ios-dark .bar-button-outline-ios-danger {
  border-color: #f53d3d;
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-outline-ios-danger.activated {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-dark .bar-button-solid-ios-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-ios-dark .bar-button-solid-ios-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-ios-dark .bar-button-light-ios,
.toolbar-ios-dark .bar-button-default.bar-button-ios-light,
.toolbar-ios-dark .bar-button-clear-ios-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-light-ios:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-default.bar-button-ios-light:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-clear-ios-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-ios-dark .bar-button-light-ios.activated,
.toolbar-ios-dark .bar-button-default.bar-button-ios-light.activated,
.toolbar-ios-dark .bar-button-clear-ios-light.activated {
  opacity: .4;
}

.toolbar-ios-dark .bar-button-outline-ios-light {
  border-color: #f4f4f4;
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-outline-ios-light.activated {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-dark .bar-button-solid-ios-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-ios-dark .bar-button-solid-ios-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-ios-dark .bar-button-dark-ios,
.toolbar-ios-dark .bar-button-default.bar-button-ios-dark,
.toolbar-ios-dark .bar-button-clear-ios-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-dark-ios:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-default.bar-button-ios-dark:hover:not(.disable-hover),
.toolbar-ios-dark .bar-button-clear-ios-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-ios-dark .bar-button-dark-ios.activated,
.toolbar-ios-dark .bar-button-default.bar-button-ios-dark.activated,
.toolbar-ios-dark .bar-button-clear-ios-dark.activated {
  opacity: .4;
}

.toolbar-ios-dark .bar-button-outline-ios-dark {
  border-color: #222;
  color: #222;
  background-color: transparent;
}

.toolbar-ios-dark .bar-button-outline-ios-dark.activated {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-dark .bar-button-solid-ios-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-ios-dark .bar-button-solid-ios-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-dark-ios,
.bar-button-default.bar-button-ios-dark,
.bar-button-clear-ios-dark {
  color: #222;
  background-color: transparent;
}

.bar-button-dark-ios:hover:not(.disable-hover),
.bar-button-default.bar-button-ios-dark:hover:not(.disable-hover),
.bar-button-clear-ios-dark:hover:not(.disable-hover) {
  color: #222;
}

.bar-button-dark-ios.activated,
.bar-button-default.bar-button-ios-dark.activated,
.bar-button-clear-ios-dark.activated {
  opacity: .4;
}

.bar-button-outline-ios-dark {
  border-color: #222;
  color: #222;
  background-color: transparent;
}

.bar-button-outline-ios-dark.activated {
  color: #fff;
  background-color: #222;
}

.bar-button-solid-ios-dark {
  color: #fff;
  background-color: #222;
}

.bar-button-solid-ios-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-strong-ios {
  font-weight: 600;
}

.toolbar-md {
  padding: 4px;
  min-height: 56px;
}

.toolbar-background-md {
  border-color: #b2b2b2;
  background: #f8f8f8;
}

.header-md::after,
.tabs-md[tabsPlacement="top"] > .tabbar::after,
.footer-md::before,
.tabs-md[tabsPlacement="bottom"] > .tabbar::before {
  left: 0;
  bottom: -5px;
  background-position: left 0 top -2px;
  position: absolute;
  width: 100%;
  height: 5px;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAHBAMAAADzDtBxAAAAD1BMVEUAAAAAAAAAAAAAAAAAAABPDueNAAAABXRSTlMUCS0gBIh/TXEAAAAaSURBVAjXYxCEAgY4UIICBmMogMsgFLtAAQCNSwXZKOdPxgAAAABJRU5ErkJggg==);
  background-repeat: repeat-x;
  content: "";
}

.footer-md::before,
.tabs-md[tabsPlacement="bottom"] > .tabbar::before {
  top: -2px;
  bottom: auto;
  background-position: left 0 top 0;
  height: 2px;
}

.header-md[no-border]::after,
.footer-md[no-border]::before,
.tabs-md[tabsPlacement="top"][no-border] > .tabbar::after,
.tabs-md[tabsPlacement="bottom"][no-border] > .tabbar::before {
  display: none;
}

.toolbar-content-md {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-ordinal-group: 4;
  -webkit-order: 3;
  -ms-flex-order: 3;
  order: 3;
  min-width: 0;
  max-width: 100%;
}

.toolbar-title-md {
  padding: 0 12px;
  font-size: 2rem;
  font-weight: 500;
  color: #424242;
}

.bar-buttons-md {
  -webkit-box-ordinal-group: 5;
  -webkit-order: 4;
  -ms-flex-order: 4;
  order: 4;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.bar-buttons-md[left] {
  -webkit-box-ordinal-group: 3;
  -webkit-order: 2;
  -ms-flex-order: 2;
  order: 2;
}

.bar-button-md:first-child {
  margin-left: 0;
}

.bar-buttons-md[end] {
  text-align: right;
  text-align: end;
  -webkit-box-ordinal-group: 6;
  -webkit-order: 5;
  -ms-flex-order: 5;
  order: 5;
}

.bar-buttons-md[right] {
  text-align: right;
  -webkit-box-ordinal-group: 7;
  -webkit-order: 6;
  -ms-flex-order: 6;
  order: 6;
}

.bar-button-md {
  margin: 0 0.2rem;
  padding: 0 5px;
  border-radius: 2px;
  height: 32px;
  border: 0;
  font-size: 1.4rem;
  font-weight: 500;
  text-transform: uppercase;
}

.bar-button-solid-md,
.bar-button-outline-md {
  overflow: hidden;
}

.bar-button-outline-md {
  border-width: 1px;
  border-style: solid;
  border-color: #424242;
  color: #424242;
  background-color: transparent;
}

.bar-button-outline-md:hover:not(.disable-hover) {
  opacity: .4;
}

.bar-button-outline-md.activated {
  background-color: transparent;
}

.bar-button-outline-md .button-effect {
  background-color: #424242;
}

.bar-button-solid-md {
  color: #fff;
  background-color: #424242;
}

.bar-button-solid-md:hover:not(.disable-hover) {
  color: #fff;
}

.bar-button-solid-md.activated {
  color: #fff;
  background-color: #515151;
}

.bar-button-md.bar-button-icon-start ion-icon {
  padding-right: 0.3em;
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
}

.bar-button-md.bar-button-icon-end ion-icon {
  padding-left: 0.4em;
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
}

.bar-button-md[icon-only] {
  padding: 0;
}

.bar-button-md[icon-only] ion-icon {
  padding: 0 0.1em;
  min-width: 28px;
  font-size: 1.8em;
  line-height: .67;
  pointer-events: none;
}

.back-button-md {
  margin: 0 6px;
  min-width: 44px;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.back-button-icon-md {
  margin: 0;
  padding: 0 6px;
  text-align: left;
  text-align: start;
  font-size: 2.4rem;
  font-weight: normal;
}

.bar-button-menutoggle-md {
  margin: 0 6px;
  padding: 0 2px;
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
  min-width: 44px;
}

.bar-button-menutoggle-md ion-icon {
  padding: 0 6px;
  font-size: 2.4rem;
}

.bar-button-menutoggle-md[end],
.bar-button-menutoggle-md[right] {
  margin: 0 2px;
  -webkit-box-ordinal-group: 8;
  -webkit-order: 7;
  -ms-flex-order: 7;
  order: 7;
  min-width: 28px;
}

.bar-button-default-md,
.bar-button-clear-md-default,
.bar-button-md-default {
  color: #424242;
  background-color: transparent;
}

.bar-button-default-md:hover:not(.disable-hover),
.bar-button-clear-md-default:hover:not(.disable-hover),
.bar-button-md-default:hover:not(.disable-hover) {
  color: #424242;
}

.bar-button-clear-md,
.bar-button-clear-md-clear,
.bar-button-md-clear {
  color: #424242;
  background-color: transparent;
}

.bar-button-clear-md:hover:not(.disable-hover),
.bar-button-clear-md-clear:hover:not(.disable-hover),
.bar-button-md-clear:hover:not(.disable-hover) {
  color: #424242;
}

.toolbar-md-primary .toolbar-background-md {
  background: #488aff;
}

.toolbar-md-primary .bar-button-clear-md,
.toolbar-md-primary .bar-button-default-md,
.toolbar-md-primary .bar-button-outline-md,
.toolbar-md-primary .toolbar-title-md {
  color: #fff;
}

.toolbar-md-primary .bar-button-clear-md .button-effect,
.toolbar-md-primary .bar-button-default-md .button-effect,
.toolbar-md-primary .bar-button-outline-md .button-effect {
  background-color: #fff;
}

.toolbar-md-primary .bar-button-outline-md {
  border-color: #fff;
}

.toolbar-md-primary .bar-button-primary-md,
.toolbar-md-primary .bar-button-clear-md-primary,
.toolbar-md-primary .bar-button-md-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-primary-md:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-clear-md-primary:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-md-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-md-primary .bar-button-outline-md-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-primary.activated {
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-primary .button-effect {
  background-color: #427feb;
}

.toolbar-md-primary .bar-button-solid-md-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-md-primary .bar-button-solid-md-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-md-primary .bar-button-secondary-md,
.toolbar-md-primary .bar-button-clear-md-secondary,
.toolbar-md-primary .bar-button-md-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-secondary-md:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-clear-md-secondary:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-md-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-md-primary .bar-button-outline-md-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-secondary.activated {
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-secondary .button-effect {
  background-color: #2ec95c;
}

.toolbar-md-primary .bar-button-solid-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-md-primary .bar-button-solid-md-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-md-primary .bar-button-danger-md,
.toolbar-md-primary .bar-button-clear-md-danger,
.toolbar-md-primary .bar-button-md-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-danger-md:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-clear-md-danger:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-md-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-md-primary .bar-button-outline-md-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-danger.activated {
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-danger .button-effect {
  background-color: #e13838;
}

.toolbar-md-primary .bar-button-solid-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-md-primary .bar-button-solid-md-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-md-primary .bar-button-light-md,
.toolbar-md-primary .bar-button-clear-md-light,
.toolbar-md-primary .bar-button-md-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-light-md:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-clear-md-light:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-md-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-md-primary .bar-button-outline-md-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-light.activated {
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-light .button-effect {
  background-color: #e0e0e0;
}

.toolbar-md-primary .bar-button-solid-md-light {
  color: #424242;
  background-color: #f4f4f4;
}

.toolbar-md-primary .bar-button-solid-md-light.activated {
  color: #424242;
  background-color: #e0e0e0;
}

.toolbar-md-primary .bar-button-dark-md,
.toolbar-md-primary .bar-button-clear-md-dark,
.toolbar-md-primary .bar-button-md-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-dark-md:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-clear-md-dark:hover:not(.disable-hover),
.toolbar-md-primary .bar-button-md-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-md-primary .bar-button-outline-md-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-dark.activated {
  background-color: transparent;
}

.toolbar-md-primary .bar-button-outline-md-dark .button-effect {
  background-color: #343434;
}

.toolbar-md-primary .bar-button-solid-md-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-md-primary .bar-button-solid-md-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-primary-md,
.bar-button-clear-md-primary,
.bar-button-md-primary {
  color: #488aff;
  background-color: transparent;
}

.bar-button-primary-md:hover:not(.disable-hover),
.bar-button-clear-md-primary:hover:not(.disable-hover),
.bar-button-md-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.bar-button-outline-md-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.bar-button-outline-md-primary.activated {
  background-color: transparent;
}

.bar-button-outline-md-primary .button-effect {
  background-color: #427feb;
}

.bar-button-solid-md-primary {
  color: #fff;
  background-color: #488aff;
}

.bar-button-solid-md-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-md-secondary .toolbar-background-md {
  background: #32db64;
}

.toolbar-md-secondary .bar-button-clear-md,
.toolbar-md-secondary .bar-button-default-md,
.toolbar-md-secondary .bar-button-outline-md,
.toolbar-md-secondary .toolbar-title-md {
  color: #fff;
}

.toolbar-md-secondary .bar-button-clear-md .button-effect,
.toolbar-md-secondary .bar-button-default-md .button-effect,
.toolbar-md-secondary .bar-button-outline-md .button-effect {
  background-color: #fff;
}

.toolbar-md-secondary .bar-button-outline-md {
  border-color: #fff;
}

.toolbar-md-secondary .bar-button-primary-md,
.toolbar-md-secondary .bar-button-clear-md-primary,
.toolbar-md-secondary .bar-button-md-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-primary-md:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-clear-md-primary:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-md-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-md-secondary .bar-button-outline-md-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-primary.activated {
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-primary .button-effect {
  background-color: #427feb;
}

.toolbar-md-secondary .bar-button-solid-md-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-md-secondary .bar-button-solid-md-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-md-secondary .bar-button-secondary-md,
.toolbar-md-secondary .bar-button-clear-md-secondary,
.toolbar-md-secondary .bar-button-md-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-secondary-md:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-clear-md-secondary:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-md-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-md-secondary .bar-button-outline-md-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-secondary.activated {
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-secondary .button-effect {
  background-color: #2ec95c;
}

.toolbar-md-secondary .bar-button-solid-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-md-secondary .bar-button-solid-md-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-md-secondary .bar-button-danger-md,
.toolbar-md-secondary .bar-button-clear-md-danger,
.toolbar-md-secondary .bar-button-md-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-danger-md:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-clear-md-danger:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-md-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-md-secondary .bar-button-outline-md-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-danger.activated {
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-danger .button-effect {
  background-color: #e13838;
}

.toolbar-md-secondary .bar-button-solid-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-md-secondary .bar-button-solid-md-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-md-secondary .bar-button-light-md,
.toolbar-md-secondary .bar-button-clear-md-light,
.toolbar-md-secondary .bar-button-md-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-light-md:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-clear-md-light:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-md-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-md-secondary .bar-button-outline-md-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-light.activated {
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-light .button-effect {
  background-color: #e0e0e0;
}

.toolbar-md-secondary .bar-button-solid-md-light {
  color: #424242;
  background-color: #f4f4f4;
}

.toolbar-md-secondary .bar-button-solid-md-light.activated {
  color: #424242;
  background-color: #e0e0e0;
}

.toolbar-md-secondary .bar-button-dark-md,
.toolbar-md-secondary .bar-button-clear-md-dark,
.toolbar-md-secondary .bar-button-md-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-dark-md:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-clear-md-dark:hover:not(.disable-hover),
.toolbar-md-secondary .bar-button-md-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-md-secondary .bar-button-outline-md-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-dark.activated {
  background-color: transparent;
}

.toolbar-md-secondary .bar-button-outline-md-dark .button-effect {
  background-color: #343434;
}

.toolbar-md-secondary .bar-button-solid-md-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-md-secondary .bar-button-solid-md-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-secondary-md,
.bar-button-clear-md-secondary,
.bar-button-md-secondary {
  color: #32db64;
  background-color: transparent;
}

.bar-button-secondary-md:hover:not(.disable-hover),
.bar-button-clear-md-secondary:hover:not(.disable-hover),
.bar-button-md-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.bar-button-outline-md-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.bar-button-outline-md-secondary.activated {
  background-color: transparent;
}

.bar-button-outline-md-secondary .button-effect {
  background-color: #2ec95c;
}

.bar-button-solid-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.bar-button-solid-md-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-md-danger .toolbar-background-md {
  background: #f53d3d;
}

.toolbar-md-danger .bar-button-clear-md,
.toolbar-md-danger .bar-button-default-md,
.toolbar-md-danger .bar-button-outline-md,
.toolbar-md-danger .toolbar-title-md {
  color: #fff;
}

.toolbar-md-danger .bar-button-clear-md .button-effect,
.toolbar-md-danger .bar-button-default-md .button-effect,
.toolbar-md-danger .bar-button-outline-md .button-effect {
  background-color: #fff;
}

.toolbar-md-danger .bar-button-outline-md {
  border-color: #fff;
}

.toolbar-md-danger .bar-button-primary-md,
.toolbar-md-danger .bar-button-clear-md-primary,
.toolbar-md-danger .bar-button-md-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-primary-md:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-clear-md-primary:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-md-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-md-danger .bar-button-outline-md-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-primary.activated {
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-primary .button-effect {
  background-color: #427feb;
}

.toolbar-md-danger .bar-button-solid-md-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-md-danger .bar-button-solid-md-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-md-danger .bar-button-secondary-md,
.toolbar-md-danger .bar-button-clear-md-secondary,
.toolbar-md-danger .bar-button-md-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-secondary-md:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-clear-md-secondary:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-md-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-md-danger .bar-button-outline-md-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-secondary.activated {
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-secondary .button-effect {
  background-color: #2ec95c;
}

.toolbar-md-danger .bar-button-solid-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-md-danger .bar-button-solid-md-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-md-danger .bar-button-danger-md,
.toolbar-md-danger .bar-button-clear-md-danger,
.toolbar-md-danger .bar-button-md-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-danger-md:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-clear-md-danger:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-md-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-md-danger .bar-button-outline-md-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-danger.activated {
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-danger .button-effect {
  background-color: #e13838;
}

.toolbar-md-danger .bar-button-solid-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-md-danger .bar-button-solid-md-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-md-danger .bar-button-light-md,
.toolbar-md-danger .bar-button-clear-md-light,
.toolbar-md-danger .bar-button-md-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-light-md:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-clear-md-light:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-md-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-md-danger .bar-button-outline-md-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-light.activated {
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-light .button-effect {
  background-color: #e0e0e0;
}

.toolbar-md-danger .bar-button-solid-md-light {
  color: #424242;
  background-color: #f4f4f4;
}

.toolbar-md-danger .bar-button-solid-md-light.activated {
  color: #424242;
  background-color: #e0e0e0;
}

.toolbar-md-danger .bar-button-dark-md,
.toolbar-md-danger .bar-button-clear-md-dark,
.toolbar-md-danger .bar-button-md-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-dark-md:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-clear-md-dark:hover:not(.disable-hover),
.toolbar-md-danger .bar-button-md-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-md-danger .bar-button-outline-md-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-dark.activated {
  background-color: transparent;
}

.toolbar-md-danger .bar-button-outline-md-dark .button-effect {
  background-color: #343434;
}

.toolbar-md-danger .bar-button-solid-md-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-md-danger .bar-button-solid-md-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-danger-md,
.bar-button-clear-md-danger,
.bar-button-md-danger {
  color: #f53d3d;
  background-color: transparent;
}

.bar-button-danger-md:hover:not(.disable-hover),
.bar-button-clear-md-danger:hover:not(.disable-hover),
.bar-button-md-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.bar-button-outline-md-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.bar-button-outline-md-danger.activated {
  background-color: transparent;
}

.bar-button-outline-md-danger .button-effect {
  background-color: #e13838;
}

.bar-button-solid-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.bar-button-solid-md-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-md-light .toolbar-background-md {
  background: #f4f4f4;
}

.toolbar-md-light .bar-button-clear-md,
.toolbar-md-light .bar-button-default-md,
.toolbar-md-light .bar-button-outline-md,
.toolbar-md-light .toolbar-title-md {
  color: #424242;
}

.toolbar-md-light .bar-button-clear-md .button-effect,
.toolbar-md-light .bar-button-default-md .button-effect,
.toolbar-md-light .bar-button-outline-md .button-effect {
  background-color: #424242;
}

.toolbar-md-light .bar-button-outline-md {
  border-color: #424242;
}

.toolbar-md-light .bar-button-primary-md,
.toolbar-md-light .bar-button-clear-md-primary,
.toolbar-md-light .bar-button-md-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-md-light .bar-button-primary-md:hover:not(.disable-hover),
.toolbar-md-light .bar-button-clear-md-primary:hover:not(.disable-hover),
.toolbar-md-light .bar-button-md-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-md-light .bar-button-outline-md-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-primary.activated {
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-primary .button-effect {
  background-color: #427feb;
}

.toolbar-md-light .bar-button-solid-md-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-md-light .bar-button-solid-md-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-md-light .bar-button-secondary-md,
.toolbar-md-light .bar-button-clear-md-secondary,
.toolbar-md-light .bar-button-md-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-md-light .bar-button-secondary-md:hover:not(.disable-hover),
.toolbar-md-light .bar-button-clear-md-secondary:hover:not(.disable-hover),
.toolbar-md-light .bar-button-md-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-md-light .bar-button-outline-md-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-secondary.activated {
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-secondary .button-effect {
  background-color: #2ec95c;
}

.toolbar-md-light .bar-button-solid-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-md-light .bar-button-solid-md-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-md-light .bar-button-danger-md,
.toolbar-md-light .bar-button-clear-md-danger,
.toolbar-md-light .bar-button-md-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-md-light .bar-button-danger-md:hover:not(.disable-hover),
.toolbar-md-light .bar-button-clear-md-danger:hover:not(.disable-hover),
.toolbar-md-light .bar-button-md-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-md-light .bar-button-outline-md-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-danger.activated {
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-danger .button-effect {
  background-color: #e13838;
}

.toolbar-md-light .bar-button-solid-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-md-light .bar-button-solid-md-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-md-light .bar-button-light-md,
.toolbar-md-light .bar-button-clear-md-light,
.toolbar-md-light .bar-button-md-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-md-light .bar-button-light-md:hover:not(.disable-hover),
.toolbar-md-light .bar-button-clear-md-light:hover:not(.disable-hover),
.toolbar-md-light .bar-button-md-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-md-light .bar-button-outline-md-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-light.activated {
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-light .button-effect {
  background-color: #e0e0e0;
}

.toolbar-md-light .bar-button-solid-md-light {
  color: #424242;
  background-color: #f4f4f4;
}

.toolbar-md-light .bar-button-solid-md-light.activated {
  color: #424242;
  background-color: #e0e0e0;
}

.toolbar-md-light .bar-button-dark-md,
.toolbar-md-light .bar-button-clear-md-dark,
.toolbar-md-light .bar-button-md-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-md-light .bar-button-dark-md:hover:not(.disable-hover),
.toolbar-md-light .bar-button-clear-md-dark:hover:not(.disable-hover),
.toolbar-md-light .bar-button-md-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-md-light .bar-button-outline-md-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-dark.activated {
  background-color: transparent;
}

.toolbar-md-light .bar-button-outline-md-dark .button-effect {
  background-color: #343434;
}

.toolbar-md-light .bar-button-solid-md-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-md-light .bar-button-solid-md-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-light-md,
.bar-button-clear-md-light,
.bar-button-md-light {
  color: #f4f4f4;
  background-color: transparent;
}

.bar-button-light-md:hover:not(.disable-hover),
.bar-button-clear-md-light:hover:not(.disable-hover),
.bar-button-md-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.bar-button-outline-md-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.bar-button-outline-md-light.activated {
  background-color: transparent;
}

.bar-button-outline-md-light .button-effect {
  background-color: #e0e0e0;
}

.bar-button-solid-md-light {
  color: #424242;
  background-color: #f4f4f4;
}

.bar-button-solid-md-light.activated {
  color: #424242;
  background-color: #e0e0e0;
}

.toolbar-md-dark .toolbar-background-md {
  background: #222;
}

.toolbar-md-dark .bar-button-clear-md,
.toolbar-md-dark .bar-button-default-md,
.toolbar-md-dark .bar-button-outline-md,
.toolbar-md-dark .toolbar-title-md {
  color: #fff;
}

.toolbar-md-dark .bar-button-clear-md .button-effect,
.toolbar-md-dark .bar-button-default-md .button-effect,
.toolbar-md-dark .bar-button-outline-md .button-effect {
  background-color: #fff;
}

.toolbar-md-dark .bar-button-outline-md {
  border-color: #fff;
}

.toolbar-md-dark .bar-button-primary-md,
.toolbar-md-dark .bar-button-clear-md-primary,
.toolbar-md-dark .bar-button-md-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-primary-md:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-clear-md-primary:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-md-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-md-dark .bar-button-outline-md-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-primary.activated {
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-primary .button-effect {
  background-color: #427feb;
}

.toolbar-md-dark .bar-button-solid-md-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-md-dark .bar-button-solid-md-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-md-dark .bar-button-secondary-md,
.toolbar-md-dark .bar-button-clear-md-secondary,
.toolbar-md-dark .bar-button-md-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-secondary-md:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-clear-md-secondary:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-md-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-md-dark .bar-button-outline-md-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-secondary.activated {
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-secondary .button-effect {
  background-color: #2ec95c;
}

.toolbar-md-dark .bar-button-solid-md-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-md-dark .bar-button-solid-md-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-md-dark .bar-button-danger-md,
.toolbar-md-dark .bar-button-clear-md-danger,
.toolbar-md-dark .bar-button-md-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-danger-md:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-clear-md-danger:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-md-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-md-dark .bar-button-outline-md-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-danger.activated {
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-danger .button-effect {
  background-color: #e13838;
}

.toolbar-md-dark .bar-button-solid-md-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-md-dark .bar-button-solid-md-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-md-dark .bar-button-light-md,
.toolbar-md-dark .bar-button-clear-md-light,
.toolbar-md-dark .bar-button-md-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-light-md:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-clear-md-light:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-md-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-md-dark .bar-button-outline-md-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-light.activated {
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-light .button-effect {
  background-color: #e0e0e0;
}

.toolbar-md-dark .bar-button-solid-md-light {
  color: #424242;
  background-color: #f4f4f4;
}

.toolbar-md-dark .bar-button-solid-md-light.activated {
  color: #424242;
  background-color: #e0e0e0;
}

.toolbar-md-dark .bar-button-dark-md,
.toolbar-md-dark .bar-button-clear-md-dark,
.toolbar-md-dark .bar-button-md-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-dark-md:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-clear-md-dark:hover:not(.disable-hover),
.toolbar-md-dark .bar-button-md-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-md-dark .bar-button-outline-md-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-dark.activated {
  background-color: transparent;
}

.toolbar-md-dark .bar-button-outline-md-dark .button-effect {
  background-color: #343434;
}

.toolbar-md-dark .bar-button-solid-md-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-md-dark .bar-button-solid-md-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-dark-md,
.bar-button-clear-md-dark,
.bar-button-md-dark {
  color: #222;
  background-color: transparent;
}

.bar-button-dark-md:hover:not(.disable-hover),
.bar-button-clear-md-dark:hover:not(.disable-hover),
.bar-button-md-dark:hover:not(.disable-hover) {
  color: #222;
}

.bar-button-outline-md-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.bar-button-outline-md-dark.activated {
  background-color: transparent;
}

.bar-button-outline-md-dark .button-effect {
  background-color: #343434;
}

.bar-button-solid-md-dark {
  color: #fff;
  background-color: #222;
}

.bar-button-solid-md-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-strong-md {
  font-weight: bold;
}

.toolbar-wp {
  padding: 4px;
  min-height: 46px;
}

.toolbar-background-wp {
  border-color: #b2b2b2;
  background: #f8f8f8;
}

.toolbar-content-wp {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
  -ms-flex: 1;
  flex: 1;
  -webkit-box-ordinal-group: 4;
  -webkit-order: 3;
  -ms-flex-order: 3;
  order: 3;
  min-width: 0;
  max-width: 100%;
}

.toolbar-title-wp {
  font-size: 1.5rem;
  font-weight: bold;
  text-transform: uppercase;
  color: #000;
  padding: 0 6px;
}

.bar-buttons-wp {
  -webkit-box-ordinal-group: 5;
  -webkit-order: 4;
  -ms-flex-order: 4;
  order: 4;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
}

.bar-buttons-wp[left] {
  -webkit-box-ordinal-group: 3;
  -webkit-order: 2;
  -ms-flex-order: 2;
  order: 2;
}

.bar-buttons-wp[left] .bar-button:first-child {
  margin-left: 0;
}

.bar-buttons-wp[end] {
  text-align: right;
  text-align: end;
  -webkit-box-ordinal-group: 6;
  -webkit-order: 5;
  -ms-flex-order: 5;
  order: 5;
}

.bar-buttons-wp[right] {
  text-align: right;
  -webkit-box-ordinal-group: 7;
  -webkit-order: 6;
  -ms-flex-order: 6;
  order: 6;
}

.bar-button-wp {
  margin: 0 0.2rem;
  padding: 0 5px;
  border-radius: 2px;
  height: 32px;
  border: 0;
  font-size: 1.4rem;
  font-weight: 500;
  text-transform: uppercase;
}

.bar-button-solid-wp,
.bar-button-outline-wp {
  overflow: hidden;
}

.bar-button-outline-wp {
  border-width: 1px;
  border-style: solid;
  border-color: #000;
  color: #000;
  background-color: transparent;
}

.bar-button-outline-wp:hover:not(.disable-hover) {
  opacity: .4;
}

.bar-button-outline-wp.activated {
  color: #fff;
  background-color: #000;
}

.bar-button-solid-wp {
  color: #fff;
  background-color: #000;
}

.bar-button-solid-wp:hover:not(.disable-hover) {
  color: #fff;
}

.bar-button-solid-wp.activated {
  color: #fff;
  background-color: #141414;
}

.bar-button-wp.bar-button-icon-start ion-icon {
  padding-right: 0.3em;
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
}

.bar-button-wp.bar-button-icon-end ion-icon {
  padding-left: 0.4em;
  font-size: 1.4em;
  line-height: .67;
  pointer-events: none;
}

.bar-button-wp[icon-only] {
  padding: 0;
}

.bar-button-wp[icon-only] ion-icon {
  padding: 0 0.1em;
  min-width: 28px;
  font-size: 1.8em;
  line-height: .67;
  pointer-events: none;
}

.back-button-wp {
  margin: 0 6px;
  min-width: 44px;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.back-button-icon-wp {
  text-align: left;
  text-align: start;
  margin: 0;
  padding: 0 6px;
  font-size: 2.4rem;
  font-weight: normal;
}

.bar-button-menutoggle-wp {
  margin: 0 6px;
  padding: 0 2px;
  -webkit-box-ordinal-group: 2;
  -webkit-order: 1;
  -ms-flex-order: 1;
  order: 1;
  min-width: 44px;
}

.bar-button-menutoggle-wp ion-icon {
  padding: 0 6px;
  font-size: 2.4rem;
}

.bar-button-menutoggle-wp[end],
.bar-button-menutoggle-wp[right] {
  margin: 0 2px;
  -webkit-box-ordinal-group: 8;
  -webkit-order: 7;
  -ms-flex-order: 7;
  order: 7;
  min-width: 28px;
}

.bar-button-default-wp,
.bar-button-clear-wp-default,
.bar-button-wp-default {
  color: #000;
  background-color: transparent;
}

.bar-button-default-wp:hover:not(.disable-hover),
.bar-button-clear-wp-default:hover:not(.disable-hover),
.bar-button-wp-default:hover:not(.disable-hover) {
  color: #000;
}

.bar-button-clear-wp,
.bar-button-clear-wp-clear,
.bar-button-wp-clear {
  color: #000;
  background-color: transparent;
}

.bar-button-clear-wp:hover:not(.disable-hover),
.bar-button-clear-wp-clear:hover:not(.disable-hover),
.bar-button-wp-clear:hover:not(.disable-hover) {
  color: #000;
}

.toolbar-wp-primary .toolbar-background-wp {
  background: #488aff;
}

.toolbar-wp-primary .bar-button-clear-wp,
.toolbar-wp-primary .bar-button-default-wp,
.toolbar-wp-primary .bar-button-outline-wp,
.toolbar-wp-primary .toolbar-title-wp {
  color: #fff;
}

.toolbar-wp-primary .bar-button-outline-wp {
  border-color: #fff;
}

.toolbar-wp-primary .bar-button-primary-wp,
.toolbar-wp-primary .bar-button-clear-wp-primary,
.toolbar-wp-primary .bar-button-wp-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-primary-wp:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-clear-wp-primary:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-wp-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-wp-primary .bar-button-outline-wp-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-outline-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-primary .bar-button-solid-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-wp-primary .bar-button-solid-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-primary .bar-button-secondary-wp,
.toolbar-wp-primary .bar-button-clear-wp-secondary,
.toolbar-wp-primary .bar-button-wp-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-secondary-wp:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-clear-wp-secondary:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-wp-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-wp-primary .bar-button-outline-wp-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-outline-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-primary .bar-button-solid-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-wp-primary .bar-button-solid-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-primary .bar-button-danger-wp,
.toolbar-wp-primary .bar-button-clear-wp-danger,
.toolbar-wp-primary .bar-button-wp-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-danger-wp:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-clear-wp-danger:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-wp-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-wp-primary .bar-button-outline-wp-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-outline-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-primary .bar-button-solid-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-wp-primary .bar-button-solid-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-primary .bar-button-light-wp,
.toolbar-wp-primary .bar-button-clear-wp-light,
.toolbar-wp-primary .bar-button-wp-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-light-wp:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-clear-wp-light:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-wp-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-wp-primary .bar-button-outline-wp-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-outline-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-primary .bar-button-solid-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-wp-primary .bar-button-solid-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-primary .bar-button-dark-wp,
.toolbar-wp-primary .bar-button-clear-wp-dark,
.toolbar-wp-primary .bar-button-wp-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-dark-wp:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-clear-wp-dark:hover:not(.disable-hover),
.toolbar-wp-primary .bar-button-wp-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-wp-primary .bar-button-outline-wp-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-wp-primary .bar-button-outline-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.toolbar-wp-primary .bar-button-solid-wp-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-wp-primary .bar-button-solid-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-primary-wp,
.bar-button-clear-wp-primary,
.bar-button-wp-primary {
  color: #488aff;
  background-color: transparent;
}

.bar-button-primary-wp:hover:not(.disable-hover),
.bar-button-clear-wp-primary:hover:not(.disable-hover),
.bar-button-wp-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.bar-button-outline-wp-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.bar-button-outline-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.bar-button-solid-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.bar-button-solid-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-secondary .toolbar-background-wp {
  background: #32db64;
}

.toolbar-wp-secondary .bar-button-clear-wp,
.toolbar-wp-secondary .bar-button-default-wp,
.toolbar-wp-secondary .bar-button-outline-wp,
.toolbar-wp-secondary .toolbar-title-wp {
  color: #fff;
}

.toolbar-wp-secondary .bar-button-outline-wp {
  border-color: #fff;
}

.toolbar-wp-secondary .bar-button-primary-wp,
.toolbar-wp-secondary .bar-button-clear-wp-primary,
.toolbar-wp-secondary .bar-button-wp-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-primary-wp:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-clear-wp-primary:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-wp-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-wp-secondary .bar-button-outline-wp-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-outline-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-secondary .bar-button-solid-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-wp-secondary .bar-button-solid-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-secondary .bar-button-secondary-wp,
.toolbar-wp-secondary .bar-button-clear-wp-secondary,
.toolbar-wp-secondary .bar-button-wp-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-secondary-wp:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-clear-wp-secondary:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-wp-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-wp-secondary .bar-button-outline-wp-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-outline-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-secondary .bar-button-solid-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-wp-secondary .bar-button-solid-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-secondary .bar-button-danger-wp,
.toolbar-wp-secondary .bar-button-clear-wp-danger,
.toolbar-wp-secondary .bar-button-wp-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-danger-wp:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-clear-wp-danger:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-wp-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-wp-secondary .bar-button-outline-wp-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-outline-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-secondary .bar-button-solid-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-wp-secondary .bar-button-solid-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-secondary .bar-button-light-wp,
.toolbar-wp-secondary .bar-button-clear-wp-light,
.toolbar-wp-secondary .bar-button-wp-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-light-wp:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-clear-wp-light:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-wp-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-wp-secondary .bar-button-outline-wp-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-outline-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-secondary .bar-button-solid-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-wp-secondary .bar-button-solid-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-secondary .bar-button-dark-wp,
.toolbar-wp-secondary .bar-button-clear-wp-dark,
.toolbar-wp-secondary .bar-button-wp-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-dark-wp:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-clear-wp-dark:hover:not(.disable-hover),
.toolbar-wp-secondary .bar-button-wp-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-wp-secondary .bar-button-outline-wp-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-wp-secondary .bar-button-outline-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.toolbar-wp-secondary .bar-button-solid-wp-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-wp-secondary .bar-button-solid-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-secondary-wp,
.bar-button-clear-wp-secondary,
.bar-button-wp-secondary {
  color: #32db64;
  background-color: transparent;
}

.bar-button-secondary-wp:hover:not(.disable-hover),
.bar-button-clear-wp-secondary:hover:not(.disable-hover),
.bar-button-wp-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.bar-button-outline-wp-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.bar-button-outline-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.bar-button-solid-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.bar-button-solid-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-danger .toolbar-background-wp {
  background: #f53d3d;
}

.toolbar-wp-danger .bar-button-clear-wp,
.toolbar-wp-danger .bar-button-default-wp,
.toolbar-wp-danger .bar-button-outline-wp,
.toolbar-wp-danger .toolbar-title-wp {
  color: #fff;
}

.toolbar-wp-danger .bar-button-outline-wp {
  border-color: #fff;
}

.toolbar-wp-danger .bar-button-primary-wp,
.toolbar-wp-danger .bar-button-clear-wp-primary,
.toolbar-wp-danger .bar-button-wp-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-primary-wp:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-clear-wp-primary:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-wp-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-wp-danger .bar-button-outline-wp-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-outline-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-danger .bar-button-solid-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-wp-danger .bar-button-solid-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-danger .bar-button-secondary-wp,
.toolbar-wp-danger .bar-button-clear-wp-secondary,
.toolbar-wp-danger .bar-button-wp-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-secondary-wp:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-clear-wp-secondary:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-wp-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-wp-danger .bar-button-outline-wp-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-outline-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-danger .bar-button-solid-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-wp-danger .bar-button-solid-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-danger .bar-button-danger-wp,
.toolbar-wp-danger .bar-button-clear-wp-danger,
.toolbar-wp-danger .bar-button-wp-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-danger-wp:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-clear-wp-danger:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-wp-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-wp-danger .bar-button-outline-wp-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-outline-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-danger .bar-button-solid-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-wp-danger .bar-button-solid-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-danger .bar-button-light-wp,
.toolbar-wp-danger .bar-button-clear-wp-light,
.toolbar-wp-danger .bar-button-wp-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-light-wp:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-clear-wp-light:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-wp-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-wp-danger .bar-button-outline-wp-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-outline-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-danger .bar-button-solid-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-wp-danger .bar-button-solid-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-danger .bar-button-dark-wp,
.toolbar-wp-danger .bar-button-clear-wp-dark,
.toolbar-wp-danger .bar-button-wp-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-dark-wp:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-clear-wp-dark:hover:not(.disable-hover),
.toolbar-wp-danger .bar-button-wp-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-wp-danger .bar-button-outline-wp-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-wp-danger .bar-button-outline-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.toolbar-wp-danger .bar-button-solid-wp-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-wp-danger .bar-button-solid-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-danger-wp,
.bar-button-clear-wp-danger,
.bar-button-wp-danger {
  color: #f53d3d;
  background-color: transparent;
}

.bar-button-danger-wp:hover:not(.disable-hover),
.bar-button-clear-wp-danger:hover:not(.disable-hover),
.bar-button-wp-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.bar-button-outline-wp-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.bar-button-outline-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.bar-button-solid-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.bar-button-solid-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-light .toolbar-background-wp {
  background: #f4f4f4;
}

.toolbar-wp-light .bar-button-clear-wp,
.toolbar-wp-light .bar-button-default-wp,
.toolbar-wp-light .bar-button-outline-wp,
.toolbar-wp-light .toolbar-title-wp {
  color: #000;
}

.toolbar-wp-light .bar-button-outline-wp {
  border-color: #000;
}

.toolbar-wp-light .bar-button-primary-wp,
.toolbar-wp-light .bar-button-clear-wp-primary,
.toolbar-wp-light .bar-button-wp-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-primary-wp:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-clear-wp-primary:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-wp-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-wp-light .bar-button-outline-wp-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-outline-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-light .bar-button-solid-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-wp-light .bar-button-solid-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-light .bar-button-secondary-wp,
.toolbar-wp-light .bar-button-clear-wp-secondary,
.toolbar-wp-light .bar-button-wp-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-secondary-wp:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-clear-wp-secondary:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-wp-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-wp-light .bar-button-outline-wp-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-outline-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-light .bar-button-solid-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-wp-light .bar-button-solid-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-light .bar-button-danger-wp,
.toolbar-wp-light .bar-button-clear-wp-danger,
.toolbar-wp-light .bar-button-wp-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-danger-wp:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-clear-wp-danger:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-wp-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-wp-light .bar-button-outline-wp-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-outline-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-light .bar-button-solid-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-wp-light .bar-button-solid-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-light .bar-button-light-wp,
.toolbar-wp-light .bar-button-clear-wp-light,
.toolbar-wp-light .bar-button-wp-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-light-wp:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-clear-wp-light:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-wp-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-wp-light .bar-button-outline-wp-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-outline-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-light .bar-button-solid-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-wp-light .bar-button-solid-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-light .bar-button-dark-wp,
.toolbar-wp-light .bar-button-clear-wp-dark,
.toolbar-wp-light .bar-button-wp-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-dark-wp:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-clear-wp-dark:hover:not(.disable-hover),
.toolbar-wp-light .bar-button-wp-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-wp-light .bar-button-outline-wp-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-wp-light .bar-button-outline-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.toolbar-wp-light .bar-button-solid-wp-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-wp-light .bar-button-solid-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-light-wp,
.bar-button-clear-wp-light,
.bar-button-wp-light {
  color: #f4f4f4;
  background-color: transparent;
}

.bar-button-light-wp:hover:not(.disable-hover),
.bar-button-clear-wp-light:hover:not(.disable-hover),
.bar-button-wp-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.bar-button-outline-wp-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.bar-button-outline-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.bar-button-solid-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.bar-button-solid-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-dark .toolbar-background-wp {
  background: #222;
}

.toolbar-wp-dark .bar-button-clear-wp,
.toolbar-wp-dark .bar-button-default-wp,
.toolbar-wp-dark .bar-button-outline-wp,
.toolbar-wp-dark .toolbar-title-wp {
  color: #fff;
}

.toolbar-wp-dark .bar-button-outline-wp {
  border-color: #fff;
}

.toolbar-wp-dark .bar-button-primary-wp,
.toolbar-wp-dark .bar-button-clear-wp-primary,
.toolbar-wp-dark .bar-button-wp-primary {
  color: #488aff;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-primary-wp:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-clear-wp-primary:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-wp-primary:hover:not(.disable-hover) {
  color: #488aff;
}

.toolbar-wp-dark .bar-button-outline-wp-primary {
  border-color: #427feb;
  color: #427feb;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-outline-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-dark .bar-button-solid-wp-primary {
  color: #fff;
  background-color: #488aff;
}

.toolbar-wp-dark .bar-button-solid-wp-primary.activated {
  color: #fff;
  background-color: #427feb;
}

.toolbar-wp-dark .bar-button-secondary-wp,
.toolbar-wp-dark .bar-button-clear-wp-secondary,
.toolbar-wp-dark .bar-button-wp-secondary {
  color: #32db64;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-secondary-wp:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-clear-wp-secondary:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-wp-secondary:hover:not(.disable-hover) {
  color: #32db64;
}

.toolbar-wp-dark .bar-button-outline-wp-secondary {
  border-color: #2ec95c;
  color: #2ec95c;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-outline-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-dark .bar-button-solid-wp-secondary {
  color: #fff;
  background-color: #32db64;
}

.toolbar-wp-dark .bar-button-solid-wp-secondary.activated {
  color: #fff;
  background-color: #2ec95c;
}

.toolbar-wp-dark .bar-button-danger-wp,
.toolbar-wp-dark .bar-button-clear-wp-danger,
.toolbar-wp-dark .bar-button-wp-danger {
  color: #f53d3d;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-danger-wp:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-clear-wp-danger:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-wp-danger:hover:not(.disable-hover) {
  color: #f53d3d;
}

.toolbar-wp-dark .bar-button-outline-wp-danger {
  border-color: #e13838;
  color: #e13838;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-outline-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-dark .bar-button-solid-wp-danger {
  color: #fff;
  background-color: #f53d3d;
}

.toolbar-wp-dark .bar-button-solid-wp-danger.activated {
  color: #fff;
  background-color: #e13838;
}

.toolbar-wp-dark .bar-button-light-wp,
.toolbar-wp-dark .bar-button-clear-wp-light,
.toolbar-wp-dark .bar-button-wp-light {
  color: #f4f4f4;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-light-wp:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-clear-wp-light:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-wp-light:hover:not(.disable-hover) {
  color: #f4f4f4;
}

.toolbar-wp-dark .bar-button-outline-wp-light {
  border-color: #e0e0e0;
  color: #e0e0e0;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-outline-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-dark .bar-button-solid-wp-light {
  color: #000;
  background-color: #f4f4f4;
}

.toolbar-wp-dark .bar-button-solid-wp-light.activated {
  color: #000;
  background-color: #e0e0e0;
}

.toolbar-wp-dark .bar-button-dark-wp,
.toolbar-wp-dark .bar-button-clear-wp-dark,
.toolbar-wp-dark .bar-button-wp-dark {
  color: #222;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-dark-wp:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-clear-wp-dark:hover:not(.disable-hover),
.toolbar-wp-dark .bar-button-wp-dark:hover:not(.disable-hover) {
  color: #222;
}

.toolbar-wp-dark .bar-button-outline-wp-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.toolbar-wp-dark .bar-button-outline-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.toolbar-wp-dark .bar-button-solid-wp-dark {
  color: #fff;
  background-color: #222;
}

.toolbar-wp-dark .bar-button-solid-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-dark-wp,
.bar-button-clear-wp-dark,
.bar-button-wp-dark {
  color: #222;
  background-color: transparent;
}

.bar-button-dark-wp:hover:not(.disable-hover),
.bar-button-clear-wp-dark:hover:not(.disable-hover),
.bar-button-wp-dark:hover:not(.disable-hover) {
  color: #222;
}

.bar-button-outline-wp-dark {
  border-color: #343434;
  color: #343434;
  background-color: transparent;
}

.bar-button-outline-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-solid-wp-dark {
  color: #fff;
  background-color: #222;
}

.bar-button-solid-wp-dark.activated {
  color: #fff;
  background-color: #343434;
}

.bar-button-strong-wp {
  font-weight: bold;
}

.text-ios-primary {
  color: #488aff;
}

.text-ios-secondary {
  color: #32db64;
}

.text-ios-danger {
  color: #f53d3d;
}

.text-ios-light {
  color: #f4f4f4;
}

.text-ios-dark {
  color: #222;
}

.text-md-primary {
  color: #488aff;
}

.text-md-secondary {
  color: #32db64;
}

.text-md-danger {
  color: #f53d3d;
}

.text-md-light {
  color: #f4f4f4;
}

.text-md-dark {
  color: #222;
}

.text-wp-primary {
  color: #488aff;
}

.text-wp-secondary {
  color: #32db64;
}

.text-wp-danger {
  color: #f53d3d;
}

.text-wp-light {
  color: #f4f4f4;
}

.text-wp-dark {
  color: #222;
}

.virtual-loading {
  opacity: 0;
}

.virtual-scroll {
  position: relative;
  contain: content;
}

.virtual-scroll .virtual-position,
.virtual-scroll .virtual-position.item {
  left: 0;
  top: 0;
  position: absolute;
  -webkit-transition-duration: 0ms;
  transition-duration: 0ms;
  contain: content;
}

.virtual-scroll .virtual-last {
  display: none;
}

.ios ion-nav > .ion-page > .toolbar.statusbar-padding:first-child,
.ios ion-nav > .ion-page > ion-header > .toolbar.statusbar-padding:first-child,
.ios ion-tab > .ion-page > .toolbar.statusbar-padding:first-child,
.ios ion-tab > .ion-page > ion-header > .toolbar.statusbar-padding:first-child,
.ios ion-tabs > .ion-page.tab-subpage > ion-header > .toolbar.statusbar-padding:first-child,
.ios ion-menu > .menu-inner > .toolbar.statusbar-padding:first-child,
.ios ion-menu > .menu-inner > ion-header > .toolbar.statusbar-padding:first-child {
  padding-top: calc(20px + 4px);
  padding-top: calc(constant(safe-area-inset-top) + 4px);
  padding-top: calc(env(safe-area-inset-top) + 4px);
  min-height: calc(44px + 20px);
  min-height: calc(44px + constant(safe-area-inset-top));
  min-height: calc(44px + env(safe-area-inset-top));
}

.ios ion-nav > .ion-page > ion-content.statusbar-padding:first-child .scroll-content,
.ios ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.ios ion-tab > .ion-page > ion-content.statusbar-padding:first-child .scroll-content,
.ios ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.ios ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.ios ion-menu > .menu-inner > ion-content.statusbar-padding:first-child .scroll-content,
.ios ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child .scroll-content {
  padding-top: 20px;
  padding-top: constant(safe-area-inset-top);
  padding-top: env(safe-area-inset-top);
}

.ios ion-nav > .ion-page > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.ios ion-nav > .ion-page > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.ios ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.ios ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.ios ion-tab > .ion-page > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.ios ion-tab > .ion-page > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.ios ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.ios ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.ios ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.ios ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.ios ion-menu > .menu-inner > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.ios ion-menu > .menu-inner > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.ios ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.ios ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content {
  padding-top: calc(16px + 20px);
  padding-top: constant(safe-area-inset-top);
  padding-top: env(safe-area-inset-top);
}

.ios ion-nav > .ion-page > .toolbar.statusbar-padding:first-child ion-segment,
.ios ion-nav > .ion-page > .toolbar.statusbar-padding:first-child ion-title,
.ios ion-nav > .ion-page > ion-header > .toolbar.statusbar-padding:first-child ion-segment,
.ios ion-nav > .ion-page > ion-header > .toolbar.statusbar-padding:first-child ion-title,
.ios ion-tab > .ion-page > .toolbar.statusbar-padding:first-child ion-segment,
.ios ion-tab > .ion-page > .toolbar.statusbar-padding:first-child ion-title,
.ios ion-tab > .ion-page > ion-header > .toolbar.statusbar-padding:first-child ion-segment,
.ios ion-tab > .ion-page > ion-header > .toolbar.statusbar-padding:first-child ion-title,
.ios ion-tabs > .ion-page.tab-subpage > ion-header > .toolbar.statusbar-padding:first-child ion-segment,
.ios ion-tabs > .ion-page.tab-subpage > ion-header > .toolbar.statusbar-padding:first-child ion-title,
.ios ion-menu > .menu-inner > .toolbar.statusbar-padding:first-child ion-segment,
.ios ion-menu > .menu-inner > .toolbar.statusbar-padding:first-child ion-title,
.ios ion-menu > .menu-inner > ion-header > .toolbar.statusbar-padding:first-child ion-segment,
.ios ion-menu > .menu-inner > ion-header > .toolbar.statusbar-padding:first-child ion-title {
  padding-top: 20px;
  padding-top: constant(safe-area-inset-top);
  padding-top: env(safe-area-inset-top);
  height: calc(44px + 20px);
  height: calc(44px + constant(safe-area-inset-top));
  height: calc(44px + env(safe-area-inset-top));
  min-height: calc(44px + 20px);
  min-height: calc(44px + constant(safe-area-inset-top));
  min-height: calc(44px + env(safe-area-inset-top));
}

@media only screen and (max-width: 767px) {
  .ios .modal-wrapper > .ion-page > ion-header > .toolbar.statusbar-padding:first-child {
    padding-top: calc(20px + 4px);
    padding-top: calc(constant(safe-area-inset-top) + 4px);
    padding-top: calc(env(safe-area-inset-top) + 4px);
    min-height: calc(44px + 20px);
    min-height: calc(44px + constant(safe-area-inset-top));
    min-height: calc(44px + env(safe-area-inset-top));
  }
  .ios .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content {
    padding-top: 20px;
    padding-top: constant(safe-area-inset-top);
    padding-top: env(safe-area-inset-top);
  }
  .ios .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
  .ios .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content {
    padding-top: calc(16px + 20px);
    padding-top: constant(safe-area-inset-top);
    padding-top: env(safe-area-inset-top);
  }
  .ios .modal-wrapper > .ion-page > ion-header > .toolbar.statusbar-padding:first-child ion-segment,
  .ios .modal-wrapper > .ion-page > ion-header > .toolbar.statusbar-padding:first-child ion-title {
    padding-top: 20px;
    padding-top: constant(safe-area-inset-top);
    padding-top: env(safe-area-inset-top);
    height: calc(44px + 20px);
    height: calc(44px + constant(safe-area-inset-top));
    height: calc(44px + env(safe-area-inset-top));
    min-height: calc(44px + 20px);
    min-height: calc(44px + constant(safe-area-inset-top));
    min-height: calc(44px + env(safe-area-inset-top));
  }
}

.ios .tabs:not(.tabs-ios[tabsPlacement=top]) .tabbar {
  padding-bottom: constant(safe-area-inset-bottom);
  padding-bottom: env(safe-area-inset-bottom);
}

.ios ion-footer .toolbar:last-child {
  padding-bottom: calc(constant(safe-area-inset-bottom) + 4px);
  padding-bottom: calc(env(safe-area-inset-bottom) + 4px);
  min-height: calc(44px + constant(safe-area-inset-bottom));
  min-height: calc(44px + env(safe-area-inset-bottom));
}

.md ion-nav > .ion-page > .toolbar.statusbar-padding:first-child,
.md ion-nav > .ion-page > ion-header > .toolbar.statusbar-padding:first-child,
.md ion-tab > .ion-page > .toolbar.statusbar-padding:first-child,
.md ion-tab > .ion-page > ion-header > .toolbar.statusbar-padding:first-child,
.md ion-tabs > .ion-page.tab-subpage > ion-header > .toolbar.statusbar-padding:first-child,
.md ion-menu > .menu-inner > .toolbar.statusbar-padding:first-child,
.md ion-menu > .menu-inner > ion-header > .toolbar.statusbar-padding:first-child {
  padding-top: calc(20px + 4px);
  padding-top: calc(constant(safe-area-inset-top) + 4px);
  padding-top: calc(env(safe-area-inset-top) + 4px);
  min-height: calc(56px + 20px);
  min-height: calc(56px + constant(safe-area-inset-top));
  min-height: calc(56px + env(safe-area-inset-top));
}

.md ion-nav > .ion-page > ion-content.statusbar-padding:first-child .scroll-content,
.md ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.md ion-tab > .ion-page > ion-content.statusbar-padding:first-child .scroll-content,
.md ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.md ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.md ion-menu > .menu-inner > ion-content.statusbar-padding:first-child .scroll-content,
.md ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child .scroll-content {
  padding-top: 20px;
  padding-top: constant(safe-area-inset-top);
  padding-top: env(safe-area-inset-top);
}

.md ion-nav > .ion-page > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.md ion-nav > .ion-page > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.md ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.md ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.md ion-tab > .ion-page > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.md ion-tab > .ion-page > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.md ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.md ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.md ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.md ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.md ion-menu > .menu-inner > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.md ion-menu > .menu-inner > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.md ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.md ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content {
  padding-top: calc(16px + 20px);
  padding-top: constant(safe-area-inset-top);
  padding-top: env(safe-area-inset-top);
}

@media only screen and (max-width: 767px) {
  .md .modal-wrapper > .ion-page > ion-header > .toolbar.statusbar-padding:first-child {
    padding-top: calc(20px + 4px);
    padding-top: calc(constant(safe-area-inset-top) + 4px);
    padding-top: calc(env(safe-area-inset-top) + 4px);
    min-height: calc(56px + 20px);
    min-height: calc(56px + constant(safe-area-inset-top));
    min-height: calc(56px + env(safe-area-inset-top));
  }
  .md .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content {
    padding-top: 20px;
    padding-top: constant(safe-area-inset-top);
    padding-top: env(safe-area-inset-top);
  }
  .md .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
  .md .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content {
    padding-top: calc(16px + 20px);
    padding-top: constant(safe-area-inset-top);
    padding-top: env(safe-area-inset-top);
  }
}

.md .tabs:not(.tabs-ios[tabsPlacement=top]) .tabbar {
  padding-bottom: constant(safe-area-inset-bottom);
  padding-bottom: env(safe-area-inset-bottom);
}

.md ion-footer .toolbar:last-child {
  padding-bottom: calc(constant(safe-area-inset-bottom) + 4px);
  padding-bottom: calc(env(safe-area-inset-bottom) + 4px);
  min-height: calc(56px + constant(safe-area-inset-bottom));
  min-height: calc(56px + env(safe-area-inset-bottom));
}

.wp ion-nav > .ion-page > .toolbar.statusbar-padding:first-child,
.wp ion-nav > .ion-page > ion-header > .toolbar.statusbar-padding:first-child,
.wp ion-tab > .ion-page > .toolbar.statusbar-padding:first-child,
.wp ion-tab > .ion-page > ion-header > .toolbar.statusbar-padding:first-child,
.wp ion-tabs > .ion-page.tab-subpage > ion-header > .toolbar.statusbar-padding:first-child,
.wp ion-menu > .menu-inner > .toolbar.statusbar-padding:first-child,
.wp ion-menu > .menu-inner > ion-header > .toolbar.statusbar-padding:first-child {
  padding-top: calc(20px + 4px);
  padding-top: calc(constant(safe-area-inset-top) + 4px);
  padding-top: calc(env(safe-area-inset-top) + 4px);
  min-height: calc(46px + 20px);
  min-height: calc(46px + constant(safe-area-inset-top));
  min-height: calc(46px + env(safe-area-inset-top));
}

.wp ion-nav > .ion-page > ion-content.statusbar-padding:first-child .scroll-content,
.wp ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.wp ion-tab > .ion-page > ion-content.statusbar-padding:first-child .scroll-content,
.wp ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.wp ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child .scroll-content,
.wp ion-menu > .menu-inner > ion-content.statusbar-padding:first-child .scroll-content,
.wp ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child .scroll-content {
  padding-top: 20px;
  padding-top: constant(safe-area-inset-top);
  padding-top: env(safe-area-inset-top);
}

.wp ion-nav > .ion-page > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.wp ion-nav > .ion-page > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.wp ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.wp ion-nav > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.wp ion-tab > .ion-page > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.wp ion-tab > .ion-page > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.wp ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.wp ion-tab > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.wp ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.wp ion-tabs > .ion-page.tab-subpage > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.wp ion-menu > .menu-inner > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.wp ion-menu > .menu-inner > ion-content.statusbar-padding:first-child[padding-top] .scroll-content,
.wp ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
.wp ion-menu > .menu-inner > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content {
  padding-top: calc(16px + 20px);
  padding-top: constant(safe-area-inset-top);
  padding-top: env(safe-area-inset-top);
}

@media only screen and (max-width: 767px) {
  .wp .modal-wrapper > .ion-page > ion-header > .toolbar.statusbar-padding:first-child {
    padding-top: calc(20px + 4px);
    padding-top: calc(constant(safe-area-inset-top) + 4px);
    padding-top: calc(env(safe-area-inset-top) + 4px);
    min-height: calc(46px + 20px);
    min-height: calc(46px + constant(safe-area-inset-top));
    min-height: calc(46px + env(safe-area-inset-top));
  }
  .wp .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child .scroll-content {
    padding-top: 20px;
    padding-top: constant(safe-area-inset-top);
    padding-top: env(safe-area-inset-top);
  }
  .wp .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding] .scroll-content,
  .wp .modal-wrapper > .ion-page > ion-header > ion-content.statusbar-padding:first-child[padding-top] .scroll-content {
    padding-top: calc(16px + 20px);
    padding-top: constant(safe-area-inset-top);
    padding-top: env(safe-area-inset-top);
  }
}

.wp .tabs:not(.tabs-ios[tabsPlacement=top]) .tabbar {
  padding-bottom: constant(safe-area-inset-bottom);
  padding-bottom: env(safe-area-inset-bottom);
}

.wp ion-footer .toolbar:last-child {
  padding-bottom: calc(constant(safe-area-inset-bottom) + 4px);
  padding-bottom: calc(env(safe-area-inset-bottom) + 4px);
  min-height: calc(46px + constant(safe-area-inset-bottom));
  min-height: calc(46px + env(safe-area-inset-bottom));
}
